(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.4' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    354663,      13953]
NotebookOptionsPosition[    349897,      13809]
NotebookOutlinePosition[    350238,      13824]
CellTagsIndexPosition[    350195,      13821]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Show Me the Money", "Title"],

Cell["Computation with Perturbation Methods", "Subtitle"],

Cell["\<\
Log utility and quadratic adjustment are assumed. Endogenous state variables \
are d and s, exogenous state is x. x is Normal with unit variance.

The underlying theory for the computations can be found in Judd, \
Schmitt-Grohe and Uribe, and especially Fernandez-Villaverde. Some of the \
code is based on Jesus' code for his computational-method comparison paper. 
\
\>", "Text",
 CellChangeTimes->{{3.689789156412642*^9, 3.689789157321733*^9}}],

Cell[BoxData[{
 RowBox[{"<<", "Statistics`NormalDistribution`"}], "\[IndentingNewLine]", 
 RowBox[{"<<", 
  "Statistics`MultiDescriptiveStatistics`"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Graphics`MultipleListPlot`"}], "\[IndentingNewLine]", 
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell1"}], "]"}]}], "Input"],

Cell[CellGroupData[{

Cell["Set Parameters", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"param", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Psi]", "\[Rule]", "0.24"}], ",", 
     RowBox[{"\[Alpha]", "\[Rule]", "0.33"}], ",", 
     RowBox[{"\[Delta]", "\[Rule]", "0.02"}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", "0.99"}], ",", 
     RowBox[{"ad1", "\[Rule]", "10"}], ",", 
     RowBox[{"ad2", "\[Rule]", 
      RowBox[{"-", "0.00465989"}]}], ",", 
     RowBox[{"ad1k", "\[Rule]", "1"}], ",", 
     RowBox[{"ad2k", "\[Rule]", 
      RowBox[{"-", "0.12077144541545722"}]}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", " ", "0.14"}], ",", 
     RowBox[{"\[Rho]", "\[Rule]", "0.5"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmean", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xconst", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Rho]"}], ")"}], " ", "xmean"}], "/.", "param"}], "//",
     "Chop"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"orderexpansion", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"myvariables", "=", 
   RowBox[{"{", 
    RowBox[{"s", ",", "d", ",", "k", ",", "x", ",", "\[Sigma]"}], "}"}]}], 
  ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Model Equations", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cond1a", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"1", "-", "\[Psi]"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "l"}], ")"}], "w"}]], "-", 
    RowBox[{"\[Beta]", 
     RowBox[{"(", 
      FractionBox["\[Psi]", 
       RowBox[{"c2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "x"}], ")"}], " ", "p2"}]], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond2a", "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"1", "-", "\[Psi]"}], 
      RowBox[{"1", "-", "l"}]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "w"], "+", 
       RowBox[{"2", "  ", "ad1", " ", 
        RowBox[{"(", 
         RowBox[{"ad2", "+", "i"}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"\[Beta]", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"1", "-", "\[Psi]"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "x"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"1", "-", "l2"}], ")"}]}]], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"1", "+", "r2"}], "w2"], "+", 
         RowBox[{"2", " ", "ad1", " ", 
          RowBox[{"(", 
           RowBox[{"ad2", "+", "i2"}], ")"}]}]}], ")"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond3a", "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"1", "-", "\[Psi]"}], 
      RowBox[{"1", "-", "l"}]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox["p", "w"], "+", 
       RowBox[{"2", "  ", "ad1k", " ", 
        RowBox[{"(", 
         RowBox[{"ad2k", "+", "z"}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"\[Beta]", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"1", "-", "\[Psi]"}], 
        RowBox[{"(", 
         RowBox[{"1", "-", "l2"}], ")"}]], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", "\[Delta]"}], ")"}], "p2"}], "+", "rk2"}], 
          "w2"], "+", 
         RowBox[{"2", " ", "ad1k", " ", 
          RowBox[{"(", 
           RowBox[{"ad2k", "+", "z2"}], ")"}]}]}], ")"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond4a", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "x"}], ")"}], " ", "d2"}], "-", 
    RowBox[{"(", 
     RowBox[{"d", "+", 
      RowBox[{"r", " ", "s"}], "+", 
      RowBox[{"rk", " ", "k"}], " ", "+", 
      RowBox[{"\[Lambda]", " ", "pi"}], " ", "+", 
      RowBox[{"w", " ", "la"}], " ", "-", "i", " ", "-", 
      RowBox[{"p", " ", 
       RowBox[{"(", 
        RowBox[{"c", "+", "z"}], ")"}]}]}], ")"}]}]}], " ", 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond5a", "=", 
   RowBox[{"i", "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "x"}], ")"}], " ", "s2"}], "-", "s"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond6a", "=", 
   RowBox[{"z", "-", 
    RowBox[{"(", 
     RowBox[{"k2", "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Delta]"}], ")"}], "k"}]}], ")"}]}]}], 
  ";"}]}], "Input"],

Cell["\<\
The replacement rules arising from the remaining model equations (this should \
be documented)\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rep0", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"l", "\[Rule]", " ", 
      RowBox[{"la", "+", "lb"}]}], ",", 
     RowBox[{"l2", "\[Rule]", " ", 
      RowBox[{"la2", "+", "lb2"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep0b", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"lb", "\[Rule]", 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"ad1", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ad2", "+", "i"}], ")"}], "^", "2"}]}], "+", 
        RowBox[{"ad1k", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ad2k", "+", "z"}], ")"}], "^", "2"}]}]}], ")"}]}], ",", 
     RowBox[{"lb2", "\[Rule]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"ad1", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ad2", "+", "i2"}], ")"}], "^", "2"}]}], "+", 
        RowBox[{"ad1k", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ad2k", "+", "z2"}], ")"}], "^", "2"}]}]}], ")"}]}]}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep1", "=", 
   RowBox[{"{", 
    RowBox[{"pi", "\[Rule]", " ", 
     RowBox[{"1", "-", "d", "-", "s"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep1b", "=", 
   RowBox[{"{", 
    RowBox[{"pi2", "\[Rule]", " ", 
     RowBox[{"1", "-", "d2", "-", "s2"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep3", "=", 
   RowBox[{"{", 
    RowBox[{"r", "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "  ", "\[Alpha]", "  ", 
         SuperscriptBox["k", 
          RowBox[{"\[Alpha]", "-", "1"}]], "  ", 
         SuperscriptBox["la", 
          RowBox[{"1", "-", "\[Alpha]"}]]}], ")"}], "/", "rk"}], "-", "1"}]}],
     "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep3b", "=", 
   RowBox[{"{", 
    RowBox[{"r2", "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p2", " ", "\[Alpha]", " ", 
         SuperscriptBox["k2", 
          RowBox[{"\[Alpha]", "-", "1"}]], " ", 
         SuperscriptBox["la2", 
          RowBox[{"1", "-", "\[Alpha]"}]]}], ")"}], "/", "rk2"}], "-", 
      "1"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep4", "=", 
   RowBox[{"{", 
    RowBox[{"rk", "\[Rule]", 
     FractionBox[
      RowBox[{"\[Alpha]", " ", "w", " ", "la"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", "k"}]]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep4b", "=", 
   RowBox[{"{", 
    RowBox[{"rk2", "\[Rule]", 
     FractionBox[
      RowBox[{"\[Alpha]", " ", "w2", " ", "la2"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", "k2"}]]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep5", "=", 
   RowBox[{"{", 
    RowBox[{"w", "\[Rule]", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Alpha]"}], ")"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "x", "-", "d"}], ")"}], "/", "la"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep5b", "=", 
   RowBox[{"{", 
    RowBox[{"w2", "\[Rule]", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Alpha]"}], ")"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "x2", "-", "d2"}], ")"}], "/", "la2"}]}]}], "}"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep6", "=", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", 
     RowBox[{"d", "/", "c"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep6b", "=", 
   RowBox[{"{", 
    RowBox[{"p2", "\[Rule]", 
     RowBox[{"d2", "/", "c2"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"replast", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"la", "\[Rule]", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"c", "+", "z"}], 
         SuperscriptBox["k", "\[Alpha]"]], ")"}], 
       FractionBox["1", 
        RowBox[{"1", "-", "\[Alpha]"}]]]}], ",", 
     RowBox[{"la2", "\[Rule]", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"c2", "+", "z2"}], 
         SuperscriptBox["k2", "\[Alpha]"]], ")"}], 
       FractionBox["1", 
        RowBox[{"1", "-", "\[Alpha]"}]]]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"repA", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"rep1", ",", "rep1b", ",", "rep3", ",", "rep3b"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"repB", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"rep4", ",", "rep4b"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"repC", "=", 
   RowBox[{"Join", "[", 
    RowBox[{"rep5", ",", "rep5b", ",", "rep6", ",", "rep6b"}], "]"}]}], 
  ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cond1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"cond1a", "/.", "rep0"}], "/.", "rep0b"}], "/.", "repA"}], "/.",
       "repB"}], "/.", "repC"}], "/.", "replast"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"cond2a", "/.", "rep0"}], "/.", "rep0b"}], "/.", "repA"}], "/.",
       "repB"}], "/.", "repC"}], "/.", "replast"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond3", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"cond3a", "/.", "rep0"}], "/.", "rep0b"}], "/.", "repA"}], "/.",
       "repB"}], "/.", "repC"}], "/.", "replast"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond4", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"cond4a", "/.", "rep0"}], "/.", "rep0b"}], "/.", "repA"}], "/.",
       "repB"}], "/.", "repC"}], "/.", "replast"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond5", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"cond5a", "/.", "rep0"}], "/.", "rep0b"}], "/.", "repA"}], "/.",
       "repB"}], "/.", "repC"}], "/.", "replast"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cond6", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"cond6a", "/.", "rep0"}], "/.", "rep0b"}], "/.", "repA"}], "/.",
        "repB"}], "/.", "repC"}], "/.", "replast"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"F", "=", 
   RowBox[{"{", 
    RowBox[{
    "cond1", ",", "cond2", ",", "cond3", ",", "cond4", ",", "cond5", ",", 
     "cond6"}], "}"}]}], ";"}]}], "Input"],

Cell["\<\
Now replace the decision variables by the functions that we are going to \
compute. Notation is moving towards Schmitt-Grohe and Uribe. g are the \
policies for jumps, h are the policies for states.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"c", "=", 
   RowBox[{"g1", "[", 
    RowBox[{"s", ",", "d", ",", "k", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"i", "=", 
   RowBox[{"g2", "[", 
    RowBox[{"s", ",", "d", ",", "k", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"z", "=", 
   RowBox[{"g3", "[", 
    RowBox[{"s", ",", "d", ",", "k", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"s2", "=", 
   RowBox[{"h1", "[", 
    RowBox[{"s", ",", "d", ",", "k", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d2", "=", 
   RowBox[{"h2", "[", 
    RowBox[{"s", ",", "d", ",", "k", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"k2", "=", 
   RowBox[{"h3", "[", 
    RowBox[{"s", ",", "d", ",", "k", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2", "=", 
   RowBox[{"g1", "[", 
    RowBox[{"s2", ",", "d2", ",", "k2", ",", "x2", ",", "\[Sigma]"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"i2", "=", 
   RowBox[{"g2", "[", 
    RowBox[{"s2", ",", "d2", ",", "k2", ",", "x2", ",", "\[Sigma]"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"z2", "=", 
   RowBox[{"g3", "[", 
    RowBox[{"s2", ",", "d2", ",", "k2", ",", "x2", ",", "\[Sigma]"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x2", "=", 
   RowBox[{"xconst", "+", 
    RowBox[{"\[Rho]", " ", "*", "x"}], "+", 
    RowBox[{"\[Sigma]", "*", "\[Epsilon]"}]}]}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The  Non-Stochastic Steady State", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"derivrule", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"d", ":", 
     RowBox[{
      RowBox[{
       RowBox[{"Derivative", "[", "__", "]"}], "[", "__", "]"}], "[", "__", 
      "]"}]}], "\[RuleDelayed]", "  ", 
    RowBox[{"d", "[", 
     RowBox[{"[", "0", "]"}], "]"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"constant1", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"constant2", "=", "0"}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"d", ":", 
    RowBox[{
     SuperscriptBox["__", 
      TagBox[
       RowBox[{"(", "__", ")"}],
       Derivative],
      MultilineFunction->None], "[", "__", "]"}]}], "\[RuleDelayed]", 
   RowBox[{"d", "\[LeftDoubleBracket]", "0", "\[RightDoubleBracket]"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"param", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Psi]", "\[Rule]", "0.24"}], ",", 
      RowBox[{"\[Alpha]", "\[Rule]", "0.33"}], ",", 
      RowBox[{"\[Delta]", "\[Rule]", "0.015"}], ",", 
      RowBox[{"\[Beta]", "\[Rule]", "0.99"}], ",", 
      RowBox[{"ad1", "\[Rule]", "10"}], ",", 
      RowBox[{"ad2", "\[Rule]", "constant1"}], ",", 
      RowBox[{"ad1k", "\[Rule]", "1"}], ",", 
      RowBox[{"ad2k", "\[Rule]", 
       RowBox[{"constant2", "-", ".001"}]}], ",", 
      RowBox[{"\[Lambda]", "\[Rule]", " ", "0.14"}], ",", 
      RowBox[{"\[Rho]", "\[Rule]", "0.5"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssfunrule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"h1", "[", "__", "]"}], "\[Rule]", " ", "s"}], ",", 
     RowBox[{
      RowBox[{"h2", "[", "__", "]"}], "\[Rule]", " ", "d"}], ",", 
     RowBox[{
      RowBox[{"h3", "[", "__", "]"}], "\[Rule]", " ", "k"}], ",", " ", 
     RowBox[{
      RowBox[{"g1", "[", "__", "]"}], "\[Rule]", " ", "cbar"}], ",", 
     RowBox[{
      RowBox[{"g2", "[", "__", "]"}], "\[Rule]", "ibar"}], ",", 
     RowBox[{
      RowBox[{"g3", "[", "__", "]"}], "\[Rule]", "zbar"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssvalrule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s", "\[Rule]", "sbar"}], ",", 
     RowBox[{"d", "\[Rule]", "dbar"}], ",", 
     RowBox[{"k", "\[Rule]", "kbar"}], ",", 
     RowBox[{"x", "\[Rule]", "xmean"}], ",", 
     RowBox[{"ibar", "\[Rule]", 
      RowBox[{"xmean", " ", "sbar"}]}], ",", 
     RowBox[{"zbar", "\[Rule]", 
      RowBox[{"\[Delta]", " ", "kbar"}]}], ",", 
     RowBox[{"\[Sigma]", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sscond", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"F", "[", 
       RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "4"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"input", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"sscond", "/.", "ssfunrule"}], "/.", "ssvalrule"}], "/.", 
    "param"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssresult", "=", 
   RowBox[{"FindRoot", "[", 
    RowBox[{"input", ",", 
     RowBox[{"{", 
      RowBox[{"sbar", ",", "0.4", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"dbar", ",", "0.5", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"kbar", ",", "7", ",", "0", ",", "50"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"cbar", ",", "0.5", ",", "0", ",", "1"}], "}"}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"varrule", "=", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"s", "\[Rule]", "sbar"}], "/.", "ssresult"}], ",", 
       RowBox[{
        RowBox[{"d", "\[Rule]", "dbar"}], "/.", "ssresult"}], ",", 
       RowBox[{
        RowBox[{"k", "\[Rule]", "kbar"}], "/.", "ssresult"}], ",", 
       RowBox[{"x", "\[Rule]", "xmean"}], ",", 
       RowBox[{"\[Sigma]", "\[Rule]", "0"}]}], "}"}], "]"}], "//", "Chop"}]}],
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"unirule", "=", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"ssfunrule", "/.", "varrule"}], "/.", "ssvalrule"}], "/.", 
         "ssresult"}], "/.", "param"}], ",", "varrule", ",", "derivrule"}], 
      "]"}], "]"}], "//", "Chop"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"constant1", "=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"g2", "[", "something", "]"}]}], "/.", 
   "unirule"}]}], "\[IndentingNewLine]", 
 RowBox[{"constant2", "=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"g3", "[", "something", "]"}]}], "/.", 
   "unirule"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Interest Rate\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"intss", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"100", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1.01", "+", "\[Lambda]"}], ")"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "sbar", "-", "dbar"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"1.01", "-", "sbar", "-", "dbar"}], ")"}]}]}], ")"}], "-", 
       "1"}], ")"}]}], "/.", "ssresult"}], "/.", 
   "param"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Price Level\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"pss", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"dbar", "/", "cbar"}], "/.", "unirule"}], "/.", 
   "ssresult"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<La\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"lass", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"cbar", "+", 
         RowBox[{"g3", "[", "something", "]"}]}], 
        SuperscriptBox["kbar", "\[Alpha]"]], ")"}], 
      FractionBox["1", 
       RowBox[{"1", "-", "\[Alpha]"}]]], "/.", "unirule"}], "/.", 
    "ssresult"}], "/.", "param"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Output\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"yss", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["lass", 
       RowBox[{"1", "-", "\[Alpha]"}]], " ", 
      SuperscriptBox["kbar", "\[Alpha]"]}], "/.", "unirule"}], "/.", 
    "ssresult"}], "/.", "param"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Wage\>\"", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"wss", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Alpha]"}], ")"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "x", "-", "dbar"}], ")"}], "/", "lass"}]}], "/.", 
     "unirule"}], "/.", "ssresult"}], "/.", 
   "param"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Return on Capital\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"rkss", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"\[Alpha]", " ", "wss", " ", "lass"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", "kbar"}]], "/.", 
     "unirule"}], "/.", "ssresult"}], "/.", 
   "param"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Net return\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rkss", "/", "pss"}], "+", "1", "-", "\[Delta]"}], "/.", 
  "param"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Print", "[", "\"\<Different way of writing the interest rate\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"intss2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"pss", " ", "\[Alpha]", "  ", 
       SuperscriptBox["kbar", 
        RowBox[{"\[Alpha]", "-", "1"}]], " ", 
       RowBox[{
        SuperscriptBox["lass", 
         RowBox[{"1", "-", "\[Alpha]"}]], "/", "rkss"}]}], "-", "1"}], "/.", 
     "unirule"}], "/.", "ssresult"}], "/.", 
   "param"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Condition 2\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"1", "-", "\[Psi]"}], 
     RowBox[{"1", "-", "lass"}]], "-", 
    RowBox[{"\[Beta]", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"1", "-", "\[Psi]"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "x"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"1", "-", "lass"}], ")"}]}]], 
       RowBox[{"(", 
        RowBox[{"1", "+", "intss2"}], ")"}]}], ")"}]}]}], "/.", "unirule"}], "/.",
   "param"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Loan Condition\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"wss", " ", "lass"}], "+", 
     RowBox[{"rkss", " ", "kbar"}], "-", "1", "-", "x", "+", "dbar"}], "/.", 
    "unirule"}], "/.", "ssresult"}], "/.", "param"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Goods Market\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cbar", "+", "z", "-", " ", 
     RowBox[{
      SuperscriptBox["kbar", "\[Alpha]"], " ", 
      SuperscriptBox["lass", 
       RowBox[{"1", "-", "\[Alpha]"}]]}]}], "/.", "unirule"}], "/.", 
   "ssresult"}], "/.", "param"}], "\[IndentingNewLine]", 
 RowBox[{""}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"sbar", "\[Rule]", "0.4656242925998698`"}], ",", 
   RowBox[{"dbar", "\[Rule]", "0.45577764054246195`"}], ",", 
   RowBox[{"kbar", "\[Rule]", "9.183696660996782`"}], ",", 
   RowBox[{"cbar", "\[Rule]", "0.5726526799357032`"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"s", "\[Rule]", "0.4656242925998698`"}], ",", 
   RowBox[{"d", "\[Rule]", "0.45577764054246195`"}], ",", 
   RowBox[{"k", "\[Rule]", "9.183696660996782`"}], ",", 
   RowBox[{"x", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"\[Sigma]", "\[Rule]", "0"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"h1", "[", "__", "]"}], "\[Rule]", "0.4656242925998698`"}], ",", 
   RowBox[{
    RowBox[{"h2", "[", "__", "]"}], "\[Rule]", "0.45577764054246195`"}], ",", 
   RowBox[{
    RowBox[{"h3", "[", "__", "]"}], "\[Rule]", "9.183696660996782`"}], ",", 
   RowBox[{
    RowBox[{"g1", "[", "__", "]"}], "\[Rule]", "0.5726526799357032`"}], ",", 
   RowBox[{
    RowBox[{"g2", "[", "__", "]"}], "\[Rule]", "0.004656242925998698`"}], ",", 
   RowBox[{
    RowBox[{"g3", "[", "__", "]"}], "\[Rule]", "0.13775544991495173`"}], ",", 
   RowBox[{"s", "\[Rule]", "0.4656242925998698`"}], ",", 
   RowBox[{"d", "\[Rule]", "0.45577764054246195`"}], ",", 
   RowBox[{"k", "\[Rule]", "9.183696660996782`"}], ",", 
   RowBox[{"x", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"\[Sigma]", "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"d", ":", 
     RowBox[{
      SuperscriptBox["__", 
       TagBox[
        RowBox[{"(", "__", ")"}],
        Derivative],
       MultilineFunction->None], "[", "__", "]"}]}], "\[RuleDelayed]", 
    RowBox[{"d", "\[LeftDoubleBracket]", "0", "\[RightDoubleBracket]"}]}]}], 
  "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"-", "0.004656242925998698`"}]], "Output"],

Cell[BoxData[
 RowBox[{"-", "0.13775544991495173`"}]], "Output"],

Cell[BoxData["\<\"Interest Rate\"\>"], "Print"],

Cell[BoxData["2.020032820270634`"], "Output"],

Cell[BoxData["\<\"Price Level\"\>"], "Print"],

Cell[BoxData["0.795905889401646`"], "Output"],

Cell[BoxData["\<\"La\"\>"], "Print"],

Cell[BoxData["0.20139466733461178`"], "Output"],

Cell[BoxData["\<\"Output\"\>"], "Print"],

Cell[BoxData["0.7104081298506549`"], "Output"],

Cell[BoxData["\<\"Wage\"\>"], "Print"],

Cell[BoxData["1.84378755282332`"], "Output"],

Cell[BoxData["\<\"Return on Capital\"\>"], "Print"],

Cell[BoxData["0.019915006491638264`"], "Output"],

Cell[BoxData["\<\"Net return\"\>"], "Print"],

Cell[BoxData["1.0100218106899677`"], "Output"],

Cell[BoxData["\<\"Different way of writing the interest rate\"\>"], "Print"],

Cell[BoxData["0.02020065552816308`"], "Output"],

Cell[BoxData["\<\"Condition 2\"\>"], "Print"],

Cell[BoxData["1.2729873242189882`*^-6"], "Output"],

Cell[BoxData["\<\"Loan Condition\"\>"], "Print"],

Cell[BoxData["2.7755575615628914`*^-17"], "Output"],

Cell[BoxData["\<\"Goods Market\"\>"], "Print"],

Cell[BoxData["0.`"], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Taylor Expansion", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"epsrule", "=", 
  RowBox[{"Append", "[", 
   RowBox[{
    RowBox[{"Reverse", "@", 
     RowBox[{"Thread", "[", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{"Range", "[", 
         RowBox[{"2", ",", "orderexpansion", ",", "2"}], "]"}]], "->", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"ExpectedValue", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox["#", "j"], "&"}], ",", 
           RowBox[{"NormalDistribution", "[", 
            RowBox[{"0", ",", "1"}], "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "2", ",", "orderexpansion", ",", "2"}], "}"}]}], 
        "]"}]}], "]"}]}], ",", 
    RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[Epsilon]", "\[Rule]", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Notice that all partial derivatives are taken below, even though some \
cross-derivatives are equal and could be left out. This slows computation, \
but as long as computation time is not an issue, it makes it easier to \
simulate from the outcome later.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Fd", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Fd", "[", 
    RowBox[{"[", "0", "]"}], "]"}], "=", "F"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Fd", "[", 
      RowBox[{"[", "j", "]"}], "]"}], "=", 
     RowBox[{"Union", "[", 
      RowBox[{"Expand", "[", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Outer", "[", 
         RowBox[{"D", ",", 
          RowBox[{"{", 
           RowBox[{"Fd", "[", 
            RowBox[{"[", 
             RowBox[{"j", "-", "1"}], "]"}], "]"}], "}"}], ",", 
          "myvariables"}], "]"}], "]"}], "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "orderexpansion"}], "}"}]}], "]"}], 
  ";"}]}], "Input"],

Cell["\<\
Now we plug in everything that is known, that is, we evaluate the derivative \
at the steady state and at calibrated parameters.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dF", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Fd", "/.", "param"}], "/.", "unirule"}], "/.", "epsrule"}], "//",
     "Chop"}]}], ";"}]], "Input"],

Cell["\<\
Now we simply need to solve the resulting system. In the first step, we also \
have to pick the correct solution. Since the system is quadratic, there may \
be more than one. How to pick this is not obvious; check the result manually \
to be sure.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"firstorder", "=", 
   RowBox[{
    RowBox[{"NSolve", "[", 
     RowBox[{"Thread", "[", 
      RowBox[{
       RowBox[{"First", "[", "dF", "]"}], "\[Equal]", "0"}], "]"}], "]"}], "//",
     "Chop"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NSolve", "::", "\<\"sfail\"\>"}], 
  RowBox[{
  ":", " "}], "\<\"Subsystem could not be solved for \\!\\(\\*SuperscriptBox[\
\\\"g3\\\", TagBox[\\((1, 0, 0, 0, 0)\\), Derivative], \
Rule[MultilineFunction, None]]\\) at value \\!\\(-0.03804211444487167`\\). \
The likely cause is failure to detect zero due to low precision. The likely \
effect is the loss of one or more solutions. Increasing WorkingPrecision \
might prevent some solutions from being lost.\"\>"}]], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "firstorder", "]"}]], "Input"],

Cell[BoxData["9"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["firstorder"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "2.0479470761199523`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.004408289314545347`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.00011183959237328484`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.0211471174507726`"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.0663224083244435`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.1458919325512896`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1.0270596421217126`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.6705407032749797`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.3297328348620453`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.000025222214668784576`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.6737781417883772`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "2.6113822006051546`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.06632240832437919`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.9894082893145454`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "3.603766313117802`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "1.150999807024033`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.14444745797111636`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.0001107322696765195`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.8892203274046171`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "3.603766313117802`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.43248823807881426`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "3.3455288390958344`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.16250980509427337`"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "2.6113822006051546`"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "2.643119641810082`"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.005239512042075345`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.000050556659778260016`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.020373510124660765`"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "5.030083054519954`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.5216307835353149`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "3.716093393026213`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.2613527964409073`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.7434640774423666`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.00009270169888939139`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "3.7686723213832067`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "2.429057749502455`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "5.0300830545199515`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.9902395120420753`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "41.72715168971289`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "1.5189331968538848`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.5164661223064133`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.00005005609879035061`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "1.8936451670043892`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "41.72715168971289`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "2.3782059112742346`"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "38.826428539311244`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.5341225288224236`"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "2.429057749502455`"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.21876334848181278`"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.004876659784996962`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.00015441440108604856`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.020773312536869308`"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "2.805357762576793`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.11514338377423336`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "1.2648187464660294`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.01154619417041891`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "1.0193931471921787`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.00013770567583484814`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "5.832744801312732`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.22876298856251442`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "2.8053577625767927`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.9898766597849968`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "25.085214489040553`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.8953871426660843`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.11400335027151798`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.00015288554562975097`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "2.8225476176610838`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "25.085214489040553`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "2.3851488012378357`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "20.489801146542163`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.09565898590725481`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.22876298856251442`"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.5234123409388673`"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.02999339621817181`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.0017744543337856328`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.0026645824520304395`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.546632099398062`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.19108276835099322`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.45659148472825306`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.4462486092057132`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.3794930888224366`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.0021022465307830446`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.3423672212471587`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.15148251890297323`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.5466320993980618`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "1.0149933962181719`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.4786046859126003`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "1.3526786667968724`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.18919085975356298`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.00175688547899569`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1.1872182432585319`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.4786046859126003`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.7334661330912536`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.45387655280699596`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.36620545346484124`"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.15148251890297323`"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.486109783568743`"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.005131504256087861`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.0008151727751625204`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.03002566943397994`"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.5047838243910852`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.18799745206527854`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.49553908692903725`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.44950240120799867`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.3760958044152485`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.0007492276748770066`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.35019118537053373`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.1114018055568602`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.5047838243910849`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.9798684957439122`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.38222788539883545`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "1.3497529236325694`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.18613609115374352`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.0008071017575866368`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1.1801830948997836`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.38222788539883545`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.7263606332489116`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.36418001724747207`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.3632504528688951`"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.1114018055568602`"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.11252780566324594`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.032421342305996095`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.007729589228223683`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.009576314069053914`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.10687981123957596`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.8875178682417239`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1.7084519806510596`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.048838163924886324`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "1.354080990920941`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.003278616623391295`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "9.516822339466295`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.07190989224174614`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.1068798112395759`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "1.0174213423059961`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "4.618290415810164`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.810178837053934`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.8787305626156183`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.007653058641805628`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "11.240284917093154`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "4.618290415810164`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "10.887063473664215`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "12.238486139432963`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.18171937457552664`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.07190989224174614`"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.06709952678115005`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.005767290683387508`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.0032009895092786345`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.0325011631696754`"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.2273641623403187`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.8530321172676285`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1.5756984059615384`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.04372450489195116`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "1.3391375122381775`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.0014578575896421787`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "9.311607162261224`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.030680142187017284`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.2273641623403187`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.9792327093166124`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "2.963707972530542`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.8218630206572527`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.8445862547204275`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.003169296543840232`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "10.771389397829243`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "2.963707972530542`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "10.413478999207664`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "10.415413417126114`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.16991834913617473`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.030680142187017284`"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.014375148774381091`"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.02833751453250256`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.0022870027380950857`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.00204928243121821`"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.5069613586256972`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.09378052023626127`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.5695237753710491`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.049957256602096656`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.46741218569902987`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.0057720449648924164`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.24318744373997614`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.027331550829514276`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.5069613586256974`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "1.0133375145325025`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.21439147002762615`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.9184356149038398`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.09285200023390827`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.0022643591466287977`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.5455866681491699`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.21439147002762615`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.08541824223079164`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.29826981770575145`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.07238002894712174`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.027331550829514276`"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.032019827077036836`"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.004722886622622262`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.0007181829928118513`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.028434678581279862`"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.4803216517550734`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.096202065767664`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.5907848367849641`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.04464771033117498`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.4610144159461531`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.002167713374981846`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.24249205554552766`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.005223103427617438`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.4803216517550734`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.9802771133773778`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.2114959398683749`"}], ",", 
     RowBox[{
      SuperscriptBox["h3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.9164458577712976`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.09524957006699175`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.0007110722701107429`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.5458472655444881`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.2114959398683749`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.08568144560006319`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.3005807306164645`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.07438968365098943`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g3", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.005223103427617438`"}]}], 
    "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solution", "=", 
  RowBox[{"firstorder", "[", 
   RowBox[{"[", "8", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.014375148774381091`"}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.02833751453250256`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.0022870027380950857`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.00204928243121821`"}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.5069613586256972`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.09378052023626127`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.5695237753710491`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.049957256602096656`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.46741218569902987`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.0057720449648924164`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.24318744373997614`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.027331550829514276`"}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.5069613586256974`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.0133375145325025`"}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.21439147002762615`"}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.9184356149038398`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.09285200023390827`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.0022643591466287977`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.5455866681491699`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.21439147002762615`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.08541824223079164`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.29826981770575145`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.07238002894712174`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.027331550829514276`"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"dF", "[", 
      RowBox[{"[", "j", "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{"dF", "[", 
       RowBox[{"[", "j", "]"}], "]"}], "/.", "solution"}]}], ";", 
    "\[IndentingNewLine]", "    ", 
    RowBox[{"nthorder", "=", 
     RowBox[{"NSolve", "[", 
      RowBox[{
       RowBox[{"dF", "[", 
        RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", 
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", 
            RowBox[{"dF", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}], 
      "]"}]}], ";", "\[IndentingNewLine]", "    ", 
    RowBox[{"solution", "=", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{"solution", ",", "nthorder"}], "}"}], "]"}], "//", 
      "Chop"}]}]}], ",", "     ", "\[IndentingNewLine]", "    ", 
   RowBox[{"{", 
    RowBox[{"j", ",", "2", ",", "orderexpansion"}], "}"}]}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["solution"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.05168790857314789`"}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.003462955653277748`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.0011661496399381216`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.02706551324196177`"}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.61423038441037`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.09871089901209505`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.40375556968468107`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.05060779019335998`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.631956944547567`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.0024105505130394417`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.331363534037008`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.009587219222125925`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.6142303844103703`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.9765370443467223`"}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.6947665338764837`"}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.9248690628206064`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.0977335633783123`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.0011546036038991292`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.5304247203595434`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.6947665338764837`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.07029571707881443`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.10997064762906601`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.0658822465511875`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.009587219222125925`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "2.3342343448104184`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "4.166854477924151`"}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.16162289931962`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "4.125598492994208`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "4.201638204369708`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.16162289931962`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.7281571242181624`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.7617298157059462`"}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.7425616664671406`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.8045339172525081`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.275480541354926`"}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.7425616664671406`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.014358999440061228`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.005727050186564954`"}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.028590816511417105`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.006813518604420266`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.004358210532016055`"}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.028590816511417105`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.001575402111830971`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.00009275471255404483`"}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.0002587027215626908`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.00009183634906327276`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.00022572034410569045`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.00025870272156257773`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.7702405075453829`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.7729428461946523`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.1323569393134039`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.8620558510623408`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.9303118075045764`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.1323569393134039`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.03529636792689288`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.003713181710264052`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.06715660081264868`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.003676417534914909`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.007042060675060191`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.06715660081264872`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "4.180996000631016`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.5433681828375063`"}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "2.963289089421326`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.5379882998391152`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "2.2928661975897646`"}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "2.963289089421326`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.8727250954901654`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.03204047360107983`"}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.30050014653396523`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.8839887021975509`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.6778479262831638`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.30050014653396523`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.015062302077224764`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.003066349690982127`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.006118446642480159`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.0030359897930516103`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.01015639337379683`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.006118446642480159`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.481299132470305`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.28280836030865225`"}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.4618079070390904`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.2800082775333191`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.1756135077099494`"}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.4618079070390904`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.0629272939682934`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.09546037930401231`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.00378726584735739`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.09451522703367556`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.02901332785462573`"}], ",", 
   RowBox[{
    SuperscriptBox["h3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.00378726584735739`"}]}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simulate the Outcome", "Section"],

Cell["\<\
simprule below eliminates the derivative that are too high (more than \
orderexpansion total); ssrule replaces the constants with steady state values.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"simprule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d", ":", 
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"n__", "/;", 
          RowBox[{
           RowBox[{"Plus", "[", "n", "]"}], ">", "orderexpansion"}]}], "]"}], 
        "[", "__", "]"}], "[", "__", "]"}]}], "\[RuleDelayed]", "  ", "0"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssrule", "=", 
   RowBox[{
    RowBox[{"ssfunrule", "/.", "ssvalrule"}], "/.", "ssresult"}]}], 
  ";"}]}], "Input"],

Cell["\<\
Generating Taylor-Series expansion that the result can be plugged into.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sfun", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"h1", "[", 
       RowBox[{"s", ",", "d", ",", "k", ",", "x", ",", "\[Sigma]"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", 
        RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", 
        RowBox[{"kbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}], 
    "//", "Normal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dfun", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"h2", "[", 
       RowBox[{"s", ",", "d", ",", "k", ",", "x", ",", "\[Sigma]"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", 
        RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", 
        RowBox[{"kbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}], 
    "//", "Normal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kfun", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"h3", "[", 
       RowBox[{"s", ",", "d", ",", "k", ",", "x", ",", "\[Sigma]"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", 
        RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", 
        RowBox[{"kbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}], 
    "//", "Normal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cfun", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"g1", "[", 
       RowBox[{"s", ",", "d", ",", "k", ",", "x", ",", "\[Sigma]"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", 
        RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", 
        RowBox[{"kbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}], 
    "//", "Normal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ifun", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"g2", "[", 
       RowBox[{"s", ",", "d", ",", "k", ",", "x", ",", "\[Sigma]"}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", 
        RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", 
        RowBox[{"kbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}], 
    "//", "Normal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"zfun", "=", 
    RowBox[{
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"g3", "[", 
        RowBox[{"s", ",", "d", ",", "k", ",", "x", ",", "\[Sigma]"}], "]"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"s", ",", 
         RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"d", ",", 
         RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"kbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}],
      "//", "Normal"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"sfun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dsimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"dfun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ksimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"kfun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"csimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"cfun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"isimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"ifun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zsimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"zfun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
      "ssrule"}], "/.", "solution"}], "/.", "param"}]}], ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ssim", "[", "1", "]"}], "=", 
   RowBox[{"sbar", "/.", "ssresult"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dsim", "[", "1", "]"}], "=", 
   RowBox[{"dbar", "/.", "ssresult"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ksim", "[", "1", "]"}], "=", 
   RowBox[{"kbar", "/.", "ssresult"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"xsim", "[", "1", "]"}], "=", "xmean"}], ";"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"This", " ", "is", " ", "a", " ", "one"}], "-", 
    RowBox[{
    "standard", " ", "deviation", " ", "contractionary", " ", "shock"}]}], 
   " ", "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"j", "=", "1"}], ",", 
   RowBox[{"j", "<", "22"}], ",", 
   RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"simrule", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "\[Rule]", 
        RowBox[{"ssim", "[", "j", "]"}]}], ",", 
       RowBox[{"d", "\[Rule]", 
        RowBox[{"dsim", "[", "j", "]"}]}], ",", 
       RowBox[{"k", "\[Rule]", 
        RowBox[{"ksim", "[", "j", "]"}]}], ",", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{"xsim", "[", "j", "]"}]}], ",", 
       RowBox[{"\[Sigma]", "\[Rule]", "0.006"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"csim", "[", "j", "]"}], "=", 
     RowBox[{"csimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"isim", "[", "j", "]"}], "=", 
     RowBox[{"isimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"zsim", "[", "j", "]"}], "=", 
     RowBox[{"zsimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ssim", "[", 
      RowBox[{"j", "+", "1"}], "]"}], "=", 
     RowBox[{"ssimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"dsim", "[", 
      RowBox[{"j", "+", "1"}], "]"}], "=", 
     RowBox[{"dsimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ksim", "[", 
      RowBox[{"j", "+", "1"}], "]"}], "=", 
     RowBox[{"ksimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xsim", "[", 
      RowBox[{"j", "+", "1"}], "]"}], "=", 
     RowBox[{
      RowBox[{"xconst", "+", 
       RowBox[{"\[Rho]", " ", 
        RowBox[{"xsim", "[", "j", "]"}]}]}], "/.", "param"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"j", "\[Equal]", "1"}], ",", 
      RowBox[{
       RowBox[{"xsim", "[", 
        RowBox[{"j", "+", "1"}], "]"}], "=", ".004"}]}], "]"}], ";"}]}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"This", " ", "is", " ", "a", " ", "one"}], "-", 
    RowBox[{
    "standard", " ", "deviation", " ", "contractionary", " ", "shock"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", "]"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", "*", 
       RowBox[{"ssim", "[", "j", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "21"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", "*", 
       RowBox[{"dsim", "[", "j", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "21"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", "*", 
       RowBox[{"csim", "[", "j", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"isim", "[", "j", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", " ", 
       RowBox[{"ksim", "[", "j", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"xsim", "[", "j", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"zout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"zsim", "[", "j", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"dsim", "[", "j", "]"}], "/", 
       RowBox[{"csim", "[", "j", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "21"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"infout", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"100", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"xout", "[", 
            RowBox[{"[", "j", "]"}], "]"}]}], ")"}], " ", 
         RowBox[{
          RowBox[{"pout", "[", 
           RowBox[{"[", 
            RowBox[{"j", "+", "1"}], "]"}], "]"}], "/", 
          RowBox[{"pout", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}]}], "-", "1"}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"infout", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "infout"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"piout", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", "-", 
       RowBox[{"sout", "[", 
        RowBox[{"[", "j", "]"}], "]"}], "-", 
       RowBox[{"dout", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "21"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"laout", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          RowBox[{
           RowBox[{"csim", "[", "j", "]"}], "+", 
           RowBox[{"zsim", "[", "j", "]"}]}], 
          SuperscriptBox[
           RowBox[{"ksim", "[", "j", "]"}], "\[Alpha]"]], ")"}], 
        FractionBox["1", 
         RowBox[{"1", "-", "\[Alpha]"}]]], "/.", "param"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"yout", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"csim", "[", "j", "]"}], "+", 
         RowBox[{"zsim", "[", "j", "]"}]}], ")"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"wout", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Alpha]"}], ")"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"xsim", "[", "j", "]"}], "-", 
          RowBox[{"dsim", "[", "j", "]"}]}], ")"}], "/", 
        RowBox[{"laout", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}]}], "/.", "param"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rkout", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"100", " ", 
        FractionBox[
         RowBox[{"\[Alpha]", " ", 
          RowBox[{"wout", "[", 
           RowBox[{"[", "j", "]"}], "]"}], "  ", 
          RowBox[{"laout", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Alpha]"}], ")"}], " ", 
          RowBox[{"ksim", "[", "j", "]"}]}]]}], "/.", "param"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rout", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"100", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"xsim", "[", "j", "]"}]}], ")"}], 
              RowBox[{
               RowBox[{"piout", "[", 
                RowBox[{"[", 
                 RowBox[{"j", "+", "1"}], "]"}], "]"}], "/", "100"}]}], "+", 
             RowBox[{"\[Lambda]", " ", 
              RowBox[{
               RowBox[{"piout", "[", 
                RowBox[{"[", "j", "]"}], "]"}], "/", "100"}]}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"xsim", "[", "j", "]"}], "-", 
             RowBox[{"dsim", "[", "j", "]"}], "-", 
             RowBox[{"ssim", "[", "j", "]"}]}], ")"}]}], "-", "1"}], ")"}]}], 
       "/.", "param"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot0", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"yout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Thickness", "[", ".01", "]"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "yout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "yout", "]"}], "-", 
              RowBox[{"Min", "[", "yout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "yout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "yout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "yout", "]"}], "-", 
            RowBox[{"Min", "[", "yout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Output\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot1", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"cout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Thickness", "[", ".01", "]"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "cout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "cout", "]"}], "-", 
              RowBox[{"Min", "[", "cout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "cout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "cout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "cout", "]"}], "-", 
            RowBox[{"Min", "[", "cout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Consumption\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot2", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"rout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "rout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "rout", "]"}], "-", 
              RowBox[{"Min", "[", "rout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "rout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "rout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "rout", "]"}], "-", 
            RowBox[{"Min", "[", "rout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Interest Rate\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot3", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"infout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "infout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "infout", "]"}], "-", 
              RowBox[{"Min", "[", "infout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "infout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "infout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "infout", "]"}], "-", 
            RowBox[{"Min", "[", "infout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Inflation Rate\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot4", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"dout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "dout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "dout", "]"}], "-", 
              RowBox[{"Min", "[", "dout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "dout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "dout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "dout", "]"}], "-", 
            RowBox[{"Min", "[", "dout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Checking Account\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot5", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"sout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "sout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "sout", "]"}], "-", 
              RowBox[{"Min", "[", "sout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "sout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "sout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "sout", "]"}], "-", 
            RowBox[{"Min", "[", "sout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Savings Account\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot6", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"piout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "piout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "piout", "]"}], "-", 
              RowBox[{"Min", "[", "piout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "piout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "piout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "piout", "]"}], "-", 
            RowBox[{"Min", "[", "piout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Retained Earnings\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot7", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"kout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Thickness", "[", ".01", "]"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "kout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "kout", "]"}], "-", 
              RowBox[{"Min", "[", "kout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "kout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "kout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "kout", "]"}], "-", 
            RowBox[{"Min", "[", "kout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Capital\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"plot8", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"rkout", ",", 
      RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Thickness", "[", ".01", "]"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Min", "[", "rkout", "]"}], "-", 
            RowBox[{".1", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Max", "[", "rkout", "]"}], "-", 
               RowBox[{"Min", "[", "rkout", "]"}]}], ")"}]}]}], ",", 
           RowBox[{"Max", "[", "rkout", "]"}]}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"Min", "[", "rkout", "]"}], "-", 
          RowBox[{".1", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Max", "[", "rkout", "]"}], "-", 
             RowBox[{"Min", "[", "rkout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
      RowBox[{"PlotLabel", "\[Rule]", "\"\<Return on Capital\>\""}], ",", 
      RowBox[{"TextStyle", "\[RuleDelayed]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontSize", "->", "18"}], ",", 
         RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"GraphicsArray", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"plot0", ",", "plot2", ",", "plot3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"plot1", ",", "plot7", ",", "plot8"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"plot4", ",", "plot5", ",", "plot6"}], "}"}]}], "}"}], "]"}], 
    "]"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -114.305 1.61679 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .00248 -47.25 -11.1875 ]
[-0.0125 .00248 0 11.1875 ]
[-0.0125 .08332 -58.0625 -11.1875 ]
[-0.0125 .08332 0 11.1875 ]
[-0.0125 .16416 -47.25 -11.1875 ]
[-0.0125 .16416 0 11.1875 ]
[-0.0125 .245 -58.0625 -11.1875 ]
[-0.0125 .245 0 11.1875 ]
[-0.0125 .32584 -47.25 -11.1875 ]
[-0.0125 .32584 0 11.1875 ]
[-0.0125 .40668 -58.0625 -11.1875 ]
[-0.0125 .40668 0 11.1875 ]
[-0.0125 .48752 -25.625 -11.1875 ]
[-0.0125 .48752 0 11.1875 ]
[-0.0125 .56836 -58.0625 -11.1875 ]
[-0.0125 .56836 0 11.1875 ]
[.5 .63053 -34.4375 0 ]
[.5 .63053 34.4375 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00248 m
.00625 .00248 L
s
gsave
-0.0125 .00248 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70.7) show
1.000 setlinewidth
grestore
0 .08332 m
.00625 .08332 L
s
gsave
-0.0125 .08332 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70.75) show
1.000 setlinewidth
grestore
0 .16416 m
.00625 .16416 L
s
gsave
-0.0125 .16416 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70.8) show
1.000 setlinewidth
grestore
0 .245 m
.00625 .245 L
s
gsave
-0.0125 .245 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70.85) show
1.000 setlinewidth
grestore
0 .32584 m
.00625 .32584 L
s
gsave
-0.0125 .32584 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70.9) show
1.000 setlinewidth
grestore
0 .40668 m
.00625 .40668 L
s
gsave
-0.0125 .40668 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70.95) show
1.000 setlinewidth
grestore
0 .48752 m
.00625 .48752 L
s
gsave
-0.0125 .48752 -86.625 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(71) show
1.000 setlinewidth
grestore
0 .56836 m
.00625 .56836 L
s
gsave
-0.0125 .56836 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(71.05) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01865 m
.00375 .01865 L
s
0 .03482 m
.00375 .03482 L
s
0 .05098 m
.00375 .05098 L
s
0 .06715 m
.00375 .06715 L
s
0 .09949 m
.00375 .09949 L
s
0 .11566 m
.00375 .11566 L
s
0 .13182 m
.00375 .13182 L
s
0 .14799 m
.00375 .14799 L
s
0 .18033 m
.00375 .18033 L
s
0 .1965 m
.00375 .1965 L
s
0 .21266 m
.00375 .21266 L
s
0 .22883 m
.00375 .22883 L
s
0 .26117 m
.00375 .26117 L
s
0 .27734 m
.00375 .27734 L
s
0 .2935 m
.00375 .2935 L
s
0 .30967 m
.00375 .30967 L
s
0 .34201 m
.00375 .34201 L
s
0 .35818 m
.00375 .35818 L
s
0 .37434 m
.00375 .37434 L
s
0 .39051 m
.00375 .39051 L
s
0 .42285 m
.00375 .42285 L
s
0 .43901 m
.00375 .43901 L
s
0 .45518 m
.00375 .45518 L
s
0 .47135 m
.00375 .47135 L
s
0 .50369 m
.00375 .50369 L
s
0 .51985 m
.00375 .51985 L
s
0 .53602 m
.00375 .53602 L
s
0 .55219 m
.00375 .55219 L
s
0 .58453 m
.00375 .58453 L
s
0 .60069 m
.00375 .60069 L
s
0 .61686 m
.00375 .61686 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -95.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Output) show
127.875 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .5535 m
.16667 .05618 L
.25 .06665 L
.33333 .23011 L
.41667 .38348 L
.5 .49117 L
.58333 .55707 L
.66667 .59336 L
.75 .61095 L
.83333 .61754 L
.91667 .61803 L
1 .61535 L
s
1 .61535 m
1 .61535 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.77254, 70.6237, \
0.058375, 0.00300879}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -158.789 2.78255 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .09429 -47.25 -11.1875 ]
[-0.0125 .09429 0 11.1875 ]
[-0.0125 .23342 -58.0625 -11.1875 ]
[-0.0125 .23342 0 11.1875 ]
[-0.0125 .37254 -47.25 -11.1875 ]
[-0.0125 .37254 0 11.1875 ]
[-0.0125 .51167 -58.0625 -11.1875 ]
[-0.0125 .51167 0 11.1875 ]
[.5 .63053 -61.4688 0 ]
[.5 .63053 61.4688 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09429 m
.00625 .09429 L
s
gsave
-0.0125 .09429 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(57.1) show
1.000 setlinewidth
grestore
0 .23342 m
.00625 .23342 L
s
gsave
-0.0125 .23342 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(57.15) show
1.000 setlinewidth
grestore
0 .37254 m
.00625 .37254 L
s
gsave
-0.0125 .37254 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(57.2) show
1.000 setlinewidth
grestore
0 .51167 m
.00625 .51167 L
s
gsave
-0.0125 .51167 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(57.25) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .12211 m
.00375 .12211 L
s
0 .14994 m
.00375 .14994 L
s
0 .17777 m
.00375 .17777 L
s
0 .20559 m
.00375 .20559 L
s
0 .26124 m
.00375 .26124 L
s
0 .28907 m
.00375 .28907 L
s
0 .31689 m
.00375 .31689 L
s
0 .34472 m
.00375 .34472 L
s
0 .40037 m
.00375 .40037 L
s
0 .42819 m
.00375 .42819 L
s
0 .45602 m
.00375 .45602 L
s
0 .48385 m
.00375 .48385 L
s
0 .06646 m
.00375 .06646 L
s
0 .03864 m
.00375 .03864 L
s
0 .01081 m
.00375 .01081 L
s
0 .5395 m
.00375 .5395 L
s
0 .56732 m
.00375 .56732 L
s
0 .59515 m
.00375 .59515 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -122.469 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Consumption) show
181.938 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .55415 m
.16667 .05618 L
.25 .0863 L
.33333 .24833 L
.41667 .39583 L
.5 .4983 L
.58333 .56067 L
.66667 .5949 L
.75 .61143 L
.83333 .6176 L
.91667 .61803 L
1 .61549 L
s
1 .61549 m
1 .61549 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.77254, 57.0224, \
0.058375, 0.00174824}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.795569 0.4482 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .01119 -36.4375 -11.1875 ]
[-0.0125 .01119 0 11.1875 ]
[-0.0125 .10083 -14.8125 -11.1875 ]
[-0.0125 .10083 0 11.1875 ]
[-0.0125 .19047 -36.4375 -11.1875 ]
[-0.0125 .19047 0 11.1875 ]
[-0.0125 .28011 -36.4375 -11.1875 ]
[-0.0125 .28011 0 11.1875 ]
[-0.0125 .36975 -36.4375 -11.1875 ]
[-0.0125 .36975 0 11.1875 ]
[-0.0125 .45939 -36.4375 -11.1875 ]
[-0.0125 .45939 0 11.1875 ]
[-0.0125 .54903 -14.8125 -11.1875 ]
[-0.0125 .54903 0 11.1875 ]
[.5 .63053 -72.2813 0 ]
[.5 .63053 72.2813 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01119 m
.00625 .01119 L
s
gsave
-0.0125 .01119 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
1.000 setlinewidth
grestore
0 .10083 m
.00625 .10083 L
s
gsave
-0.0125 .10083 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .19047 m
.00625 .19047 L
s
gsave
-0.0125 .19047 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
1.000 setlinewidth
grestore
0 .28011 m
.00625 .28011 L
s
gsave
-0.0125 .28011 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
1.000 setlinewidth
grestore
0 .36975 m
.00625 .36975 L
s
gsave
-0.0125 .36975 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
1.000 setlinewidth
grestore
0 .45939 m
.00625 .45939 L
s
gsave
-0.0125 .45939 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
1.000 setlinewidth
grestore
0 .54903 m
.00625 .54903 L
s
gsave
-0.0125 .54903 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0336 m
.00375 .0336 L
s
0 .05601 m
.00375 .05601 L
s
0 .07842 m
.00375 .07842 L
s
0 .12324 m
.00375 .12324 L
s
0 .14565 m
.00375 .14565 L
s
0 .16806 m
.00375 .16806 L
s
0 .21288 m
.00375 .21288 L
s
0 .23529 m
.00375 .23529 L
s
0 .2577 m
.00375 .2577 L
s
0 .30252 m
.00375 .30252 L
s
0 .32493 m
.00375 .32493 L
s
0 .34734 m
.00375 .34734 L
s
0 .39216 m
.00375 .39216 L
s
0 .41457 m
.00375 .41457 L
s
0 .43698 m
.00375 .43698 L
s
0 .4818 m
.00375 .4818 L
s
0 .50421 m
.00375 .50421 L
s
0 .52662 m
.00375 .52662 L
s
0 .57144 m
.00375 .57144 L
s
0 .59385 m
.00375 .59385 L
s
0 .61626 m
.00375 .61626 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -133.281 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Interest) show
160.313 20.000 moveto
(Rate) show
203.563 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .10981 m
.16667 .59711 L
.25 .61803 L
.33333 .45614 L
.41667 .29919 L
.5 .18895 L
.58333 .12155 L
.66667 .08416 L
.75 .06552 L
.83333 .05783 L
.91667 .05618 L
1 .0577 L
s
1 .0577 m
1 .0577 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.14136, 1.50429, \
0.058375, 0.0108536}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.350182 0.735375 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .09104 -36.4375 -11.1875 ]
[-0.0125 .09104 0 11.1875 ]
[-0.0125 .23812 -36.4375 -11.1875 ]
[-0.0125 .23812 0 11.1875 ]
[-0.0125 .38519 -14.8125 -11.1875 ]
[-0.0125 .38519 0 11.1875 ]
[-0.0125 .53227 -36.4375 -11.1875 ]
[-0.0125 .53227 0 11.1875 ]
[.5 .63053 -77.6875 0 ]
[.5 .63053 77.6875 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09104 m
.00625 .09104 L
s
gsave
-0.0125 .09104 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .23812 m
.00625 .23812 L
s
gsave
-0.0125 .23812 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .38519 m
.00625 .38519 L
s
gsave
-0.0125 .38519 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .53227 m
.00625 .53227 L
s
gsave
-0.0125 .53227 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .12781 m
.00375 .12781 L
s
0 .16458 m
.00375 .16458 L
s
0 .20135 m
.00375 .20135 L
s
0 .27489 m
.00375 .27489 L
s
0 .31166 m
.00375 .31166 L
s
0 .34842 m
.00375 .34842 L
s
0 .42196 m
.00375 .42196 L
s
0 .45873 m
.00375 .45873 L
s
0 .4955 m
.00375 .4955 L
s
0 .05427 m
.00375 .05427 L
s
0 .01751 m
.00375 .01751 L
s
0 .56904 m
.00375 .56904 L
s
0 .60581 m
.00375 .60581 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -138.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Inflation) show
171.125 20.000 moveto
(Rate) show
214.375 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .38519 m
.16667 .61803 L
.25 .16629 L
.33333 .05618 L
.41667 .12066 L
.5 .20903 L
.58333 .27954 L
.66667 .32696 L
.75 .35617 L
.83333 .37312 L
.91667 .38248 L
1 .38738 L
s
1 .38738 m
1 .38738 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJy1WOlyFUUU7tyeO3MTEpJ7s5GQkFClomxCIEBCJCAl4FaixBi0tIwRK1Ep
qBDLDR33FXcttVwKlxfwBdzRn76CP/Upxp6v7+k509OTOzdV5sfJuef7zunt
9Onpvn1+ZfHM2fmVpYX50ePL8+cXlxYujB47t6xMskWIllEhxA9dQukXhfxb
jERhtDmMhGj2/6kwqggxHEZlSE+ITZD9sJehV6FLyB7baSiMfJJ9sHvQu2yn
mTAqCXEV5DBkKYykEIPQPcgNkAGhSnYzy0Ac5m6omxB3I3PNhvGZpQZZIVSI
WerHGsK0QvbHYe6BOgQpSZc0tI2YiYGcMG2QfXGYORamRHpA05oXYB1kbxzg
NAsQd0TEf/WfXv1n/ffqY2uHpFU2oBVZr99IgXjcQlHN/OiEG4a+iRF7kVk8
Dbpg8Zkv5ZSPfugAPk15HwXwyVXrvfUMUq2OwmkU+hDkIOWIh+hG71vLvhoP
o78QGKpQTYUKitsz+kgBPY8/aAf+p25Qvf43D/t/DTcy/bukN0chv7fZR7Aq
39rmw+k8U/o3sdqNhahgyQLSjdM0pY4yXI7pNSx2AINPOqcb3UOwr+tOPN1M
ffIZ/RBVI+X0VexUZVm7nunc6Qba7crwZQMnRZmifaj0Lxx06erYFNPb0b3P
Ha5BeiIOwt4J+mfujiXFg0/4JG1wZfjUduyk2mToE7T7VTufOKZaYnY43eja
6eNkUauQfOgHqP4ow0dJsmhPTtxPBV4ZPkwS9EB6Wyn1Azsr99FhoQzv2+A4
1UJleM8G9wLcDPBdB2h0TXnHpuyhQ1MZLtngGMBrIC8lA9LmayHftn12M30L
wr5lU3bBcyvAN93gNoBvuMHtAF93gzsAvuYGdwJ81QavB7gL4CvJOLXPbphf
dvuMAXzJDe4B+KIb3AvwhcbFZyfo+2B/vnHx0fT9oD9n74XOnAqinSYQ8mLj
CqLpk9CfLVqltNNBOD3j2NPOcUyB/nRj+g7YD4H+VNEuaadpOD3ZnNNhTPAT
RSdYOx2B00qyiF054ziKLl1IkqNGaaEzXMmbQFm2k2s7wGOgn3eDxwGec4M3
AzzrBm/BmfqYG7wNno/a4DaAdwBcdIMnEfaRZOPpgHfB/LDbZwYBF9zgLMB5
G9wKcA5z/oAbvBdn2H1u8H54nnaDDwKcTQahu/IQAp5y+5wBeNIGrwO4FEat
QtzqBh8Po3bkgIiLbCWdbJqyDMr0ahS1UTpRWkS9Q60Ziqo4VWx4F2U90/uB
qoo9gIOM0RWjA1J/wqvzrVb/cHVGLBHxMmQB4o+5FCnq/cqh6O3KKFuQcxZF
4rteUX5yU/THHKOYhkpUUhg4nvaUdBfIgFX6qskH9eX1ZwcoqS5lwBp9W+WA
kvqcAbvZgAg0Pcz3kVQWf7HBHlYzmwYllegM2MvqtwuUdAv9NRmEzoG02fj0
NQAlXZUzoA7LwCptRYnHD2tbNk+XlGe/xfQetrb8A3kDS0hG1AvaliZKOmcY
sYftZf1YkKH0ktnEyiHqyQzSREkX+d8TYn/mFB0kS5rIT+1V6VVs3WrOFWeQ
ZjlNr2XOaP2cU7a70c3OaP1I4yUUnhT8NedKs6CkT40MaN681gKqgf5hm/VD
HZlLuIN4Dp6+mjRhVqH+jM1zzHylmCEq+DxyJ70Oeunbfom9Guq7eXID1Y+R
Hj1Mlg2D+a+DXdIiOfz1J/lE0U5IHPMevgRK1K3A5aWbLlEKtDJmRd8y60+g
AUuhMm3xUvqprJzh6CIjSRq0g3Rjz0bQeTXduAsBepztFA/Gmy3RnjReAUZe
YLQVrEPBpnx6wMtvxGw8HrLdNcl8Go1XB8bQxvgB01lTPksOn00az1lu4evj
pZlBPQ9nWM+SdPVYExVKd9OEsaR8+KWozHy0Ppk01s2mROtjrJ/6i+lEske6
WM5z16uBVm26fqRx0gM6/040Uy5Ey38uNO8l\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.14136, 0.31118, \
0.058375, 0.0066151}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -143.155 3.1444 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .07193 -58.0625 -11.1875 ]
[-0.0125 .07193 0 11.1875 ]
[-0.0125 .15054 -68.875 -11.1875 ]
[-0.0125 .15054 0 11.1875 ]
[-0.0125 .22915 -47.25 -11.1875 ]
[-0.0125 .22915 0 11.1875 ]
[-0.0125 .30776 -68.875 -11.1875 ]
[-0.0125 .30776 0 11.1875 ]
[-0.0125 .38637 -58.0625 -11.1875 ]
[-0.0125 .38637 0 11.1875 ]
[-0.0125 .46498 -68.875 -11.1875 ]
[-0.0125 .46498 0 11.1875 ]
[-0.0125 .54359 -47.25 -11.1875 ]
[-0.0125 .54359 0 11.1875 ]
[.5 .63053 -88.7188 0 ]
[.5 .63053 88.7188 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07193 m
.00625 .07193 L
s
gsave
-0.0125 .07193 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45.55) show
1.000 setlinewidth
grestore
0 .15054 m
.00625 .15054 L
s
gsave
-0.0125 .15054 -129.875 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45.575) show
1.000 setlinewidth
grestore
0 .22915 m
.00625 .22915 L
s
gsave
-0.0125 .22915 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45.6) show
1.000 setlinewidth
grestore
0 .30776 m
.00625 .30776 L
s
gsave
-0.0125 .30776 -129.875 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45.625) show
1.000 setlinewidth
grestore
0 .38637 m
.00625 .38637 L
s
gsave
-0.0125 .38637 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45.65) show
1.000 setlinewidth
grestore
0 .46498 m
.00625 .46498 L
s
gsave
-0.0125 .46498 -129.875 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45.675) show
1.000 setlinewidth
grestore
0 .54359 m
.00625 .54359 L
s
gsave
-0.0125 .54359 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45.7) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08765 m
.00375 .08765 L
s
0 .10337 m
.00375 .10337 L
s
0 .11909 m
.00375 .11909 L
s
0 .13481 m
.00375 .13481 L
s
0 .16626 m
.00375 .16626 L
s
0 .18198 m
.00375 .18198 L
s
0 .1977 m
.00375 .1977 L
s
0 .21342 m
.00375 .21342 L
s
0 .24487 m
.00375 .24487 L
s
0 .26059 m
.00375 .26059 L
s
0 .27631 m
.00375 .27631 L
s
0 .29203 m
.00375 .29203 L
s
0 .32348 m
.00375 .32348 L
s
0 .3392 m
.00375 .3392 L
s
0 .35492 m
.00375 .35492 L
s
0 .37064 m
.00375 .37064 L
s
0 .40209 m
.00375 .40209 L
s
0 .41781 m
.00375 .41781 L
s
0 .43353 m
.00375 .43353 L
s
0 .44925 m
.00375 .44925 L
s
0 .4807 m
.00375 .4807 L
s
0 .49642 m
.00375 .49642 L
s
0 .51214 m
.00375 .51214 L
s
0 .52786 m
.00375 .52786 L
s
0 .0562 m
.00375 .0562 L
s
0 .04048 m
.00375 .04048 L
s
0 .02476 m
.00375 .02476 L
s
0 .00904 m
.00375 .00904 L
s
0 .55931 m
.00375 .55931 L
s
0 .57503 m
.00375 .57503 L
s
0 .59075 m
.00375 .59075 L
s
0 .60647 m
.00375 .60647 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -149.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Checking) show
160.750 20.000 moveto
(Account) show
236.438 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .15923 m
.16667 .15923 L
.25 .61803 L
.33333 .55399 L
.41667 .38814 L
.5 .24636 L
.58333 .15163 L
.66667 .09663 L
.75 .06879 L
.83333 .0577 L
.91667 .05618 L
1 .05979 L
s
1 .05979 m
1 .05979 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.22599, 45.4865, \
0.0591787, 0.00156836}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -48.8358 1.05003 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .09564 -47.25 -11.1875 ]
[-0.0125 .09564 0 11.1875 ]
[-0.0125 .20064 -47.25 -11.1875 ]
[-0.0125 .20064 0 11.1875 ]
[-0.0125 .30564 -47.25 -11.1875 ]
[-0.0125 .30564 0 11.1875 ]
[-0.0125 .41064 -47.25 -11.1875 ]
[-0.0125 .41064 0 11.1875 ]
[-0.0125 .51565 -25.625 -11.1875 ]
[-0.0125 .51565 0 11.1875 ]
[.5 .63053 -83.3125 0 ]
[.5 .63053 83.3125 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09564 m
.00625 .09564 L
s
gsave
-0.0125 .09564 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(46.6) show
1.000 setlinewidth
grestore
0 .20064 m
.00625 .20064 L
s
gsave
-0.0125 .20064 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(46.7) show
1.000 setlinewidth
grestore
0 .30564 m
.00625 .30564 L
s
gsave
-0.0125 .30564 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(46.8) show
1.000 setlinewidth
grestore
0 .41064 m
.00625 .41064 L
s
gsave
-0.0125 .41064 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(46.9) show
1.000 setlinewidth
grestore
0 .51565 m
.00625 .51565 L
s
gsave
-0.0125 .51565 -86.625 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(47) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .11664 m
.00375 .11664 L
s
0 .13764 m
.00375 .13764 L
s
0 .15864 m
.00375 .15864 L
s
0 .17964 m
.00375 .17964 L
s
0 .22164 m
.00375 .22164 L
s
0 .24264 m
.00375 .24264 L
s
0 .26364 m
.00375 .26364 L
s
0 .28464 m
.00375 .28464 L
s
0 .32664 m
.00375 .32664 L
s
0 .34764 m
.00375 .34764 L
s
0 .36864 m
.00375 .36864 L
s
0 .38964 m
.00375 .38964 L
s
0 .43165 m
.00375 .43165 L
s
0 .45265 m
.00375 .45265 L
s
0 .47365 m
.00375 .47365 L
s
0 .49465 m
.00375 .49465 L
s
0 .53665 m
.00375 .53665 L
s
0 .55765 m
.00375 .55765 L
s
0 .57865 m
.00375 .57865 L
s
0 .59965 m
.00375 .59965 L
s
0 .07463 m
.00375 .07463 L
s
0 .05363 m
.00375 .05363 L
s
0 .03263 m
.00375 .03263 L
s
0 .01163 m
.00375 .01163 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -144.313 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Savings) show
149.938 20.000 moveto
(Account) show
225.625 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .05618 m
.16667 .05618 L
.25 .39991 L
.33333 .55766 L
.41667 .61432 L
.5 .61803 L
.58333 .59547 L
.66667 .56103 L
.75 .52234 L
.83333 .4833 L
.91667 .4458 L
1 .4107 L
s
1 .4107 m
1 .4107 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.45695, 46.3934, \
0.058375, 0.0046328}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -6.68917 0.929693 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .00462 -36.4375 -11.1875 ]
[-0.0125 .00462 0 11.1875 ]
[-0.0125 .09759 -36.4375 -11.1875 ]
[-0.0125 .09759 0 11.1875 ]
[-0.0125 .19055 -36.4375 -11.1875 ]
[-0.0125 .19055 0 11.1875 ]
[-0.0125 .28352 -36.4375 -11.1875 ]
[-0.0125 .28352 0 11.1875 ]
[-0.0125 .37649 -36.4375 -11.1875 ]
[-0.0125 .37649 0 11.1875 ]
[-0.0125 .46946 -36.4375 -11.1875 ]
[-0.0125 .46946 0 11.1875 ]
[-0.0125 .56243 -36.4375 -11.1875 ]
[-0.0125 .56243 0 11.1875 ]
[.5 .63053 -94.0313 0 ]
[.5 .63053 94.0313 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00462 m
.00625 .00462 L
s
gsave
-0.0125 .00462 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.2) show
1.000 setlinewidth
grestore
0 .09759 m
.00625 .09759 L
s
gsave
-0.0125 .09759 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.3) show
1.000 setlinewidth
grestore
0 .19055 m
.00625 .19055 L
s
gsave
-0.0125 .19055 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.4) show
1.000 setlinewidth
grestore
0 .28352 m
.00625 .28352 L
s
gsave
-0.0125 .28352 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.5) show
1.000 setlinewidth
grestore
0 .37649 m
.00625 .37649 L
s
gsave
-0.0125 .37649 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.6) show
1.000 setlinewidth
grestore
0 .46946 m
.00625 .46946 L
s
gsave
-0.0125 .46946 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.7) show
1.000 setlinewidth
grestore
0 .56243 m
.00625 .56243 L
s
gsave
-0.0125 .56243 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02321 m
.00375 .02321 L
s
0 .0418 m
.00375 .0418 L
s
0 .0604 m
.00375 .0604 L
s
0 .07899 m
.00375 .07899 L
s
0 .11618 m
.00375 .11618 L
s
0 .13477 m
.00375 .13477 L
s
0 .15337 m
.00375 .15337 L
s
0 .17196 m
.00375 .17196 L
s
0 .20915 m
.00375 .20915 L
s
0 .22774 m
.00375 .22774 L
s
0 .24634 m
.00375 .24634 L
s
0 .26493 m
.00375 .26493 L
s
0 .30212 m
.00375 .30212 L
s
0 .32071 m
.00375 .32071 L
s
0 .33931 m
.00375 .33931 L
s
0 .3579 m
.00375 .3579 L
s
0 .39509 m
.00375 .39509 L
s
0 .41368 m
.00375 .41368 L
s
0 .43228 m
.00375 .43228 L
s
0 .45087 m
.00375 .45087 L
s
0 .48806 m
.00375 .48806 L
s
0 .50665 m
.00375 .50665 L
s
0 .52524 m
.00375 .52524 L
s
0 .54384 m
.00375 .54384 L
s
0 .58103 m
.00375 .58103 L
s
0 .59962 m
.00375 .59962 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -155.031 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Retained) show
160.563 20.000 moveto
(Earnings) show
247.063 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .61803 m
.16667 .61803 L
.25 .17804 L
.33333 .05731 L
.41667 .05618 L
.5 .09481 L
.58333 .1428 L
.66667 .18955 L
.75 .23204 L
.83333 .26989 L
.91667 .30353 L
1 .33355 L
s
1 .33355 m
1 .33355 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.14136, 7.06451, \
0.058375, 0.00523246}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -1284.1 1.39891 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .1009 -36.4375 -11.1875 ]
[-0.0125 .1009 0 11.1875 ]
[-0.0125 .24079 -58.0625 -11.1875 ]
[-0.0125 .24079 0 11.1875 ]
[-0.0125 .38069 -58.0625 -11.1875 ]
[-0.0125 .38069 0 11.1875 ]
[-0.0125 .52058 -58.0625 -11.1875 ]
[-0.0125 .52058 0 11.1875 ]
[.5 .63053 -39.8438 0 ]
[.5 .63053 39.8438 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .1009 m
.00625 .1009 L
s
gsave
-0.0125 .1009 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(918) show
1.000 setlinewidth
grestore
0 .24079 m
.00625 .24079 L
s
gsave
-0.0125 .24079 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(918.1) show
1.000 setlinewidth
grestore
0 .38069 m
.00625 .38069 L
s
gsave
-0.0125 .38069 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(918.2) show
1.000 setlinewidth
grestore
0 .52058 m
.00625 .52058 L
s
gsave
-0.0125 .52058 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(918.3) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .12888 m
.00375 .12888 L
s
0 .15686 m
.00375 .15686 L
s
0 .18484 m
.00375 .18484 L
s
0 .21282 m
.00375 .21282 L
s
0 .26877 m
.00375 .26877 L
s
0 .29675 m
.00375 .29675 L
s
0 .32473 m
.00375 .32473 L
s
0 .35271 m
.00375 .35271 L
s
0 .40866 m
.00375 .40866 L
s
0 .43664 m
.00375 .43664 L
s
0 .46462 m
.00375 .46462 L
s
0 .4926 m
.00375 .4926 L
s
0 .07292 m
.00375 .07292 L
s
0 .04495 m
.00375 .04495 L
s
0 .01697 m
.00375 .01697 L
s
0 .54856 m
.00375 .54856 L
s
0 .57653 m
.00375 .57653 L
s
0 .60451 m
.00375 .60451 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -100.844 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Capital) show
138.688 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .61803 m
.16667 .61803 L
.25 .43808 L
.33333 .25475 L
.41667 .13414 L
.5 .07388 L
.58333 .05618 L
.66667 .06442 L
.75 .08672 L
.83333 .1156 L
.91667 .14665 L
1 .17744 L
s
1 .17744 m
1 .17744 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJytWGlzFFUUfZmlZybJJJMFMJBlQGMkohEFWTQgQYKkTESwSLlFh0hVUiUu
QFl+0OrSSvnZnQCCsqMoEBYVl9/gL9Dyn7Td5/W7fee91z2TlPnwcnLuPfe+
7r7vTKbHK8dmDh2uHJudrpR3H6m8MzM7fbQ8+vYRn0o3CNFQFkIslISPPxDp
f0Wf53qrXU+Ixf6ecr28ED2ul8WaEaIX6wrwWeA24DTWgi7qdj1HrcvBZ4BL
uug110sJcR/WHqwp10sLsRI4g/UerDkV9dcOxrQEZV4H7EXdVUxqlnEY0441
j7UYlKmofSyhTAFrc1DmIGA31rTCaXVpq3AnumLKNGJtCspMszIphXPqtsYV
aFJlhHiDFQg2IoKf8M9M+Gf4d/K1NasrxFOmoFZZPr++OupxRlWl+yMHrge4
lyUuw2TxMSiBcZhWzZSDfcgCjrrly1UBR0klbgwnyO9ahqgM3I11pZoRH3cy
3LSUc/WU6/2FkwMo/FauHwq2Srgcw8dhnt+qF/47JPxd/xMX+z+Iuuq/63pF
PJxq+rDrdQkxqdOzOIRFaPZFbQ65XgGz768TumYaj3MNlGNBUD7CHHOtPEuv
gBlEdDRMd5BIfpVj6XJChhAdCdLlsOSMiXaYaAqijTi32wPRamZdcaJXIdqC
HQwHol50ooPm2NT++gp026DbGuT2oK+jWmoX9BLSdyBnU3j9dJLiRC8iOgrR
hlCkbSPusibRbwzS9YuTHoB0ArsZqtqqTM/GS1+AdD+k68Kb4igRXZ8vkokH
wAyGdz2jPh7yxvTsB/8y0gf0SdyH4BSC/XrweQQPqmE1gnyeczCy6pS90M+o
zwJ1NCT9JuguXfMcw2+h8wo9ZQL6owh26sFxBN9DccO/xhl+H/e1pKc8C/2H
FrPyaRn8VNeMgf7MQhM2NHug+VynnwH9RdRyDwsa2buR8mVA52wOklYmkWWi
UYi+CkWmj8SJCKNfU4yntKkppPRdYL4ORM0xnmKKngZzPBAVankKqf11F6uB
lnnDWdqNZjvBzId3xOospmgEzIlQlGAP5sWNMDy/lAI7wJys2rDVX1rAaFLC
J8IbpLlMqxKlRNjpVPgcNJfpMDbGh/OkPq2Jwe2o9Y2FJnxKD26D5nR0WHi2
UWoYKWcsNOHTevBJaL610ITPRO2HLTQRTyDlOwtN2OizFZqzFpqwUXALNOei
XfFso9RmpJxfnINsZvjc4nxkE/pdSHKQVqyN1SLC55N8pET/qMdKF+UmcrcX
7T5C3+2oweMMX0hyk07jw38jmEu1zUBKs9VSwhdrF2hhmJfZAOZyXZ5CF6UV
IHzJ7iwlrLKY7HfF7iztahap4mMMX9anODH4KOp+b6EJX4lOi8z+Qc9ez7BR
6hForlpowkbBIWh+tNCEr0a7ktk/6dkPM2yUegiaaxaasFFwHTTXLTTha9Gu
ZPYNPftBhq/XcBbtn/ZBVFxI8pQMGKdaRPhGkrMU1dBro78WzM0kZzGP3VqG
F+pylg510T6WLW/ZnaVNnTlq8ADDN5OcpT5pgj10GOd6APztpVjTAMO36nIW
bk0pEfa+Y3eTVnXjqMf9DN+u11n6Ef1Zn+J+hu/oQfke8BcLTVgVTKm3hr/q
2fcybJRaA81dC03YKCi/sv9moQnfjXYls3/Xs8sMG6X6oPlDp/2D1SHEnwG9
N4JejZdMx/Es5zQ4jxafBHAOrHSM6D2gnB46ZylmCRlrdh5fmYX4GC9jUmql
97tZzBHnVTrNYYpNZhoznGaHOa94LVPONt4YfQTYhE7pahtKsQHNWUTNGPY4
UYF9pDJRKXGrxaTtyRuRwX10lP3aNkZHN6t68IeSZQWy7I3oZHRvMxDJ87es
KlhQr7XzypQyYXBOPl/VKCar1uip36LhPwlDCJI=\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.77254, 917.842, \
0.058375, 0.00347741}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -47.1893 23.9832 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .05761 -47.25 -11.1875 ]
[-0.0125 .05761 0 11.1875 ]
[-0.0125 .17752 -58.0625 -11.1875 ]
[-0.0125 .17752 0 11.1875 ]
[-0.0125 .29744 -47.25 -11.1875 ]
[-0.0125 .29744 0 11.1875 ]
[-0.0125 .41736 -58.0625 -11.1875 ]
[-0.0125 .41736 0 11.1875 ]
[-0.0125 .53727 -47.25 -11.1875 ]
[-0.0125 .53727 0 11.1875 ]
[.5 .63053 -93.9063 0 ]
[.5 .63053 93.9063 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05761 m
.00625 .05761 L
s
gsave
-0.0125 .05761 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.97) show
1.000 setlinewidth
grestore
0 .17752 m
.00625 .17752 L
s
gsave
-0.0125 .17752 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.975) show
1.000 setlinewidth
grestore
0 .29744 m
.00625 .29744 L
s
gsave
-0.0125 .29744 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.98) show
1.000 setlinewidth
grestore
0 .41736 m
.00625 .41736 L
s
gsave
-0.0125 .41736 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.985) show
1.000 setlinewidth
grestore
0 .53727 m
.00625 .53727 L
s
gsave
-0.0125 .53727 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.99) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08159 m
.00375 .08159 L
s
0 .10557 m
.00375 .10557 L
s
0 .12956 m
.00375 .12956 L
s
0 .15354 m
.00375 .15354 L
s
0 .20151 m
.00375 .20151 L
s
0 .22549 m
.00375 .22549 L
s
0 .24947 m
.00375 .24947 L
s
0 .27346 m
.00375 .27346 L
s
0 .32142 m
.00375 .32142 L
s
0 .34541 m
.00375 .34541 L
s
0 .36939 m
.00375 .36939 L
s
0 .39337 m
.00375 .39337 L
s
0 .44134 m
.00375 .44134 L
s
0 .46532 m
.00375 .46532 L
s
0 .4893 m
.00375 .4893 L
s
0 .51329 m
.00375 .51329 L
s
0 .03362 m
.00375 .03362 L
s
0 .00964 m
.00375 .00964 L
s
0 .56125 m
.00375 .56125 L
s
0 .58524 m
.00375 .58524 L
s
0 .60922 m
.00375 .60922 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -154.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Return) show
138.688 20.000 moveto
(on) show
171.125 20.000 moveto
(Capital) show
246.813 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .57326 m
.16667 .05618 L
.25 .19561 L
.33333 .34924 L
.41667 .46384 L
.5 .53728 L
.58333 .58007 L
.66667 .60293 L
.75 .61378 L
.83333 .61776 L
.91667 .61803 L
1 .6164 L
s
1 .6164 m
1 .6164 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.77254, 1.96254, \
0.058375, 0.000202833}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0147151 0.31746 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.321429 0.198654 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -143.155 3.1444 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .07193 -58.0625 -11.1875 ]
[-0.0125 .07193 0 11.1875 ]
[-0.0125 .15054 -68.875 -11.1875 ]
[-0.0125 .15054 0 11.1875 ]
[-0.0125 .22915 -47.25 -11.1875 ]
[-0.0125 .22915 0 11.1875 ]
[-0.0125 .30776 -68.875 -11.1875 ]
[-0.0125 .30776 0 11.1875 ]
[-0.0125 .38637 -58.0625 -11.1875 ]
[-0.0125 .38637 0 11.1875 ]
[-0.0125 .46498 -68.875 -11.1875 ]
[-0.0125 .46498 0 11.1875 ]
[-0.0125 .54359 -47.25 -11.1875 ]
[-0.0125 .54359 0 11.1875 ]
[.5 .63053 -88.7188 0 ]
[.5 .63053 88.7188 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07193 m
.00625 .07193 L
s
gsave
-0.0125 .07193 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45.55) show
1.000 setlinewidth
grestore
0 .15054 m
.00625 .15054 L
s
gsave
-0.0125 .15054 -129.875 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45.575) show
1.000 setlinewidth
grestore
0 .22915 m
.00625 .22915 L
s
gsave
-0.0125 .22915 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45.6) show
1.000 setlinewidth
grestore
0 .30776 m
.00625 .30776 L
s
gsave
-0.0125 .30776 -129.875 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45.625) show
1.000 setlinewidth
grestore
0 .38637 m
.00625 .38637 L
s
gsave
-0.0125 .38637 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45.65) show
1.000 setlinewidth
grestore
0 .46498 m
.00625 .46498 L
s
gsave
-0.0125 .46498 -129.875 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45.675) show
1.000 setlinewidth
grestore
0 .54359 m
.00625 .54359 L
s
gsave
-0.0125 .54359 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(45.7) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08765 m
.00375 .08765 L
s
0 .10337 m
.00375 .10337 L
s
0 .11909 m
.00375 .11909 L
s
0 .13481 m
.00375 .13481 L
s
0 .16626 m
.00375 .16626 L
s
0 .18198 m
.00375 .18198 L
s
0 .1977 m
.00375 .1977 L
s
0 .21342 m
.00375 .21342 L
s
0 .24487 m
.00375 .24487 L
s
0 .26059 m
.00375 .26059 L
s
0 .27631 m
.00375 .27631 L
s
0 .29203 m
.00375 .29203 L
s
0 .32348 m
.00375 .32348 L
s
0 .3392 m
.00375 .3392 L
s
0 .35492 m
.00375 .35492 L
s
0 .37064 m
.00375 .37064 L
s
0 .40209 m
.00375 .40209 L
s
0 .41781 m
.00375 .41781 L
s
0 .43353 m
.00375 .43353 L
s
0 .44925 m
.00375 .44925 L
s
0 .4807 m
.00375 .4807 L
s
0 .49642 m
.00375 .49642 L
s
0 .51214 m
.00375 .51214 L
s
0 .52786 m
.00375 .52786 L
s
0 .0562 m
.00375 .0562 L
s
0 .04048 m
.00375 .04048 L
s
0 .02476 m
.00375 .02476 L
s
0 .00904 m
.00375 .00904 L
s
0 .55931 m
.00375 .55931 L
s
0 .57503 m
.00375 .57503 L
s
0 .59075 m
.00375 .59075 L
s
0 .60647 m
.00375 .60647 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -149.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Checking) show
160.750 20.000 moveto
(Account) show
236.438 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .15923 m
.16667 .15923 L
.25 .61803 L
.33333 .55399 L
.41667 .38814 L
.5 .24636 L
.58333 .15163 L
.66667 .09663 L
.75 .06879 L
.83333 .0577 L
.91667 .05618 L
1 .05979 L
s
1 .05979 m
1 .05979 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.0147151 0.64881 0.198654 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -48.8358 1.05003 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .09564 -47.25 -11.1875 ]
[-0.0125 .09564 0 11.1875 ]
[-0.0125 .20064 -47.25 -11.1875 ]
[-0.0125 .20064 0 11.1875 ]
[-0.0125 .30564 -47.25 -11.1875 ]
[-0.0125 .30564 0 11.1875 ]
[-0.0125 .41064 -47.25 -11.1875 ]
[-0.0125 .41064 0 11.1875 ]
[-0.0125 .51565 -25.625 -11.1875 ]
[-0.0125 .51565 0 11.1875 ]
[.5 .63053 -83.3125 0 ]
[.5 .63053 83.3125 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09564 m
.00625 .09564 L
s
gsave
-0.0125 .09564 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(46.6) show
1.000 setlinewidth
grestore
0 .20064 m
.00625 .20064 L
s
gsave
-0.0125 .20064 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(46.7) show
1.000 setlinewidth
grestore
0 .30564 m
.00625 .30564 L
s
gsave
-0.0125 .30564 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(46.8) show
1.000 setlinewidth
grestore
0 .41064 m
.00625 .41064 L
s
gsave
-0.0125 .41064 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(46.9) show
1.000 setlinewidth
grestore
0 .51565 m
.00625 .51565 L
s
gsave
-0.0125 .51565 -86.625 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(47) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .11664 m
.00375 .11664 L
s
0 .13764 m
.00375 .13764 L
s
0 .15864 m
.00375 .15864 L
s
0 .17964 m
.00375 .17964 L
s
0 .22164 m
.00375 .22164 L
s
0 .24264 m
.00375 .24264 L
s
0 .26364 m
.00375 .26364 L
s
0 .28464 m
.00375 .28464 L
s
0 .32664 m
.00375 .32664 L
s
0 .34764 m
.00375 .34764 L
s
0 .36864 m
.00375 .36864 L
s
0 .38964 m
.00375 .38964 L
s
0 .43165 m
.00375 .43165 L
s
0 .45265 m
.00375 .45265 L
s
0 .47365 m
.00375 .47365 L
s
0 .49465 m
.00375 .49465 L
s
0 .53665 m
.00375 .53665 L
s
0 .55765 m
.00375 .55765 L
s
0 .57865 m
.00375 .57865 L
s
0 .59965 m
.00375 .59965 L
s
0 .07463 m
.00375 .07463 L
s
0 .05363 m
.00375 .05363 L
s
0 .03263 m
.00375 .03263 L
s
0 .01163 m
.00375 .01163 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -144.313 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Savings) show
149.938 20.000 moveto
(Account) show
225.625 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .05618 m
.16667 .05618 L
.25 .39991 L
.33333 .55766 L
.41667 .61432 L
.5 .61803 L
.58333 .59547 L
.66667 .56103 L
.75 .52234 L
.83333 .4833 L
.91667 .4458 L
1 .4107 L
s
1 .4107 m
1 .4107 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.0147151 0.97619 0.198654 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -6.68917 0.929693 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .00462 -36.4375 -11.1875 ]
[-0.0125 .00462 0 11.1875 ]
[-0.0125 .09759 -36.4375 -11.1875 ]
[-0.0125 .09759 0 11.1875 ]
[-0.0125 .19055 -36.4375 -11.1875 ]
[-0.0125 .19055 0 11.1875 ]
[-0.0125 .28352 -36.4375 -11.1875 ]
[-0.0125 .28352 0 11.1875 ]
[-0.0125 .37649 -36.4375 -11.1875 ]
[-0.0125 .37649 0 11.1875 ]
[-0.0125 .46946 -36.4375 -11.1875 ]
[-0.0125 .46946 0 11.1875 ]
[-0.0125 .56243 -36.4375 -11.1875 ]
[-0.0125 .56243 0 11.1875 ]
[.5 .63053 -94.0313 0 ]
[.5 .63053 94.0313 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00462 m
.00625 .00462 L
s
gsave
-0.0125 .00462 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.2) show
1.000 setlinewidth
grestore
0 .09759 m
.00625 .09759 L
s
gsave
-0.0125 .09759 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.3) show
1.000 setlinewidth
grestore
0 .19055 m
.00625 .19055 L
s
gsave
-0.0125 .19055 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.4) show
1.000 setlinewidth
grestore
0 .28352 m
.00625 .28352 L
s
gsave
-0.0125 .28352 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.5) show
1.000 setlinewidth
grestore
0 .37649 m
.00625 .37649 L
s
gsave
-0.0125 .37649 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.6) show
1.000 setlinewidth
grestore
0 .46946 m
.00625 .46946 L
s
gsave
-0.0125 .46946 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.7) show
1.000 setlinewidth
grestore
0 .56243 m
.00625 .56243 L
s
gsave
-0.0125 .56243 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02321 m
.00375 .02321 L
s
0 .0418 m
.00375 .0418 L
s
0 .0604 m
.00375 .0604 L
s
0 .07899 m
.00375 .07899 L
s
0 .11618 m
.00375 .11618 L
s
0 .13477 m
.00375 .13477 L
s
0 .15337 m
.00375 .15337 L
s
0 .17196 m
.00375 .17196 L
s
0 .20915 m
.00375 .20915 L
s
0 .22774 m
.00375 .22774 L
s
0 .24634 m
.00375 .24634 L
s
0 .26493 m
.00375 .26493 L
s
0 .30212 m
.00375 .30212 L
s
0 .32071 m
.00375 .32071 L
s
0 .33931 m
.00375 .33931 L
s
0 .3579 m
.00375 .3579 L
s
0 .39509 m
.00375 .39509 L
s
0 .41368 m
.00375 .41368 L
s
0 .43228 m
.00375 .43228 L
s
0 .45087 m
.00375 .45087 L
s
0 .48806 m
.00375 .48806 L
s
0 .50665 m
.00375 .50665 L
s
0 .52524 m
.00375 .52524 L
s
0 .54384 m
.00375 .54384 L
s
0 .58103 m
.00375 .58103 L
s
0 .59962 m
.00375 .59962 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -155.031 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Retained) show
160.563 20.000 moveto
(Earnings) show
247.063 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .61803 m
.16667 .61803 L
.25 .17804 L
.33333 .05731 L
.41667 .05618 L
.5 .09481 L
.58333 .1428 L
.66667 .18955 L
.75 .23204 L
.83333 .26989 L
.91667 .30353 L
1 .33355 L
s
1 .33355 m
1 .33355 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.217048 0.321429 0.400986 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -158.789 2.78255 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .09429 -47.25 -11.1875 ]
[-0.0125 .09429 0 11.1875 ]
[-0.0125 .23342 -58.0625 -11.1875 ]
[-0.0125 .23342 0 11.1875 ]
[-0.0125 .37254 -47.25 -11.1875 ]
[-0.0125 .37254 0 11.1875 ]
[-0.0125 .51167 -58.0625 -11.1875 ]
[-0.0125 .51167 0 11.1875 ]
[.5 .63053 -61.4688 0 ]
[.5 .63053 61.4688 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09429 m
.00625 .09429 L
s
gsave
-0.0125 .09429 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(57.1) show
1.000 setlinewidth
grestore
0 .23342 m
.00625 .23342 L
s
gsave
-0.0125 .23342 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(57.15) show
1.000 setlinewidth
grestore
0 .37254 m
.00625 .37254 L
s
gsave
-0.0125 .37254 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(57.2) show
1.000 setlinewidth
grestore
0 .51167 m
.00625 .51167 L
s
gsave
-0.0125 .51167 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(57.25) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .12211 m
.00375 .12211 L
s
0 .14994 m
.00375 .14994 L
s
0 .17777 m
.00375 .17777 L
s
0 .20559 m
.00375 .20559 L
s
0 .26124 m
.00375 .26124 L
s
0 .28907 m
.00375 .28907 L
s
0 .31689 m
.00375 .31689 L
s
0 .34472 m
.00375 .34472 L
s
0 .40037 m
.00375 .40037 L
s
0 .42819 m
.00375 .42819 L
s
0 .45602 m
.00375 .45602 L
s
0 .48385 m
.00375 .48385 L
s
0 .06646 m
.00375 .06646 L
s
0 .03864 m
.00375 .03864 L
s
0 .01081 m
.00375 .01081 L
s
0 .5395 m
.00375 .5395 L
s
0 .56732 m
.00375 .56732 L
s
0 .59515 m
.00375 .59515 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -122.469 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Consumption) show
181.938 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .55415 m
.16667 .05618 L
.25 .0863 L
.33333 .24833 L
.41667 .39583 L
.5 .4983 L
.58333 .56067 L
.66667 .5949 L
.75 .61143 L
.83333 .6176 L
.91667 .61803 L
1 .61549 L
s
1 .61549 m
1 .61549 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.217048 0.64881 0.400986 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -1284.1 1.39891 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .1009 -36.4375 -11.1875 ]
[-0.0125 .1009 0 11.1875 ]
[-0.0125 .24079 -58.0625 -11.1875 ]
[-0.0125 .24079 0 11.1875 ]
[-0.0125 .38069 -58.0625 -11.1875 ]
[-0.0125 .38069 0 11.1875 ]
[-0.0125 .52058 -58.0625 -11.1875 ]
[-0.0125 .52058 0 11.1875 ]
[.5 .63053 -39.8438 0 ]
[.5 .63053 39.8438 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .1009 m
.00625 .1009 L
s
gsave
-0.0125 .1009 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(918) show
1.000 setlinewidth
grestore
0 .24079 m
.00625 .24079 L
s
gsave
-0.0125 .24079 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(918.1) show
1.000 setlinewidth
grestore
0 .38069 m
.00625 .38069 L
s
gsave
-0.0125 .38069 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(918.2) show
1.000 setlinewidth
grestore
0 .52058 m
.00625 .52058 L
s
gsave
-0.0125 .52058 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(918.3) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .12888 m
.00375 .12888 L
s
0 .15686 m
.00375 .15686 L
s
0 .18484 m
.00375 .18484 L
s
0 .21282 m
.00375 .21282 L
s
0 .26877 m
.00375 .26877 L
s
0 .29675 m
.00375 .29675 L
s
0 .32473 m
.00375 .32473 L
s
0 .35271 m
.00375 .35271 L
s
0 .40866 m
.00375 .40866 L
s
0 .43664 m
.00375 .43664 L
s
0 .46462 m
.00375 .46462 L
s
0 .4926 m
.00375 .4926 L
s
0 .07292 m
.00375 .07292 L
s
0 .04495 m
.00375 .04495 L
s
0 .01697 m
.00375 .01697 L
s
0 .54856 m
.00375 .54856 L
s
0 .57653 m
.00375 .57653 L
s
0 .60451 m
.00375 .60451 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -100.844 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Capital) show
138.688 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .61803 m
.16667 .61803 L
.25 .43808 L
.33333 .25475 L
.41667 .13414 L
.5 .07388 L
.58333 .05618 L
.66667 .06442 L
.75 .08672 L
.83333 .1156 L
.91667 .14665 L
1 .17744 L
s
1 .17744 m
1 .17744 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.217048 0.97619 0.400986 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -47.1893 23.9832 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .05761 -47.25 -11.1875 ]
[-0.0125 .05761 0 11.1875 ]
[-0.0125 .17752 -58.0625 -11.1875 ]
[-0.0125 .17752 0 11.1875 ]
[-0.0125 .29744 -47.25 -11.1875 ]
[-0.0125 .29744 0 11.1875 ]
[-0.0125 .41736 -58.0625 -11.1875 ]
[-0.0125 .41736 0 11.1875 ]
[-0.0125 .53727 -47.25 -11.1875 ]
[-0.0125 .53727 0 11.1875 ]
[.5 .63053 -93.9063 0 ]
[.5 .63053 93.9063 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05761 m
.00625 .05761 L
s
gsave
-0.0125 .05761 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.97) show
1.000 setlinewidth
grestore
0 .17752 m
.00625 .17752 L
s
gsave
-0.0125 .17752 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.975) show
1.000 setlinewidth
grestore
0 .29744 m
.00625 .29744 L
s
gsave
-0.0125 .29744 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.98) show
1.000 setlinewidth
grestore
0 .41736 m
.00625 .41736 L
s
gsave
-0.0125 .41736 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.985) show
1.000 setlinewidth
grestore
0 .53727 m
.00625 .53727 L
s
gsave
-0.0125 .53727 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.99) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08159 m
.00375 .08159 L
s
0 .10557 m
.00375 .10557 L
s
0 .12956 m
.00375 .12956 L
s
0 .15354 m
.00375 .15354 L
s
0 .20151 m
.00375 .20151 L
s
0 .22549 m
.00375 .22549 L
s
0 .24947 m
.00375 .24947 L
s
0 .27346 m
.00375 .27346 L
s
0 .32142 m
.00375 .32142 L
s
0 .34541 m
.00375 .34541 L
s
0 .36939 m
.00375 .36939 L
s
0 .39337 m
.00375 .39337 L
s
0 .44134 m
.00375 .44134 L
s
0 .46532 m
.00375 .46532 L
s
0 .4893 m
.00375 .4893 L
s
0 .51329 m
.00375 .51329 L
s
0 .03362 m
.00375 .03362 L
s
0 .00964 m
.00375 .00964 L
s
0 .56125 m
.00375 .56125 L
s
0 .58524 m
.00375 .58524 L
s
0 .60922 m
.00375 .60922 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -154.906 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Return) show
138.688 20.000 moveto
(on) show
171.125 20.000 moveto
(Capital) show
246.813 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .57326 m
.16667 .05618 L
.25 .19561 L
.33333 .34924 L
.41667 .46384 L
.5 .53728 L
.58333 .58007 L
.66667 .60293 L
.75 .61378 L
.83333 .61776 L
.91667 .61803 L
1 .6164 L
s
1 .6164 m
1 .6164 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.41938 0.321429 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -114.305 1.61679 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .00248 -47.25 -11.1875 ]
[-0.0125 .00248 0 11.1875 ]
[-0.0125 .08332 -58.0625 -11.1875 ]
[-0.0125 .08332 0 11.1875 ]
[-0.0125 .16416 -47.25 -11.1875 ]
[-0.0125 .16416 0 11.1875 ]
[-0.0125 .245 -58.0625 -11.1875 ]
[-0.0125 .245 0 11.1875 ]
[-0.0125 .32584 -47.25 -11.1875 ]
[-0.0125 .32584 0 11.1875 ]
[-0.0125 .40668 -58.0625 -11.1875 ]
[-0.0125 .40668 0 11.1875 ]
[-0.0125 .48752 -25.625 -11.1875 ]
[-0.0125 .48752 0 11.1875 ]
[-0.0125 .56836 -58.0625 -11.1875 ]
[-0.0125 .56836 0 11.1875 ]
[.5 .63053 -34.4375 0 ]
[.5 .63053 34.4375 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00248 m
.00625 .00248 L
s
gsave
-0.0125 .00248 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70.7) show
1.000 setlinewidth
grestore
0 .08332 m
.00625 .08332 L
s
gsave
-0.0125 .08332 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70.75) show
1.000 setlinewidth
grestore
0 .16416 m
.00625 .16416 L
s
gsave
-0.0125 .16416 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70.8) show
1.000 setlinewidth
grestore
0 .245 m
.00625 .245 L
s
gsave
-0.0125 .245 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70.85) show
1.000 setlinewidth
grestore
0 .32584 m
.00625 .32584 L
s
gsave
-0.0125 .32584 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70.9) show
1.000 setlinewidth
grestore
0 .40668 m
.00625 .40668 L
s
gsave
-0.0125 .40668 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70.95) show
1.000 setlinewidth
grestore
0 .48752 m
.00625 .48752 L
s
gsave
-0.0125 .48752 -86.625 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(71) show
1.000 setlinewidth
grestore
0 .56836 m
.00625 .56836 L
s
gsave
-0.0125 .56836 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(71.05) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01865 m
.00375 .01865 L
s
0 .03482 m
.00375 .03482 L
s
0 .05098 m
.00375 .05098 L
s
0 .06715 m
.00375 .06715 L
s
0 .09949 m
.00375 .09949 L
s
0 .11566 m
.00375 .11566 L
s
0 .13182 m
.00375 .13182 L
s
0 .14799 m
.00375 .14799 L
s
0 .18033 m
.00375 .18033 L
s
0 .1965 m
.00375 .1965 L
s
0 .21266 m
.00375 .21266 L
s
0 .22883 m
.00375 .22883 L
s
0 .26117 m
.00375 .26117 L
s
0 .27734 m
.00375 .27734 L
s
0 .2935 m
.00375 .2935 L
s
0 .30967 m
.00375 .30967 L
s
0 .34201 m
.00375 .34201 L
s
0 .35818 m
.00375 .35818 L
s
0 .37434 m
.00375 .37434 L
s
0 .39051 m
.00375 .39051 L
s
0 .42285 m
.00375 .42285 L
s
0 .43901 m
.00375 .43901 L
s
0 .45518 m
.00375 .45518 L
s
0 .47135 m
.00375 .47135 L
s
0 .50369 m
.00375 .50369 L
s
0 .51985 m
.00375 .51985 L
s
0 .53602 m
.00375 .53602 L
s
0 .55219 m
.00375 .55219 L
s
0 .58453 m
.00375 .58453 L
s
0 .60069 m
.00375 .60069 L
s
0 .61686 m
.00375 .61686 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -95.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Output) show
127.875 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .5535 m
.16667 .05618 L
.25 .06665 L
.33333 .23011 L
.41667 .38348 L
.5 .49117 L
.58333 .55707 L
.66667 .59336 L
.75 .61095 L
.83333 .61754 L
.91667 .61803 L
1 .61535 L
s
1 .61535 m
1 .61535 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.41938 0.64881 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.795569 0.4482 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .01119 -36.4375 -11.1875 ]
[-0.0125 .01119 0 11.1875 ]
[-0.0125 .10083 -14.8125 -11.1875 ]
[-0.0125 .10083 0 11.1875 ]
[-0.0125 .19047 -36.4375 -11.1875 ]
[-0.0125 .19047 0 11.1875 ]
[-0.0125 .28011 -36.4375 -11.1875 ]
[-0.0125 .28011 0 11.1875 ]
[-0.0125 .36975 -36.4375 -11.1875 ]
[-0.0125 .36975 0 11.1875 ]
[-0.0125 .45939 -36.4375 -11.1875 ]
[-0.0125 .45939 0 11.1875 ]
[-0.0125 .54903 -14.8125 -11.1875 ]
[-0.0125 .54903 0 11.1875 ]
[.5 .63053 -72.2813 0 ]
[.5 .63053 72.2813 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01119 m
.00625 .01119 L
s
gsave
-0.0125 .01119 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
1.000 setlinewidth
grestore
0 .10083 m
.00625 .10083 L
s
gsave
-0.0125 .10083 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .19047 m
.00625 .19047 L
s
gsave
-0.0125 .19047 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
1.000 setlinewidth
grestore
0 .28011 m
.00625 .28011 L
s
gsave
-0.0125 .28011 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
1.000 setlinewidth
grestore
0 .36975 m
.00625 .36975 L
s
gsave
-0.0125 .36975 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
1.000 setlinewidth
grestore
0 .45939 m
.00625 .45939 L
s
gsave
-0.0125 .45939 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
1.000 setlinewidth
grestore
0 .54903 m
.00625 .54903 L
s
gsave
-0.0125 .54903 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0336 m
.00375 .0336 L
s
0 .05601 m
.00375 .05601 L
s
0 .07842 m
.00375 .07842 L
s
0 .12324 m
.00375 .12324 L
s
0 .14565 m
.00375 .14565 L
s
0 .16806 m
.00375 .16806 L
s
0 .21288 m
.00375 .21288 L
s
0 .23529 m
.00375 .23529 L
s
0 .2577 m
.00375 .2577 L
s
0 .30252 m
.00375 .30252 L
s
0 .32493 m
.00375 .32493 L
s
0 .34734 m
.00375 .34734 L
s
0 .39216 m
.00375 .39216 L
s
0 .41457 m
.00375 .41457 L
s
0 .43698 m
.00375 .43698 L
s
0 .4818 m
.00375 .4818 L
s
0 .50421 m
.00375 .50421 L
s
0 .52662 m
.00375 .52662 L
s
0 .57144 m
.00375 .57144 L
s
0 .59385 m
.00375 .59385 L
s
0 .61626 m
.00375 .61626 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -133.281 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Interest) show
160.313 20.000 moveto
(Rate) show
203.563 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .10981 m
.16667 .59711 L
.25 .61803 L
.33333 .45614 L
.41667 .29919 L
.5 .18895 L
.58333 .12155 L
.66667 .08416 L
.75 .06552 L
.83333 .05783 L
.91667 .05618 L
1 .0577 L
s
1 .0577 m
1 .0577 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.41938 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.350182 0.735375 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .09104 -36.4375 -11.1875 ]
[-0.0125 .09104 0 11.1875 ]
[-0.0125 .23812 -36.4375 -11.1875 ]
[-0.0125 .23812 0 11.1875 ]
[-0.0125 .38519 -14.8125 -11.1875 ]
[-0.0125 .38519 0 11.1875 ]
[-0.0125 .53227 -36.4375 -11.1875 ]
[-0.0125 .53227 0 11.1875 ]
[.5 .63053 -77.6875 0 ]
[.5 .63053 77.6875 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09104 m
.00625 .09104 L
s
gsave
-0.0125 .09104 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .23812 m
.00625 .23812 L
s
gsave
-0.0125 .23812 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .38519 m
.00625 .38519 L
s
gsave
-0.0125 .38519 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .53227 m
.00625 .53227 L
s
gsave
-0.0125 .53227 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .12781 m
.00375 .12781 L
s
0 .16458 m
.00375 .16458 L
s
0 .20135 m
.00375 .20135 L
s
0 .27489 m
.00375 .27489 L
s
0 .31166 m
.00375 .31166 L
s
0 .34842 m
.00375 .34842 L
s
0 .42196 m
.00375 .42196 L
s
0 .45873 m
.00375 .45873 L
s
0 .4955 m
.00375 .4955 L
s
0 .05427 m
.00375 .05427 L
s
0 .01751 m
.00375 .01751 L
s
0 .56904 m
.00375 .56904 L
s
0 .60581 m
.00375 .60581 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -138.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Inflation) show
171.125 20.000 moveto
(Rate) show
214.375 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .38519 m
.16667 .61803 L
.25 .16629 L
.33333 .05618 L
.41667 .12066 L
.5 .20903 L
.58333 .27954 L
.66667 .32696 L
.75 .35617 L
.83333 .37312 L
.91667 .38248 L
1 .38738 L
s
1 .38738 m
1 .38738 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{723, 446.688},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 722}, {445.688, 0}} -> {-0.0768893, -0.0463623, \
0.00436812, 0.00436812}, {{17.5625, 232.188}, {435.063, 302.375}} -> \
{-9.47118, 45.4053, 0.107837, 0.00285791}, {{253.688, 468.313}, {435.063, \
302.375}} -> {-27.1702, 46.2672, 0.0877491, 0.00696402}, {{489.75, 704.375}, \
{435.063, 302.375}} -> {-46.9398, 6.92202, 0.0877491, 0.00786542}, {{17.5625, \
232.188}, {289.125, 156.5}} -> {-7.0272, 56.5909, 0.0878116, 0.00262983}, \
{{253.688, 468.313}, {289.125, 156.5}} -> {-27.7617, 916.984, 0.0878116, \
0.00523095}, {{489.75, 704.375}, {289.125, 156.5}} -> {-53.921, 1.90447, \
0.0981557, 0.000341057}, {{17.5625, 232.188}, {143.25, 10.5625}} -> {-7.018, \
69.2219, 0.0877491, 0.0045228}, {{253.688, 468.313}, {143.25, 10.5625}} -> \
{-26.789, -3.55221, 0.0877491, 0.0163151}, {{489.75, 704.375}, {143.25, \
10.5625}} -> {-47.5033, -2.77068, 0.0877491, 0.0099438}}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", "\"\<c:/temp\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<imp_cap_cost.eps\>\"", ",", "plot", ",", "\"\<EPS\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "1000"}]}], "]"}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing the Autocorrelation Function", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"nsim", "=", "40000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ndist", "=", 
    RowBox[{"NormalDistribution", "[", 
     RowBox[{"0", ",", "1"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssim2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"nsim", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dsim2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"nsim", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xsim2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"nsim", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ksim2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"nsim", "+", "1"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"ysim2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"nsim", "+", "1"}]}], "}"}]}], "]"}]}], ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ssim2", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "=", 
   RowBox[{"sbar", "/.", "ssresult"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dsim2", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "=", 
   RowBox[{"dbar", "/.", "ssresult"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ksim2", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "=", 
   RowBox[{"dbar", "/.", "ssresult"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"xsim2", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "=", "xmean"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"j", "=", "1"}], ",", 
   RowBox[{"j", "<", 
    RowBox[{"nsim", "+", "1"}]}], ",", 
   RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"simrule", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "\[Rule]", 
        RowBox[{"ssim2", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], ",", 
       RowBox[{"d", "\[Rule]", 
        RowBox[{"dsim2", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], ",", 
       RowBox[{"k", "\[Rule]", 
        RowBox[{"ksim2", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], ",", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{"xsim2", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], ",", 
       RowBox[{"\[Sigma]", "\[Rule]", "0.006"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ysim2", "[", 
      RowBox[{"[", "j", "]"}], "]"}], "=", 
     RowBox[{"First", "@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"csimfun", "+", "zsimfun"}], "/.", "simrule"}], "}"}], 
       "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ssim2", "[", 
      RowBox[{"[", 
       RowBox[{"j", "+", "1"}], "]"}], "]"}], "=", 
     RowBox[{"First", "@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{"ssimfun", "/.", "simrule"}], "}"}], "]"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"dsim2", "[", 
      RowBox[{"[", 
       RowBox[{"j", "+", "1"}], "]"}], "]"}], "=", 
     RowBox[{"First", "@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{"dsimfun", "/.", "simrule"}], "}"}], "]"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xsim2", "[", 
      RowBox[{"[", 
       RowBox[{"j", "+", "1"}], "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"xconst", "+", 
        RowBox[{"\[Rho]", " ", 
         RowBox[{"xsim2", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], "+", 
        RowBox[{"\[Sigma]", " ", 
         RowBox[{"Random", "[", "ndist", "]"}]}]}], "/.", "param"}], "/.", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", "\[Rule]", "0.006"}], "}"}]}]}], ";"}]}], 
  "\[IndentingNewLine]", "]"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"autocorrtab", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Correlation", "[", 
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"ysim2", ",", 
        RowBox[{"-", "j"}]}], "]"}], ",", 
      RowBox[{"Drop", "[", 
       RowBox[{"ysim2", ",", "j"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "6"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.7275680167071286`", ",", "0.42186242393327505`", ",", 
   "0.1830094428479949`", ",", "0.029406583751941644`", ",", 
   RowBox[{"-", "0.05539773690300432`"}], ",", 
   RowBox[{"-", "0.09690873130404902`"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{891, 662},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (April 11, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 34, 0, 101, "Title"],
Cell[617, 24, 57, 0, 56, "Subtitle"],
Cell[677, 26, 457, 9, 125, "Text"],
Cell[1137, 37, 416, 8, 112, "Input"],
Cell[CellGroupData[{
Cell[1578, 49, 33, 0, 70, "Section"],
Cell[1614, 51, 1216, 34, 132, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2867, 90, 38, 0, 70, "Section"],
Cell[2908, 92, 3217, 112, 186, "Input"],
Cell[6128, 206, 118, 3, 30, "Text"],
Cell[6249, 211, 4861, 160, 398, "Input"],
Cell[11113, 373, 1881, 67, 172, "Input"],
Cell[12997, 442, 222, 4, 49, "Text"],
Cell[13222, 448, 1670, 50, 212, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14929, 503, 51, 0, 70, "Section"],
Cell[CellGroupData[{
Cell[15005, 507, 473, 14, 72, "Input"],
Cell[15481, 523, 334, 11, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15852, 539, 8782, 265, 897, "Input"],
Cell[24637, 806, 297, 6, 31, "Output"],
Cell[24937, 814, 318, 7, 31, "Output"],
Cell[25258, 823, 1164, 29, 55, "Output"],
Cell[26425, 854, 65, 1, 31, "Output"],
Cell[26493, 857, 64, 1, 31, "Output"],
Cell[26560, 860, 47, 0, 23, "Print"],
Cell[26610, 862, 45, 0, 31, "Output"],
Cell[26658, 864, 45, 0, 23, "Print"],
Cell[26706, 866, 45, 0, 31, "Output"],
Cell[26754, 868, 36, 0, 23, "Print"],
Cell[26793, 870, 47, 0, 31, "Output"],
Cell[26843, 872, 40, 0, 23, "Print"],
Cell[26886, 874, 46, 0, 31, "Output"],
Cell[26935, 876, 38, 0, 23, "Print"],
Cell[26976, 878, 44, 0, 31, "Output"],
Cell[27023, 880, 51, 0, 23, "Print"],
Cell[27077, 882, 48, 0, 31, "Output"],
Cell[27128, 884, 44, 0, 23, "Print"],
Cell[27175, 886, 46, 0, 31, "Output"],
Cell[27224, 888, 76, 0, 23, "Print"],
Cell[27303, 890, 47, 0, 31, "Output"],
Cell[27353, 892, 45, 0, 23, "Print"],
Cell[27401, 894, 50, 0, 31, "Output"],
Cell[27454, 896, 48, 0, 23, "Print"],
Cell[27505, 898, 51, 0, 31, "Output"],
Cell[27559, 900, 46, 0, 23, "Print"],
Cell[27608, 902, 30, 0, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[27687, 908, 39, 0, 70, "Section"],
Cell[CellGroupData[{
Cell[27751, 912, 771, 21, 119, "Input"],
Cell[28525, 935, 88, 2, 31, "Output"]
}, Open  ]],
Cell[28628, 940, 278, 5, 68, "Text"],
Cell[28909, 947, 940, 30, 92, "Input"],
Cell[29852, 979, 152, 3, 49, "Text"],
Cell[30007, 984, 199, 7, 31, "Input"],
Cell[30209, 993, 271, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[30505, 1002, 252, 8, 31, "Input"],
Cell[30760, 1012, 512, 9, 77, "Message"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31309, 1026, 68, 1, 31, "Input"],
Cell[31380, 1029, 28, 0, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31445, 1034, 36, 0, 31, "Input"],
Cell[31484, 1036, 68145, 2011, 1336, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[99666, 3052, 117, 3, 31, "Input"],
Cell[99786, 3057, 7116, 222, 156, "Output"]
}, Open  ]],
Cell[106917, 3282, 1072, 31, 92, "Input"],
Cell[CellGroupData[{
Cell[108014, 3317, 34, 0, 31, "Input"],
Cell[108051, 3319, 28305, 887, 576, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[136405, 4212, 39, 0, 70, "Section"],
Cell[136447, 4214, 174, 3, 49, "Text"],
Cell[136624, 4219, 561, 18, 52, "Input"],
Cell[137188, 4239, 95, 2, 30, "Text"],
Cell[137286, 4243, 6518, 195, 512, "Input"],
Cell[143807, 4440, 2987, 82, 332, "Input"],
Cell[CellGroupData[{
Cell[146819, 4526, 20228, 591, 1297, "Input"],
Cell[CellGroupData[{
Cell[167072, 5121, 11722, 553, 186, 9172, 509, "GraphicsData", "PostScript", \
"Graphics"],
Cell[178797, 5676, 9425, 435, 186, 7058, 394, "GraphicsData", "PostScript", \
"Graphics"],
Cell[188225, 6113, 10955, 505, 186, 8483, 462, "GraphicsData", "PostScript", \
"Graphics"],
Cell[199183, 6620, 9181, 420, 186, 6949, 381, "GraphicsData", "PostScript", \
"Graphics"],
Cell[208367, 7042, 11687, 545, 186, 8814, 495, "GraphicsData", "PostScript", \
"Graphics"],
Cell[220057, 7589, 9966, 473, 186, 7693, 433, "GraphicsData", "PostScript", \
"Graphics"],
Cell[230026, 8064, 10994, 518, 186, 8639, 477, "GraphicsData", "PostScript", \
"Graphics"],
Cell[241023, 8584, 9233, 432, 186, 7057, 394, "GraphicsData", "PostScript", \
"Graphics"],
Cell[250259, 9018, 10214, 471, 186, 7646, 426, "GraphicsData", "PostScript", \
"Graphics"],
Cell[260476, 9491, 84076, 4137, 455, 70607, 3917, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[344579, 13632, 302, 7, 52, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[344918, 13644, 57, 0, 70, "Section"],
Cell[344978, 13646, 1305, 45, 172, "Input"],
Cell[346286, 13693, 2882, 87, 252, "Input"],
Cell[CellGroupData[{
Cell[349193, 13784, 390, 12, 31, "Input"],
Cell[349586, 13798, 271, 6, 31, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

