(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.4' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    212567,       8631]
NotebookOptionsPosition[    209121,       8520]
NotebookOutlinePosition[    209463,       8535]
CellTagsIndexPosition[    209420,       8532]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Show Me the Money", "Title"],

Cell["Computation with Perturbation Methods", "Subtitle"],

Cell["\<\
Log utility and quadratic adjustment are assumed. Endogenous state variables \
are d and s, exogenous state is x. x is Normal with unit variance.

The underlying theory for the computations can be found in Judd, \
Schmitt-Grohe and Uribe, and especially Fernandez-Villaverde. Some of the \
code is based on Jesus' code for his computational-method comparison paper. \
\>", "Text",
 CellChangeTimes->{{3.689789196664667*^9, 3.6897891976627665`*^9}}],

Cell[BoxData[{
 RowBox[{"<<", "Statistics`NormalDistribution`"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Graphics`MultipleListPlot`"}], "\[IndentingNewLine]", 
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell1"}], "]"}]}], "Input"],

Cell[CellGroupData[{

Cell["Set Parameters", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"param", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Psi]", "\[Rule]", "0.24"}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", "0.99"}], ",", 
     RowBox[{"ad1", "\[Rule]", "10"}], ",", 
     RowBox[{"ad2", "\[Rule]", 
      RowBox[{"-", "0.004255412342697785"}]}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", " ", "0.14"}], ",", 
     RowBox[{"\[Rho]", "\[Rule]", ".5"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmean", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xconst", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Rho]"}], ")"}], " ", "xmean"}], "/.", "param"}], "//",
     "Chop"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"orderexpansion", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"myvariables", "=", 
   RowBox[{"{", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "}"}]}], 
  ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Model Equations", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cond1a", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"1", "-", "\[Psi]"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "l"}], ")"}], "w"}]], "-", 
    RowBox[{"\[Beta]", 
     RowBox[{"(", 
      FractionBox["\[Psi]", 
       RowBox[{"c2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "x"}], ")"}], " ", "p2"}]], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond2a", "=", 
   RowBox[{
    FractionBox["\[Psi]", 
     RowBox[{"c", " ", "p"}]], "+", 
    RowBox[{
     FractionBox[
      RowBox[{"1", "-", "\[Psi]"}], 
      RowBox[{"1", "-", "l"}]], 
     RowBox[{"(", 
      RowBox[{"2", "  ", "ad1", " ", 
       RowBox[{"(", 
        RowBox[{"ad2", "+", "i"}], ")"}]}], ")"}]}], "-", 
    RowBox[{"\[Beta]", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["\[Psi]", 
        RowBox[{"c2", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "x"}], ")"}], " ", "p2"}]], "+", 
       RowBox[{
        FractionBox[
         RowBox[{"1", "-", "\[Psi]"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "x"}], ")"}], 
          RowBox[{"(", 
           RowBox[{"1", "-", "l2"}], ")"}]}]], 
        RowBox[{"(", 
         RowBox[{
          FractionBox["r2", "w2"], "+", 
          RowBox[{"2", " ", "ad1", " ", 
           RowBox[{"(", 
            RowBox[{"ad2", "+", "i2"}], ")"}]}]}], ")"}]}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond3a", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "x"}], ")"}], " ", "d2"}], "-", 
    RowBox[{"(", 
     RowBox[{"d", "+", 
      RowBox[{"r", " ", "s"}], " ", "+", 
      RowBox[{"\[Lambda]", " ", "pi"}], " ", "+", 
      RowBox[{"w", " ", "la"}], " ", "-", "i", " ", "-", 
      RowBox[{"p", " ", "c"}]}], ")"}]}]}], " ", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond4a", "=", 
   RowBox[{"i", "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "x"}], ")"}], " ", "s2"}], "-", "s"}], ")"}]}]}], 
  ";"}]}], "Input"],

Cell["\<\
The replacement rules arising from the remaining model equations (this should \
be documented)\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"rep0", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"l", "\[Rule]", " ", 
       RowBox[{"la", "+", "lb"}]}], ",", 
      RowBox[{"l2", "\[Rule]", " ", 
       RowBox[{"la2", "+", "lb2"}]}]}], "}"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Adding", " ", "up", " ", "for", " ", "labor"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rep0b", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"lb", "\[Rule]", " ", 
       RowBox[{"ad1", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"ad2", "+", "i"}], ")"}], "^", "2"}]}]}], ",", 
      RowBox[{"lb2", "\[Rule]", " ", 
       RowBox[{"ad1", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"ad2", "+", "i2"}], ")"}], "^", "2"}]}]}]}], "}"}]}], ";"}],
   " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Adjustment", " ", "cost"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rep1", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"la", "\[Rule]", "c"}], ",", 
      RowBox[{"la2", "\[Rule]", "c2"}]}], "}"}]}], ";"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{"Market", " ", 
    RowBox[{"clearing", "/", "production"}], " ", "function"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rep2", "=", 
    RowBox[{"{", 
     RowBox[{"pi", "\[Rule]", " ", 
      RowBox[{"1", "-", "d", "-", "s"}]}], "}"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Market", " ", "clearing", " ", "asset", " ", "market"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep2b", "=", 
   RowBox[{"{", 
    RowBox[{"pi2", "\[Rule]", " ", 
     RowBox[{"1", "-", "d2", "-", "s2"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rep3", "=", 
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"d", "-", "i"}], ")"}], "/", "c"}]}], "}"}]}], ";"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{"CIA", " ", "constraint"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep3b", "=", 
   RowBox[{"{", 
    RowBox[{"p2", "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"d2", "-", "i2"}], ")"}], "/", "c2"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rep4", "=", 
    RowBox[{"{", 
     RowBox[{"b", "->", 
      RowBox[{"1", "+", "x", "-", 
       RowBox[{"(", 
        RowBox[{"d", "-", "i"}], ")"}]}]}], "}"}]}], ";"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{"Reserve", " ", "requirement"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rep5", "=", 
    RowBox[{"{", 
     RowBox[{"w", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "x", "-", "d"}], ")"}], "/", "c"}]}], "}"}]}], 
   ";"}], "   ", 
  RowBox[{"(*", " ", 
   RowBox[{"Wage", " ", "bill", " ", "equals", " ", "loan"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep5b", "=", 
   RowBox[{"{", 
    RowBox[{"w2", "\[Rule]", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "x2", "-", "d2"}], ")"}], "/", "c2"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rep6", "=", 
    RowBox[{"{", 
     RowBox[{"r", "\[Rule]", 
      RowBox[{
       RowBox[{"d", "/", 
        RowBox[{"(", 
         RowBox[{"1", "+", "x", "-", "d"}], ")"}]}], "-", "1"}]}], "}"}]}], 
   ";"}], "    ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Firm", " ", "FOC", " ", "goods", " ", "and", " ", "loan", " ", "market", 
    " ", "clearing"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep6b", "=", 
   RowBox[{"{", 
    RowBox[{"r2", "\[Rule]", 
     RowBox[{
      RowBox[{"d2", "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", "x2", "-", "d2"}], ")"}]}], "-", "1"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"repall", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
    "rep1", ",", "rep2", ",", "rep2b", ",", "rep3", ",", "rep3b", ",", "rep4",
      ",", "rep5", ",", "rep5b", ",", "rep6", ",", "rep6b"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{""}]}], "Input"],

Cell["Rework cond2 so that it will be easier to take expectations", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cond1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"cond1a", "/.", "rep0"}], "/.", "rep0b"}], "/.", "repall"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"cond2a", "/.", "rep0"}], "/.", "rep0b"}], "/.", "repall"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond3", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"cond3a", "/.", "rep0"}], "/.", "rep0b"}], "/.", "repall"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cond4", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"cond4a", "/.", "rep0"}], "/.", "rep0b"}], "/.", "repall"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"F", "=", 
   RowBox[{"{", 
    RowBox[{"cond1", ",", "cond2", ",", "cond3", ",", "cond4"}], "}"}]}], 
  ";"}]}], "Input"],

Cell["\<\
Now replace the decision variables by the functions that we are going to \
compute. Notation is moving towards Schmitt-Grohe and Uribe. g are the \
policies for jumps, h are the policies for states.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"c", "=", 
   RowBox[{"g1", "[", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"i", "=", 
   RowBox[{"g2", "[", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"s2", "=", 
   RowBox[{"h1", "[", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d2", "=", 
   RowBox[{"h2", "[", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2", "=", 
   RowBox[{"g1", "[", 
    RowBox[{"s2", ",", "d2", ",", "x2", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"i2", "=", 
   RowBox[{"g2", "[", 
    RowBox[{"s2", ",", "d2", ",", "x2", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x2", "=", 
   RowBox[{"xconst", "+", 
    RowBox[{"\[Rho]", " ", "*", "x"}], "+", 
    RowBox[{"\[Sigma]", "*", "\[Epsilon]"}]}]}], ";"}]}], "Input"],

Cell["\<\
In terms of number of equations and unknowns, this is fine now. s and d are \
endogenous states, c and i are jumps. x is chosen by nature.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The  Non-Stochastic Steady State", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ssfunrule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"h1", "[", "__", "]"}], "\[Rule]", " ", "s"}], ",", 
     RowBox[{
      RowBox[{"h2", "[", "__", "]"}], "\[Rule]", " ", "d"}], ",", " ", 
     RowBox[{
      RowBox[{"g1", "[", "__", "]"}], "\[Rule]", " ", "cbar"}], ",", 
     RowBox[{
      RowBox[{"g2", "[", "__", "]"}], "\[Rule]", "ibar"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssvalrule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s", "\[Rule]", "sbar"}], ",", 
     RowBox[{"d", "\[Rule]", "dbar"}], ",", 
     RowBox[{"x", "\[Rule]", "xmean"}], ",", 
     RowBox[{"ibar", "\[Rule]", 
      RowBox[{"xmean", " ", "sbar"}]}], ",", 
     RowBox[{"\[Sigma]", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sscond", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"F", "[", 
       RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"ssresult", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"sscond", "/.", "param"}], "/.", "ssfunrule"}], "/.", 
     "ssvalrule"}], ",", 
    RowBox[{"{", 
     RowBox[{"sbar", ",", "dbar", ",", "cbar"}], "}"}]}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", 
      RowBox[{"-", "62.13956510400305`"}]}], ",", 
     RowBox[{"sbar", "\[Rule]", 
      RowBox[{"-", "3312.5678332766006`"}]}], ",", 
     RowBox[{"dbar", "\[Rule]", "13.80456546966195`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", 
      RowBox[{"-", "1.6189817923755392`"}]}], ",", 
     RowBox[{"sbar", "\[Rule]", "65.76283447639177`"}], ",", 
     RowBox[{"dbar", "\[Rule]", "0.5380648620494763`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", "0.00023333982238484574`"}], ",", 
     RowBox[{"sbar", "\[Rule]", "0.014684929406639766`"}], ",", 
     RowBox[{"dbar", "\[Rule]", "1.0099999999999976`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", "0.23403100914108968`"}], ",", 
     RowBox[{"sbar", "\[Rule]", "0.43710610186951177`"}], ",", 
     RowBox[{"dbar", "\[Rule]", "0.5101930487334576`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", "0.2800035477392976`"}], ",", 
     RowBox[{"sbar", "\[Rule]", "16.87238152846719`"}], ",", 
     RowBox[{"dbar", "\[Rule]", "0.53814675902888`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", "0.9996714908039447`"}], ",", 
     RowBox[{"sbar", "\[Rule]", "0.9986997140746602`"}], ",", 
     RowBox[{"dbar", "\[Rule]", "0.009986858398607612`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", "12.221116446696145`"}], ",", 
     RowBox[{"sbar", "\[Rule]", "769.2529993129914`"}], ",", 
     RowBox[{"dbar", "\[Rule]", "0.5380397168370926`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", "93.20934765600457`"}], ",", 
     RowBox[{"sbar", "\[Rule]", "3312.5678332766006`"}], ",", 
     RowBox[{"dbar", "\[Rule]", 
      RowBox[{"-", "13.05981979991433`"}]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ssresult", "=", 
  RowBox[{"ssresult", "[", 
   RowBox[{"[", "4", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"cbar", "\[Rule]", "0.23403100914108968`"}], ",", 
   RowBox[{"sbar", "\[Rule]", "0.43710610186951177`"}], ",", 
   RowBox[{"dbar", "\[Rule]", "0.5101930487334576`"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"varrule", "=", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"s", "\[Rule]", "sbar"}], "/.", "ssresult"}], ",", 
      RowBox[{
       RowBox[{"d", "\[Rule]", "dbar"}], "/.", "ssresult"}], ",", 
      RowBox[{"x", "\[Rule]", "xmean"}], ",", 
      RowBox[{"\[Sigma]", "\[Rule]", "0"}]}], "}"}], "]"}], "//", 
   "Chop"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"s", "\[Rule]", "0.43710610186951177`"}], ",", 
   RowBox[{"d", "\[Rule]", "0.5101930487334576`"}], ",", 
   RowBox[{"x", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"\[Sigma]", "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
The role of derivrule is to suppress the arguments of all the derivatives. \
The : is a general pattern operator here. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"derivrule", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"d", ":", 
     RowBox[{
      RowBox[{
       RowBox[{"Derivative", "[", "__", "]"}], "[", "__", "]"}], "[", "__", 
      "]"}]}], "\[RuleDelayed]", "  ", 
    RowBox[{"d", "[", 
     RowBox[{"[", "0", "]"}], "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"d", ":", 
    RowBox[{
     SuperscriptBox["__", 
      TagBox[
       RowBox[{"(", "__", ")"}],
       Derivative],
      MultilineFunction->None], "[", "__", "]"}]}], "\[RuleDelayed]", 
   RowBox[{"d", "\[LeftDoubleBracket]", "0", "\[RightDoubleBracket]"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"unirule", "=", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"ssfunrule", "/.", "varrule"}], "/.", "ssvalrule"}], "/.", 
       "ssresult"}], ",", "varrule", ",", "derivrule"}], "]"}], "]"}], "//", 
   "Chop"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"h1", "[", "__", "]"}], "\[Rule]", "0.43710610186951177`"}], ",", 
   RowBox[{
    RowBox[{"h2", "[", "__", "]"}], "\[Rule]", "0.5101930487334576`"}], ",", 
   RowBox[{
    RowBox[{"g1", "[", "__", "]"}], "\[Rule]", "0.23403100914108968`"}], ",", 
   RowBox[{
    RowBox[{"g2", "[", "__", "]"}], "\[Rule]", "0.004371061018695117`"}], ",", 
   RowBox[{"s", "\[Rule]", "0.43710610186951177`"}], ",", 
   RowBox[{"d", "\[Rule]", "0.5101930487334576`"}], ",", 
   RowBox[{"x", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"\[Sigma]", "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"d", ":", 
     RowBox[{
      SuperscriptBox["__", 
       TagBox[
        RowBox[{"(", "__", ")"}],
        Derivative],
       MultilineFunction->None], "[", "__", "]"}]}], "\[RuleDelayed]", 
    RowBox[{"d", "\[LeftDoubleBracket]", "0", "\[RightDoubleBracket]"}]}]}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Taylor Expansion", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"epsrule", "=", 
  RowBox[{"Append", "[", 
   RowBox[{
    RowBox[{"Reverse", "@", 
     RowBox[{"Thread", "[", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{"Range", "[", 
         RowBox[{"2", ",", "orderexpansion", ",", "2"}], "]"}]], "->", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"ExpectedValue", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox["#", "j"], "&"}], ",", 
           RowBox[{"NormalDistribution", "[", 
            RowBox[{"0", ",", "1"}], "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "2", ",", "orderexpansion", ",", "2"}], "}"}]}], 
        "]"}]}], "]"}]}], ",", 
    RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Epsilon]", "2"], "\[Rule]", "1"}], ",", 
   RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Notice that all partial derivatives are taken below, even though some \
cross-derivatives are equal and could be left out. This slows computation, \
but as long as computation time is not an issue, it makes it easier to \
simulate from the outcome later.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Fd", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Fd", "[", 
    RowBox[{"[", "0", "]"}], "]"}], "=", "F"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Fd", "[", 
      RowBox[{"[", "j", "]"}], "]"}], "=", 
     RowBox[{"Union", "[", 
      RowBox[{"Expand", "[", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Outer", "[", 
         RowBox[{"D", ",", 
          RowBox[{"{", 
           RowBox[{"Fd", "[", 
            RowBox[{"[", 
             RowBox[{"j", "-", "1"}], "]"}], "]"}], "}"}], ",", 
          "myvariables"}], "]"}], "]"}], "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "orderexpansion"}], "}"}]}], "]"}], 
  ";"}]}], "Input"],

Cell["\<\
Now we plug in everything that is known, that is, we evaluate the derivative \
at the steady state and at calibrated parameters.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dF", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Fd", "/.", "param"}], "/.", "unirule"}], "/.", "epsrule"}], "//",
     "Chop"}]}], ";"}]], "Input"],

Cell["\<\
Now we simply need to solve the resulting system. In the first step, we also \
have to pick the correct solution. Since the system is quadratic, there may \
be more than one. How to pick this is not obvious; check the result manually \
to be sure.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"firstorder", "=", 
  RowBox[{
   RowBox[{"N", "[", 
    RowBox[{"Solve", "[", 
     RowBox[{"Thread", "[", 
      RowBox[{
       RowBox[{"First", "[", "dF", "]"}], "\[Equal]", "0"}], "]"}], "]"}], 
    "]"}], "//", "Chop"}]}], "\[IndentingNewLine]", 
 RowBox[{"solution", "=", 
  RowBox[{"First", "@", 
   RowBox[{"Select", "[", 
    RowBox[{"firstorder", ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "]"}], "[", "g1", 
          "]"}], "]"}], "<", "1"}], "/.", "#"}], "&"}]}], "]"}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "5.866068768876643`*^6"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "16035.197663318584`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "15876.000551699717`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "4571.912023685919`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1030.8260172886203`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.39892698110826263`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.6210624429827387`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.1180393879966241`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "1.6892782367382844`*^6"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "381303.4000996183`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "4617.631143922778`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1042.1342774615066`"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1.7214948227864497`*^6"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "4704.389205700768`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "4657.378316434553`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1309.9073063400497`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1031.1991337847237`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.39892698110826263`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.6210624429827387`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.1180393879966241`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "484173.05715454964`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "381441.24313204846`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1323.0063794034502`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1042.511125122571`"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1.104687161791906`*^6"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "3018.8057521125093`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "2988.4838079313267`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "824.6479184008068`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1031.2546390025939`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.39892698110826263`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.6210624429827387`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.1180393879966241`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "304825.7667636859`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "381461.757336772`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "832.894397584815`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1042.5671853926199`"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "0.2054930288828319`"}], "-", 
       RowBox[{"0.2685664741494312`", " ", "\[ImaginaryI]"}]}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "1.525275260291797`"}], "-", 
       RowBox[{"0.7439312016058168`", " ", "\[ImaginaryI]"}]}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "1.942951843724068`"}], "-", 
       RowBox[{"0.7365655461443731`", " ", "\[ImaginaryI]"}]}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{
       RowBox[{"0.5318916779588786`", "\[InvisibleSpace]"}], "+", 
       RowBox[{"0.21214049667093884`", " ", "\[ImaginaryI]"}]}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{
       RowBox[{"1.2697780195733566`", "\[InvisibleSpace]"}], "+", 
       RowBox[{"0.04721780745173044`", " ", "\[ImaginaryI]"}]}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.39892698110826263`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.6210624429827387`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.1180393879966241`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "0.41120412858443434`"}], "+", 
       RowBox[{"0.07735065197314542`", " ", "\[ImaginaryI]"}]}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{
       RowBox[{"0.14567573041351234`", "\[InvisibleSpace]"}], "+", 
       RowBox[{"0.017216553408937716`", " ", "\[ImaginaryI]"}]}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{
       RowBox[{"0.5372105947384673`", "\[InvisibleSpace]"}], "+", 
       RowBox[{"0.21426190163764824`", " ", "\[ImaginaryI]"}]}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{
       RowBox[{"0.28247579976909015`", "\[InvisibleSpace]"}], "+", 
       RowBox[{"0.047689985526247744`", " ", "\[ImaginaryI]"}]}]}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "0.2054930288828319`"}], "+", 
       RowBox[{"0.2685664741494312`", " ", "\[ImaginaryI]"}]}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "1.525275260291797`"}], "+", 
       RowBox[{"0.7439312016058168`", " ", "\[ImaginaryI]"}]}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "1.942951843724068`"}], "+", 
       RowBox[{"0.7365655461443731`", " ", "\[ImaginaryI]"}]}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{
       RowBox[{"0.5318916779588786`", "\[InvisibleSpace]"}], "-", 
       RowBox[{"0.21214049667093884`", " ", "\[ImaginaryI]"}]}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{
       RowBox[{"1.2697780195733566`", "\[InvisibleSpace]"}], "-", 
       RowBox[{"0.04721780745173044`", " ", "\[ImaginaryI]"}]}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.39892698110826263`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.6210624429827387`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.1180393879966241`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "0.41120412858443434`"}], "-", 
       RowBox[{"0.07735065197314542`", " ", "\[ImaginaryI]"}]}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{
       RowBox[{"0.14567573041351234`", "\[InvisibleSpace]"}], "-", 
       RowBox[{"0.017216553408937716`", " ", "\[ImaginaryI]"}]}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{
       RowBox[{"0.5372105947384673`", "\[InvisibleSpace]"}], "-", 
       RowBox[{"0.21426190163764824`", " ", "\[ImaginaryI]"}]}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{
       RowBox[{"0.28247579976909015`", "\[InvisibleSpace]"}], "-", 
       RowBox[{"0.047689985526247744`", " ", "\[ImaginaryI]"}]}]}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.31109810730874604`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.0943138348084193`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.5261583531464664`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.13762435358273753`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.8578372146944958`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.39892698110826263`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.6210624429827387`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.1180393879966241`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.5549618508052285`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.004526094941633016`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.13900059711856494`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.1335844131585593`"}]}]}], "}"}]}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "0.2054930288828319`"}], "-", 
     RowBox[{"0.2685664741494312`", " ", "\[ImaginaryI]"}]}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "1.525275260291797`"}], "-", 
     RowBox[{"0.7439312016058168`", " ", "\[ImaginaryI]"}]}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "1.942951843724068`"}], "-", 
     RowBox[{"0.7365655461443731`", " ", "\[ImaginaryI]"}]}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{
     RowBox[{"0.5318916779588786`", "\[InvisibleSpace]"}], "+", 
     RowBox[{"0.21214049667093884`", " ", "\[ImaginaryI]"}]}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{
     RowBox[{"1.2697780195733566`", "\[InvisibleSpace]"}], "+", 
     RowBox[{"0.04721780745173044`", " ", "\[ImaginaryI]"}]}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.39892698110826263`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.6210624429827387`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.1180393879966241`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "0.41120412858443434`"}], "+", 
     RowBox[{"0.07735065197314542`", " ", "\[ImaginaryI]"}]}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{
     RowBox[{"0.14567573041351234`", "\[InvisibleSpace]"}], "+", 
     RowBox[{"0.017216553408937716`", " ", "\[ImaginaryI]"}]}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{
     RowBox[{"0.5372105947384673`", "\[InvisibleSpace]"}], "+", 
     RowBox[{"0.21426190163764824`", " ", "\[ImaginaryI]"}]}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{
     RowBox[{"0.28247579976909015`", "\[InvisibleSpace]"}], "+", 
     RowBox[{"0.047689985526247744`", " ", "\[ImaginaryI]"}]}]}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solution", "=", 
  RowBox[{"firstorder", "[", 
   RowBox[{"[", "6", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.31109810730874604`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.0943138348084193`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.5261583531464664`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.13762435358273753`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.8578372146944958`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.39892698110826263`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.6210624429827387`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.1180393879966241`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.5549618508052285`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.004526094941633016`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.13900059711856494`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.1335844131585593`"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"dF", "[", 
      RowBox[{"[", "j", "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{"dF", "[", 
       RowBox[{"[", "j", "]"}], "]"}], "/.", "solution"}]}], ";", 
    "\[IndentingNewLine]", "    ", 
    RowBox[{"nthorder", "=", 
     RowBox[{"NSolve", "[", 
      RowBox[{
       RowBox[{"dF", "[", 
        RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", 
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", 
            RowBox[{"dF", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}], 
      "]"}]}], ";", "\[IndentingNewLine]", "    ", 
    RowBox[{"solution", "=", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{"solution", ",", "nthorder"}], "}"}], "]"}], "//", 
      "Chop"}]}]}], ",", "     ", "\[IndentingNewLine]", "    ", 
   RowBox[{"{", 
    RowBox[{"j", ",", "2", ",", "orderexpansion"}], "}"}]}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["solution"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.31109810730874604`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.0943138348084193`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.5261583531464664`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.13762435358273753`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.8578372146944958`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.39892698110826263`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.6210624429827387`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.1180393879966241`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.5549618508052285`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.004526094941633016`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.13900059711856494`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.1335844131585593`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "7.048948123151095`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "19.61999880162591`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "19.425741387748428`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.930698900773337`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "2.839093976689517`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "3.8528818643390608`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "4.326857441733893`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.5033676601560402`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "2.5461252189730272`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "2.657177794609668`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "5.884267139789419`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.5968703349058841`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.9911691298471024`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.9714545840070319`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "7.001804636113309`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.6381400225232889`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.1375602445927896`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.7131455149521843`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.9052570237808995`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.0872000142280513`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.7572489402191942`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.7497514259595981`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "4.003090569511711`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.20347810509165368`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.35377865724983637`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.3502758982671647`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simulate the Outcome", "Section"],

Cell["\<\
simprule below eliminates the derivative that are too high (more than \
orderexpansion total); ssrule replaces the constants with steady state values.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"simprule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d", ":", 
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"n__", "/;", 
          RowBox[{
           RowBox[{"Plus", "[", "n", "]"}], ">", "orderexpansion"}]}], "]"}], 
        "[", "__", "]"}], "[", "__", "]"}]}], "\[RuleDelayed]", "  ", "0"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssrule", "=", 
   RowBox[{
    RowBox[{"ssfunrule", "/.", "ssvalrule"}], "/.", "ssresult"}]}], 
  ";"}]}], "Input"],

Cell["\<\
Generating Taylor-Series expansion that the result can be plugged into.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sfun", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"h1", "[", 
       RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", 
        RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}], 
    "//", "Normal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dfun", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"h2", "[", 
       RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", 
        RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}], 
    "//", "Normal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cfun", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"g1", "[", 
       RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", 
        RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}], 
    "//", "Normal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ifun", "=", 
    RowBox[{
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"g2", "[", 
        RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"s", ",", 
         RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"d", ",", 
         RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}],
      "//", "Normal"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"sfun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dsimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"dfun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"csimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"cfun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"isimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"ifun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ssim", "[", "1", "]"}], "=", 
   RowBox[{"sbar", "/.", "ssresult"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dsim", "[", "1", "]"}], "=", 
   RowBox[{"dbar", "/.", "ssresult"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"xsim", "[", "1", "]"}], "=", "xmean"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"j", "=", "1"}], ",", 
    RowBox[{"j", "<", "22"}], ",", 
    RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"simrule", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"s", "\[Rule]", 
         RowBox[{"ssim", "[", "j", "]"}]}], ",", 
        RowBox[{"d", "\[Rule]", 
         RowBox[{"dsim", "[", "j", "]"}]}], ",", 
        RowBox[{"x", "\[Rule]", 
         RowBox[{"xsim", "[", "j", "]"}]}], ",", 
        RowBox[{"\[Sigma]", "\[Rule]", "0.006"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"csim", "[", "j", "]"}], "=", 
      RowBox[{"csimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"isim", "[", "j", "]"}], "=", 
      RowBox[{"isimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ssim", "[", 
       RowBox[{"j", "+", "1"}], "]"}], "=", 
      RowBox[{"ssimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"dsim", "[", 
       RowBox[{"j", "+", "1"}], "]"}], "=", 
      RowBox[{"dsimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"xsim", "[", 
       RowBox[{"j", "+", "1"}], "]"}], "=", 
      RowBox[{
       RowBox[{"xconst", "+", 
        RowBox[{"\[Rho]", " ", 
         RowBox[{"xsim", "[", "j", "]"}]}]}], "/.", "param"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"j", "\[Equal]", "1"}], ",", 
       RowBox[{
        RowBox[{"xsim", "[", 
         RowBox[{"j", "+", "1"}], "]"}], "=", ".004"}]}], "]"}], ";"}]}], 
   "  ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"This", " ", "is", " ", "a", " ", "one"}], "-", 
     RowBox[{
     "standard", " ", "deviation", " ", "contractionary", " ", "shock"}]}], 
    " ", "*)"}], "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Multiply", " ", "by", " ", "100", " ", "below", " ", "to", " ", "get", 
    " ", "percentages", " ", "and", " ", "more", " ", "convenient", " ", 
    "units"}], " ", "*)"}]}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", "*", 
       RowBox[{"ssim", "[", "j", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", "*", 
       RowBox[{"dsim", "[", "j", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", "*", 
       RowBox[{"csim", "[", "j", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"isim", "[", "j", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"xsim", "[", "j", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pout", "=", 
    RowBox[{"Flatten", "@", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"dsim", "[", "j", "]"}], "/", 
        RowBox[{"csim", "[", "j", "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "21"}], "}"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rout", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"100", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"dout", "[", 
          RowBox[{"[", "j", "]"}], "]"}], "/", 
         RowBox[{"(", 
          RowBox[{"100", "+", 
           RowBox[{"100", " ", 
            RowBox[{"xout", "[", 
             RowBox[{"[", "j", "]"}], "]"}]}], "-", 
           RowBox[{"dout", "[", 
            RowBox[{"[", "j", "]"}], "]"}]}], ")"}]}], "-", "1"}], ")"}]}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"infout", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"100", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"xout", "[", 
            RowBox[{"[", "j", "]"}], "]"}]}], ")"}], " ", 
         RowBox[{
          RowBox[{"pout", "[", 
           RowBox[{"[", 
            RowBox[{"j", "+", "1"}], "]"}], "]"}], "/", 
          RowBox[{"pout", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}]}], "-", "1"}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"infout", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "infout"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"piout", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", "-", 
       RowBox[{"sout", "[", 
        RowBox[{"[", "j", "]"}], "]"}], "-", 
       RowBox[{"dout", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot1", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"cout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Thickness", "[", ".01", "]"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "cout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "cout", "]"}], "-", 
              RowBox[{"Min", "[", "cout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "cout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "cout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "cout", "]"}], "-", 
            RowBox[{"Min", "[", "cout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Output\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot2", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"rout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "rout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "rout", "]"}], "-", 
              RowBox[{"Min", "[", "rout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "rout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "rout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "rout", "]"}], "-", 
            RowBox[{"Min", "[", "rout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Interest Rate\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot3", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"infout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "infout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "infout", "]"}], "-", 
              RowBox[{"Min", "[", "infout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "infout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "infout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "infout", "]"}], "-", 
            RowBox[{"Min", "[", "infout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Inflation Rate\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot4", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"dout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "dout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "dout", "]"}], "-", 
              RowBox[{"Min", "[", "dout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "dout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "dout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "dout", "]"}], "-", 
            RowBox[{"Min", "[", "dout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Checking Account\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot5", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"sout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "sout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "sout", "]"}], "-", 
              RowBox[{"Min", "[", "sout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "sout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "sout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "sout", "]"}], "-", 
            RowBox[{"Min", "[", "sout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Savings Account\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"plot6", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"piout", ",", 
      RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Min", "[", "piout", "]"}], "-", 
            RowBox[{".1", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Max", "[", "piout", "]"}], "-", 
               RowBox[{"Min", "[", "piout", "]"}]}], ")"}]}]}], ",", 
           RowBox[{"Max", "[", "piout", "]"}]}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"Min", "[", "piout", "]"}], "-", 
          RowBox[{".1", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Max", "[", "piout", "]"}], "-", 
             RowBox[{"Min", "[", "piout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
      RowBox[{"PlotLabel", "\[Rule]", "\"\<Retained Earnings\>\""}], ",", 
      RowBox[{"TextStyle", "\[RuleDelayed]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontSize", "->", "18"}], ",", 
         RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"GraphicsArray", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"plot1", ",", "plot2", ",", "plot3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"plot4", ",", "plot5", ",", "plot6"}], "}"}]}], "}"}], "]"}], 
    "]"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -42.2126 1.82337 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .08954 -47.25 -11.1875 ]
[-0.0125 .08954 0 11.1875 ]
[-0.0125 .18071 -58.0625 -11.1875 ]
[-0.0125 .18071 0 11.1875 ]
[-0.0125 .27188 -47.25 -11.1875 ]
[-0.0125 .27188 0 11.1875 ]
[-0.0125 .36305 -58.0625 -11.1875 ]
[-0.0125 .36305 0 11.1875 ]
[-0.0125 .45421 -47.25 -11.1875 ]
[-0.0125 .45421 0 11.1875 ]
[-0.0125 .54538 -58.0625 -11.1875 ]
[-0.0125 .54538 0 11.1875 ]
[.5 .63053 -34.4375 0 ]
[.5 .63053 34.4375 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08954 m
.00625 .08954 L
s
gsave
-0.0125 .08954 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.2) show
1.000 setlinewidth
grestore
0 .18071 m
.00625 .18071 L
s
gsave
-0.0125 .18071 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.25) show
1.000 setlinewidth
grestore
0 .27188 m
.00625 .27188 L
s
gsave
-0.0125 .27188 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.3) show
1.000 setlinewidth
grestore
0 .36305 m
.00625 .36305 L
s
gsave
-0.0125 .36305 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.35) show
1.000 setlinewidth
grestore
0 .45421 m
.00625 .45421 L
s
gsave
-0.0125 .45421 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.4) show
1.000 setlinewidth
grestore
0 .54538 m
.00625 .54538 L
s
gsave
-0.0125 .54538 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.45) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01661 m
.00375 .01661 L
s
0 .03484 m
.00375 .03484 L
s
0 .05307 m
.00375 .05307 L
s
0 .07131 m
.00375 .07131 L
s
0 .10777 m
.00375 .10777 L
s
0 .12601 m
.00375 .12601 L
s
0 .14424 m
.00375 .14424 L
s
0 .16248 m
.00375 .16248 L
s
0 .19894 m
.00375 .19894 L
s
0 .21718 m
.00375 .21718 L
s
0 .23541 m
.00375 .23541 L
s
0 .25364 m
.00375 .25364 L
s
0 .29011 m
.00375 .29011 L
s
0 .30835 m
.00375 .30835 L
s
0 .32658 m
.00375 .32658 L
s
0 .34481 m
.00375 .34481 L
s
0 .38128 m
.00375 .38128 L
s
0 .39951 m
.00375 .39951 L
s
0 .41775 m
.00375 .41775 L
s
0 .43598 m
.00375 .43598 L
s
0 .47245 m
.00375 .47245 L
s
0 .49068 m
.00375 .49068 L
s
0 .50892 m
.00375 .50892 L
s
0 .52715 m
.00375 .52715 L
s
0 .56362 m
.00375 .56362 L
s
0 .58185 m
.00375 .58185 L
s
0 .60008 m
.00375 .60008 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -95.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Output) show
127.875 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .483 m
.16667 .13907 L
.25 .05618 L
.33333 .14475 L
.41667 .27594 L
.5 .39704 L
.58333 .4902 L
.66667 .55359 L
.75 .59185 L
.83333 .61135 L
.91667 .61803 L
1 .61667 L
s
1 .61667 m
1 .61667 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.77254, 23.0843, \
0.058375, 0.00266791}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.340553 0.259608 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .04886 -36.4375 -11.1875 ]
[-0.0125 .04886 0 11.1875 ]
[-0.0125 .17866 -14.8125 -11.1875 ]
[-0.0125 .17866 0 11.1875 ]
[-0.0125 .30847 -36.4375 -11.1875 ]
[-0.0125 .30847 0 11.1875 ]
[-0.0125 .43827 -14.8125 -11.1875 ]
[-0.0125 .43827 0 11.1875 ]
[-0.0125 .56807 -36.4375 -11.1875 ]
[-0.0125 .56807 0 11.1875 ]
[.5 .63053 -72.2813 0 ]
[.5 .63053 72.2813 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04886 m
.00625 .04886 L
s
gsave
-0.0125 .04886 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .17866 m
.00625 .17866 L
s
gsave
-0.0125 .17866 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .30847 m
.00625 .30847 L
s
gsave
-0.0125 .30847 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
0 .43827 m
.00625 .43827 L
s
gsave
-0.0125 .43827 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
0 .56807 m
.00625 .56807 L
s
gsave
-0.0125 .56807 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07482 m
.00375 .07482 L
s
0 .10078 m
.00375 .10078 L
s
0 .12674 m
.00375 .12674 L
s
0 .1527 m
.00375 .1527 L
s
0 .20462 m
.00375 .20462 L
s
0 .23058 m
.00375 .23058 L
s
0 .25654 m
.00375 .25654 L
s
0 .28251 m
.00375 .28251 L
s
0 .33443 m
.00375 .33443 L
s
0 .36039 m
.00375 .36039 L
s
0 .38635 m
.00375 .38635 L
s
0 .41231 m
.00375 .41231 L
s
0 .46423 m
.00375 .46423 L
s
0 .49019 m
.00375 .49019 L
s
0 .51615 m
.00375 .51615 L
s
0 .54211 m
.00375 .54211 L
s
0 .0229 m
.00375 .0229 L
s
0 .59403 m
.00375 .59403 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -133.281 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Interest) show
160.313 20.000 moveto
(Rate) show
203.563 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .19892 m
.16667 .52091 L
.25 .61803 L
.33333 .53233 L
.41667 .40075 L
.5 .27862 L
.58333 .18456 L
.66667 .12059 L
.75 .08209 L
.83333 .06263 L
.91667 .05618 L
1 .05792 L
s
1 .05792 m
1 .05792 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJydWGl3FFUQfZnu6clGmIQsJmSZmEgSIogeUY56DC4scgiiRgIiBwfEk+hB
NIkIiLSoLKKiiKgIIi5RcUFx+R3+BT/qr2i7b3W9rn7dPYHkQ6Xm3lv19lfd
PVqemdiztzwzubtcWjdVfmlicvd0ae2+KR+yqpSqKimlrhWV7x9W1j+qx3O9
XtdT6kb/P+F61Up1uV4e1laqG7YNeB5+I3wLttkM6nQ9h20rcBt+0Qwac72c
Uv2wXbA517OU6oBvw94EW2DWt4sE0h6keRJuN/IuFqHJNI5AmmCrmVVqC/dj
HmlqYNuCNONwO2Et9i0e2mLMRHtGmlrY1iDNVpEmx36BpzUrQR1sS5Bgm0gQ
dEQFf+FPO/wZ/q48tnpYXmVNGplp/XquI59EOKueH9pwXfC7hbAFO0tugyIQ
R8TynnLQD0rg8JS3cgKHQ8lvCXeQ32oJQSX4nbAdvEdsZNd+63zO1UrX+xuJ
4Sq/Kdengva033Mdfpa+w0z8bxbgD+O/VI5ONU1pHrNTXUliwy+YkmZeHlo8
C/I0SRtvh4qkzwm4NZHwiuv1hdNKkkacE9mtWdcbMCXG4C67Xo1SIzEJ7X0t
uQjJQ+Es5IXEt5+BXB8jjV6cA7KxUkfPInSzuThnAD9uwqcxirFoVd8HsMXU
nUL4NhM+CXi7CR8HvMOEj2Hj7zThtwCXoz4QsMvUHcW6PWvCLtR7TPgI4OdM
+HUkmYgaI2AyAAZ4Y2r1ISR5Pp08CPKFgBzkm1OTB5B2b0AO8b2syf2IfDEg
l/Ld73OvAN4XwMN8U+iYGUheDshbuXppchrkVEAuS5yIBuGXIZwOB6SvRilf
AMku4DOhUN+PRt4c1i2HrmMWHL5gF8I+w+PCLNjxEVH8Tkj2m+vUAHgH7Ksm
ScmfBnkgndwO8mC0zkUAT8E/ZMbQTUPl7rV0civiM8hxkIdTSAuVwcI+465Q
DRsDfMSMaWTSt246SSX0jRTSdx+DTZDU5maQRzNJ374Z9ZOekh7lMznX5d4E
fBTyt0158qKn7KPxi4Anpynj6qegjbDHAvmi+HOCFPruBuDHo/tSlgRCNsQv
KFRzelgwmib5I7AnAmErb3TjBibhetiTgZAabUhMWDPaWCeQE+G06YPZkCgh
1L21sO+Ecn08tTzH3VsDeyqcWSetv5TxYdh3wzm1cWCSQouqlygL8Z1EjT4I
+146+QDXmQTpu6sFwvF6fUdgT5uRNL33w36QScqSl5D47n0QfmiS1PK9sGei
DrUzrIUZkffAfpRC+u4qkGdNkpKvEkginiR3w34cdYseNu+CPZcSY8URRA4k
9iVluRP2k0CyJHF4tUQ+mkCYw9VgnMYONH0H8E/d1CpFr0u385MQqpzFR1WT
Wo4sQ/wQbmRZAXs+U+K7yyH5PNaQltB7yXKBnE/vNAkJv+Ami2qOX2qoZF8M
Jca5ope7YYFccFMrJuWiR4YvzOXVpHzaTJPQ88ilaNd0o33q+pdmDL1BDQjk
UrqE1v5yCmnxC/pXJknvev0CScSTpA/266jPJYa1MC257/ZC+I1J0osaJf/W
JHv5PdInZ03yZsC0ZrNRh/r5APrwd64nXhBSi2UfcLoGvg/kRT5jqcWyHzjd
kT+Ecn3SFmQUy1u4zPn2iqsLUXNiGy+BhOr3j67HDWmh3h1Ua35yqUjkObnM
NchV0Qd+joTJsjMoKtYvUaPJMjkEnIra1WgYydK4FMJa2KvunJV0GEJaoF9D
eUH0lE62voN+cyuUxmW8HD5wzdwxdNdYIH9PIS35OeUPU3Ab5u9PE16BuL8C
eFLA0Hnz/Gw3zl/XbPFVJscf7BysjMWf8Bz+JlcAW49uWjxUW45Jxo9UasjG
xFITOf7sR8oC0hSwvnl+3snhlVlGBZU+fMovcF/0QSGfvv3UCU1thrJOLJwl
9lIy25pKzRa4l9rPYwzEFjmNxSOUURXHk0xsiW9cRV4dp1JKi4eQF43kebA2
+3LIsgtFXpPUDKIpR3y51QtWw0srl7BezLrEyR+JpYwdHZu3Zp77buytfHwT
18eXNB/PsDpqiF4yVorlot6Rvyna0UUhXAikcQ5Jgd91Nt3IQVVV/wMRQKeF
\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.14136, 0.844369, \
0.058375, 0.0187382}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.0872334 0.387463 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .06775 -36.4375 -11.1875 ]
[-0.0125 .06775 0 11.1875 ]
[-0.0125 .14524 -36.4375 -11.1875 ]
[-0.0125 .14524 0 11.1875 ]
[-0.0125 .22274 -36.4375 -11.1875 ]
[-0.0125 .22274 0 11.1875 ]
[-0.0125 .30023 -14.8125 -11.1875 ]
[-0.0125 .30023 0 11.1875 ]
[-0.0125 .37772 -36.4375 -11.1875 ]
[-0.0125 .37772 0 11.1875 ]
[-0.0125 .45521 -36.4375 -11.1875 ]
[-0.0125 .45521 0 11.1875 ]
[-0.0125 .53271 -36.4375 -11.1875 ]
[-0.0125 .53271 0 11.1875 ]
[-0.0125 .6102 -36.4375 -11.1875 ]
[-0.0125 .6102 0 11.1875 ]
[.5 .63053 -77.6875 0 ]
[.5 .63053 77.6875 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06775 m
.00625 .06775 L
s
gsave
-0.0125 .06775 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .14524 m
.00625 .14524 L
s
gsave
-0.0125 .14524 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .22274 m
.00625 .22274 L
s
gsave
-0.0125 .22274 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .30023 m
.00625 .30023 L
s
gsave
-0.0125 .30023 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .37772 m
.00625 .37772 L
s
gsave
-0.0125 .37772 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .45521 m
.00625 .45521 L
s
gsave
-0.0125 .45521 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
0 .53271 m
.00625 .53271 L
s
gsave
-0.0125 .53271 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
0 .6102 m
.00625 .6102 L
s
gsave
-0.0125 .6102 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08712 m
.00375 .08712 L
s
0 .1065 m
.00375 .1065 L
s
0 .12587 m
.00375 .12587 L
s
0 .16462 m
.00375 .16462 L
s
0 .18399 m
.00375 .18399 L
s
0 .20336 m
.00375 .20336 L
s
0 .24211 m
.00375 .24211 L
s
0 .26148 m
.00375 .26148 L
s
0 .28086 m
.00375 .28086 L
s
0 .3196 m
.00375 .3196 L
s
0 .33898 m
.00375 .33898 L
s
0 .35835 m
.00375 .35835 L
s
0 .3971 m
.00375 .3971 L
s
0 .41647 m
.00375 .41647 L
s
0 .43584 m
.00375 .43584 L
s
0 .47459 m
.00375 .47459 L
s
0 .49396 m
.00375 .49396 L
s
0 .51333 m
.00375 .51333 L
s
0 .55208 m
.00375 .55208 L
s
0 .57145 m
.00375 .57145 L
s
0 .59083 m
.00375 .59083 L
s
0 .04838 m
.00375 .04838 L
s
0 .02901 m
.00375 .02901 L
s
0 .00963 m
.00375 .00963 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -138.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Inflation) show
171.125 20.000 moveto
(Rate) show
214.375 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .30023 m
.16667 .61803 L
.25 .32999 L
.33333 .09936 L
.41667 .05618 L
.5 .08637 L
.58333 .13922 L
.66667 .19183 L
.75 .23518 L
.83333 .26719 L
.91667 .28892 L
1 .30253 L
s
1 .30253 m
1 .30253 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.14136, -0.0880465, \
0.058375, 0.0125549}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -75.1042 1.47714 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .08224 -47.25 -11.1875 ]
[-0.0125 .08224 0 11.1875 ]
[-0.0125 .22996 -25.625 -11.1875 ]
[-0.0125 .22996 0 11.1875 ]
[-0.0125 .37767 -47.25 -11.1875 ]
[-0.0125 .37767 0 11.1875 ]
[-0.0125 .52539 -47.25 -11.1875 ]
[-0.0125 .52539 0 11.1875 ]
[.5 .63053 -88.7188 0 ]
[.5 .63053 88.7188 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08224 m
.00625 .08224 L
s
gsave
-0.0125 .08224 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.9) show
1.000 setlinewidth
grestore
0 .22996 m
.00625 .22996 L
s
gsave
-0.0125 .22996 -86.625 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51) show
1.000 setlinewidth
grestore
0 .37767 m
.00625 .37767 L
s
gsave
-0.0125 .37767 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.1) show
1.000 setlinewidth
grestore
0 .52539 m
.00625 .52539 L
s
gsave
-0.0125 .52539 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .11179 m
.00375 .11179 L
s
0 .14133 m
.00375 .14133 L
s
0 .17087 m
.00375 .17087 L
s
0 .20041 m
.00375 .20041 L
s
0 .2595 m
.00375 .2595 L
s
0 .28904 m
.00375 .28904 L
s
0 .31859 m
.00375 .31859 L
s
0 .34813 m
.00375 .34813 L
s
0 .40721 m
.00375 .40721 L
s
0 .43676 m
.00375 .43676 L
s
0 .4663 m
.00375 .4663 L
s
0 .49584 m
.00375 .49584 L
s
0 .0527 m
.00375 .0527 L
s
0 .02316 m
.00375 .02316 L
s
0 .55493 m
.00375 .55493 L
s
0 .58447 m
.00375 .58447 L
s
0 .61401 m
.00375 .61401 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -149.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Checking) show
160.750 20.000 moveto
(Account) show
236.438 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .25847 m
.16667 .25847 L
.25 .61803 L
.33333 .6121 L
.41667 .48525 L
.5 .34245 L
.58333 .22427 L
.66667 .14109 L
.75 .0902 L
.83333 .06443 L
.91667 .05618 L
1 .05908 L
s
1 .05908 m
1 .05908 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.45695, 50.7622, \
0.058375, 0.00329324}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -38.2873 0.877212 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .04688 -47.25 -11.1875 ]
[-0.0125 .04688 0 11.1875 ]
[-0.0125 .1346 -47.25 -11.1875 ]
[-0.0125 .1346 0 11.1875 ]
[-0.0125 .22232 -47.25 -11.1875 ]
[-0.0125 .22232 0 11.1875 ]
[-0.0125 .31004 -25.625 -11.1875 ]
[-0.0125 .31004 0 11.1875 ]
[-0.0125 .39776 -47.25 -11.1875 ]
[-0.0125 .39776 0 11.1875 ]
[-0.0125 .48548 -47.25 -11.1875 ]
[-0.0125 .48548 0 11.1875 ]
[-0.0125 .5732 -47.25 -11.1875 ]
[-0.0125 .5732 0 11.1875 ]
[.5 .63053 -83.3125 0 ]
[.5 .63053 83.3125 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04688 m
.00625 .04688 L
s
gsave
-0.0125 .04688 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(43.7) show
1.000 setlinewidth
grestore
0 .1346 m
.00625 .1346 L
s
gsave
-0.0125 .1346 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(43.8) show
1.000 setlinewidth
grestore
0 .22232 m
.00625 .22232 L
s
gsave
-0.0125 .22232 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(43.9) show
1.000 setlinewidth
grestore
0 .31004 m
.00625 .31004 L
s
gsave
-0.0125 .31004 -86.625 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(44) show
1.000 setlinewidth
grestore
0 .39776 m
.00625 .39776 L
s
gsave
-0.0125 .39776 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(44.1) show
1.000 setlinewidth
grestore
0 .48548 m
.00625 .48548 L
s
gsave
-0.0125 .48548 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(44.2) show
1.000 setlinewidth
grestore
0 .5732 m
.00625 .5732 L
s
gsave
-0.0125 .5732 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(44.3) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06442 m
.00375 .06442 L
s
0 .08197 m
.00375 .08197 L
s
0 .09951 m
.00375 .09951 L
s
0 .11705 m
.00375 .11705 L
s
0 .15214 m
.00375 .15214 L
s
0 .16969 m
.00375 .16969 L
s
0 .18723 m
.00375 .18723 L
s
0 .20478 m
.00375 .20478 L
s
0 .23986 m
.00375 .23986 L
s
0 .25741 m
.00375 .25741 L
s
0 .27495 m
.00375 .27495 L
s
0 .2925 m
.00375 .2925 L
s
0 .32759 m
.00375 .32759 L
s
0 .34513 m
.00375 .34513 L
s
0 .36267 m
.00375 .36267 L
s
0 .38022 m
.00375 .38022 L
s
0 .41531 m
.00375 .41531 L
s
0 .43285 m
.00375 .43285 L
s
0 .4504 m
.00375 .4504 L
s
0 .46794 m
.00375 .46794 L
s
0 .50303 m
.00375 .50303 L
s
0 .52057 m
.00375 .52057 L
s
0 .53812 m
.00375 .53812 L
s
0 .55566 m
.00375 .55566 L
s
0 .02933 m
.00375 .02933 L
s
0 .01179 m
.00375 .01179 L
s
0 .59075 m
.00375 .59075 L
s
0 .60829 m
.00375 .60829 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -144.313 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Savings) show
149.938 20.000 moveto
(Account) show
225.625 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .05618 m
.16667 .08686 L
.25 .39631 L
.33333 .55134 L
.41667 .6124 L
.5 .61803 L
.58333 .59286 L
.66667 .5525 L
.75 .50664 L
.83333 .46101 L
.91667 .41878 L
1 .38144 L
s
1 .38144 m
1 .38144 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.45695, 43.5082, \
0.058375, 0.0055455}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -3.06542 0.698936 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .0099 -36.4375 -11.1875 ]
[-0.0125 .0099 0 11.1875 ]
[-0.0125 .14969 -36.4375 -11.1875 ]
[-0.0125 .14969 0 11.1875 ]
[-0.0125 .28947 -36.4375 -11.1875 ]
[-0.0125 .28947 0 11.1875 ]
[-0.0125 .42926 -14.8125 -11.1875 ]
[-0.0125 .42926 0 11.1875 ]
[-0.0125 .56905 -36.4375 -11.1875 ]
[-0.0125 .56905 0 11.1875 ]
[.5 .63053 -94.0313 0 ]
[.5 .63053 94.0313 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0099 m
.00625 .0099 L
s
gsave
-0.0125 .0099 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.4) show
1.000 setlinewidth
grestore
0 .14969 m
.00625 .14969 L
s
gsave
-0.0125 .14969 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.6) show
1.000 setlinewidth
grestore
0 .28947 m
.00625 .28947 L
s
gsave
-0.0125 .28947 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.8) show
1.000 setlinewidth
grestore
0 .42926 m
.00625 .42926 L
s
gsave
-0.0125 .42926 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .56905 m
.00625 .56905 L
s
gsave
-0.0125 .56905 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04485 m
.00375 .04485 L
s
0 .07979 m
.00375 .07979 L
s
0 .11474 m
.00375 .11474 L
s
0 .18463 m
.00375 .18463 L
s
0 .21958 m
.00375 .21958 L
s
0 .25453 m
.00375 .25453 L
s
0 .32442 m
.00375 .32442 L
s
0 .35937 m
.00375 .35937 L
s
0 .39431 m
.00375 .39431 L
s
0 .46421 m
.00375 .46421 L
s
0 .49916 m
.00375 .49916 L
s
0 .5341 m
.00375 .5341 L
s
0 .604 m
.00375 .604 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -155.031 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Retained) show
160.563 20.000 moveto
(Earnings) show
247.063 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .61803 m
.16667 .59359 L
.25 .1769 L
.33333 .05618 L
.41667 .06756 L
.5 .13064 L
.58333 .20661 L
.66667 .27812 L
.75 .33875 L
.83333 .3873 L
.91667 .42485 L
1 .45323 L
s
1 .45323 m
1 .45323 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.14136, 4.21222, \
0.058375, 0.00695998}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .40558 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00965678 0.31746 [
[ 0 0 0 0 ]
[ 1 .40558 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .40558 L
0 .40558 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00965678 0.321429 0.193595 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -75.1042 1.47714 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .08224 -47.25 -11.1875 ]
[-0.0125 .08224 0 11.1875 ]
[-0.0125 .22996 -25.625 -11.1875 ]
[-0.0125 .22996 0 11.1875 ]
[-0.0125 .37767 -47.25 -11.1875 ]
[-0.0125 .37767 0 11.1875 ]
[-0.0125 .52539 -47.25 -11.1875 ]
[-0.0125 .52539 0 11.1875 ]
[.5 .63053 -88.7188 0 ]
[.5 .63053 88.7188 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08224 m
.00625 .08224 L
s
gsave
-0.0125 .08224 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.9) show
1.000 setlinewidth
grestore
0 .22996 m
.00625 .22996 L
s
gsave
-0.0125 .22996 -86.625 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51) show
1.000 setlinewidth
grestore
0 .37767 m
.00625 .37767 L
s
gsave
-0.0125 .37767 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.1) show
1.000 setlinewidth
grestore
0 .52539 m
.00625 .52539 L
s
gsave
-0.0125 .52539 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .11179 m
.00375 .11179 L
s
0 .14133 m
.00375 .14133 L
s
0 .17087 m
.00375 .17087 L
s
0 .20041 m
.00375 .20041 L
s
0 .2595 m
.00375 .2595 L
s
0 .28904 m
.00375 .28904 L
s
0 .31859 m
.00375 .31859 L
s
0 .34813 m
.00375 .34813 L
s
0 .40721 m
.00375 .40721 L
s
0 .43676 m
.00375 .43676 L
s
0 .4663 m
.00375 .4663 L
s
0 .49584 m
.00375 .49584 L
s
0 .0527 m
.00375 .0527 L
s
0 .02316 m
.00375 .02316 L
s
0 .55493 m
.00375 .55493 L
s
0 .58447 m
.00375 .58447 L
s
0 .61401 m
.00375 .61401 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -149.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Checking) show
160.750 20.000 moveto
(Account) show
236.438 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .25847 m
.16667 .25847 L
.25 .61803 L
.33333 .6121 L
.41667 .48525 L
.5 .34245 L
.58333 .22427 L
.66667 .14109 L
.75 .0902 L
.83333 .06443 L
.91667 .05618 L
1 .05908 L
s
1 .05908 m
1 .05908 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00965678 0.64881 0.193595 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -38.2873 0.877212 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .04688 -47.25 -11.1875 ]
[-0.0125 .04688 0 11.1875 ]
[-0.0125 .1346 -47.25 -11.1875 ]
[-0.0125 .1346 0 11.1875 ]
[-0.0125 .22232 -47.25 -11.1875 ]
[-0.0125 .22232 0 11.1875 ]
[-0.0125 .31004 -25.625 -11.1875 ]
[-0.0125 .31004 0 11.1875 ]
[-0.0125 .39776 -47.25 -11.1875 ]
[-0.0125 .39776 0 11.1875 ]
[-0.0125 .48548 -47.25 -11.1875 ]
[-0.0125 .48548 0 11.1875 ]
[-0.0125 .5732 -47.25 -11.1875 ]
[-0.0125 .5732 0 11.1875 ]
[.5 .63053 -83.3125 0 ]
[.5 .63053 83.3125 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04688 m
.00625 .04688 L
s
gsave
-0.0125 .04688 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(43.7) show
1.000 setlinewidth
grestore
0 .1346 m
.00625 .1346 L
s
gsave
-0.0125 .1346 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(43.8) show
1.000 setlinewidth
grestore
0 .22232 m
.00625 .22232 L
s
gsave
-0.0125 .22232 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(43.9) show
1.000 setlinewidth
grestore
0 .31004 m
.00625 .31004 L
s
gsave
-0.0125 .31004 -86.625 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(44) show
1.000 setlinewidth
grestore
0 .39776 m
.00625 .39776 L
s
gsave
-0.0125 .39776 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(44.1) show
1.000 setlinewidth
grestore
0 .48548 m
.00625 .48548 L
s
gsave
-0.0125 .48548 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(44.2) show
1.000 setlinewidth
grestore
0 .5732 m
.00625 .5732 L
s
gsave
-0.0125 .5732 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(44.3) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06442 m
.00375 .06442 L
s
0 .08197 m
.00375 .08197 L
s
0 .09951 m
.00375 .09951 L
s
0 .11705 m
.00375 .11705 L
s
0 .15214 m
.00375 .15214 L
s
0 .16969 m
.00375 .16969 L
s
0 .18723 m
.00375 .18723 L
s
0 .20478 m
.00375 .20478 L
s
0 .23986 m
.00375 .23986 L
s
0 .25741 m
.00375 .25741 L
s
0 .27495 m
.00375 .27495 L
s
0 .2925 m
.00375 .2925 L
s
0 .32759 m
.00375 .32759 L
s
0 .34513 m
.00375 .34513 L
s
0 .36267 m
.00375 .36267 L
s
0 .38022 m
.00375 .38022 L
s
0 .41531 m
.00375 .41531 L
s
0 .43285 m
.00375 .43285 L
s
0 .4504 m
.00375 .4504 L
s
0 .46794 m
.00375 .46794 L
s
0 .50303 m
.00375 .50303 L
s
0 .52057 m
.00375 .52057 L
s
0 .53812 m
.00375 .53812 L
s
0 .55566 m
.00375 .55566 L
s
0 .02933 m
.00375 .02933 L
s
0 .01179 m
.00375 .01179 L
s
0 .59075 m
.00375 .59075 L
s
0 .60829 m
.00375 .60829 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -144.313 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Savings) show
149.938 20.000 moveto
(Account) show
225.625 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .05618 m
.16667 .08686 L
.25 .39631 L
.33333 .55134 L
.41667 .6124 L
.5 .61803 L
.58333 .59286 L
.66667 .5525 L
.75 .50664 L
.83333 .46101 L
.91667 .41878 L
1 .38144 L
s
1 .38144 m
1 .38144 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00965678 0.97619 0.193595 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -3.06542 0.698936 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .0099 -36.4375 -11.1875 ]
[-0.0125 .0099 0 11.1875 ]
[-0.0125 .14969 -36.4375 -11.1875 ]
[-0.0125 .14969 0 11.1875 ]
[-0.0125 .28947 -36.4375 -11.1875 ]
[-0.0125 .28947 0 11.1875 ]
[-0.0125 .42926 -14.8125 -11.1875 ]
[-0.0125 .42926 0 11.1875 ]
[-0.0125 .56905 -36.4375 -11.1875 ]
[-0.0125 .56905 0 11.1875 ]
[.5 .63053 -94.0313 0 ]
[.5 .63053 94.0313 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0099 m
.00625 .0099 L
s
gsave
-0.0125 .0099 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.4) show
1.000 setlinewidth
grestore
0 .14969 m
.00625 .14969 L
s
gsave
-0.0125 .14969 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.6) show
1.000 setlinewidth
grestore
0 .28947 m
.00625 .28947 L
s
gsave
-0.0125 .28947 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.8) show
1.000 setlinewidth
grestore
0 .42926 m
.00625 .42926 L
s
gsave
-0.0125 .42926 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .56905 m
.00625 .56905 L
s
gsave
-0.0125 .56905 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04485 m
.00375 .04485 L
s
0 .07979 m
.00375 .07979 L
s
0 .11474 m
.00375 .11474 L
s
0 .18463 m
.00375 .18463 L
s
0 .21958 m
.00375 .21958 L
s
0 .25453 m
.00375 .25453 L
s
0 .32442 m
.00375 .32442 L
s
0 .35937 m
.00375 .35937 L
s
0 .39431 m
.00375 .39431 L
s
0 .46421 m
.00375 .46421 L
s
0 .49916 m
.00375 .49916 L
s
0 .5341 m
.00375 .5341 L
s
0 .604 m
.00375 .604 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -155.031 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Retained) show
160.563 20.000 moveto
(Earnings) show
247.063 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .61803 m
.16667 .59359 L
.25 .1769 L
.33333 .05618 L
.41667 .06756 L
.5 .13064 L
.58333 .20661 L
.66667 .27812 L
.75 .33875 L
.83333 .3873 L
.91667 .42485 L
1 .45323 L
s
1 .45323 m
1 .45323 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.211989 0.321429 0.395928 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -42.2126 1.82337 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .08954 -47.25 -11.1875 ]
[-0.0125 .08954 0 11.1875 ]
[-0.0125 .18071 -58.0625 -11.1875 ]
[-0.0125 .18071 0 11.1875 ]
[-0.0125 .27188 -47.25 -11.1875 ]
[-0.0125 .27188 0 11.1875 ]
[-0.0125 .36305 -58.0625 -11.1875 ]
[-0.0125 .36305 0 11.1875 ]
[-0.0125 .45421 -47.25 -11.1875 ]
[-0.0125 .45421 0 11.1875 ]
[-0.0125 .54538 -58.0625 -11.1875 ]
[-0.0125 .54538 0 11.1875 ]
[.5 .63053 -34.4375 0 ]
[.5 .63053 34.4375 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08954 m
.00625 .08954 L
s
gsave
-0.0125 .08954 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.2) show
1.000 setlinewidth
grestore
0 .18071 m
.00625 .18071 L
s
gsave
-0.0125 .18071 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.25) show
1.000 setlinewidth
grestore
0 .27188 m
.00625 .27188 L
s
gsave
-0.0125 .27188 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.3) show
1.000 setlinewidth
grestore
0 .36305 m
.00625 .36305 L
s
gsave
-0.0125 .36305 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.35) show
1.000 setlinewidth
grestore
0 .45421 m
.00625 .45421 L
s
gsave
-0.0125 .45421 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.4) show
1.000 setlinewidth
grestore
0 .54538 m
.00625 .54538 L
s
gsave
-0.0125 .54538 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.45) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01661 m
.00375 .01661 L
s
0 .03484 m
.00375 .03484 L
s
0 .05307 m
.00375 .05307 L
s
0 .07131 m
.00375 .07131 L
s
0 .10777 m
.00375 .10777 L
s
0 .12601 m
.00375 .12601 L
s
0 .14424 m
.00375 .14424 L
s
0 .16248 m
.00375 .16248 L
s
0 .19894 m
.00375 .19894 L
s
0 .21718 m
.00375 .21718 L
s
0 .23541 m
.00375 .23541 L
s
0 .25364 m
.00375 .25364 L
s
0 .29011 m
.00375 .29011 L
s
0 .30835 m
.00375 .30835 L
s
0 .32658 m
.00375 .32658 L
s
0 .34481 m
.00375 .34481 L
s
0 .38128 m
.00375 .38128 L
s
0 .39951 m
.00375 .39951 L
s
0 .41775 m
.00375 .41775 L
s
0 .43598 m
.00375 .43598 L
s
0 .47245 m
.00375 .47245 L
s
0 .49068 m
.00375 .49068 L
s
0 .50892 m
.00375 .50892 L
s
0 .52715 m
.00375 .52715 L
s
0 .56362 m
.00375 .56362 L
s
0 .58185 m
.00375 .58185 L
s
0 .60008 m
.00375 .60008 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -95.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Output) show
127.875 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .483 m
.16667 .13907 L
.25 .05618 L
.33333 .14475 L
.41667 .27594 L
.5 .39704 L
.58333 .4902 L
.66667 .55359 L
.75 .59185 L
.83333 .61135 L
.91667 .61803 L
1 .61667 L
s
1 .61667 m
1 .61667 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.211989 0.64881 0.395928 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.340553 0.259608 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .04886 -36.4375 -11.1875 ]
[-0.0125 .04886 0 11.1875 ]
[-0.0125 .17866 -14.8125 -11.1875 ]
[-0.0125 .17866 0 11.1875 ]
[-0.0125 .30847 -36.4375 -11.1875 ]
[-0.0125 .30847 0 11.1875 ]
[-0.0125 .43827 -14.8125 -11.1875 ]
[-0.0125 .43827 0 11.1875 ]
[-0.0125 .56807 -36.4375 -11.1875 ]
[-0.0125 .56807 0 11.1875 ]
[.5 .63053 -72.2813 0 ]
[.5 .63053 72.2813 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04886 m
.00625 .04886 L
s
gsave
-0.0125 .04886 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .17866 m
.00625 .17866 L
s
gsave
-0.0125 .17866 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .30847 m
.00625 .30847 L
s
gsave
-0.0125 .30847 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
0 .43827 m
.00625 .43827 L
s
gsave
-0.0125 .43827 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
0 .56807 m
.00625 .56807 L
s
gsave
-0.0125 .56807 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07482 m
.00375 .07482 L
s
0 .10078 m
.00375 .10078 L
s
0 .12674 m
.00375 .12674 L
s
0 .1527 m
.00375 .1527 L
s
0 .20462 m
.00375 .20462 L
s
0 .23058 m
.00375 .23058 L
s
0 .25654 m
.00375 .25654 L
s
0 .28251 m
.00375 .28251 L
s
0 .33443 m
.00375 .33443 L
s
0 .36039 m
.00375 .36039 L
s
0 .38635 m
.00375 .38635 L
s
0 .41231 m
.00375 .41231 L
s
0 .46423 m
.00375 .46423 L
s
0 .49019 m
.00375 .49019 L
s
0 .51615 m
.00375 .51615 L
s
0 .54211 m
.00375 .54211 L
s
0 .0229 m
.00375 .0229 L
s
0 .59403 m
.00375 .59403 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -133.281 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Interest) show
160.313 20.000 moveto
(Rate) show
203.563 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .19892 m
.16667 .52091 L
.25 .61803 L
.33333 .53233 L
.41667 .40075 L
.5 .27862 L
.58333 .18456 L
.66667 .12059 L
.75 .08209 L
.83333 .06263 L
.91667 .05618 L
1 .05792 L
s
1 .05792 m
1 .05792 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.211989 0.97619 0.395928 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.0872334 0.387463 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .06775 -36.4375 -11.1875 ]
[-0.0125 .06775 0 11.1875 ]
[-0.0125 .14524 -36.4375 -11.1875 ]
[-0.0125 .14524 0 11.1875 ]
[-0.0125 .22274 -36.4375 -11.1875 ]
[-0.0125 .22274 0 11.1875 ]
[-0.0125 .30023 -14.8125 -11.1875 ]
[-0.0125 .30023 0 11.1875 ]
[-0.0125 .37772 -36.4375 -11.1875 ]
[-0.0125 .37772 0 11.1875 ]
[-0.0125 .45521 -36.4375 -11.1875 ]
[-0.0125 .45521 0 11.1875 ]
[-0.0125 .53271 -36.4375 -11.1875 ]
[-0.0125 .53271 0 11.1875 ]
[-0.0125 .6102 -36.4375 -11.1875 ]
[-0.0125 .6102 0 11.1875 ]
[.5 .63053 -77.6875 0 ]
[.5 .63053 77.6875 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06775 m
.00625 .06775 L
s
gsave
-0.0125 .06775 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .14524 m
.00625 .14524 L
s
gsave
-0.0125 .14524 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .22274 m
.00625 .22274 L
s
gsave
-0.0125 .22274 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .30023 m
.00625 .30023 L
s
gsave
-0.0125 .30023 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .37772 m
.00625 .37772 L
s
gsave
-0.0125 .37772 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .45521 m
.00625 .45521 L
s
gsave
-0.0125 .45521 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
0 .53271 m
.00625 .53271 L
s
gsave
-0.0125 .53271 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
0 .6102 m
.00625 .6102 L
s
gsave
-0.0125 .6102 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08712 m
.00375 .08712 L
s
0 .1065 m
.00375 .1065 L
s
0 .12587 m
.00375 .12587 L
s
0 .16462 m
.00375 .16462 L
s
0 .18399 m
.00375 .18399 L
s
0 .20336 m
.00375 .20336 L
s
0 .24211 m
.00375 .24211 L
s
0 .26148 m
.00375 .26148 L
s
0 .28086 m
.00375 .28086 L
s
0 .3196 m
.00375 .3196 L
s
0 .33898 m
.00375 .33898 L
s
0 .35835 m
.00375 .35835 L
s
0 .3971 m
.00375 .3971 L
s
0 .41647 m
.00375 .41647 L
s
0 .43584 m
.00375 .43584 L
s
0 .47459 m
.00375 .47459 L
s
0 .49396 m
.00375 .49396 L
s
0 .51333 m
.00375 .51333 L
s
0 .55208 m
.00375 .55208 L
s
0 .57145 m
.00375 .57145 L
s
0 .59083 m
.00375 .59083 L
s
0 .04838 m
.00375 .04838 L
s
0 .02901 m
.00375 .02901 L
s
0 .00963 m
.00375 .00963 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -138.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Inflation) show
171.125 20.000 moveto
(Rate) show
214.375 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .30023 m
.16667 .61803 L
.25 .32999 L
.33333 .09936 L
.41667 .05618 L
.5 .08637 L
.58333 .13922 L
.66667 .19183 L
.75 .23518 L
.83333 .26719 L
.91667 .28892 L
1 .30253 L
s
1 .30253 m
1 .30253 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{762, 308.875},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 761}, {307.875, 0}} -> {-0.078962, -0.0304253, \
0.00414971, 0.00414971}, {{19, 244.938}, {300.5, 160.875}} -> {-6.12199, \
50.6994, 0.0813327, 0.00458841}, {{267.5, 493.438}, {300.5, 160.875}} -> \
{-26.42, 43.4025, 0.0813327, 0.00772644}, {{516, 741.938}, {300.5, 160.875}} -> \
{-45.8886, 4.07946, 0.0813327, 0.0096972}, {{19, 244.938}, {146.938, 7.3125}} -> \
{-6.64853, 22.4626, 0.0813327, 0.00371714}, {{267.5, 493.438}, {146.938, \
7.3125}} -> {-25.9803, -3.5222, 0.0813327, 0.0261075}, {{516, 741.938}, \
{146.938, 7.3125}} -> {-46.1915, -3.01374, 0.0813327, 0.0174926}}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", "\"\<c:/temp\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<imp_cia.eps\>\"", ",", "plot", ",", "\"\<EPS\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "1000"}]}], "]"}], ";"}]}], "Input"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (April 11, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 34, 0, 101, "Title"],
Cell[617, 24, 57, 0, 56, "Subtitle"],
Cell[677, 26, 458, 8, 106, "Text"],
Cell[1138, 36, 330, 6, 92, "Input"],
Cell[CellGroupData[{
Cell[1493, 46, 33, 0, 70, "Section"],
Cell[1529, 48, 981, 29, 112, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2547, 82, 38, 0, 70, "Section"],
Cell[2588, 84, 2105, 71, 128, "Input"],
Cell[4696, 157, 118, 3, 30, "Text"],
Cell[4817, 162, 4148, 136, 292, "Input"],
Cell[8968, 300, 75, 0, 30, "Text"],
Cell[9046, 302, 878, 30, 132, "Input"],
Cell[9927, 334, 222, 4, 49, "Text"],
Cell[10152, 340, 1113, 35, 152, "Input"],
Cell[11268, 377, 162, 3, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11467, 385, 51, 0, 70, "Section"],
Cell[CellGroupData[{
Cell[11543, 389, 1383, 42, 92, "Input"],
Cell[12929, 433, 1966, 46, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14932, 484, 115, 3, 31, "Input"],
Cell[15050, 489, 238, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15325, 499, 413, 12, 31, "Input"],
Cell[15741, 513, 261, 6, 31, "Output"]
}, Open  ]],
Cell[16017, 522, 143, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[16185, 529, 319, 10, 31, "Input"],
Cell[16507, 541, 334, 11, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16878, 557, 328, 10, 31, "Input"],
Cell[17209, 569, 928, 24, 55, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18186, 599, 39, 0, 70, "Section"],
Cell[CellGroupData[{
Cell[18250, 603, 771, 21, 119, "Input"],
Cell[19024, 626, 177, 5, 33, "Output"]
}, Open  ]],
Cell[19216, 634, 278, 5, 49, "Text"],
Cell[19497, 641, 940, 30, 72, "Input"],
Cell[20440, 673, 152, 3, 30, "Text"],
Cell[20595, 678, 199, 7, 31, "Input"],
Cell[20797, 687, 271, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[21093, 696, 672, 20, 52, "Input"],
Cell[21768, 718, 25354, 774, 441, "Output"],
Cell[47125, 1494, 4584, 144, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51746, 1643, 117, 3, 31, "Input"],
Cell[51866, 1648, 3679, 121, 76, "Output"]
}, Open  ]],
Cell[55560, 1772, 1072, 31, 92, "Input"],
Cell[CellGroupData[{
Cell[56657, 1807, 34, 0, 31, "Input"],
Cell[56694, 1809, 12520, 412, 216, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[69263, 2227, 39, 0, 70, "Section"],
Cell[69305, 2229, 174, 3, 49, "Text"],
Cell[69482, 2234, 561, 18, 52, "Input"],
Cell[70046, 2254, 95, 2, 30, "Text"],
Cell[70144, 2258, 3731, 110, 272, "Input"],
Cell[73878, 2370, 2619, 73, 312, "Input"],
Cell[CellGroupData[{
Cell[76522, 2447, 12697, 372, 772, "Input"],
Cell[CellGroupData[{
Cell[89244, 2823, 10719, 503, 186, 8193, 459, "GraphicsData", "PostScript", \
"Graphics"],
Cell[99966, 3328, 9907, 457, 186, 7527, 415, "GraphicsData", "PostScript", \
"Graphics"],
Cell[109876, 3787, 11483, 533, 186, 9012, 490, "GraphicsData", "PostScript", \
"Graphics"],
Cell[121362, 4322, 9456, 435, 186, 7052, 393, "GraphicsData", "PostScript", \
"Graphics"],
Cell[130821, 4759, 11180, 527, 186, 8671, 483, "GraphicsData", "PostScript", \
"Graphics"],
Cell[142004, 5288, 9758, 442, 186, 7378, 400, "GraphicsData", "PostScript", \
"Graphics"],
Cell[151765, 5732, 57004, 2773, 317, 47436, 2616, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[208796, 8509, 297, 7, 52, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

