(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.4' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    189745,       8106]
NotebookOptionsPosition[    185912,       7982]
NotebookOutlinePosition[    186253,       7997]
CellTagsIndexPosition[    186210,       7994]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Show Me the Money", "Title"],

Cell["Computation with Perturbation Methods", "Subtitle"],

Cell["\<\
Log utility and quadratic adjustment are assumed. Endogenous state variables \
are d and s, exogenous state is x. x is Normal with unit variance.

The underlying theory for the computations can be found in Judd, \
Schmitt-Grohe and Uribe, and especially Fernandez-Villaverde. Some of the \
code is based on Jesus' code for his computational-method comparison paper. 
\
\>", "Text",
 CellChangeTimes->{{3.6897892667676764`*^9, 3.6897892673357334`*^9}}],

Cell[BoxData[{
 RowBox[{"<<", "Statistics`NormalDistribution`"}], "\[IndentingNewLine]", 
 RowBox[{"<<", 
  "Statistics`MultiDescriptiveStatistics`"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Graphics`MultipleListPlot`"}], "\[IndentingNewLine]", 
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell1"}], "]"}]}], "Input"],

Cell[CellGroupData[{

Cell["Set Parameters", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"param", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Psi]", "\[Rule]", "0.24"}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", "0.99"}], ",", 
     RowBox[{"ad1", "\[Rule]", "0"}], ",", 
     RowBox[{"ad2", "\[Rule]", 
      RowBox[{"-", "0.004114605920440126"}]}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", " ", "0.14"}], ",", 
     RowBox[{"\[Rho]", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmean", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xconst", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Rho]"}], ")"}], " ", "xmean"}], "/.", "param"}], "//",
     "Chop"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"orderexpansion", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"myvariables", "=", 
   RowBox[{"{", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "}"}]}], 
  ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Model Equations", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cond1a", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"1", "-", "\[Psi]"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "l"}], ")"}], "w"}]], "-", 
    RowBox[{"\[Beta]", 
     RowBox[{"(", 
      FractionBox["\[Psi]", 
       RowBox[{"c2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "x"}], ")"}], " ", "p2"}]], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond2a", "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"1", "-", "\[Psi]"}], 
      RowBox[{"1", "-", "l"}]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "w"], "+", 
       RowBox[{"2", "  ", "ad1", " ", 
        RowBox[{"(", 
         RowBox[{"ad2", "+", "i"}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"\[Beta]", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"1", "-", "\[Psi]"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "x"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"1", "-", "l2"}], ")"}]}]], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"1", "+", "r2"}], "w2"], "+", 
         RowBox[{"2", " ", "ad1", " ", 
          RowBox[{"(", 
           RowBox[{"ad2", "+", "i2"}], ")"}]}]}], ")"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond3a", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "x"}], ")"}], " ", "d2"}], "-", 
    RowBox[{"(", 
     RowBox[{"d", "+", 
      RowBox[{"r", " ", "s"}], " ", "+", 
      RowBox[{"\[Lambda]", " ", "pi"}], " ", "+", 
      RowBox[{"w", " ", "la"}], " ", "-", "i", " ", "-", 
      RowBox[{"p", " ", "c"}]}], ")"}]}]}], " ", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond4a", "=", 
   RowBox[{"i", "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "x"}], ")"}], " ", "s2"}], "-", "s"}], ")"}]}]}], 
  ";"}]}], "Input"],

Cell["\<\
The replacement rules arising from the remaining model equations (this should \
be documented)\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rep0", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"l", "\[Rule]", " ", 
      RowBox[{"la", "+", "lb"}]}], ",", 
     RowBox[{"l2", "\[Rule]", " ", 
      RowBox[{"la2", "+", "lb2"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep0b", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"lb", "\[Rule]", " ", 
      RowBox[{"ad1", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"ad2", "+", "i"}], ")"}], "^", "2"}]}]}], ",", 
     RowBox[{"lb2", "\[Rule]", " ", 
      RowBox[{"ad1", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"ad2", "+", "i2"}], ")"}], "^", "2"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"la", "\[Rule]", "c"}], ",", 
     RowBox[{"la2", "\[Rule]", "c2"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep2", "=", 
   RowBox[{"{", 
    RowBox[{"pi", "\[Rule]", " ", 
     RowBox[{"1", "-", "d", "-", "s"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep2b", "=", 
   RowBox[{"{", 
    RowBox[{"pi2", "\[Rule]", " ", 
     RowBox[{"1", "-", "d2", "-", "s2"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep3", "=", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", 
     RowBox[{"d", "/", "c"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep3b", "=", 
   RowBox[{"{", 
    RowBox[{"p2", "\[Rule]", 
     RowBox[{"d2", "/", "c2"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep4", "=", 
   RowBox[{"{", 
    RowBox[{"b", "->", 
     RowBox[{"1", "+", "x", "-", "d"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep5", "=", 
   RowBox[{"{", 
    RowBox[{"w", "\[Rule]", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "x", "-", "d"}], ")"}], "/", "c"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep5b", "=", 
   RowBox[{"{", 
    RowBox[{"w2", "\[Rule]", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "x2", "-", "d2"}], ")"}], "/", "c2"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep6", "=", 
   RowBox[{"{", 
    RowBox[{"r", "\[Rule]", 
     RowBox[{
      RowBox[{"d", "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", "x", "-", "d"}], ")"}]}], "-", "1"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep6b", "=", 
   RowBox[{"{", 
    RowBox[{"r2", "\[Rule]", 
     RowBox[{
      RowBox[{"d2", "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", "x2", "-", "d2"}], ")"}]}], "-", "1"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"repall", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
    "rep1", ",", "rep2", ",", "rep2b", ",", "rep3", ",", "rep3b", ",", "rep4",
      ",", "rep5", ",", "rep5b", ",", "rep6", ",", "rep6b"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{""}]}], "Input"],

Cell["Rework cond2 so that it will be easier to take expectations", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cond1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"cond1a", "/.", "rep0"}], "/.", "rep0b"}], "/.", "repall"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"cond2a", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", "d2", "+", "x2"}], ")"}], "2"]}], ")"}], "/.", 
      "rep0"}], "/.", "rep0b"}], "/.", "repall"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond2", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{"cond2", ",", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "d2", "+", "x2"}], ")"}], "2"]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond3", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"cond3a", "/.", "rep0"}], "/.", "rep0b"}], "/.", "repall"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cond4", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"cond4a", "/.", "rep0"}], "/.", "rep0b"}], "/.", "repall"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"F", "=", 
   RowBox[{"{", 
    RowBox[{"cond1", ",", "cond2", ",", "cond3", ",", "cond4"}], "}"}]}], 
  ";"}]}], "Input"],

Cell["\<\
Now replace the decision variables by the functions that we are going to \
compute. Notation is moving towards Schmitt-Grohe and Uribe. g are the \
policies for jumps, h are the policies for states.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"c", "=", 
   RowBox[{"g1", "[", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"i", "=", 
   RowBox[{"g2", "[", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"s2", "=", 
   RowBox[{"h1", "[", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d2", "=", 
   RowBox[{"h2", "[", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2", "=", 
   RowBox[{"g1", "[", 
    RowBox[{"s2", ",", "d2", ",", "x2", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"i2", "=", 
   RowBox[{"g2", "[", 
    RowBox[{"s2", ",", "d2", ",", "x2", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x2", "=", 
   RowBox[{"xconst", "+", 
    RowBox[{"\[Rho]", " ", "*", "x"}], "+", 
    RowBox[{"\[Sigma]", "*", "\[Epsilon]"}]}]}], ";"}]}], "Input"],

Cell["\<\
In terms of number of equations and unknowns, this is fine now. s and d are \
endogenous states, c and i are jumps. x is chosen by nature.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The  Non-Stochastic Steady State", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ssfunrule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"h1", "[", "__", "]"}], "\[Rule]", " ", "s"}], ",", 
     RowBox[{
      RowBox[{"h2", "[", "__", "]"}], "\[Rule]", " ", "d"}], ",", " ", 
     RowBox[{
      RowBox[{"g1", "[", "__", "]"}], "\[Rule]", " ", "cbar"}], ",", 
     RowBox[{
      RowBox[{"g2", "[", "__", "]"}], "\[Rule]", "ibar"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssvalrule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s", "\[Rule]", "sbar"}], ",", 
     RowBox[{"d", "\[Rule]", "dbar"}], ",", 
     RowBox[{"x", "\[Rule]", "xmean"}], ",", 
     RowBox[{"ibar", "\[Rule]", 
      RowBox[{"xmean", " ", "sbar"}]}], ",", 
     RowBox[{"\[Sigma]", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sscond", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"F", "[", 
       RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"ssresult", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"sscond", "/.", "param"}], "/.", "ssfunrule"}], "/.", 
     "ssvalrule"}], ",", 
    RowBox[{"{", 
     RowBox[{"sbar", ",", "dbar", ",", "cbar"}], "}"}]}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"sbar", "\[Rule]", "0.41135077821011673`"}], ",", 
    RowBox[{"cbar", "\[Rule]", "0.23277981197427017`"}], ",", 
    RowBox[{"dbar", "\[Rule]", "0.51005`"}]}], "}"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ssresult", "=", 
  RowBox[{"ssresult", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"sbar", "\[Rule]", "0.41135077821011673`"}], ",", 
   RowBox[{"cbar", "\[Rule]", "0.23277981197427017`"}], ",", 
   RowBox[{"dbar", "\[Rule]", "0.51005`"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"varrule", "=", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"s", "\[Rule]", "sbar"}], "/.", "ssresult"}], ",", 
      RowBox[{
       RowBox[{"d", "\[Rule]", "dbar"}], "/.", "ssresult"}], ",", 
      RowBox[{"x", "\[Rule]", "xmean"}], ",", 
      RowBox[{"\[Sigma]", "\[Rule]", "0"}]}], "}"}], "]"}], "//", 
   "Chop"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"s", "\[Rule]", "0.41135077821011673`"}], ",", 
   RowBox[{"d", "\[Rule]", "0.51005`"}], ",", 
   RowBox[{"x", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"\[Sigma]", "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
The role of derivrule is to suppress the arguments of all the derivatives. \
The : is a general pattern operator here. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"derivrule", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"d", ":", 
     RowBox[{
      RowBox[{
       RowBox[{"Derivative", "[", "__", "]"}], "[", "__", "]"}], "[", "__", 
      "]"}]}], "\[RuleDelayed]", "  ", 
    RowBox[{"d", "[", 
     RowBox[{"[", "0", "]"}], "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"d", ":", 
    RowBox[{
     SuperscriptBox["__", 
      TagBox[
       RowBox[{"(", "__", ")"}],
       Derivative],
      MultilineFunction->None], "[", "__", "]"}]}], "\[RuleDelayed]", 
   RowBox[{"d", "\[LeftDoubleBracket]", "0", "\[RightDoubleBracket]"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"unirule", "=", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"ssfunrule", "/.", "varrule"}], "/.", "ssvalrule"}], "/.", 
       "ssresult"}], ",", "varrule", ",", "derivrule"}], "]"}], "]"}], "//", 
   "Chop"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"h1", "[", "__", "]"}], "\[Rule]", "0.41135077821011673`"}], ",", 
   RowBox[{
    RowBox[{"h2", "[", "__", "]"}], "\[Rule]", "0.51005`"}], ",", 
   RowBox[{
    RowBox[{"g1", "[", "__", "]"}], "\[Rule]", "0.23277981197427017`"}], ",", 
   RowBox[{
    RowBox[{"g2", "[", "__", "]"}], "\[Rule]", "0.0041135077821011674`"}], 
   ",", 
   RowBox[{"s", "\[Rule]", "0.41135077821011673`"}], ",", 
   RowBox[{"d", "\[Rule]", "0.51005`"}], ",", 
   RowBox[{"x", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"\[Sigma]", "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"d", ":", 
     RowBox[{
      SuperscriptBox["__", 
       TagBox[
        RowBox[{"(", "__", ")"}],
        Derivative],
       MultilineFunction->None], "[", "__", "]"}]}], "\[RuleDelayed]", 
    RowBox[{"d", "\[LeftDoubleBracket]", "0", "\[RightDoubleBracket]"}]}]}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Taylor Expansion", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"epsrule", "=", 
  RowBox[{"Append", "[", 
   RowBox[{
    RowBox[{"Reverse", "@", 
     RowBox[{"Thread", "[", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{"Range", "[", 
         RowBox[{"2", ",", "orderexpansion", ",", "2"}], "]"}]], "->", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"ExpectedValue", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox["#", "j"], "&"}], ",", 
           RowBox[{"NormalDistribution", "[", 
            RowBox[{"0", ",", "1"}], "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "2", ",", "orderexpansion", ",", "2"}], "}"}]}], 
        "]"}]}], "]"}]}], ",", 
    RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Epsilon]", "2"], "\[Rule]", "1"}], ",", 
   RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Notice that all partial derivatives are taken below, even though some \
cross-derivatives are equal and could be left out. This slows computation, \
but as long as computation time is not an issue, it makes it easier to \
simulate from the outcome later.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Fd", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Fd", "[", 
    RowBox[{"[", "0", "]"}], "]"}], "=", "F"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Fd", "[", 
      RowBox[{"[", "j", "]"}], "]"}], "=", 
     RowBox[{"Union", "[", 
      RowBox[{"Expand", "[", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Outer", "[", 
         RowBox[{"D", ",", 
          RowBox[{"{", 
           RowBox[{"Fd", "[", 
            RowBox[{"[", 
             RowBox[{"j", "-", "1"}], "]"}], "]"}], "}"}], ",", 
          "myvariables"}], "]"}], "]"}], "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "orderexpansion"}], "}"}]}], "]"}], 
  ";"}]}], "Input"],

Cell["\<\
Now we plug in everything that is known, that is, we evaluate the derivative \
at the steady state and at calibrated parameters.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dF", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Fd", "/.", "param"}], "/.", "unirule"}], "/.", "epsrule"}], "//",
     "Chop"}]}], ";"}]], "Input"],

Cell["\<\
Now we simply need to solve the resulting system. In the first step, we also \
have to pick the correct solution. Since the system is quadratic, there may \
be more than one. How to pick this is not obvious; check the result manually \
to be sure.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"firstorder", "=", 
   RowBox[{
    RowBox[{"NSolve", "[", 
     RowBox[{"Thread", "[", 
      RowBox[{
       RowBox[{"First", "[", "dF", "]"}], "\[Equal]", "0"}], "]"}], "]"}], "//",
     "Chop"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"solution", "=", 
  RowBox[{"First", "@", 
   RowBox[{"Select", "[", 
    RowBox[{"firstorder", ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "]"}], "[", "g1", 
          "]"}], "]"}], "<", "1"}], "/.", "#"}], "&"}]}], "]"}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.4184516806049876`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "4.961317131642087`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "3.6876013653588413`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "5.215815840502855`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "5.319473178071489`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "3.6510904607513286`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "6.154273109408768`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "4.566199407114626`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "3.1340710892067465`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "5.282785960693897`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.740168617041209`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.849760912814025`"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["firstorder"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1.4184516806049876`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "4.961317131642087`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "3.6876013653588413`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "5.215815840502855`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "5.319473178071489`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "3.6510904607513286`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "6.154273109408768`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "4.566199407114626`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "3.1340710892067465`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "5.282785960693897`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.740168617041209`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "1.849760912814025`"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.1803973445570645`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.349455730456313`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.5221895652600271`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.11979797979798`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.7532737709568614`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.5170193715445814`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.8714871487148713`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.3572224644694343`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "2.854095107101877`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "7.362794341602491`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "2.5282144751440128`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.11979797979798`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "6.882617389497399`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "2.503182648657439`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.8714871487148713`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "7.635891160454263`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "3.02020202020202`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1.4147424335423135`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solution", "=", 
  RowBox[{"firstorder", "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.1803973445570645`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.349455730456313`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.5221895652600271`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.11979797979798`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.7532737709568614`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.5170193715445814`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.8714871487148713`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.3572224644694343`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"dF", "[", 
      RowBox[{"[", "j", "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{"dF", "[", 
       RowBox[{"[", "j", "]"}], "]"}], "/.", "solution"}]}], ";", 
    "\[IndentingNewLine]", "    ", 
    RowBox[{"nthorder", "=", 
     RowBox[{"NSolve", "[", 
      RowBox[{
       RowBox[{"dF", "[", 
        RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", 
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", 
            RowBox[{"dF", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}], 
      "]"}]}], ";", "\[IndentingNewLine]", "    ", 
    RowBox[{"solution", "=", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{"solution", ",", "nthorder"}], "}"}], "]"}], "//", 
      "Chop"}]}]}], ",", "     ", "\[IndentingNewLine]", "    ", 
   RowBox[{"{", 
    RowBox[{"j", ",", "2", ",", "orderexpansion"}], "}"}]}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["solution"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.1803973445570645`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.349455730456313`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.5221895652600271`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.11979797979798`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.7532737709568614`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.5170193715445814`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.8714871487148713`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.3572224644694343`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.8841963366835299`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "2.5504540404040497`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "2.5252020202020296`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "2.5252020202020296`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.4420565249677187`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "3.3579587176970263`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "4.816342831297772`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.5216738469960434`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "5.003690960528737`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "5.466049833735958`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.332649977446466`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "6.649423203360447`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "6.583587330059848`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "2.0406081012141617`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "2.883262623692112`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "4.040808121216162`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "4.0008001200160015`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simulate the Outcome", "Section"],

Cell["\<\
simprule below eliminates the derivative that are too high (more than \
orderexpansion total); ssrule replaces the constants with steady state values.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"simprule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d", ":", 
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"n__", "/;", 
          RowBox[{
           RowBox[{"Plus", "[", "n", "]"}], ">", "orderexpansion"}]}], "]"}], 
        "[", "__", "]"}], "[", "__", "]"}]}], "\[RuleDelayed]", "  ", "0"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssrule", "=", 
   RowBox[{
    RowBox[{"ssfunrule", "/.", "ssvalrule"}], "/.", "ssresult"}]}], 
  ";"}]}], "Input"],

Cell["\<\
Generating Taylor-Series expansion that the result can be plugged into.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sfun", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"h1", "[", 
       RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", 
        RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}], 
    "//", "Normal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dfun", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"h2", "[", 
       RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", 
        RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}], 
    "//", "Normal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cfun", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"g1", "[", 
       RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", 
        RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}], 
    "//", "Normal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ifun", "=", 
    RowBox[{
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"g2", "[", 
        RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"s", ",", 
         RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"d", ",", 
         RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}],
      "//", "Normal"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"sfun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dsimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"dfun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"csimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"cfun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"isimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"ifun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ssim", "[", "1", "]"}], "=", 
   RowBox[{"sbar", "/.", "ssresult"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dsim", "[", "1", "]"}], "=", 
   RowBox[{"dbar", "/.", "ssresult"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"xsim", "[", "1", "]"}], "=", "xmean"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"j", "=", "1"}], ",", 
    RowBox[{"j", "<", "22"}], ",", 
    RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"simrule", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"s", "\[Rule]", 
         RowBox[{"ssim", "[", "j", "]"}]}], ",", 
        RowBox[{"d", "\[Rule]", 
         RowBox[{"dsim", "[", "j", "]"}]}], ",", 
        RowBox[{"x", "\[Rule]", 
         RowBox[{"xsim", "[", "j", "]"}]}], ",", 
        RowBox[{"\[Sigma]", "\[Rule]", "0.006"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"csim", "[", "j", "]"}], "=", 
      RowBox[{"csimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"isim", "[", "j", "]"}], "=", 
      RowBox[{"isimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ssim", "[", 
       RowBox[{"j", "+", "1"}], "]"}], "=", 
      RowBox[{"ssimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"dsim", "[", 
       RowBox[{"j", "+", "1"}], "]"}], "=", 
      RowBox[{"dsimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"xsim", "[", 
       RowBox[{"j", "+", "1"}], "]"}], "=", 
      RowBox[{
       RowBox[{"xconst", "+", 
        RowBox[{"\[Rho]", " ", 
         RowBox[{"xsim", "[", "j", "]"}]}]}], "/.", "param"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"j", "\[Equal]", "1"}], ",", 
       RowBox[{
        RowBox[{"xsim", "[", 
         RowBox[{"j", "+", "1"}], "]"}], "=", ".004"}]}], "]"}], ";"}]}], 
   "  ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"This", " ", "is", " ", "a", " ", "one"}], "-", 
     RowBox[{
     "standard", " ", "deviation", " ", "contractionary", " ", "shock"}]}], 
    " ", "*)"}], "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Multiply", " ", "by", " ", "100", " ", "below", " ", "to", " ", "get", 
    " ", "percentages", " ", "and", " ", "more", " ", "convenient", " ", 
    "units"}], " ", "*)"}]}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", "*", 
       RowBox[{"ssim", "[", "j", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", "*", 
       RowBox[{"dsim", "[", "j", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", "*", 
       RowBox[{"csim", "[", "j", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"isim", "[", "j", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"xsim", "[", "j", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pout", "=", 
    RowBox[{"Flatten", "@", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"dsim", "[", "j", "]"}], "/", 
        RowBox[{"csim", "[", "j", "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "21"}], "}"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rout", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"100", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"dout", "[", 
          RowBox[{"[", "j", "]"}], "]"}], "/", 
         RowBox[{"(", 
          RowBox[{"100", "+", 
           RowBox[{"100", " ", 
            RowBox[{"xout", "[", 
             RowBox[{"[", "j", "]"}], "]"}]}], "-", 
           RowBox[{"dout", "[", 
            RowBox[{"[", "j", "]"}], "]"}]}], ")"}]}], "-", "1"}], ")"}]}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"infout", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"100", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"xout", "[", 
            RowBox[{"[", "j", "]"}], "]"}]}], ")"}], " ", 
         RowBox[{
          RowBox[{"pout", "[", 
           RowBox[{"[", 
            RowBox[{"j", "+", "1"}], "]"}], "]"}], "/", 
          RowBox[{"pout", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}]}], "-", "1"}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"infout", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "infout"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"piout", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", "-", 
       RowBox[{"sout", "[", 
        RowBox[{"[", "j", "]"}], "]"}], "-", 
       RowBox[{"dout", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot1", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"cout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Thickness", "[", ".01", "]"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "cout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "cout", "]"}], "-", 
              RowBox[{"Min", "[", "cout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "cout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "cout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "cout", "]"}], "-", 
            RowBox[{"Min", "[", "cout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Output\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot2", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"rout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "rout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "rout", "]"}], "-", 
              RowBox[{"Min", "[", "rout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "rout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "rout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "rout", "]"}], "-", 
            RowBox[{"Min", "[", "rout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Interest Rate\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot3", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"infout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "infout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "infout", "]"}], "-", 
              RowBox[{"Min", "[", "infout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "infout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "infout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "infout", "]"}], "-", 
            RowBox[{"Min", "[", "infout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Inflation Rate\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot4", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"dout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"50.95", ",", "51.2"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "50.95"}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Checking Account\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot5", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"sout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "sout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "sout", "]"}], "-", 
              RowBox[{"Min", "[", "sout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "sout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "sout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "sout", "]"}], "-", 
            RowBox[{"Min", "[", "sout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Savings Account\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"plot6", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"piout", ",", 
      RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Min", "[", "piout", "]"}], "-", 
            RowBox[{".1", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Max", "[", "piout", "]"}], "-", 
               RowBox[{"Min", "[", "piout", "]"}]}], ")"}]}]}], ",", 
           RowBox[{"Max", "[", "piout", "]"}]}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"Min", "[", "piout", "]"}], "-", 
          RowBox[{".1", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Max", "[", "piout", "]"}], "-", 
             RowBox[{"Min", "[", "piout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
      RowBox[{"PlotLabel", "\[Rule]", "\"\<Retained Earnings\>\""}], ",", 
      RowBox[{"TextStyle", "\[RuleDelayed]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontSize", "->", "18"}], ",", 
         RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"GraphicsArray", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"plot1", ",", "plot2", ",", "plot3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"plot4", ",", "plot5", ",", "plot6"}], "}"}]}], "}"}], "]"}], 
    "]"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -117.549 5.0767 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .02716 -58.0625 -11.1875 ]
[-0.0125 .02716 0 11.1875 ]
[-0.0125 .12869 -58.0625 -11.1875 ]
[-0.0125 .12869 0 11.1875 ]
[-0.0125 .23023 -47.25 -11.1875 ]
[-0.0125 .23023 0 11.1875 ]
[-0.0125 .33176 -58.0625 -11.1875 ]
[-0.0125 .33176 0 11.1875 ]
[-0.0125 .43329 -58.0625 -11.1875 ]
[-0.0125 .43329 0 11.1875 ]
[-0.0125 .53483 -58.0625 -11.1875 ]
[-0.0125 .53483 0 11.1875 ]
[.5 .63053 -34.4375 0 ]
[.5 .63053 34.4375 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02716 m
.00625 .02716 L
s
gsave
-0.0125 .02716 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.16) show
1.000 setlinewidth
grestore
0 .12869 m
.00625 .12869 L
s
gsave
-0.0125 .12869 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.18) show
1.000 setlinewidth
grestore
0 .23023 m
.00625 .23023 L
s
gsave
-0.0125 .23023 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.2) show
1.000 setlinewidth
grestore
0 .33176 m
.00625 .33176 L
s
gsave
-0.0125 .33176 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.22) show
1.000 setlinewidth
grestore
0 .43329 m
.00625 .43329 L
s
gsave
-0.0125 .43329 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.24) show
1.000 setlinewidth
grestore
0 .53483 m
.00625 .53483 L
s
gsave
-0.0125 .53483 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.26) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05254 m
.00375 .05254 L
s
0 .07793 m
.00375 .07793 L
s
0 .10331 m
.00375 .10331 L
s
0 .15408 m
.00375 .15408 L
s
0 .17946 m
.00375 .17946 L
s
0 .20484 m
.00375 .20484 L
s
0 .25561 m
.00375 .25561 L
s
0 .28099 m
.00375 .28099 L
s
0 .30638 m
.00375 .30638 L
s
0 .35714 m
.00375 .35714 L
s
0 .38253 m
.00375 .38253 L
s
0 .40791 m
.00375 .40791 L
s
0 .45868 m
.00375 .45868 L
s
0 .48406 m
.00375 .48406 L
s
0 .50945 m
.00375 .50945 L
s
0 .00178 m
.00375 .00178 L
s
0 .56021 m
.00375 .56021 L
s
0 .5856 m
.00375 .5856 L
s
0 .61098 m
.00375 .61098 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -95.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Output) show
127.875 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .61803 m
.16667 .05618 L
.25 .60979 L
.33333 .60979 L
.41667 .60979 L
.5 .60979 L
.58333 .60979 L
.66667 .60979 L
.75 .60979 L
.83333 .60979 L
.91667 .60979 L
1 .60979 L
s
1 .60979 m
1 .60979 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJy9WEtv3EYMHmskrdavfdqOH2tvgPyQPTWnArmmBdxu3QLJoWiRGj0V0K1B
/kGA5J4AeTRO0qSJ25/Q9hcU6D9RJVKcpYYzktZO6gPNJflxXvyGkj6dn976
5tv56e2T+fT6nfn3t26f/DD95Ls7uUmvKLUyVUqd9VWu/6T0v+ooS7OraabU
sv+P0yxRapJmEchQqUOQO2CPQB+ArkF2bdBBmsUkt8Eegt63QV+kWaDUNZAT
kEGaaaX2QA9BXgHZIW8uR8yyWaT5EtRDyLvPoDJNzCxDkAnIjSLNnOZxgTRd
kOtFmq9APQCpSde0tH3YiV1PmlWQa0WaE5YmIL1D2+pLsEZplPqaJSgmooq/
8mdY/ix/169tnVYIp2ycVmY8v6MW+biFspr9wYKbgH7IAregsngZ9MESMyzV
VAzzwAQxbfk2JYgJivpqWUH5qFMATUE/ALlHNZLrY6avXYRXszT7G5gDQyMT
YsiogVaGXLlX5aY0BxYLMfrUY/fpPL63GDYA2WHDIj1jFv5PEZ4wokUgB1Uy
YoIqqEuEMuH8vEW4qXjtCQ9UZR3nBWiNphGxmtKuKR3Z0HUK59BOdfECtEFH
b01ywSPfkZ2X284L3trH1QaoWZdmaTapgjWlFJuUwKGGsLoehKOFbw8y7I/y
3LD0QrphV0G3wnP197KYP4g5IK62hU+q1875B/IHdN1UPe2J6srbnm8utI9+
Pj6ZDprL98tRkXer921pObFBkpYdsVAxkiRkC5CPkC1W5iPjMglqKOnbJrS8
cxNTrnifJXjnpmciSlCAZpdxmhZfi8H1/raUc48V9uWdAT2tMfPAQ9tY5EKS
vV2AJFtrQUM2NG5Uj6jjB40YMfuiCeyy2oTwsSAjOvfswC1GQFMk/rzbjHpj
gvrDdxjpxgS1wvHeeFNup0W0TWZpgvooZuxYW7u0NQQdMnL1QedrumKHjxit
hiCTuvDZck68235dFOquw1yLMc4dVjKXdwb0dI5H8tqNYU5fH9TUDZugklYt
oLID9lg5cc5sM+9ru/f1GahbB5Jdr8uou2OH8343YuEdMQbO4JXd78YMFNeB
eL/joKgOJDsdJyDnVVOaRjLq6uN3QHfLYJEmEcSMRNfbskFdQc+O6HoIwnv4
pV3ISzvN1C+SEI9mVOdEedbGGdCF3hbjIykWW9QMdfa+JqiPpBuirEdsTWdu
knbEpTBiZ/LCTdKYQGZiLFySNGL1L6fHoJKqCA2aoZKwCDVP+LXoeubWZBqy
i4oytemkIfVTnAr2hl/ctE0IZI3KQJK23WbQ7DJO19Q5BgsFH5ief1ynuR7a
Ytq/Y3qgbV4wkV74QP+subfKLykigZO8VpEObFDje6V/PCeRdaupSiKH4qOP
AEkKI4HcH30Qju96T5s5jJI/weDuH1YSNFI3ZB+A+nYCSd1YfAASozqpGzaA
Zss58SPxkwVf+g6zweC2TT+m8371IGlaPQp5WH62lfirafbA6/yzMN8A9a9C
zRo+ED+CAj211MeQ4MdCvUeHo3kZ4j0RVrtCQN9E7bjPi5936ZZIqEACYblZ
Blo1yx/yNLNoVqgyBpL9zAivmYzEVSS9x/9PAmshtQmCKkHxIu5WH4bR/lkr
qK4eX+hOw0+E8+Z4ca7CfI/oXDU31SP9Vyv/AePUtyg=\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.77254, 23.1307, \
0.058375, 0.000958217}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.84612 0.446641 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .04716 -14.8125 -11.1875 ]
[-0.0125 .04716 0 11.1875 ]
[-0.0125 .13649 -36.4375 -11.1875 ]
[-0.0125 .13649 0 11.1875 ]
[-0.0125 .22582 -36.4375 -11.1875 ]
[-0.0125 .22582 0 11.1875 ]
[-0.0125 .31515 -36.4375 -11.1875 ]
[-0.0125 .31515 0 11.1875 ]
[-0.0125 .40447 -36.4375 -11.1875 ]
[-0.0125 .40447 0 11.1875 ]
[-0.0125 .4938 -14.8125 -11.1875 ]
[-0.0125 .4938 0 11.1875 ]
[-0.0125 .58313 -36.4375 -11.1875 ]
[-0.0125 .58313 0 11.1875 ]
[.5 .63053 -72.2813 0 ]
[.5 .63053 72.2813 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04716 m
.00625 .04716 L
s
gsave
-0.0125 .04716 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .13649 m
.00625 .13649 L
s
gsave
-0.0125 .13649 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
1.000 setlinewidth
grestore
0 .22582 m
.00625 .22582 L
s
gsave
-0.0125 .22582 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
1.000 setlinewidth
grestore
0 .31515 m
.00625 .31515 L
s
gsave
-0.0125 .31515 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
1.000 setlinewidth
grestore
0 .40447 m
.00625 .40447 L
s
gsave
-0.0125 .40447 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
1.000 setlinewidth
grestore
0 .4938 m
.00625 .4938 L
s
gsave
-0.0125 .4938 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
0 .58313 m
.00625 .58313 L
s
gsave
-0.0125 .58313 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06949 m
.00375 .06949 L
s
0 .09183 m
.00375 .09183 L
s
0 .11416 m
.00375 .11416 L
s
0 .15882 m
.00375 .15882 L
s
0 .18115 m
.00375 .18115 L
s
0 .20349 m
.00375 .20349 L
s
0 .24815 m
.00375 .24815 L
s
0 .27048 m
.00375 .27048 L
s
0 .29281 m
.00375 .29281 L
s
0 .33748 m
.00375 .33748 L
s
0 .35981 m
.00375 .35981 L
s
0 .38214 m
.00375 .38214 L
s
0 .42681 m
.00375 .42681 L
s
0 .44914 m
.00375 .44914 L
s
0 .47147 m
.00375 .47147 L
s
0 .51614 m
.00375 .51614 L
s
0 .53847 m
.00375 .53847 L
s
0 .5608 m
.00375 .5608 L
s
0 .02483 m
.00375 .02483 L
s
0 .0025 m
.00375 .0025 L
s
0 .60546 m
.00375 .60546 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -133.281 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Interest) show
160.313 20.000 moveto
(Rate) show
203.563 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .05618 m
.16667 .61803 L
.25 .06439 L
.33333 .06439 L
.41667 .06439 L
.5 .06439 L
.58333 .06439 L
.66667 .06439 L
.75 .06439 L
.83333 .06439 L
.91667 .06439 L
1 .06439 L
s
1 .06439 m
1 .06439 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJy1WMlyHEUQLXX1MhoJzaaesfYhgkAGxHGumAtwwhcWG24KBxH2wQFhfCSi
f4Sf4MK+g8yRK0eO8BVNd2Zn9auqXmZkrEMqJ/NlVlbVq6Xr7cvH9z96ePn4
wb3L5VuPLj+5/+Dep8s3P35UmPSWUltLpdQXY1Xonyn9tzrLs/z5LFdq0//v
ZPlAqZMsj0iGSp2SXJA9In1Cuia57wYdZ3ksck72kPSxG/RulgdKvUDyhGSQ
5VqpQ9JDkjdIJuIt5AwsB2Wa90g9pbxHEOqnicEyJTkQr1LvSx3XSLNNclGm
uUPqMUktupauHdFIHLSkGZKcl2nuQppA9ESGtS3BDsm0TPABJCgLUeVf9TOs
fla/u/u2S1Jm2TidzDx/Z2vkQ4tkNePDhDsh/RSAKTELaTAmSwyxwqmY6uAE
sQz5XBLEEsp6WjGoaHVJQUvSj0keCkdCym70+XXW1SrL/6TEpKqiqaxwle0Z
/WwNvQ1/6Cb+Zz3DORGeJ+Vfy2DjbgrBbPNLQlzb/LIsi8JKhldk+GzchSxm
Y94jy1+l81Xhi+P8FixHVcmGKT68GLHPq4E/B7pwl0cu5CbRwq9oSfLLqs+h
3RcPsupxMoHNivFiRv1OXh5fPbXTlALmiXBA047v8GEMO/Z14FNZ+w6hPOAM
gEMPyDvQ1yVwH4BMOg+SAmTQlWsOwKQLuAAg9ndClqMaOAF67tlUNbuiDTck
3bMJ297GVHY2h7wTOMO+qcY0JLhDYQ+46nEGMj8HzTHTp3TeMGvdag3MSLuB
HAftWTaEowFHlMtY1MCZTKPDew/IVMEyPEgK61G3NM0E/a7m6hiOxU74AuDm
5O6MQOp2xO3LIQ1xhrcT4loCEAAyb2cE7Mw4k1O4D7jynCy/r5mUNphNTApk
e5ZO5EEiy9GMPrPvBxcYews8deG4u/obhwefgcE/QedCWYHvg8HAtfKBhsmN
+5cHZ8OI7rhJF3AB22h9kR14IczWH10S8wm40wM3NY9IDmErGNVA5u6EJHZu
4QINd8Me4KrH2VSFH8OD89NGTk773PpOs32DuZHS7Vm6ie3Bp7CCfKYynD9W
fu4n9oHwQOBtxPaAqQCdej2gIVYfECdmjUq7rxN8SDNjf3Hp3N0GBLVdJzj7
dg1su054wFWPM5DrzAYxjpP3z19dJ6dNLGcgNzkwn1NvB12RLxJjkx5IQLdg
Z4g9oP9140EuZGloGRye498y/gqJ7FqOoel1IRfe1uxB/EI9iPMBFsgt3oYk
TbVw0O9Z43cVZ9E1ZNXjDOQzZoOY/83JN7CruhT+fjM3pqtqOTLLGr+VThsi
xkK6TSLM4PsHXlME3gyH8Ppio+Zyn+OV2JlxRtybycLEN4tCfVJD/C8tgMzl
ZcdhIEAad89AnnOeNOyYjTeSMwueNG1+dumN2x7P+B8l5C6Yr56ZIXdeme7I
I2sIExLIuy2fslpecmN5muXDepfmQwvRQ7xgYfytroZCGjxuIpDXX0YmlCYh
hkUyB4XctqNeK5N9CHuhBjprWGk7gBm2IHdE12IJW7K90dVsIlUaPaI+RLBu
AlmhiR3V2R8/sYanTsPBuCulli5E0EgknQ1Fxy5jCWOZk8YM0FQMD/hmwrZl
anEKd2HU0c76LSulRpqFQs1Iane4Fdkk3rWnNLIzvF43xBsRPndpeCe6XTN6
DMARWSY9kERumbebFmTbf7X1H5QYBxQ=\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.14136, 1.62272, \
0.058375, 0.0108915}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 0.0815083 0.359707 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .08151 -14.8125 -11.1875 ]
[-0.0125 .08151 0 11.1875 ]
[-0.0125 .17144 -47.25 -11.1875 ]
[-0.0125 .17144 0 11.1875 ]
[-0.0125 .26136 -36.4375 -11.1875 ]
[-0.0125 .26136 0 11.1875 ]
[-0.0125 .35129 -47.25 -11.1875 ]
[-0.0125 .35129 0 11.1875 ]
[-0.0125 .44122 -14.8125 -11.1875 ]
[-0.0125 .44122 0 11.1875 ]
[-0.0125 .53114 -47.25 -11.1875 ]
[-0.0125 .53114 0 11.1875 ]
[.5 .63053 -77.6875 0 ]
[.5 .63053 77.6875 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08151 m
.00625 .08151 L
s
gsave
-0.0125 .08151 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .17144 m
.00625 .17144 L
s
gsave
-0.0125 .17144 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
0 .26136 m
.00625 .26136 L
s
gsave
-0.0125 .26136 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .35129 m
.00625 .35129 L
s
gsave
-0.0125 .35129 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .44122 m
.00625 .44122 L
s
gsave
-0.0125 .44122 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .53114 m
.00625 .53114 L
s
gsave
-0.0125 .53114 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .09949 m
.00375 .09949 L
s
0 .11748 m
.00375 .11748 L
s
0 .13546 m
.00375 .13546 L
s
0 .15345 m
.00375 .15345 L
s
0 .18942 m
.00375 .18942 L
s
0 .20741 m
.00375 .20741 L
s
0 .22539 m
.00375 .22539 L
s
0 .24338 m
.00375 .24338 L
s
0 .27935 m
.00375 .27935 L
s
0 .29733 m
.00375 .29733 L
s
0 .31532 m
.00375 .31532 L
s
0 .3333 m
.00375 .3333 L
s
0 .36927 m
.00375 .36927 L
s
0 .38726 m
.00375 .38726 L
s
0 .40524 m
.00375 .40524 L
s
0 .42323 m
.00375 .42323 L
s
0 .4592 m
.00375 .4592 L
s
0 .47719 m
.00375 .47719 L
s
0 .49517 m
.00375 .49517 L
s
0 .51316 m
.00375 .51316 L
s
0 .54913 m
.00375 .54913 L
s
0 .56711 m
.00375 .56711 L
s
0 .5851 m
.00375 .5851 L
s
0 .60308 m
.00375 .60308 L
s
0 .06352 m
.00375 .06352 L
s
0 .04554 m
.00375 .04554 L
s
0 .02755 m
.00375 .02755 L
s
0 .00957 m
.00375 .00957 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -138.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Inflation) show
171.125 20.000 moveto
(Rate) show
214.375 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .44122 m
.16667 .61803 L
.25 .05618 L
.33333 .44122 L
.41667 .44122 L
.5 .44122 L
.58333 .44122 L
.66667 .44122 L
.75 .44122 L
.83333 .44122 L
.91667 .44122 L
1 .44122 L
s
1 .44122 m
1 .44122 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzNWMuOG0UUremn7fHYbntsz3uMFCAZZoYgYIOXkWDFGjEQ0ChCShYIFLJE
6j38BM/wJmQPBPgAvgHxI033Ld/q0/Vot0cTYBY11/eec6vqPqq6+9Xze7ff
eff83p1b57NX7p6/f/vOrQ9mL793N1f5a0KszYQQDwcilz8U/l/iMEuzJ9JM
iFX/v55mLSH20ywUYi/NAiEOaJySPiQ5Idmnsa+TdtMsImo+TkgfkDzQSWdp
5glxhcY9Gr0084XYITmgcYvGmK35OALNZuHmDRIPyC9STTcRaIY0ttilEG+S
uH8hN22WhbgJ2/Fp3KVNya3J2Gw73HRoTAo3b1WjIt3EHFaXg3UaB4WDt8FB
sRBR/O3Kn8Hi58Jcv7cujZxlZdQ8y5+HDfyhhr2q+OxTee2RfADAMVUWlsGA
NBFwuaYiWod0FnHIJ+wgYqqSqYLyWWdEOuQVBJz6FsmbICcX6at5mv1JXUSi
yKdKc1Mxn1WeNcCgPNYd//04FNdBfvAvGZ+lyD8s1KcU/nbVmIs/FcYTSmjL
aVSl44AcQ73FjSD5eJ1W9GAJfxnktNpMjxXrisQp6H+0x9OAmPkwIPOmxhPY
ww//H2NI4/eFsUe7bVE5hHyZaSEySBsEiYHk0YhpOoaDkUl40KlqC8hNVEft
wpYkdYMhzUgJnPoScgIr+E6Hq5vLujAHacRybAuEg7TJd6oW8lpSD2Sfd6ao
z5BG3t7f6oHvw93SjCrvk8i2MwMui2lIY7gcPl/NKJ8kvlnJeETq9cswblc7
RUvYEVTY1wV8C3okMLrDBldJUvnVys8gTY1KQvg16BQ3PB+PYNavdODIWMa1
OnjPSPsyuBbIZXCtZA04BrLvgEv9/TJNfWPVV+GwuV+mf7AcOL9Eozy3vrw8
49NwvjmM8hz7Qr8cWlwwWr4MEl4OkhQa5W8jqawNuWesTWBQzYN73WiFVUj5
eBVa5HML3KeTSlvYU2Qd20muy6EZSQv5MpL1bDdI2rXguW8USZ3Q+FmZ4j4/
Llj3BPAet04zOJbkk6Se1hllw3/6XxmPjeKWEPk6+4kdIr8P7JQQ+T7QWQ3S
A3nkhMv0msCPFy9uVr+q/PM3zY+cQPQru+hnJ1A12i92yKAqM/CY3ms7hjGp
gyTG1I5JHcB5FaJOacM4NKJmg6gL6lfdOAK564R43KyGcRPkdSfEE+i8S9UY
1T7xj0Hu1FHN5/4xnKZEwty7nvgnIMs741FJxQg0JuG2IzhE2jpwzEWhLWkK
cqyTJo7jXM5hLGbKB6sW5i2QI52U1J7J+A3x0SI3IZFqnu+3QZaOfyupQ8dT
vjzIwhKusmJ9yt8B2S9J8ypE7cww7oLsOSEqJoZxr9iblN0ANYEQv1vsHnxf
MOz7PIHLGljUB5SRFdT5Ev4o1DdBTVvJLvgJ/DVu9QA253EH+/xNO8BPqfLD
eMAfyUOFAH6H9D6nxMKXz4wvNF1EPra5Dj1eVmxjyak9Lvk2IHPW8wXwDNrE
h0LuwMEQgB4xEXeRD/tThwrqTQ+ycl9avoSYVmwuCp3htB4fvooV084b7LZF
eWg4VcQfk92T+LxNdNm1BRnDqFhd2kMH8DHIMFUExRFB0LBmUYP5CarIeFGH
Z7CyslwDmKLF5a6mUJoKZ6NaAGG1XV4sJxtBSKT8HKxTPl/cKHtkADWP1Ctk
TXR4QrmywmO+fG+sclyItX8Axwi1qg==\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.45695, -0.563949, \
0.058375, 0.0135237}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -125.955 2.47214 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .12361 -25.625 -11.1875 ]
[-0.0125 .12361 0 11.1875 ]
[-0.0125 .24721 -58.0625 -11.1875 ]
[-0.0125 .24721 0 11.1875 ]
[-0.0125 .37082 -47.25 -11.1875 ]
[-0.0125 .37082 0 11.1875 ]
[-0.0125 .49443 -58.0625 -11.1875 ]
[-0.0125 .49443 0 11.1875 ]
[-0.0125 .61803 -47.25 -11.1875 ]
[-0.0125 .61803 0 11.1875 ]
[.5 .63053 -88.7188 0 ]
[.5 .63053 88.7188 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
gsave
-0.0125 .12361 -86.625 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51) show
1.000 setlinewidth
grestore
0 .24721 m
.00625 .24721 L
s
gsave
-0.0125 .24721 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.05) show
1.000 setlinewidth
grestore
0 .37082 m
.00625 .37082 L
s
gsave
-0.0125 .37082 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.1) show
1.000 setlinewidth
grestore
0 .49443 m
.00625 .49443 L
s
gsave
-0.0125 .49443 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.15) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -149.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Checking) show
160.750 20.000 moveto
(Account) show
236.438 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .13597 m
.16667 .1472 L
.25 .1472 L
.33333 .1472 L
.41667 .1472 L
.5 .1472 L
.58333 .1472 L
.66667 .1472 L
.75 .1472 L
.83333 .1472 L
.91667 .1472 L
1 .1472 L
s
1 .1472 m
1 .1472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzdWEtv1DAQdm3H2ewDdtvtFvpcoKIXuHJEnOCERNU7sBREe0BUpRcQUn4N
J8QB/gInLvALqDgV/kVIxhlnbCebbBHlUamzk/Hn8Wf78+Rxd3K09+TZ5Gh/
dzK+czg52NvffTG+/fwwDYk5xubGjLH3fZb6r5n4xjaSOLkUJ4zN+ns/TlqM
rcVJAFYytg52CeIB+APwBdjI7bQaJwrtCOIS/L7b6UGccMY2wa6B5XEiGFsG
X4K9ADbE1tQukMi5LM1DcNch7wrp6qdRJDIPtgW2l6WZII9TpInAdrM0j8Bd
BSvQFzi1FViJixVp2mA7WZpdkoajH+KyViXoYBrGHpMEGRGW/eWXMr/Mr6fP
rYszhF02jU5mvX8bDfLRCGY166MFtwb+OgEugrKoDPoQUaQvakoBD51A4ZKP
MIHCrtpv5wpKRx1DpzH4q2CXUSOpPyR+5zTn6lacfIGTAy5Lh4rTpoyq8ccV
8Sqf4s+7ib82DqTzOj5973803RZsfwDHXbm4q1i2Khq1LgWKOXIh14nS6xqR
0LWKhD2IfM45h3gKHEga/1RMq+VBUnl0GPuYQ6xjjZAhQN6SSL+AR3BmNN30
RH3IlawZSWykKn1nQXzSf1wBvztdaCtMQERCRIFvw5WtOa0FhTdMT4XKU+E8
qY6CtAZu1x4R4MCuxhzgOKVaoJ23S8hQeKucRkiEQeEC4t6EQ6JsB162nCFR
uQM3N8rjAqj1TZdQmptxCWuJcAV+BV8zvQXc+DLgGWj0rM7AwJN8RYHte2Kv
BjoyH5ZXkiWi1VkgSH1UP8SA7Gg1xIi0GmKEORWiJTkghfe4YCHtxpmJ/lWV
8tfS+XU2wDeNZnVWw3nTOjskZbJBhR2S/Z4FiNPrekN36uvpEPPWVVIDrKuh
Q8K0rCg6gjVAskuObKvZNZvGfyRhr+0sCul8+V7SKqnftdvTIFML6SLYH25N
GoH9XkxUa1GnPXGLJL17k0ajNoEvgCfFOPT+/BTsK5eEvifvQeRl1vgGwuDu
QHcJCPOKy/FDRoDPZXpkibVDlOFppAOXAq1JFZB32eLlnHvp9MeXzSywHSdR
GUSQjyy8AUONpMQ4ySBwMVtlY+kHn8s5HVO1hGcjU7CklhFEi5nqDQntfgIt
rYjcK33+pelr8PTJj3IE6vdIpTKDR/gU2IZZR2UETTL9+mWmyu0naYr3iWzV
UzBpZiJi1qvUn4WUsF8q6EaYrgGe4dDGm+3oeZsrvTyc4B2CwqZvEwxRihJF
y4lQBa6dufFHSMdgAk/zgtQVeqauFCMrQrHQssKzHGD+9J9XUxJOZ0mvHZpO
VlF2KW3iVnpZTGGbrKyegv52dwMiN4tVNoVGwAc1gTrdgtEIcMepD/U9mn45
Y3M/AaTKSYM=\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.77254, 50.9007, \
0.058375, 0.00196776}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -50.2804 1.22382 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .01882 -47.25 -11.1875 ]
[-0.0125 .01882 0 11.1875 ]
[-0.0125 .1412 -47.25 -11.1875 ]
[-0.0125 .1412 0 11.1875 ]
[-0.0125 .26358 -47.25 -11.1875 ]
[-0.0125 .26358 0 11.1875 ]
[-0.0125 .38597 -47.25 -11.1875 ]
[-0.0125 .38597 0 11.1875 ]
[-0.0125 .50835 -47.25 -11.1875 ]
[-0.0125 .50835 0 11.1875 ]
[.5 .63053 -83.3125 0 ]
[.5 .63053 83.3125 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01882 m
.00625 .01882 L
s
gsave
-0.0125 .01882 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.1) show
1.000 setlinewidth
grestore
0 .1412 m
.00625 .1412 L
s
gsave
-0.0125 .1412 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.2) show
1.000 setlinewidth
grestore
0 .26358 m
.00625 .26358 L
s
gsave
-0.0125 .26358 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.3) show
1.000 setlinewidth
grestore
0 .38597 m
.00625 .38597 L
s
gsave
-0.0125 .38597 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.4) show
1.000 setlinewidth
grestore
0 .50835 m
.00625 .50835 L
s
gsave
-0.0125 .50835 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0433 m
.00375 .0433 L
s
0 .06777 m
.00375 .06777 L
s
0 .09225 m
.00375 .09225 L
s
0 .11672 m
.00375 .11672 L
s
0 .16568 m
.00375 .16568 L
s
0 .19015 m
.00375 .19015 L
s
0 .21463 m
.00375 .21463 L
s
0 .23911 m
.00375 .23911 L
s
0 .28806 m
.00375 .28806 L
s
0 .31254 m
.00375 .31254 L
s
0 .33701 m
.00375 .33701 L
s
0 .36149 m
.00375 .36149 L
s
0 .41044 m
.00375 .41044 L
s
0 .43492 m
.00375 .43492 L
s
0 .4594 m
.00375 .4594 L
s
0 .48387 m
.00375 .48387 L
s
0 .53282 m
.00375 .53282 L
s
0 .5573 m
.00375 .5573 L
s
0 .58178 m
.00375 .58178 L
s
0 .60625 m
.00375 .60625 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -144.313 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Savings) show
149.938 20.000 moveto
(Account) show
225.625 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .06175 m
.16667 .05618 L
.25 .61803 L
.33333 .54396 L
.41667 .47939 L
.5 .42311 L
.58333 .37405 L
.66667 .33128 L
.75 .29401 L
.83333 .26152 L
.91667 .23319 L
1 .20851 L
s
1 .20851 m
1 .20851 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.45695, 40.9856, \
0.058375, 0.00397491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -9.00113 1.22382 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .05517 -36.4375 -11.1875 ]
[-0.0125 .05517 0 11.1875 ]
[-0.0125 .17755 -36.4375 -11.1875 ]
[-0.0125 .17755 0 11.1875 ]
[-0.0125 .29993 -36.4375 -11.1875 ]
[-0.0125 .29993 0 11.1875 ]
[-0.0125 .42232 -36.4375 -11.1875 ]
[-0.0125 .42232 0 11.1875 ]
[-0.0125 .5447 -36.4375 -11.1875 ]
[-0.0125 .5447 0 11.1875 ]
[.5 .63053 -94.0313 0 ]
[.5 .63053 94.0313 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05517 m
.00625 .05517 L
s
gsave
-0.0125 .05517 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.4) show
1.000 setlinewidth
grestore
0 .17755 m
.00625 .17755 L
s
gsave
-0.0125 .17755 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.5) show
1.000 setlinewidth
grestore
0 .29993 m
.00625 .29993 L
s
gsave
-0.0125 .29993 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.6) show
1.000 setlinewidth
grestore
0 .42232 m
.00625 .42232 L
s
gsave
-0.0125 .42232 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.7) show
1.000 setlinewidth
grestore
0 .5447 m
.00625 .5447 L
s
gsave
-0.0125 .5447 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07965 m
.00375 .07965 L
s
0 .10412 m
.00375 .10412 L
s
0 .1286 m
.00375 .1286 L
s
0 .15308 m
.00375 .15308 L
s
0 .20203 m
.00375 .20203 L
s
0 .22651 m
.00375 .22651 L
s
0 .25098 m
.00375 .25098 L
s
0 .27546 m
.00375 .27546 L
s
0 .32441 m
.00375 .32441 L
s
0 .34889 m
.00375 .34889 L
s
0 .37336 m
.00375 .37336 L
s
0 .39784 m
.00375 .39784 L
s
0 .44679 m
.00375 .44679 L
s
0 .47127 m
.00375 .47127 L
s
0 .49575 m
.00375 .49575 L
s
0 .52022 m
.00375 .52022 L
s
0 .03069 m
.00375 .03069 L
s
0 .00622 m
.00375 .00622 L
s
0 .56918 m
.00375 .56918 L
s
0 .59365 m
.00375 .59365 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -155.031 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Retained) show
160.563 20.000 moveto
(Earnings) show
247.063 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .61803 m
.16667 .61803 L
.25 .05618 L
.33333 .13026 L
.41667 .19483 L
.5 .25111 L
.58333 .30017 L
.66667 .34293 L
.75 .38021 L
.83333 .4127 L
.91667 .44102 L
1 .46571 L
s
1 .46571 m
1 .46571 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.14136, 7.25579, \
0.058375, 0.00397491}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .40558 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00965678 0.31746 [
[ 0 0 0 0 ]
[ 1 .40558 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .40558 L
0 .40558 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00965678 0.321429 0.193595 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -125.955 2.47214 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .12361 -25.625 -11.1875 ]
[-0.0125 .12361 0 11.1875 ]
[-0.0125 .24721 -58.0625 -11.1875 ]
[-0.0125 .24721 0 11.1875 ]
[-0.0125 .37082 -47.25 -11.1875 ]
[-0.0125 .37082 0 11.1875 ]
[-0.0125 .49443 -58.0625 -11.1875 ]
[-0.0125 .49443 0 11.1875 ]
[-0.0125 .61803 -47.25 -11.1875 ]
[-0.0125 .61803 0 11.1875 ]
[.5 .63053 -88.7188 0 ]
[.5 .63053 88.7188 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12361 m
.00625 .12361 L
s
gsave
-0.0125 .12361 -86.625 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51) show
1.000 setlinewidth
grestore
0 .24721 m
.00625 .24721 L
s
gsave
-0.0125 .24721 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.05) show
1.000 setlinewidth
grestore
0 .37082 m
.00625 .37082 L
s
gsave
-0.0125 .37082 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.1) show
1.000 setlinewidth
grestore
0 .49443 m
.00625 .49443 L
s
gsave
-0.0125 .49443 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.15) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02472 m
.00375 .02472 L
s
0 .04944 m
.00375 .04944 L
s
0 .07416 m
.00375 .07416 L
s
0 .09889 m
.00375 .09889 L
s
0 .14833 m
.00375 .14833 L
s
0 .17305 m
.00375 .17305 L
s
0 .19777 m
.00375 .19777 L
s
0 .22249 m
.00375 .22249 L
s
0 .27193 m
.00375 .27193 L
s
0 .29666 m
.00375 .29666 L
s
0 .32138 m
.00375 .32138 L
s
0 .3461 m
.00375 .3461 L
s
0 .39554 m
.00375 .39554 L
s
0 .42026 m
.00375 .42026 L
s
0 .44498 m
.00375 .44498 L
s
0 .46971 m
.00375 .46971 L
s
0 .51915 m
.00375 .51915 L
s
0 .54387 m
.00375 .54387 L
s
0 .56859 m
.00375 .56859 L
s
0 .59331 m
.00375 .59331 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -149.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Checking) show
160.750 20.000 moveto
(Account) show
236.438 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .13597 m
.16667 .1472 L
.25 .1472 L
.33333 .1472 L
.41667 .1472 L
.5 .1472 L
.58333 .1472 L
.66667 .1472 L
.75 .1472 L
.83333 .1472 L
.91667 .1472 L
1 .1472 L
s
1 .1472 m
1 .1472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00965678 0.64881 0.193595 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -50.2804 1.22382 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .01882 -47.25 -11.1875 ]
[-0.0125 .01882 0 11.1875 ]
[-0.0125 .1412 -47.25 -11.1875 ]
[-0.0125 .1412 0 11.1875 ]
[-0.0125 .26358 -47.25 -11.1875 ]
[-0.0125 .26358 0 11.1875 ]
[-0.0125 .38597 -47.25 -11.1875 ]
[-0.0125 .38597 0 11.1875 ]
[-0.0125 .50835 -47.25 -11.1875 ]
[-0.0125 .50835 0 11.1875 ]
[.5 .63053 -83.3125 0 ]
[.5 .63053 83.3125 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01882 m
.00625 .01882 L
s
gsave
-0.0125 .01882 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.1) show
1.000 setlinewidth
grestore
0 .1412 m
.00625 .1412 L
s
gsave
-0.0125 .1412 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.2) show
1.000 setlinewidth
grestore
0 .26358 m
.00625 .26358 L
s
gsave
-0.0125 .26358 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.3) show
1.000 setlinewidth
grestore
0 .38597 m
.00625 .38597 L
s
gsave
-0.0125 .38597 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.4) show
1.000 setlinewidth
grestore
0 .50835 m
.00625 .50835 L
s
gsave
-0.0125 .50835 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0433 m
.00375 .0433 L
s
0 .06777 m
.00375 .06777 L
s
0 .09225 m
.00375 .09225 L
s
0 .11672 m
.00375 .11672 L
s
0 .16568 m
.00375 .16568 L
s
0 .19015 m
.00375 .19015 L
s
0 .21463 m
.00375 .21463 L
s
0 .23911 m
.00375 .23911 L
s
0 .28806 m
.00375 .28806 L
s
0 .31254 m
.00375 .31254 L
s
0 .33701 m
.00375 .33701 L
s
0 .36149 m
.00375 .36149 L
s
0 .41044 m
.00375 .41044 L
s
0 .43492 m
.00375 .43492 L
s
0 .4594 m
.00375 .4594 L
s
0 .48387 m
.00375 .48387 L
s
0 .53282 m
.00375 .53282 L
s
0 .5573 m
.00375 .5573 L
s
0 .58178 m
.00375 .58178 L
s
0 .60625 m
.00375 .60625 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -144.313 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Savings) show
149.938 20.000 moveto
(Account) show
225.625 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .06175 m
.16667 .05618 L
.25 .61803 L
.33333 .54396 L
.41667 .47939 L
.5 .42311 L
.58333 .37405 L
.66667 .33128 L
.75 .29401 L
.83333 .26152 L
.91667 .23319 L
1 .20851 L
s
1 .20851 m
1 .20851 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00965678 0.97619 0.193595 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -9.00113 1.22382 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .05517 -36.4375 -11.1875 ]
[-0.0125 .05517 0 11.1875 ]
[-0.0125 .17755 -36.4375 -11.1875 ]
[-0.0125 .17755 0 11.1875 ]
[-0.0125 .29993 -36.4375 -11.1875 ]
[-0.0125 .29993 0 11.1875 ]
[-0.0125 .42232 -36.4375 -11.1875 ]
[-0.0125 .42232 0 11.1875 ]
[-0.0125 .5447 -36.4375 -11.1875 ]
[-0.0125 .5447 0 11.1875 ]
[.5 .63053 -94.0313 0 ]
[.5 .63053 94.0313 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05517 m
.00625 .05517 L
s
gsave
-0.0125 .05517 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.4) show
1.000 setlinewidth
grestore
0 .17755 m
.00625 .17755 L
s
gsave
-0.0125 .17755 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.5) show
1.000 setlinewidth
grestore
0 .29993 m
.00625 .29993 L
s
gsave
-0.0125 .29993 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.6) show
1.000 setlinewidth
grestore
0 .42232 m
.00625 .42232 L
s
gsave
-0.0125 .42232 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.7) show
1.000 setlinewidth
grestore
0 .5447 m
.00625 .5447 L
s
gsave
-0.0125 .5447 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .07965 m
.00375 .07965 L
s
0 .10412 m
.00375 .10412 L
s
0 .1286 m
.00375 .1286 L
s
0 .15308 m
.00375 .15308 L
s
0 .20203 m
.00375 .20203 L
s
0 .22651 m
.00375 .22651 L
s
0 .25098 m
.00375 .25098 L
s
0 .27546 m
.00375 .27546 L
s
0 .32441 m
.00375 .32441 L
s
0 .34889 m
.00375 .34889 L
s
0 .37336 m
.00375 .37336 L
s
0 .39784 m
.00375 .39784 L
s
0 .44679 m
.00375 .44679 L
s
0 .47127 m
.00375 .47127 L
s
0 .49575 m
.00375 .49575 L
s
0 .52022 m
.00375 .52022 L
s
0 .03069 m
.00375 .03069 L
s
0 .00622 m
.00375 .00622 L
s
0 .56918 m
.00375 .56918 L
s
0 .59365 m
.00375 .59365 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -155.031 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Retained) show
160.563 20.000 moveto
(Earnings) show
247.063 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .61803 m
.16667 .61803 L
.25 .05618 L
.33333 .13026 L
.41667 .19483 L
.5 .25111 L
.58333 .30017 L
.66667 .34293 L
.75 .38021 L
.83333 .4127 L
.91667 .44102 L
1 .46571 L
s
1 .46571 m
1 .46571 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.211989 0.321429 0.395928 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -117.549 5.0767 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .02716 -58.0625 -11.1875 ]
[-0.0125 .02716 0 11.1875 ]
[-0.0125 .12869 -58.0625 -11.1875 ]
[-0.0125 .12869 0 11.1875 ]
[-0.0125 .23023 -47.25 -11.1875 ]
[-0.0125 .23023 0 11.1875 ]
[-0.0125 .33176 -58.0625 -11.1875 ]
[-0.0125 .33176 0 11.1875 ]
[-0.0125 .43329 -58.0625 -11.1875 ]
[-0.0125 .43329 0 11.1875 ]
[-0.0125 .53483 -58.0625 -11.1875 ]
[-0.0125 .53483 0 11.1875 ]
[.5 .63053 -34.4375 0 ]
[.5 .63053 34.4375 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02716 m
.00625 .02716 L
s
gsave
-0.0125 .02716 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.16) show
1.000 setlinewidth
grestore
0 .12869 m
.00625 .12869 L
s
gsave
-0.0125 .12869 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.18) show
1.000 setlinewidth
grestore
0 .23023 m
.00625 .23023 L
s
gsave
-0.0125 .23023 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.2) show
1.000 setlinewidth
grestore
0 .33176 m
.00625 .33176 L
s
gsave
-0.0125 .33176 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.22) show
1.000 setlinewidth
grestore
0 .43329 m
.00625 .43329 L
s
gsave
-0.0125 .43329 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.24) show
1.000 setlinewidth
grestore
0 .53483 m
.00625 .53483 L
s
gsave
-0.0125 .53483 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.26) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05254 m
.00375 .05254 L
s
0 .07793 m
.00375 .07793 L
s
0 .10331 m
.00375 .10331 L
s
0 .15408 m
.00375 .15408 L
s
0 .17946 m
.00375 .17946 L
s
0 .20484 m
.00375 .20484 L
s
0 .25561 m
.00375 .25561 L
s
0 .28099 m
.00375 .28099 L
s
0 .30638 m
.00375 .30638 L
s
0 .35714 m
.00375 .35714 L
s
0 .38253 m
.00375 .38253 L
s
0 .40791 m
.00375 .40791 L
s
0 .45868 m
.00375 .45868 L
s
0 .48406 m
.00375 .48406 L
s
0 .50945 m
.00375 .50945 L
s
0 .00178 m
.00375 .00178 L
s
0 .56021 m
.00375 .56021 L
s
0 .5856 m
.00375 .5856 L
s
0 .61098 m
.00375 .61098 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -95.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Output) show
127.875 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .61803 m
.16667 .05618 L
.25 .60979 L
.33333 .60979 L
.41667 .60979 L
.5 .60979 L
.58333 .60979 L
.66667 .60979 L
.75 .60979 L
.83333 .60979 L
.91667 .60979 L
1 .60979 L
s
1 .60979 m
1 .60979 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.211989 0.64881 0.395928 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.84612 0.446641 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .04716 -14.8125 -11.1875 ]
[-0.0125 .04716 0 11.1875 ]
[-0.0125 .13649 -36.4375 -11.1875 ]
[-0.0125 .13649 0 11.1875 ]
[-0.0125 .22582 -36.4375 -11.1875 ]
[-0.0125 .22582 0 11.1875 ]
[-0.0125 .31515 -36.4375 -11.1875 ]
[-0.0125 .31515 0 11.1875 ]
[-0.0125 .40447 -36.4375 -11.1875 ]
[-0.0125 .40447 0 11.1875 ]
[-0.0125 .4938 -14.8125 -11.1875 ]
[-0.0125 .4938 0 11.1875 ]
[-0.0125 .58313 -36.4375 -11.1875 ]
[-0.0125 .58313 0 11.1875 ]
[.5 .63053 -72.2813 0 ]
[.5 .63053 72.2813 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04716 m
.00625 .04716 L
s
gsave
-0.0125 .04716 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .13649 m
.00625 .13649 L
s
gsave
-0.0125 .13649 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
1.000 setlinewidth
grestore
0 .22582 m
.00625 .22582 L
s
gsave
-0.0125 .22582 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
1.000 setlinewidth
grestore
0 .31515 m
.00625 .31515 L
s
gsave
-0.0125 .31515 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
1.000 setlinewidth
grestore
0 .40447 m
.00625 .40447 L
s
gsave
-0.0125 .40447 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
1.000 setlinewidth
grestore
0 .4938 m
.00625 .4938 L
s
gsave
-0.0125 .4938 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
0 .58313 m
.00625 .58313 L
s
gsave
-0.0125 .58313 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06949 m
.00375 .06949 L
s
0 .09183 m
.00375 .09183 L
s
0 .11416 m
.00375 .11416 L
s
0 .15882 m
.00375 .15882 L
s
0 .18115 m
.00375 .18115 L
s
0 .20349 m
.00375 .20349 L
s
0 .24815 m
.00375 .24815 L
s
0 .27048 m
.00375 .27048 L
s
0 .29281 m
.00375 .29281 L
s
0 .33748 m
.00375 .33748 L
s
0 .35981 m
.00375 .35981 L
s
0 .38214 m
.00375 .38214 L
s
0 .42681 m
.00375 .42681 L
s
0 .44914 m
.00375 .44914 L
s
0 .47147 m
.00375 .47147 L
s
0 .51614 m
.00375 .51614 L
s
0 .53847 m
.00375 .53847 L
s
0 .5608 m
.00375 .5608 L
s
0 .02483 m
.00375 .02483 L
s
0 .0025 m
.00375 .0025 L
s
0 .60546 m
.00375 .60546 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -133.281 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Interest) show
160.313 20.000 moveto
(Rate) show
203.563 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .05618 m
.16667 .61803 L
.25 .06439 L
.33333 .06439 L
.41667 .06439 L
.5 .06439 L
.58333 .06439 L
.66667 .06439 L
.75 .06439 L
.83333 .06439 L
.91667 .06439 L
1 .06439 L
s
1 .06439 m
1 .06439 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.211989 0.97619 0.395928 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 0.0815083 0.359707 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .08151 -14.8125 -11.1875 ]
[-0.0125 .08151 0 11.1875 ]
[-0.0125 .17144 -47.25 -11.1875 ]
[-0.0125 .17144 0 11.1875 ]
[-0.0125 .26136 -36.4375 -11.1875 ]
[-0.0125 .26136 0 11.1875 ]
[-0.0125 .35129 -47.25 -11.1875 ]
[-0.0125 .35129 0 11.1875 ]
[-0.0125 .44122 -14.8125 -11.1875 ]
[-0.0125 .44122 0 11.1875 ]
[-0.0125 .53114 -47.25 -11.1875 ]
[-0.0125 .53114 0 11.1875 ]
[.5 .63053 -77.6875 0 ]
[.5 .63053 77.6875 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08151 m
.00625 .08151 L
s
gsave
-0.0125 .08151 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .17144 m
.00625 .17144 L
s
gsave
-0.0125 .17144 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
0 .26136 m
.00625 .26136 L
s
gsave
-0.0125 .26136 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .35129 m
.00625 .35129 L
s
gsave
-0.0125 .35129 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
0 .44122 m
.00625 .44122 L
s
gsave
-0.0125 .44122 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .53114 m
.00625 .53114 L
s
gsave
-0.0125 .53114 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .09949 m
.00375 .09949 L
s
0 .11748 m
.00375 .11748 L
s
0 .13546 m
.00375 .13546 L
s
0 .15345 m
.00375 .15345 L
s
0 .18942 m
.00375 .18942 L
s
0 .20741 m
.00375 .20741 L
s
0 .22539 m
.00375 .22539 L
s
0 .24338 m
.00375 .24338 L
s
0 .27935 m
.00375 .27935 L
s
0 .29733 m
.00375 .29733 L
s
0 .31532 m
.00375 .31532 L
s
0 .3333 m
.00375 .3333 L
s
0 .36927 m
.00375 .36927 L
s
0 .38726 m
.00375 .38726 L
s
0 .40524 m
.00375 .40524 L
s
0 .42323 m
.00375 .42323 L
s
0 .4592 m
.00375 .4592 L
s
0 .47719 m
.00375 .47719 L
s
0 .49517 m
.00375 .49517 L
s
0 .51316 m
.00375 .51316 L
s
0 .54913 m
.00375 .54913 L
s
0 .56711 m
.00375 .56711 L
s
0 .5851 m
.00375 .5851 L
s
0 .60308 m
.00375 .60308 L
s
0 .06352 m
.00375 .06352 L
s
0 .04554 m
.00375 .04554 L
s
0 .02755 m
.00375 .02755 L
s
0 .00957 m
.00375 .00957 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -138.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Inflation) show
171.125 20.000 moveto
(Rate) show
214.375 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .44122 m
.16667 .61803 L
.25 .05618 L
.33333 .44122 L
.41667 .44122 L
.5 .44122 L
.58333 .44122 L
.66667 .44122 L
.75 .44122 L
.83333 .44122 L
.91667 .44122 L
1 .44122 L
s
1 .44122 m
1 .44122 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 116.75},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {115.75, 0}} -> {-0.0838802, -0.0304253, \
0.0110375, 0.0110375}, {{7.5625, 92.5}, {112.938, 60.5}} -> {-44.2196, \
50.0925, 1.00376, 0.0338359}, {{101, 185.938}, {112.938, 60.5}} -> {-138.009, \
39.353, 1.00376, 0.0683491}, {{194.438, 279.375}, {112.938, 60.5}} -> \
{-231.798, 5.62319, 1.00376, 0.0683491}, {{7.5625, 92.5}, {55.25, 2.75}} -> \
{-58.6509, 21.7977, 0.99567, 0.0163438}, {{101, 185.938}, {55.25, 2.75}} -> \
{-136.847, -13.5293, 0.99567, 0.18577}, {{194.438, 279.375}, {55.25, 2.75}} -> \
{-229.88, -19.3779, 0.99567, 0.230667}}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", "\"\<c:/temp\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<imp_base.eps\>\"", ",", "plot", ",", "\"\<EPS\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "1000"}]}], "]"}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing the Autocorrelation Function", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"nsim", "=", "10000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ndist", "=", 
    RowBox[{"NormalDistribution", "[", 
     RowBox[{"0", ",", "1"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssim", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"nsim", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dsim", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"nsim", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xsim", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"nsim", "+", "1"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"csim", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"nsim", "+", "1"}]}], "}"}]}], "]"}]}], ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ssim", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "=", 
   RowBox[{"First", "[", 
    RowBox[{"sbar", "/.", "ssresult"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dsim", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "=", 
   RowBox[{"First", "[", 
    RowBox[{"dbar", "/.", "ssresult"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"xsim", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "=", "xmean"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"j", "=", "1"}], ",", 
   RowBox[{"j", "<", 
    RowBox[{"nsim", "+", "1"}]}], ",", 
   RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"simrule", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "\[Rule]", 
        RowBox[{"ssim", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], ",", 
       RowBox[{"d", "\[Rule]", 
        RowBox[{"dsim", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], ",", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{"xsim", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], ",", 
       RowBox[{"\[Sigma]", "\[Rule]", "0.006"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"csim", "[", 
      RowBox[{"[", "j", "]"}], "]"}], "=", 
     RowBox[{"First", "@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"csimfun", "/.", "simrule"}], "]"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ssim", "[", 
      RowBox[{"[", 
       RowBox[{"j", "+", "1"}], "]"}], "]"}], "=", 
     RowBox[{"First", "@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"ssimfun", "/.", "simrule"}], "]"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"dsim", "[", 
      RowBox[{"[", 
       RowBox[{"j", "+", "1"}], "]"}], "]"}], "=", 
     RowBox[{"First", "@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"dsimfun", "/.", "simrule"}], "]"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xsim", "[", 
      RowBox[{"[", 
       RowBox[{"j", "+", "1"}], "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"xconst", "+", 
        RowBox[{"\[Rho]", " ", 
         RowBox[{"xsim", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], "+", 
        RowBox[{"\[Sigma]", " ", 
         RowBox[{"Random", "[", "ndist", "]"}]}]}], "/.", "param"}], "/.", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", "\[Rule]", "0.006"}], "}"}]}]}], ";"}]}], 
  "\[IndentingNewLine]", "]"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"autocorrtab", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Correlation", "[", 
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"csim", ",", 
        RowBox[{"-", "j"}]}], "]"}], ",", 
      RowBox[{"Drop", "[", 
       RowBox[{"csim", ",", "j"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "6"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.00991908194332946`"}], ",", 
   RowBox[{"-", "0.024487043968402962`"}], ",", "0.007947967520641417`", ",", 
   RowBox[{"-", "0.011789300347654035`"}], ",", 
   RowBox[{"-", "0.031450448977813905`"}], ",", 
   RowBox[{"-", "0.0026027600422398383`"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.08763753204599779`", ",", 
   RowBox[{"-", "0.011675042111376948`"}], ",", 
   RowBox[{"-", "0.010544513751081534`"}], ",", 
   RowBox[{"-", "0.00983234796629448`"}], ",", 
   RowBox[{"-", "0.08738159425996381`"}], ",", 
   RowBox[{"-", "0.09452212368674089`"}]}], "}"}]], "Input"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{882, 675},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (April 11, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 34, 0, 101, "Title"],
Cell[617, 24, 57, 0, 56, "Subtitle"],
Cell[677, 26, 461, 9, 125, "Text"],
Cell[1141, 37, 416, 8, 112, "Input"],
Cell[CellGroupData[{
Cell[1582, 49, 33, 0, 70, "Section"],
Cell[1618, 51, 979, 29, 112, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2634, 85, 38, 0, 70, "Section"],
Cell[2675, 87, 1954, 67, 128, "Input"],
Cell[4632, 156, 118, 3, 30, "Text"],
Cell[4753, 161, 2954, 100, 292, "Input"],
Cell[7710, 263, 75, 0, 30, "Text"],
Cell[7788, 265, 1280, 44, 157, "Input"],
Cell[9071, 311, 222, 4, 49, "Text"],
Cell[9296, 317, 1113, 35, 152, "Input"],
Cell[10412, 354, 162, 3, 49, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10611, 362, 51, 0, 70, "Section"],
Cell[CellGroupData[{
Cell[10687, 366, 1383, 42, 92, "Input"],
Cell[12073, 410, 254, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12364, 421, 115, 3, 31, "Input"],
Cell[12482, 426, 227, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12746, 436, 413, 12, 31, "Input"],
Cell[13162, 450, 250, 6, 31, "Output"]
}, Open  ]],
Cell[13427, 459, 143, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[13595, 466, 319, 10, 31, "Input"],
Cell[13917, 478, 334, 11, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14288, 494, 328, 10, 31, "Input"],
Cell[14619, 506, 911, 25, 55, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15579, 537, 39, 0, 70, "Section"],
Cell[CellGroupData[{
Cell[15643, 541, 771, 21, 119, "Input"],
Cell[16417, 564, 177, 5, 33, "Output"]
}, Open  ]],
Cell[16609, 572, 278, 5, 68, "Text"],
Cell[16890, 579, 940, 30, 92, "Input"],
Cell[17833, 611, 152, 3, 49, "Text"],
Cell[17988, 616, 199, 7, 31, "Input"],
Cell[18190, 625, 271, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[18486, 634, 663, 20, 52, "Input"],
Cell[19152, 656, 3628, 120, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22817, 781, 36, 0, 31, "Input"],
Cell[22856, 783, 11466, 359, 266, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34359, 1147, 117, 3, 31, "Input"],
Cell[34479, 1152, 3538, 118, 76, "Output"]
}, Open  ]],
Cell[38032, 1273, 1072, 31, 92, "Input"],
Cell[CellGroupData[{
Cell[39129, 1308, 34, 0, 31, "Input"],
Cell[39166, 1310, 12176, 407, 236, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[51391, 1723, 39, 0, 70, "Section"],
Cell[51433, 1725, 174, 3, 49, "Text"],
Cell[51610, 1730, 561, 18, 52, "Input"],
Cell[52174, 1750, 95, 2, 30, "Text"],
Cell[52272, 1754, 3731, 110, 352, "Input"],
Cell[56006, 1866, 2619, 73, 312, "Input"],
Cell[CellGroupData[{
Cell[58650, 1943, 12165, 357, 752, "Input"],
Cell[CellGroupData[{
Cell[70840, 2304, 9906, 469, 186, 7969, 435, "GraphicsData", "PostScript", \
"Graphics"],
Cell[80749, 2775, 10468, 497, 186, 8484, 462, "GraphicsData", "PostScript", \
"Graphics"],
Cell[91220, 3274, 10234, 499, 186, 8248, 464, "GraphicsData", "PostScript", \
"Graphics"],
Cell[101457, 3775, 9236, 451, 186, 7576, 421, "GraphicsData", "PostScript", \
"Graphics"],
Cell[110696, 4228, 9838, 461, 186, 7572, 421, "GraphicsData", "PostScript", \
"Graphics"],
Cell[120537, 4691, 9918, 462, 186, 7587, 421, "GraphicsData", "PostScript", \
"Graphics"],
Cell[130458, 5155, 50295, 2654, 125, 47039, 2600, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[180780, 7813, 298, 7, 52, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[181115, 7825, 57, 0, 70, "Section"],
Cell[181175, 7827, 1084, 37, 152, "Input"],
Cell[182262, 7866, 2540, 77, 232, "Input"],
Cell[CellGroupData[{
Cell[184827, 7947, 388, 12, 31, "Input"],
Cell[185218, 7961, 328, 7, 31, "Output"]
}, Open  ]],
Cell[185561, 7971, 323, 7, 52, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

