(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.4' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    199944,       8477]
NotebookOptionsPosition[    195890,       8345]
NotebookOutlinePosition[    196232,       8360]
CellTagsIndexPosition[    196189,       8357]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Show Me the Money", "Title"],

Cell["Computation with Perturbation Methods", "Subtitle"],

Cell["\<\
Log utility and quadratic adjustment are assumed. Endogenous state variables \
are d and s, exogenous state is x. x is Normal with unit variance.

The underlying theory for the computations can be found in Judd, \
Schmitt-Grohe and Uribe, and especially Fernandez-Villaverde. Some of the \
code is based on Jesus' code for his computational-method comparison paper. 
\
\>", "Text",
 CellChangeTimes->{{3.6897892959995995`*^9, 3.6897892966816673`*^9}}],

Cell[BoxData[{
 RowBox[{"<<", "Statistics`NormalDistribution`"}], "\[IndentingNewLine]", 
 RowBox[{"<<", 
  "Statistics`MultiDescriptiveStatistics`"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Graphics`MultipleListPlot`"}], "\[IndentingNewLine]", 
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell1"}], "]"}]}], "Input"],

Cell[CellGroupData[{

Cell["Set Parameters", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"param", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Psi]", "\[Rule]", "0.24"}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", "0.99"}], ",", 
     RowBox[{"ad1", "\[Rule]", "10"}], ",", 
     RowBox[{"ad2", "\[Rule]", 
      RowBox[{"-", "0.004796553930556677"}]}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", " ", "1"}], ",", 
     RowBox[{"\[Rho]", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmean", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xconst", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Rho]"}], ")"}], " ", "xmean"}], "/.", "param"}], "//",
     "Chop"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"orderexpansion", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"myvariables", "=", 
   RowBox[{"{", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "}"}]}], 
  ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Model Equations", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cond1a", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"1", "-", "\[Psi]"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "l"}], ")"}], "w"}]], "-", 
    RowBox[{"\[Beta]", 
     RowBox[{"(", 
      FractionBox["\[Psi]", 
       RowBox[{"c2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "x"}], ")"}], " ", "p2"}]], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond2a", "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"1", "-", "\[Psi]"}], 
      RowBox[{"1", "-", "l"}]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "w"], "+", 
       RowBox[{"2", "  ", "ad1", " ", 
        RowBox[{"(", 
         RowBox[{"ad2", "+", "i"}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"\[Beta]", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"1", "-", "\[Psi]"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "x"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"1", "-", "l2"}], ")"}]}]], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"1", "+", "r2"}], "w2"], "+", 
         RowBox[{"2", " ", "ad1", " ", 
          RowBox[{"(", 
           RowBox[{"ad2", "+", "i2"}], ")"}]}]}], ")"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond3a", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "x"}], ")"}], " ", "d2"}], "-", 
    RowBox[{"(", 
     RowBox[{"d", "+", 
      RowBox[{"r", " ", "s"}], " ", "+", 
      RowBox[{"\[Lambda]", " ", "pi"}], " ", "+", 
      RowBox[{"w", " ", "la"}], " ", "-", "i", " ", "-", 
      RowBox[{"p", " ", "c"}]}], ")"}]}]}], " ", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond4a", "=", 
   RowBox[{"i", "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "x"}], ")"}], " ", "s2"}], "-", "s"}], ")"}]}]}], 
  ";"}]}], "Input"],

Cell["\<\
The replacement rules arising from the remaining model equations (this should \
be documented)\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rep0", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"l", "\[Rule]", " ", 
      RowBox[{"la", "+", "lb"}]}], ",", 
     RowBox[{"l2", "\[Rule]", " ", 
      RowBox[{"la2", "+", "lb2"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep0b", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"lb", "\[Rule]", " ", 
      RowBox[{"ad1", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"ad2", "+", "i"}], ")"}], "^", "2"}]}]}], ",", 
     RowBox[{"lb2", "\[Rule]", " ", 
      RowBox[{"ad1", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"ad2", "+", "i2"}], ")"}], "^", "2"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"la", "\[Rule]", "c"}], ",", 
     RowBox[{"la2", "\[Rule]", "c2"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep2", "=", 
   RowBox[{"{", 
    RowBox[{"pi", "\[Rule]", " ", 
     RowBox[{"1", "-", "d", "-", "s"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep2b", "=", 
   RowBox[{"{", 
    RowBox[{"pi2", "\[Rule]", " ", 
     RowBox[{"1", "-", "d2", "-", "s2"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep3", "=", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", 
     RowBox[{"d", "/", "c"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep3b", "=", 
   RowBox[{"{", 
    RowBox[{"p2", "\[Rule]", 
     RowBox[{"d2", "/", "c2"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep4", "=", 
   RowBox[{"{", 
    RowBox[{"b", "->", 
     RowBox[{"1", "+", "x", "-", "d"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep5", "=", 
   RowBox[{"{", 
    RowBox[{"w", "\[Rule]", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "x", "-", "d"}], ")"}], "/", "c"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep5b", "=", 
   RowBox[{"{", 
    RowBox[{"w2", "\[Rule]", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "x2", "-", "d2"}], ")"}], "/", "c2"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep6", "=", 
   RowBox[{"{", 
    RowBox[{"r", "\[Rule]", 
     RowBox[{
      RowBox[{"d", "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", "x", "-", "d"}], ")"}]}], "-", "1"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep6b", "=", 
   RowBox[{"{", 
    RowBox[{"r2", "\[Rule]", 
     RowBox[{
      RowBox[{"d2", "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", "x2", "-", "d2"}], ")"}]}], "-", "1"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"repall", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
    "rep1", ",", "rep2", ",", "rep2b", ",", "rep3", ",", "rep3b", ",", "rep4",
      ",", "rep5", ",", "rep5b", ",", "rep6", ",", "rep6b"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{""}]}], "Input"],

Cell["Rework cond2 so that it will be easier to take expectations", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cond1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"cond1a", "/.", "rep0"}], "/.", "rep0b"}], "/.", "repall"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"cond2a", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", "d2", "+", "x2"}], ")"}], "2"]}], ")"}], "/.", 
      "rep0"}], "/.", "rep0b"}], "/.", "repall"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond2", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{"cond2", ",", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "d2", "+", "x2"}], ")"}], "2"]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond3", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"cond3a", "/.", "rep0"}], "/.", "rep0b"}], "/.", "repall"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cond4", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"cond4a", "/.", "rep0"}], "/.", "rep0b"}], "/.", "repall"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"F", "=", 
   RowBox[{"{", 
    RowBox[{"cond1", ",", "cond2", ",", "cond3", ",", "cond4"}], "}"}]}], 
  ";"}]}], "Input"],

Cell["\<\
Now replace the decision variables by the functions that we are going to \
compute. Notation is moving towards Schmitt-Grohe and Uribe. g are the \
policies for jumps, h are the policies for states.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"c", "=", 
   RowBox[{"g1", "[", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"i", "=", 
   RowBox[{"g2", "[", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"s2", "=", 
   RowBox[{"h1", "[", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d2", "=", 
   RowBox[{"h2", "[", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2", "=", 
   RowBox[{"g1", "[", 
    RowBox[{"s2", ",", "d2", ",", "x2", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"i2", "=", 
   RowBox[{"g2", "[", 
    RowBox[{"s2", ",", "d2", ",", "x2", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x2", "=", 
   RowBox[{"xconst", "+", 
    RowBox[{"\[Rho]", " ", "*", "x"}], "+", 
    RowBox[{"\[Sigma]", "*", "\[Epsilon]"}]}]}], ";"}]}], "Input"],

Cell["\<\
In terms of number of equations and unknowns, this is fine now. s and d are \
endogenous states, c and i are jumps. x is chosen by nature.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The  Non-Stochastic Steady State", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ssfunrule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"h1", "[", "__", "]"}], "\[Rule]", " ", "s"}], ",", 
     RowBox[{
      RowBox[{"h2", "[", "__", "]"}], "\[Rule]", " ", "d"}], ",", " ", 
     RowBox[{
      RowBox[{"g1", "[", "__", "]"}], "\[Rule]", " ", "cbar"}], ",", 
     RowBox[{
      RowBox[{"g2", "[", "__", "]"}], "\[Rule]", "ibar"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssvalrule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s", "\[Rule]", "sbar"}], ",", 
     RowBox[{"d", "\[Rule]", "dbar"}], ",", 
     RowBox[{"x", "\[Rule]", "xmean"}], ",", 
     RowBox[{"ibar", "\[Rule]", 
      RowBox[{"xmean", " ", "sbar"}]}], ",", 
     RowBox[{"\[Sigma]", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sscond", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"F", "[", 
       RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"ssresult", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"sscond", "/.", "param"}], "/.", "ssfunrule"}], "/.", 
     "ssvalrule"}], ",", 
    RowBox[{"{", 
     RowBox[{"sbar", ",", "dbar", ",", "cbar"}], "}"}]}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", 
      RowBox[{"-", "0.4053087204021167`"}]}], ",", 
     RowBox[{"dbar", "\[Rule]", 
      RowBox[{"-", "13.218701016249616`"}]}], ",", 
     RowBox[{"sbar", "\[Rule]", "14.221861994230268`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", 
      RowBox[{"-", "0.33076560336609284`"}]}], ",", 
     RowBox[{"dbar", "\[Rule]", "13.876761659609318`"}], ",", 
     RowBox[{"sbar", "\[Rule]", 
      RowBox[{"-", "12.873269679888342`"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", 
      RowBox[{"-", "0.050951874469560086`"}]}], ",", 
     RowBox[{"dbar", "\[Rule]", "0.6743913017215635`"}], ",", 
     RowBox[{"sbar", "\[Rule]", 
      RowBox[{"-", "36.69187794432362`"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", 
      RowBox[{"-", "2.258816888493989`*^-17"}]}], ",", 
     RowBox[{"dbar", "\[Rule]", "1.01`"}], ",", 
     RowBox[{"sbar", "\[Rule]", 
      RowBox[{"-", "4.218253550847776`*^-18"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", "0.03681892170478063`"}], ",", 
     RowBox[{"dbar", "\[Rule]", "0.6745346376912575`"}], ",", 
     RowBox[{"sbar", "\[Rule]", "27.387012510429265`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", "0.23277983102081035`"}], ",", 
     RowBox[{"dbar", "\[Rule]", "0.5100499730741429`"}], ",", 
     RowBox[{"sbar", "\[Rule]", "0.4796428549566466`"}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ssresult", "=", 
  RowBox[{"ssresult", "[", 
   RowBox[{"[", "6", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"cbar", "\[Rule]", "0.23277983102081035`"}], ",", 
   RowBox[{"dbar", "\[Rule]", "0.5100499730741429`"}], ",", 
   RowBox[{"sbar", "\[Rule]", "0.4796428549566466`"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"varrule", "=", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"s", "\[Rule]", "sbar"}], "/.", "ssresult"}], ",", 
      RowBox[{
       RowBox[{"d", "\[Rule]", "dbar"}], "/.", "ssresult"}], ",", 
      RowBox[{"x", "\[Rule]", "xmean"}], ",", 
      RowBox[{"\[Sigma]", "\[Rule]", "0"}]}], "}"}], "]"}], "//", 
   "Chop"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"s", "\[Rule]", "0.4796428549566466`"}], ",", 
   RowBox[{"d", "\[Rule]", "0.5100499730741429`"}], ",", 
   RowBox[{"x", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"\[Sigma]", "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
The role of derivrule is to suppress the arguments of all the derivatives. \
The : is a general pattern operator here. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"derivrule", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"d", ":", 
     RowBox[{
      RowBox[{
       RowBox[{"Derivative", "[", "__", "]"}], "[", "__", "]"}], "[", "__", 
      "]"}]}], "\[RuleDelayed]", "  ", 
    RowBox[{"d", "[", 
     RowBox[{"[", "0", "]"}], "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"d", ":", 
    RowBox[{
     SuperscriptBox["__", 
      TagBox[
       RowBox[{"(", "__", ")"}],
       Derivative],
      MultilineFunction->None], "[", "__", "]"}]}], "\[RuleDelayed]", 
   RowBox[{"d", "\[LeftDoubleBracket]", "0", "\[RightDoubleBracket]"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"unirule", "=", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"ssfunrule", "/.", "varrule"}], "/.", "ssvalrule"}], "/.", 
       "ssresult"}], ",", "varrule", ",", "derivrule"}], "]"}], "]"}], "//", 
   "Chop"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"h1", "[", "__", "]"}], "\[Rule]", "0.4796428549566466`"}], ",", 
   RowBox[{
    RowBox[{"h2", "[", "__", "]"}], "\[Rule]", "0.5100499730741429`"}], ",", 
   RowBox[{
    RowBox[{"g1", "[", "__", "]"}], "\[Rule]", "0.23277983102081035`"}], ",", 
   RowBox[{
    RowBox[{"g2", "[", "__", "]"}], "\[Rule]", "0.004796428549566466`"}], ",", 
   RowBox[{"s", "\[Rule]", "0.4796428549566466`"}], ",", 
   RowBox[{"d", "\[Rule]", "0.5100499730741429`"}], ",", 
   RowBox[{"x", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"\[Sigma]", "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"d", ":", 
     RowBox[{
      SuperscriptBox["__", 
       TagBox[
        RowBox[{"(", "__", ")"}],
        Derivative],
       MultilineFunction->None], "[", "__", "]"}]}], "\[RuleDelayed]", 
    RowBox[{"d", "\[LeftDoubleBracket]", "0", "\[RightDoubleBracket]"}]}]}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Taylor Expansion", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"epsrule", "=", 
  RowBox[{"Append", "[", 
   RowBox[{
    RowBox[{"Reverse", "@", 
     RowBox[{"Thread", "[", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{"Range", "[", 
         RowBox[{"2", ",", "orderexpansion", ",", "2"}], "]"}]], "->", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"ExpectedValue", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox["#", "j"], "&"}], ",", 
           RowBox[{"NormalDistribution", "[", 
            RowBox[{"0", ",", "1"}], "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "2", ",", "orderexpansion", ",", "2"}], "}"}]}], 
        "]"}]}], "]"}]}], ",", 
    RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Epsilon]", "2"], "\[Rule]", "1"}], ",", 
   RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Notice that all partial derivatives are taken below, even though some \
cross-derivatives are equal and could be left out. This slows computation, \
but as long as computation time is not an issue, it makes it easier to \
simulate from the outcome later.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Fd", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Fd", "[", 
    RowBox[{"[", "0", "]"}], "]"}], "=", "F"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Fd", "[", 
      RowBox[{"[", "j", "]"}], "]"}], "=", 
     RowBox[{"Union", "[", 
      RowBox[{"Expand", "[", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Outer", "[", 
         RowBox[{"D", ",", 
          RowBox[{"{", 
           RowBox[{"Fd", "[", 
            RowBox[{"[", 
             RowBox[{"j", "-", "1"}], "]"}], "]"}], "}"}], ",", 
          "myvariables"}], "]"}], "]"}], "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "orderexpansion"}], "}"}]}], "]"}], 
  ";"}]}], "Input"],

Cell["\<\
Now we plug in everything that is known, that is, we evaluate the derivative \
at the steady state and at calibrated parameters.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dF", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Fd", "/.", "param"}], "/.", "unirule"}], "/.", "epsrule"}], "//",
     "Chop"}]}], ";"}]], "Input"],

Cell["\<\
Now we simply need to solve the resulting system. In the first step, we also \
have to pick the correct solution. Since the system is quadratic, there may \
be more than one. How to pick this is not obvious; check the result manually \
to be sure.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"firstorder", "=", 
   RowBox[{
    RowBox[{"NSolve", "[", 
     RowBox[{"Thread", "[", 
      RowBox[{
       RowBox[{"First", "[", "dF", "]"}], "\[Equal]", "0"}], "]"}], "]"}], "//",
     "Chop"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"solution", "=", 
  RowBox[{"First", "@", 
   RowBox[{"Select", "[", 
    RowBox[{"firstorder", ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "]"}], "[", "g1", 
          "]"}], "]"}], "<", "1"}], "/.", "#"}], "&"}]}], "]"}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.4508959031207393`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.3394116987061432`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.2877260404118045`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.05086629876605511`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.17078564206675922`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.3077279328868578`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.010376736059261602`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.7880814534269321`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.316319413004555`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.24019753700318175`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.010480503419854218`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.3208052122157265`"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["firstorder"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "4.027776206695572`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "5.098524523938694`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "11.503020885731086`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "13.540797982057645`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "204.36643471249192`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "11.483018993256032`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "13.602041016882962`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "205.32530180798133`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "206.89891197110452`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "71.37838341928008`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "13.738061427051791`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "12.597849183188593`"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.4508959031207393`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.3394116987061432`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1.2877260404118045`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.05086629876605511`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.17078564206675922`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "1.3077279328868578`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.010376736059261602`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.7880814534269321`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.316319413004555`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.24019753700318175`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.010480503419854218`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.3208052122157265`"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.2503082119646607`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.33789057393388666`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.714862849901986`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.05521051542848383`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.5128905779013271`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.7348647423770394`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.006032519396832883`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.44597651759236334`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.02920657218835964`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.35998536828465155`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.006092844590801212`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.2577866101991902`"}]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solution", "=", 
  RowBox[{"firstorder", "[", 
   RowBox[{"[", "3", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.2503082119646607`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.33789057393388666`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.714862849901986`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.05521051542848383`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.5128905779013271`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.7348647423770394`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.006032519396832883`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.44597651759236334`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.02920657218835964`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.35998536828465155`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.006092844590801212`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.2577866101991902`"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"dF", "[", 
      RowBox[{"[", "j", "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{"dF", "[", 
       RowBox[{"[", "j", "]"}], "]"}], "/.", "solution"}]}], ";", 
    "\[IndentingNewLine]", "    ", 
    RowBox[{"nthorder", "=", 
     RowBox[{"NSolve", "[", 
      RowBox[{
       RowBox[{"dF", "[", 
        RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", 
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", 
            RowBox[{"dF", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}], 
      "]"}]}], ";", "\[IndentingNewLine]", "    ", 
    RowBox[{"solution", "=", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{"solution", ",", "nthorder"}], "}"}], "]"}], "//", 
      "Chop"}]}]}], ",", "     ", "\[IndentingNewLine]", "    ", 
   RowBox[{"{", 
    RowBox[{"j", ",", "2", ",", "orderexpansion"}], "}"}]}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["solution"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.2503082119646607`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.33789057393388666`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.714862849901986`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.05521051542848383`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.5128905779013271`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.7348647423770394`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.006032519396832883`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.44597651759236334`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.02920657218835964`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.35998536828465155`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.006092844590801212`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.2577866101991902`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.47340239141582663`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.3655212381488264`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.352001225889928`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.3520012258899272`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.5019697323266505`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.5367806821057232`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.4145878389014355`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "4.360835208736315`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "2.189717184442906`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.53251261454955`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.521267420943284`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "5.194727665470672`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "2.794930260590308`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.7613894075006176`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.7538508985154628`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "6.922736286712334`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.162266803727065`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.42186844390959444`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.309897325215292`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.7303102650439195`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.5219391267896534`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.3237817035776491`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.32057594413628626`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "3.680223744936768`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.247912489680258`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.05475302561558416`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.054210916451073426`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.05421091645107342`"}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simulate the Outcome", "Section"],

Cell["\<\
simprule below eliminates the derivative that are too high (more than \
orderexpansion total); ssrule replaces the constants with steady state values.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"simprule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d", ":", 
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"n__", "/;", 
          RowBox[{
           RowBox[{"Plus", "[", "n", "]"}], ">", "orderexpansion"}]}], "]"}], 
        "[", "__", "]"}], "[", "__", "]"}]}], "\[RuleDelayed]", "  ", "0"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssrule", "=", 
   RowBox[{
    RowBox[{"ssfunrule", "/.", "ssvalrule"}], "/.", "ssresult"}]}], 
  ";"}]}], "Input"],

Cell["\<\
Generating Taylor-Series expansion that the result can be plugged into.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sfun", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"h1", "[", 
       RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", 
        RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}], 
    "//", "Normal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dfun", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"h2", "[", 
       RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", 
        RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}], 
    "//", "Normal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cfun", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"g1", "[", 
       RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", 
        RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}], 
    "//", "Normal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ifun", "=", 
    RowBox[{
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"g2", "[", 
        RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"s", ",", 
         RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"d", ",", 
         RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}],
      "//", "Normal"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"sfun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dsimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"dfun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"csimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"cfun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"isimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"ifun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ssim", "[", "1", "]"}], "=", 
   RowBox[{"sbar", "/.", "ssresult"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dsim", "[", "1", "]"}], "=", 
   RowBox[{"dbar", "/.", "ssresult"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"xsim", "[", "1", "]"}], "=", "xmean"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"j", "=", "1"}], ",", 
    RowBox[{"j", "<", "22"}], ",", 
    RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"simrule", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"s", "\[Rule]", 
         RowBox[{"ssim", "[", "j", "]"}]}], ",", 
        RowBox[{"d", "\[Rule]", 
         RowBox[{"dsim", "[", "j", "]"}]}], ",", 
        RowBox[{"x", "\[Rule]", 
         RowBox[{"xsim", "[", "j", "]"}]}], ",", 
        RowBox[{"\[Sigma]", "\[Rule]", "0.006"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"csim", "[", "j", "]"}], "=", 
      RowBox[{"csimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"isim", "[", "j", "]"}], "=", 
      RowBox[{"isimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ssim", "[", 
       RowBox[{"j", "+", "1"}], "]"}], "=", 
      RowBox[{"ssimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"dsim", "[", 
       RowBox[{"j", "+", "1"}], "]"}], "=", 
      RowBox[{"dsimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"xsim", "[", 
       RowBox[{"j", "+", "1"}], "]"}], "=", 
      RowBox[{
       RowBox[{"xconst", "+", 
        RowBox[{"\[Rho]", " ", 
         RowBox[{"xsim", "[", "j", "]"}]}]}], "/.", "param"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"j", "\[Equal]", "1"}], ",", 
       RowBox[{
        RowBox[{"xsim", "[", 
         RowBox[{"j", "+", "1"}], "]"}], "=", ".004"}]}], "]"}], ";"}]}], 
   "  ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"This", " ", "is", " ", "a", " ", "one"}], "-", 
     RowBox[{
     "standard", " ", "deviation", " ", "contractionary", " ", "shock"}]}], 
    " ", "*)"}], "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Multiply", " ", "by", " ", "100", " ", "below", " ", "to", " ", "get", 
    " ", "percentages", " ", "and", " ", "more", " ", "convenient", " ", 
    "units"}], " ", "*)"}]}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", "*", 
       RowBox[{"ssim", "[", "j", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", "*", 
       RowBox[{"dsim", "[", "j", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", "*", 
       RowBox[{"csim", "[", "j", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"isim", "[", "j", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"xsim", "[", "j", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pout", "=", 
    RowBox[{"Flatten", "@", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"dsim", "[", "j", "]"}], "/", 
        RowBox[{"csim", "[", "j", "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "21"}], "}"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rout", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"100", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"dout", "[", 
          RowBox[{"[", "j", "]"}], "]"}], "/", 
         RowBox[{"(", 
          RowBox[{"100", "+", 
           RowBox[{"100", " ", 
            RowBox[{"xout", "[", 
             RowBox[{"[", "j", "]"}], "]"}]}], "-", 
           RowBox[{"dout", "[", 
            RowBox[{"[", "j", "]"}], "]"}]}], ")"}]}], "-", "1"}], ")"}]}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"infout", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"100", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"xout", "[", 
            RowBox[{"[", "j", "]"}], "]"}]}], ")"}], " ", 
         RowBox[{
          RowBox[{"pout", "[", 
           RowBox[{"[", 
            RowBox[{"j", "+", "1"}], "]"}], "]"}], "/", 
          RowBox[{"pout", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}]}], "-", "1"}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"infout", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "infout"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"piout", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", "-", 
       RowBox[{"sout", "[", 
        RowBox[{"[", "j", "]"}], "]"}], "-", 
       RowBox[{"dout", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot1", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"cout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Thickness", "[", ".01", "]"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "cout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "cout", "]"}], "-", 
              RowBox[{"Min", "[", "cout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "cout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "cout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "cout", "]"}], "-", 
            RowBox[{"Min", "[", "cout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Output\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot2", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"rout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "rout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "rout", "]"}], "-", 
              RowBox[{"Min", "[", "rout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "rout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "rout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "rout", "]"}], "-", 
            RowBox[{"Min", "[", "rout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Interest Rate\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot3", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"infout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "infout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "infout", "]"}], "-", 
              RowBox[{"Min", "[", "infout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "infout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "infout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "infout", "]"}], "-", 
            RowBox[{"Min", "[", "infout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Inflation Rate\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot4", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"dout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "dout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "dout", "]"}], "-", 
              RowBox[{"Min", "[", "dout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "dout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "dout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "dout", "]"}], "-", 
            RowBox[{"Min", "[", "dout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Checking Account\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot5", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"sout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "sout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "sout", "]"}], "-", 
              RowBox[{"Min", "[", "sout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "sout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "sout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "sout", "]"}], "-", 
            RowBox[{"Min", "[", "sout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Savings Account\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"plot6", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"piout", ",", 
      RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Min", "[", "piout", "]"}], "-", 
            RowBox[{".1", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Max", "[", "piout", "]"}], "-", 
               RowBox[{"Min", "[", "piout", "]"}]}], ")"}]}]}], ",", 
           RowBox[{"Max", "[", "piout", "]"}]}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"Min", "[", "piout", "]"}], "-", 
          RowBox[{".1", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Max", "[", "piout", "]"}], "-", 
             RowBox[{"Min", "[", "piout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
      RowBox[{"PlotLabel", "\[Rule]", "\"\<Retained Earnings\>\""}], ",", 
      RowBox[{"TextStyle", "\[RuleDelayed]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontSize", "->", "18"}], ",", 
         RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"GraphicsArray", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"plot1", ",", "plot2", ",", "plot3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"plot4", ",", "plot5", ",", "plot6"}], "}"}]}], "}"}], "]"}], 
    "]"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -38.1858 1.65826 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .03697 -58.0625 -11.1875 ]
[-0.0125 .03697 0 11.1875 ]
[-0.0125 .11988 -47.25 -11.1875 ]
[-0.0125 .11988 0 11.1875 ]
[-0.0125 .2028 -58.0625 -11.1875 ]
[-0.0125 .2028 0 11.1875 ]
[-0.0125 .28571 -47.25 -11.1875 ]
[-0.0125 .28571 0 11.1875 ]
[-0.0125 .36862 -58.0625 -11.1875 ]
[-0.0125 .36862 0 11.1875 ]
[-0.0125 .45153 -47.25 -11.1875 ]
[-0.0125 .45153 0 11.1875 ]
[-0.0125 .53445 -58.0625 -11.1875 ]
[-0.0125 .53445 0 11.1875 ]
[-0.0125 .61736 -47.25 -11.1875 ]
[-0.0125 .61736 0 11.1875 ]
[.5 .63053 -34.4375 0 ]
[.5 .63053 34.4375 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03697 m
.00625 .03697 L
s
gsave
-0.0125 .03697 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.05) show
1.000 setlinewidth
grestore
0 .11988 m
.00625 .11988 L
s
gsave
-0.0125 .11988 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.1) show
1.000 setlinewidth
grestore
0 .2028 m
.00625 .2028 L
s
gsave
-0.0125 .2028 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.15) show
1.000 setlinewidth
grestore
0 .28571 m
.00625 .28571 L
s
gsave
-0.0125 .28571 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.2) show
1.000 setlinewidth
grestore
0 .36862 m
.00625 .36862 L
s
gsave
-0.0125 .36862 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.25) show
1.000 setlinewidth
grestore
0 .45153 m
.00625 .45153 L
s
gsave
-0.0125 .45153 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.3) show
1.000 setlinewidth
grestore
0 .53445 m
.00625 .53445 L
s
gsave
-0.0125 .53445 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.35) show
1.000 setlinewidth
grestore
0 .61736 m
.00625 .61736 L
s
gsave
-0.0125 .61736 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.4) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05355 m
.00375 .05355 L
s
0 .07014 m
.00375 .07014 L
s
0 .08672 m
.00375 .08672 L
s
0 .1033 m
.00375 .1033 L
s
0 .13647 m
.00375 .13647 L
s
0 .15305 m
.00375 .15305 L
s
0 .16963 m
.00375 .16963 L
s
0 .18621 m
.00375 .18621 L
s
0 .21938 m
.00375 .21938 L
s
0 .23596 m
.00375 .23596 L
s
0 .25254 m
.00375 .25254 L
s
0 .26913 m
.00375 .26913 L
s
0 .30229 m
.00375 .30229 L
s
0 .31887 m
.00375 .31887 L
s
0 .33546 m
.00375 .33546 L
s
0 .35204 m
.00375 .35204 L
s
0 .3852 m
.00375 .3852 L
s
0 .40179 m
.00375 .40179 L
s
0 .41837 m
.00375 .41837 L
s
0 .43495 m
.00375 .43495 L
s
0 .46812 m
.00375 .46812 L
s
0 .4847 m
.00375 .4847 L
s
0 .50128 m
.00375 .50128 L
s
0 .51787 m
.00375 .51787 L
s
0 .55103 m
.00375 .55103 L
s
0 .56761 m
.00375 .56761 L
s
0 .5842 m
.00375 .5842 L
s
0 .60078 m
.00375 .60078 L
s
0 .02039 m
.00375 .02039 L
s
0 .00381 m
.00375 .00381 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -95.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Output) show
127.875 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .41644 m
.16667 .05618 L
.25 .35154 L
.33333 .61803 L
.41667 .55617 L
.5 .52291 L
.58333 .49746 L
.66667 .47868 L
.75 .46478 L
.83333 .4545 L
.91667 .44688 L
1 .44124 L
s
1 .44124 m
1 .44124 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.77254, 22.9545, \
0.058375, 0.00293354}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.257695 0.26644 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .00875 -14.8125 -11.1875 ]
[-0.0125 .00875 0 11.1875 ]
[-0.0125 .14197 -36.4375 -11.1875 ]
[-0.0125 .14197 0 11.1875 ]
[-0.0125 .27519 -14.8125 -11.1875 ]
[-0.0125 .27519 0 11.1875 ]
[-0.0125 .40841 -36.4375 -11.1875 ]
[-0.0125 .40841 0 11.1875 ]
[-0.0125 .54163 -14.8125 -11.1875 ]
[-0.0125 .54163 0 11.1875 ]
[.5 .63053 -72.2813 0 ]
[.5 .63053 72.2813 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00875 m
.00625 .00875 L
s
gsave
-0.0125 .00875 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .14197 m
.00625 .14197 L
s
gsave
-0.0125 .14197 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .27519 m
.00625 .27519 L
s
gsave
-0.0125 .27519 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .40841 m
.00625 .40841 L
s
gsave
-0.0125 .40841 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
0 .54163 m
.00625 .54163 L
s
gsave
-0.0125 .54163 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03539 m
.00375 .03539 L
s
0 .06203 m
.00375 .06203 L
s
0 .08868 m
.00375 .08868 L
s
0 .11532 m
.00375 .11532 L
s
0 .16861 m
.00375 .16861 L
s
0 .19525 m
.00375 .19525 L
s
0 .2219 m
.00375 .2219 L
s
0 .24854 m
.00375 .24854 L
s
0 .30183 m
.00375 .30183 L
s
0 .32847 m
.00375 .32847 L
s
0 .35512 m
.00375 .35512 L
s
0 .38176 m
.00375 .38176 L
s
0 .43505 m
.00375 .43505 L
s
0 .46169 m
.00375 .46169 L
s
0 .48834 m
.00375 .48834 L
s
0 .51498 m
.00375 .51498 L
s
0 .56827 m
.00375 .56827 L
s
0 .59491 m
.00375 .59491 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -133.281 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Interest) show
160.313 20.000 moveto
(Rate) show
203.563 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .28057 m
.16667 .60808 L
.25 .61803 L
.33333 .05618 L
.41667 .13461 L
.5 .16852 L
.58333 .19527 L
.66667 .21499 L
.75 .22959 L
.83333 .2404 L
.91667 .24841 L
1 .25434 L
s
1 .25434 m
1 .25434 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJy1WFlvHEUQbm/PzPpY1rvr7Dq+HY4YOwYhIeclYCdBEF6whDgCiBcnAsUg
DhkjIUE0SAgJIQES4kbcvBHIgeFv8Bd4hEck3oeer6Zmarp7x0eIH9q19X1V
Xd1d3TXdD21sX3jmhY3tzfMb82e2Nl6+sHn+lfkHXtoyKj2g1MC8UupqSxn5
DaX/VHNJnByJE6X2+/+ROBlUaiZOQrSBUrNox6EPIbcha7SHbKPpOIm47UEf
QG7ZRo/GSU2pW9HOoK3FiVZqEnKA9jDaOqOmHROaidTNYxBn4XdKmLpuIqHp
oB1kVKnHOY4DuBlCO566OQtxGq1mWfPQpjATE33cDKPtpW6eEG5qLNd5Wvs5
GEHbTR08KRykgaj0L/sZZD+z39Vja6DlVc5ByzOt39we/EkNe83nhxJuBvKs
IHaRWTINWtBEwpZzKkIc5CDiKe+xg4hNSe5mGWR6nYfRPORptJOcIwG853Kv
av8sIIP+scQlmP9biCZl/kA/QkHdK/MvNt7SUewq9+NPlhzn6r/+N/UCJrG/
2tj8XWG+UqU4LeQfbPAU5unHTG18n8aa+Hgmku896tIW+M5PoJT61g9qgN/4
wQDg10V8pzjtjfor2+Ykn2ZmCF/6Qcq5L/zgMNx+7gdHAH5mh9KA+lO/zU0A
P0lBOuUp8BC7ZVDQ10AfBfqxTQ8g1x16C+hHKf0QK/I5ixx6G0P/sKCP81xa
xA7C+8BDNLw1PmsM5b2C0uvT6TiI7xbENk5edzATIL5TIlqTtMpFxejfLhFp
HSziHIhvZbMZCmKNh3EzKG+WKFZ0q1xXjf5i1TCIuACPr9vpQOASwNf84DI8
vmqD9wK8C+BWkXxkczcy40W/zfE4GVLqOT94ApbP+sE1gOf84H1xMqzU03Yo
Z+KkgbpftrkH4HqcjCj1sB80Vaap1IN+0FTeDgLygecAHveDz8dJW6k7izgp
/O04mUAScUWROXsClItwO11FeV9oUB1u5zPCIv6Ugot8uvhAWbCagrJUUI7x
0ZWDdLAcKyjLfPTllCY0gnKHs92bnJWmvZQNN/9K2I2YfypYRM3jvZTNS8Tf
GnQ8CXARJ5Ic16hNWdkHqHkZHLDFe9O0PxcZ0faopY0Rj/pBsrwRoBFvs+Mc
4zPItL/YNp3rAY14ix+kPstgjU+/vdpUF70x6I+Aftmmu0WPuhb0Dlcrb9Fz
6BRd/iVNH7n0lciUfnWxC40gkqLrdOoQe1zYrWrhEKnTpjNJXfH5fiWbpHyP
Np3SR/2V6flOzen5IAWRqr4bqeNxDLu25SNqvrtcsVNjnGt3f5AuQVeLXDvs
UUsbzXdLByTLGwFqvsiIOElB18hrts3ELqDmcTrgpJiEPYF54P1tNC/8tewU
t7KN7GnJf00pR51t6KPUsL2tTeMQ3QI0hYi6BWWZd5TmhRfgIl81c/uDUJad
TUtvCnQ87PgDnRHn8E7sVsp8h5Qp1g6hq3inoLgFcFacaTv2Al4XqLkA/1ak
C50/ZbW8AR8cHObnIAc0fY551Iv4Wv09VW8KNUaSHPD17Sw/kgXicaXG724R
sl/zS1zET2t0f2wgk+jRKfOQX3Ol/VpVRwFSgLqo8esdMetwU8dnYcgHdA2T
IK1WU2dPIYo6x5LvNpLpCWdEcIb7MEdY1qwJ+ni7v6rbOkeZyyHGEIqcqHHN
r5etKsfjOtbiqarFqxNVudQ8hFB0EvJgA5blkGUILV4TrwfRVSQeYPMFG+Kl
lUvYELMu9SSvlVxqmWYBp2bIsVu5FZaTuFFe0rDs4WTRER1SK2K5tDgf1ouM
bgniKDTtXSh1PoLW97NR1cB/UFWAuQ==\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.14136, 0.511736, \
0.058375, 0.0182577}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 0.206591 0.211366 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .10091 -48.3125 -11.1875 ]
[-0.0125 .10091 0 11.1875 ]
[-0.0125 .20659 -14.8125 -11.1875 ]
[-0.0125 .20659 0 11.1875 ]
[-0.0125 .31227 -36.4375 -11.1875 ]
[-0.0125 .31227 0 11.1875 ]
[-0.0125 .41796 -14.8125 -11.1875 ]
[-0.0125 .41796 0 11.1875 ]
[-0.0125 .52364 -36.4375 -11.1875 ]
[-0.0125 .52364 0 11.1875 ]
[.5 .63053 -77.6875 0 ]
[.5 .63053 77.6875 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10091 m
.00625 .10091 L
s
gsave
-0.0125 .10091 -109.313 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.875 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .20659 m
.00625 .20659 L
s
gsave
-0.0125 .20659 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .31227 m
.00625 .31227 L
s
gsave
-0.0125 .31227 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .41796 m
.00625 .41796 L
s
gsave
-0.0125 .41796 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .52364 m
.00625 .52364 L
s
gsave
-0.0125 .52364 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01636 m
.00375 .01636 L
s
0 .0375 m
.00375 .0375 L
s
0 .05863 m
.00375 .05863 L
s
0 .07977 m
.00375 .07977 L
s
0 .12204 m
.00375 .12204 L
s
0 .14318 m
.00375 .14318 L
s
0 .16432 m
.00375 .16432 L
s
0 .18545 m
.00375 .18545 L
s
0 .22773 m
.00375 .22773 L
s
0 .24886 m
.00375 .24886 L
s
0 .27 m
.00375 .27 L
s
0 .29114 m
.00375 .29114 L
s
0 .33341 m
.00375 .33341 L
s
0 .35455 m
.00375 .35455 L
s
0 .37568 m
.00375 .37568 L
s
0 .39682 m
.00375 .39682 L
s
0 .43909 m
.00375 .43909 L
s
0 .46023 m
.00375 .46023 L
s
0 .48137 m
.00375 .48137 L
s
0 .5025 m
.00375 .5025 L
s
0 .54478 m
.00375 .54478 L
s
0 .56591 m
.00375 .56591 L
s
0 .58705 m
.00375 .58705 L
s
0 .60819 m
.00375 .60819 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -138.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Inflation) show
171.125 20.000 moveto
(Rate) show
214.375 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .41796 m
.16667 .61803 L
.25 .25812 L
.33333 .05618 L
.41667 .48292 L
.5 .44959 L
.58333 .44247 L
.66667 .43602 L
.75 .43133 L
.83333 .42786 L
.91667 .42528 L
1 .42338 L
s
1 .42338 m
1 .42338 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJylWM1uHEUQbu/Mzqwdx96112uvfzchUXBiJzGJCcQEQiLCAeUcESDIipCS
QwQKQeIAGgkhISQOQEj4S+AZuALBvAGvgOBBht6vtnpqerpndo0P5dqqr6p6
uutnpq/u3rv1zp3de7dv7vZevbv73q3bN9/vXXn3rhYFY0qN9ZRSvzSV5j9S
wd9qLU3SQ0mq1Kj/X0/ShlIrSVoHDZVaBZ2HvA6+BT4AnbKNlpM0YtqBPATf
tI2uJ2lNqSOgK6C1JA2UWgQfgi6AxqzVdFZIZvtu3gC7Cr9LwrToJhKSGdAG
80q9yevYh5tx0FbfzVtgl0ED5gN+tCXsRNfjZgK02XdzQ7ipMR/ztvocHACd
7jt4WzjoL0T1/wY/w8HPwe/yZ5sE5VM2Sssznd/aEP6khL2a/aGEWwG/KoBz
yCyZBk1IImHLORVhHeQg4i3vsIOITYmfHmSQjtqDUQ/8Mugi54jm24Jv7qeu
dpL0L6wDrNKhEq3qxzP82hC8D9+2Hf8zEOhV/+vTVQuGsr4k+McjKV9GhJ+z
YJdwCD/ZuIvY932Iu2Ab8FrHiVPJX0QOALIAcQxIiPKPha+XRM49HsCNYIpT
NEAqGqMXOS3ZaBLFG4qMbnMxSCPTM6qMtE0BPi+As4UlXYDEA59CpDgPr2HH
NH3kgNNGGvgLvMEeOPURCTed4JG9qdOi7VxwAKlqrfXu8AMzsMuVWgSavv+j
nTjn4SWvrDEd99r4lc/DoV9pevYPWTSyyYuNzXNic0ZTnoNbv9Ic1Pd95Smu
Gy04x+2VlSe5Yoz9s+LkGGIOtBS4KRJF5us2gvqBWrnNg6DK11nAW5B/VwE0
c+p/ATWloALi25IzXLECaG3vM/BF1f9t7ngkhOYkQ3YqlJoltx6bLYg7buVp
WFKRP3Qozfx/mEXbcohLbYzyFKL5lTUe1Q+yaKdtsXMS+L2UTwUXvHIqnBRv
tw/sJlmcB5Qv9J71jRceqHJgcRKUwouTYBMO/HBrI6kQVrxw06BoGfSSd987
Ayy/ebhzEmyIl8f7ZZNgA5C1DEiJs+kQl9pYyh7o17byBL9depRafCin1OyG
Q1xqY5THEe0wlF85lFr8VE6p2RO2eBNpH5VZFiHriCwgVIjjAjIleDr0o6Bf
5uAacRC064VIj7U88EOhnfMama5CRq8k6fbgFb0Ip5Sch9FR7vBXquGaHgPV
p3FYqddy8BoSM+A+e4zbShffo9jfet5vU7Rlguu51lLqjhdOkyNguF7YAaU+
cK+6JZrL01yDusw+ztJkBr5oXK2zAw1J7DSbEXNtnduVBn5SDaQLg08dQJrj
AQPN96eu8M+yNbZ5YzQ9jsL/3PZFfbHJEG3/hQ1p8/lQcRi5C0gvSJr+aivn
ROf7bdAQG9y65SdJpwxYHEFzXCIMXxTLLQ6fDp9mkIPPF8ZOR7x+/u4Amrlf
gHQKQalaJmxgq9CLqQpdQGu8LIj2kAeawdIVL/FPBvtYFxDji/qFC2itjjzG
GdD3GItik57YibAovpH+yHKVJmtebGyWKpQBKiBwKOUN1F4WbUV8me7ZNuYS
zqMMRMEV9KvYPJdY19af2QrWcgJ5lxGUi28I8Z5TkI54JXONbyRD8WC0A+am
MiStuTKjC9CQL0PrBiHsJyAP+AQc9tQJzw67CE3H4SNmOfFFKwpd41MeF0ht
daYPpGvXWORHXVSfvJ6rFzCRSLlAaCeZN/KiB8qr89VLiLHi4qKkMxm2xoVl
rGI8+RBP28A5DBkq4ktDfxBTW9LlpGuT5TYaK7rxmRD4WPAiVCSSIxKbJnNW
SuT5hHlkPMjD62JlWbqGIkSD092EMJKczcF8AtTz5bKdBZsVW0L8llgnTbLL
WY00Rc5L0yPQtmw4DQ8nPOYP88ujtAs19h/a2/Ud\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.48796, -1.55152, \
0.058375, 0.023015}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -54.7457 1.07887 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .06081 -47.25 -11.1875 ]
[-0.0125 .06081 0 11.1875 ]
[-0.0125 .16869 -47.25 -11.1875 ]
[-0.0125 .16869 0 11.1875 ]
[-0.0125 .27658 -25.625 -11.1875 ]
[-0.0125 .27658 0 11.1875 ]
[-0.0125 .38447 -47.25 -11.1875 ]
[-0.0125 .38447 0 11.1875 ]
[-0.0125 .49235 -47.25 -11.1875 ]
[-0.0125 .49235 0 11.1875 ]
[-0.0125 .60024 -47.25 -11.1875 ]
[-0.0125 .60024 0 11.1875 ]
[.5 .63053 -88.7188 0 ]
[.5 .63053 88.7188 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06081 m
.00625 .06081 L
s
gsave
-0.0125 .06081 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.8) show
1.000 setlinewidth
grestore
0 .16869 m
.00625 .16869 L
s
gsave
-0.0125 .16869 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.9) show
1.000 setlinewidth
grestore
0 .27658 m
.00625 .27658 L
s
gsave
-0.0125 .27658 -86.625 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51) show
1.000 setlinewidth
grestore
0 .38447 m
.00625 .38447 L
s
gsave
-0.0125 .38447 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.1) show
1.000 setlinewidth
grestore
0 .49235 m
.00625 .49235 L
s
gsave
-0.0125 .49235 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.2) show
1.000 setlinewidth
grestore
0 .60024 m
.00625 .60024 L
s
gsave
-0.0125 .60024 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.3) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08238 m
.00375 .08238 L
s
0 .10396 m
.00375 .10396 L
s
0 .12554 m
.00375 .12554 L
s
0 .14712 m
.00375 .14712 L
s
0 .19027 m
.00375 .19027 L
s
0 .21185 m
.00375 .21185 L
s
0 .23343 m
.00375 .23343 L
s
0 .255 m
.00375 .255 L
s
0 .29816 m
.00375 .29816 L
s
0 .31974 m
.00375 .31974 L
s
0 .34131 m
.00375 .34131 L
s
0 .36289 m
.00375 .36289 L
s
0 .40605 m
.00375 .40605 L
s
0 .42762 m
.00375 .42762 L
s
0 .4492 m
.00375 .4492 L
s
0 .47078 m
.00375 .47078 L
s
0 .51393 m
.00375 .51393 L
s
0 .53551 m
.00375 .53551 L
s
0 .55709 m
.00375 .55709 L
s
0 .57866 m
.00375 .57866 L
s
0 .03923 m
.00375 .03923 L
s
0 .01765 m
.00375 .01765 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -149.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Checking) show
160.750 20.000 moveto
(Account) show
236.438 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .28197 m
.16667 .27935 L
.25 .61803 L
.33333 .05618 L
.41667 .13531 L
.5 .16946 L
.58333 .19637 L
.66667 .21618 L
.75 .23084 L
.83333 .2417 L
.91667 .24973 L
1 .25568 L
s
1 .25568 m
1 .25568 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.45695, 50.6311, \
0.058375, 0.00450896}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -98.1656 2.04781 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .02693 -58.0625 -11.1875 ]
[-0.0125 .02693 0 11.1875 ]
[-0.0125 .12932 -25.625 -11.1875 ]
[-0.0125 .12932 0 11.1875 ]
[-0.0125 .23171 -58.0625 -11.1875 ]
[-0.0125 .23171 0 11.1875 ]
[-0.0125 .3341 -47.25 -11.1875 ]
[-0.0125 .3341 0 11.1875 ]
[-0.0125 .43649 -58.0625 -11.1875 ]
[-0.0125 .43649 0 11.1875 ]
[-0.0125 .53888 -47.25 -11.1875 ]
[-0.0125 .53888 0 11.1875 ]
[.5 .63053 -83.3125 0 ]
[.5 .63053 83.3125 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02693 m
.00625 .02693 L
s
gsave
-0.0125 .02693 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(47.95) show
1.000 setlinewidth
grestore
0 .12932 m
.00625 .12932 L
s
gsave
-0.0125 .12932 -86.625 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(48) show
1.000 setlinewidth
grestore
0 .23171 m
.00625 .23171 L
s
gsave
-0.0125 .23171 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(48.05) show
1.000 setlinewidth
grestore
0 .3341 m
.00625 .3341 L
s
gsave
-0.0125 .3341 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(48.1) show
1.000 setlinewidth
grestore
0 .43649 m
.00625 .43649 L
s
gsave
-0.0125 .43649 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(48.15) show
1.000 setlinewidth
grestore
0 .53888 m
.00625 .53888 L
s
gsave
-0.0125 .53888 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(48.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04741 m
.00375 .04741 L
s
0 .06789 m
.00375 .06789 L
s
0 .08837 m
.00375 .08837 L
s
0 .10884 m
.00375 .10884 L
s
0 .1498 m
.00375 .1498 L
s
0 .17028 m
.00375 .17028 L
s
0 .19076 m
.00375 .19076 L
s
0 .21123 m
.00375 .21123 L
s
0 .25219 m
.00375 .25219 L
s
0 .27267 m
.00375 .27267 L
s
0 .29315 m
.00375 .29315 L
s
0 .31362 m
.00375 .31362 L
s
0 .35458 m
.00375 .35458 L
s
0 .37506 m
.00375 .37506 L
s
0 .39554 m
.00375 .39554 L
s
0 .41601 m
.00375 .41601 L
s
0 .45697 m
.00375 .45697 L
s
0 .47745 m
.00375 .47745 L
s
0 .49793 m
.00375 .49793 L
s
0 .51841 m
.00375 .51841 L
s
0 .00645 m
.00375 .00645 L
s
0 .55936 m
.00375 .55936 L
s
0 .57984 m
.00375 .57984 L
s
0 .60032 m
.00375 .60032 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -144.313 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Savings) show
149.938 20.000 moveto
(Account) show
225.625 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .05618 m
.16667 .06117 L
.25 .61803 L
.33333 .47156 L
.41667 .36908 L
.5 .2928 L
.58333 .23635 L
.66667 .19455 L
.75 .16361 L
.83333 .1407 L
.91667 .12374 L
1 .11118 L
s
1 .11118 m
1 .11118 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.77254, 47.8776, \
0.058375, 0.0023755}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.365798 0.94858 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .01363 -36.4375 -11.1875 ]
[-0.0125 .01363 0 11.1875 ]
[-0.0125 .10849 -36.4375 -11.1875 ]
[-0.0125 .10849 0 11.1875 ]
[-0.0125 .20335 -36.4375 -11.1875 ]
[-0.0125 .20335 0 11.1875 ]
[-0.0125 .29821 -36.4375 -11.1875 ]
[-0.0125 .29821 0 11.1875 ]
[-0.0125 .39307 -36.4375 -11.1875 ]
[-0.0125 .39307 0 11.1875 ]
[-0.0125 .48792 -36.4375 -11.1875 ]
[-0.0125 .48792 0 11.1875 ]
[-0.0125 .58278 -14.8125 -11.1875 ]
[-0.0125 .58278 0 11.1875 ]
[.5 .63053 -94.0313 0 ]
[.5 .63053 94.0313 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01363 m
.00625 .01363 L
s
gsave
-0.0125 .01363 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .10849 m
.00625 .10849 L
s
gsave
-0.0125 .10849 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .20335 m
.00625 .20335 L
s
gsave
-0.0125 .20335 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .29821 m
.00625 .29821 L
s
gsave
-0.0125 .29821 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
0 .39307 m
.00625 .39307 L
s
gsave
-0.0125 .39307 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .48792 m
.00625 .48792 L
s
gsave
-0.0125 .48792 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
1.000 setlinewidth
grestore
0 .58278 m
.00625 .58278 L
s
gsave
-0.0125 .58278 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03261 m
.00375 .03261 L
s
0 .05158 m
.00375 .05158 L
s
0 .07055 m
.00375 .07055 L
s
0 .08952 m
.00375 .08952 L
s
0 .12746 m
.00375 .12746 L
s
0 .14644 m
.00375 .14644 L
s
0 .16541 m
.00375 .16541 L
s
0 .18438 m
.00375 .18438 L
s
0 .22232 m
.00375 .22232 L
s
0 .24129 m
.00375 .24129 L
s
0 .26027 m
.00375 .26027 L
s
0 .27924 m
.00375 .27924 L
s
0 .31718 m
.00375 .31718 L
s
0 .33615 m
.00375 .33615 L
s
0 .35512 m
.00375 .35512 L
s
0 .37409 m
.00375 .37409 L
s
0 .41204 m
.00375 .41204 L
s
0 .43101 m
.00375 .43101 L
s
0 .44998 m
.00375 .44998 L
s
0 .46895 m
.00375 .46895 L
s
0 .5069 m
.00375 .5069 L
s
0 .52587 m
.00375 .52587 L
s
0 .54484 m
.00375 .54484 L
s
0 .56381 m
.00375 .56381 L
s
0 .60175 m
.00375 .60175 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -155.031 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Retained) show
160.563 20.000 moveto
(Earnings) show
247.063 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .61192 m
.16667 .61192 L
.25 .05618 L
.33333 .61803 L
.41667 .59593 L
.5 .60124 L
.58333 .60373 L
.66667 .60568 L
.75 .60712 L
.83333 .60818 L
.91667 .60898 L
1 .60956 L
s
1 .60956 m
1 .60956 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJy1WUtzHDUQllfzWgfsjffhxM91TOw4MXlA7YUTHIALnCAEbrhSqUoOVFKJ
j1TNhV9CFQnPQMLjb/AXuMGBC79g0HRPa3skjTSzhBw6va3va7WkVksjv39y
evfOZyen926fTN99ePLg7r3bj6bv3H+oTHJJiKWpEOLZQCj9cyH/ELtFXuzl
hRBd//8gLzIhtvMiBhkJsQNyHewx6GdBlyBHJmkrLxKSE7BHoA9M0od50RPi
FZDbIHt5IYXYAD0CeQ5kSq1KDpnlfOnmJqg74HeTUW03CbOsgcyoVYiPKI4F
3PRBrpduboG6BVKSLmlomzAT5xvcLIOclG4+Zm56pKc0rU0OzoAclw4+YQ7K
QET5r/oZVT+r3/6xvQSSVlk3Gp5x/XZb+OMW8qrnBxNuG/QdBhxDZvE0GIAl
YVzKqQTiQAcJTfmEHCRERX1cZZDqdQqkKehbIDcoRyLwrvVJm300BGgGTjPo
8Z/SvAbdpg6zHtqIMvx3CAS2m56JFUhQNW6hHOSqszJire+20JvwG41dKcRf
jkad4SnzYgFX2ci8wEE9ozj2BtN/CfPUz9dMBp/gNVgabwe4TEMYuxc4pOwI
AWfuuGbMcB0gvznMSv3Vb1bEG21wHcw8g2OYDyyX1+sTzuYL0zqCvOGTcc3N
0AuyQssp66nt4vGlH1FF6c5QhBB22DmeFajRoZEbDJxXzbjKNtbP7l2HJfma
CeQzukrAZr+4ZKtWyBYQ82AQBs7ccc0CHN34KphjkM/bNCr1aldOcyPP95R0
Vxc82RPStd9jdsw9N9dlQLqRWcdUH5V85l71yEr2LiTFCcHlIoGlrsF7Q5pf
P7K2RMxmvN0c00FMQGN6JdyjtN8rYMcL2k/zxTsLMvEBdWWPAsAZi6tu9nLa
NV5mQ/9x3tsVh9nLWbDRuMXoOK3+jXsNArXfI1a3CN5jx7GsJwPCXwb51EwG
fXPvCFfoENA4w71w/R3yf8ElFZEjtnmeugu9XRsusdYfauU+CwB1uQ8BZyy6
utnLadd4yMol6w05OFPfuzltG5vKvdWFv9xbftusjkVqU+4PWD6HSIpzwPLu
O0dFNcbxIuH+EbQjKXlowttM7UWwjGok/OgzRmABMSHWKBUM4Bjkt/NUPHCY
vZzFG5WK5ombg28o6yC/+W+NxqU/oleJiyaQ74rYusVafvnS2Z9VFtxfOvfB
cs4NxzuAvnLjZkAGvpt87cjutJ5EXnjTVSlEcqZrF1KPXssY3NgS0vWpfQEs
GzWSc0tYwKYtgUB8JnsyT9J9h9nLWbxRqWjecnP2wo34ZvW4bDyk0067dTU2
8/He1H9REAnvUD16A2vgt4bgs9xXYYi6jIyE+KIGVHKPQVQ1uCTEo2pe4mZf
CWwqVV7fBgcas+mmYtfoQAJVncO3qgcwO2oNVyvzaV7sV0C+yG9BH1+W5rZv
33/Cjni9UlN8rhF/Q++gvgk+JW1L/ISIqFLOv2x69NYdsUqkOSZazemyRgd9
eHxzi4SujuZRY8GS9CKfgqXf7E+SvU8R+vFBP7imolwYNEuayjNk0aWM17yU
tUq2RdADflTEFhctGWM5vcl6JChZmD160uqT44xOC9tZn0LAznloOP6WQWlW
DCtH4WDq6ED6lIAtA9EHQ9I9EAmBXK4CSeuTHFHx4G70ScTd9OoLl9DSx/SV
rVlOP6HFkrRYaT3RI3LPLRmFkBBeJ7eBR3s9ffX4Y3KGOh/JfC8n9NcKvjf4
qmhjRB7t3VXz2NhPrYZgEbBmCD+r3rCS9LSqFhldQ8Z0IkpYqWW69b5XAVO6
gHiBbcuvWPoXh921qg==\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.14136, 0.257701, \
0.058375, 0.00512827}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .40558 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00965678 0.31746 [
[ 0 0 0 0 ]
[ 1 .40558 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .40558 L
0 .40558 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00965678 0.321429 0.193595 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -54.7457 1.07887 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .06081 -47.25 -11.1875 ]
[-0.0125 .06081 0 11.1875 ]
[-0.0125 .16869 -47.25 -11.1875 ]
[-0.0125 .16869 0 11.1875 ]
[-0.0125 .27658 -25.625 -11.1875 ]
[-0.0125 .27658 0 11.1875 ]
[-0.0125 .38447 -47.25 -11.1875 ]
[-0.0125 .38447 0 11.1875 ]
[-0.0125 .49235 -47.25 -11.1875 ]
[-0.0125 .49235 0 11.1875 ]
[-0.0125 .60024 -47.25 -11.1875 ]
[-0.0125 .60024 0 11.1875 ]
[.5 .63053 -88.7188 0 ]
[.5 .63053 88.7188 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06081 m
.00625 .06081 L
s
gsave
-0.0125 .06081 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.8) show
1.000 setlinewidth
grestore
0 .16869 m
.00625 .16869 L
s
gsave
-0.0125 .16869 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.9) show
1.000 setlinewidth
grestore
0 .27658 m
.00625 .27658 L
s
gsave
-0.0125 .27658 -86.625 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51) show
1.000 setlinewidth
grestore
0 .38447 m
.00625 .38447 L
s
gsave
-0.0125 .38447 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.1) show
1.000 setlinewidth
grestore
0 .49235 m
.00625 .49235 L
s
gsave
-0.0125 .49235 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.2) show
1.000 setlinewidth
grestore
0 .60024 m
.00625 .60024 L
s
gsave
-0.0125 .60024 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.3) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .08238 m
.00375 .08238 L
s
0 .10396 m
.00375 .10396 L
s
0 .12554 m
.00375 .12554 L
s
0 .14712 m
.00375 .14712 L
s
0 .19027 m
.00375 .19027 L
s
0 .21185 m
.00375 .21185 L
s
0 .23343 m
.00375 .23343 L
s
0 .255 m
.00375 .255 L
s
0 .29816 m
.00375 .29816 L
s
0 .31974 m
.00375 .31974 L
s
0 .34131 m
.00375 .34131 L
s
0 .36289 m
.00375 .36289 L
s
0 .40605 m
.00375 .40605 L
s
0 .42762 m
.00375 .42762 L
s
0 .4492 m
.00375 .4492 L
s
0 .47078 m
.00375 .47078 L
s
0 .51393 m
.00375 .51393 L
s
0 .53551 m
.00375 .53551 L
s
0 .55709 m
.00375 .55709 L
s
0 .57866 m
.00375 .57866 L
s
0 .03923 m
.00375 .03923 L
s
0 .01765 m
.00375 .01765 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -149.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Checking) show
160.750 20.000 moveto
(Account) show
236.438 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .28197 m
.16667 .27935 L
.25 .61803 L
.33333 .05618 L
.41667 .13531 L
.5 .16946 L
.58333 .19637 L
.66667 .21618 L
.75 .23084 L
.83333 .2417 L
.91667 .24973 L
1 .25568 L
s
1 .25568 m
1 .25568 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00965678 0.64881 0.193595 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -98.1656 2.04781 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .02693 -58.0625 -11.1875 ]
[-0.0125 .02693 0 11.1875 ]
[-0.0125 .12932 -25.625 -11.1875 ]
[-0.0125 .12932 0 11.1875 ]
[-0.0125 .23171 -58.0625 -11.1875 ]
[-0.0125 .23171 0 11.1875 ]
[-0.0125 .3341 -47.25 -11.1875 ]
[-0.0125 .3341 0 11.1875 ]
[-0.0125 .43649 -58.0625 -11.1875 ]
[-0.0125 .43649 0 11.1875 ]
[-0.0125 .53888 -47.25 -11.1875 ]
[-0.0125 .53888 0 11.1875 ]
[.5 .63053 -83.3125 0 ]
[.5 .63053 83.3125 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02693 m
.00625 .02693 L
s
gsave
-0.0125 .02693 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(47.95) show
1.000 setlinewidth
grestore
0 .12932 m
.00625 .12932 L
s
gsave
-0.0125 .12932 -86.625 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(48) show
1.000 setlinewidth
grestore
0 .23171 m
.00625 .23171 L
s
gsave
-0.0125 .23171 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(48.05) show
1.000 setlinewidth
grestore
0 .3341 m
.00625 .3341 L
s
gsave
-0.0125 .3341 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(48.1) show
1.000 setlinewidth
grestore
0 .43649 m
.00625 .43649 L
s
gsave
-0.0125 .43649 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(48.15) show
1.000 setlinewidth
grestore
0 .53888 m
.00625 .53888 L
s
gsave
-0.0125 .53888 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(48.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04741 m
.00375 .04741 L
s
0 .06789 m
.00375 .06789 L
s
0 .08837 m
.00375 .08837 L
s
0 .10884 m
.00375 .10884 L
s
0 .1498 m
.00375 .1498 L
s
0 .17028 m
.00375 .17028 L
s
0 .19076 m
.00375 .19076 L
s
0 .21123 m
.00375 .21123 L
s
0 .25219 m
.00375 .25219 L
s
0 .27267 m
.00375 .27267 L
s
0 .29315 m
.00375 .29315 L
s
0 .31362 m
.00375 .31362 L
s
0 .35458 m
.00375 .35458 L
s
0 .37506 m
.00375 .37506 L
s
0 .39554 m
.00375 .39554 L
s
0 .41601 m
.00375 .41601 L
s
0 .45697 m
.00375 .45697 L
s
0 .47745 m
.00375 .47745 L
s
0 .49793 m
.00375 .49793 L
s
0 .51841 m
.00375 .51841 L
s
0 .00645 m
.00375 .00645 L
s
0 .55936 m
.00375 .55936 L
s
0 .57984 m
.00375 .57984 L
s
0 .60032 m
.00375 .60032 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -144.313 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Savings) show
149.938 20.000 moveto
(Account) show
225.625 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .05618 m
.16667 .06117 L
.25 .61803 L
.33333 .47156 L
.41667 .36908 L
.5 .2928 L
.58333 .23635 L
.66667 .19455 L
.75 .16361 L
.83333 .1407 L
.91667 .12374 L
1 .11118 L
s
1 .11118 m
1 .11118 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00965678 0.97619 0.193595 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.365798 0.94858 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .01363 -36.4375 -11.1875 ]
[-0.0125 .01363 0 11.1875 ]
[-0.0125 .10849 -36.4375 -11.1875 ]
[-0.0125 .10849 0 11.1875 ]
[-0.0125 .20335 -36.4375 -11.1875 ]
[-0.0125 .20335 0 11.1875 ]
[-0.0125 .29821 -36.4375 -11.1875 ]
[-0.0125 .29821 0 11.1875 ]
[-0.0125 .39307 -36.4375 -11.1875 ]
[-0.0125 .39307 0 11.1875 ]
[-0.0125 .48792 -36.4375 -11.1875 ]
[-0.0125 .48792 0 11.1875 ]
[-0.0125 .58278 -14.8125 -11.1875 ]
[-0.0125 .58278 0 11.1875 ]
[.5 .63053 -94.0313 0 ]
[.5 .63053 94.0313 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01363 m
.00625 .01363 L
s
gsave
-0.0125 .01363 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .10849 m
.00625 .10849 L
s
gsave
-0.0125 .10849 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .20335 m
.00625 .20335 L
s
gsave
-0.0125 .20335 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .29821 m
.00625 .29821 L
s
gsave
-0.0125 .29821 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
0 .39307 m
.00625 .39307 L
s
gsave
-0.0125 .39307 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .48792 m
.00625 .48792 L
s
gsave
-0.0125 .48792 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
1.000 setlinewidth
grestore
0 .58278 m
.00625 .58278 L
s
gsave
-0.0125 .58278 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03261 m
.00375 .03261 L
s
0 .05158 m
.00375 .05158 L
s
0 .07055 m
.00375 .07055 L
s
0 .08952 m
.00375 .08952 L
s
0 .12746 m
.00375 .12746 L
s
0 .14644 m
.00375 .14644 L
s
0 .16541 m
.00375 .16541 L
s
0 .18438 m
.00375 .18438 L
s
0 .22232 m
.00375 .22232 L
s
0 .24129 m
.00375 .24129 L
s
0 .26027 m
.00375 .26027 L
s
0 .27924 m
.00375 .27924 L
s
0 .31718 m
.00375 .31718 L
s
0 .33615 m
.00375 .33615 L
s
0 .35512 m
.00375 .35512 L
s
0 .37409 m
.00375 .37409 L
s
0 .41204 m
.00375 .41204 L
s
0 .43101 m
.00375 .43101 L
s
0 .44998 m
.00375 .44998 L
s
0 .46895 m
.00375 .46895 L
s
0 .5069 m
.00375 .5069 L
s
0 .52587 m
.00375 .52587 L
s
0 .54484 m
.00375 .54484 L
s
0 .56381 m
.00375 .56381 L
s
0 .60175 m
.00375 .60175 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -155.031 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Retained) show
160.563 20.000 moveto
(Earnings) show
247.063 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .61192 m
.16667 .61192 L
.25 .05618 L
.33333 .61803 L
.41667 .59593 L
.5 .60124 L
.58333 .60373 L
.66667 .60568 L
.75 .60712 L
.83333 .60818 L
.91667 .60898 L
1 .60956 L
s
1 .60956 m
1 .60956 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.211989 0.321429 0.395928 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -38.1858 1.65826 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .03697 -58.0625 -11.1875 ]
[-0.0125 .03697 0 11.1875 ]
[-0.0125 .11988 -47.25 -11.1875 ]
[-0.0125 .11988 0 11.1875 ]
[-0.0125 .2028 -58.0625 -11.1875 ]
[-0.0125 .2028 0 11.1875 ]
[-0.0125 .28571 -47.25 -11.1875 ]
[-0.0125 .28571 0 11.1875 ]
[-0.0125 .36862 -58.0625 -11.1875 ]
[-0.0125 .36862 0 11.1875 ]
[-0.0125 .45153 -47.25 -11.1875 ]
[-0.0125 .45153 0 11.1875 ]
[-0.0125 .53445 -58.0625 -11.1875 ]
[-0.0125 .53445 0 11.1875 ]
[-0.0125 .61736 -47.25 -11.1875 ]
[-0.0125 .61736 0 11.1875 ]
[.5 .63053 -34.4375 0 ]
[.5 .63053 34.4375 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03697 m
.00625 .03697 L
s
gsave
-0.0125 .03697 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.05) show
1.000 setlinewidth
grestore
0 .11988 m
.00625 .11988 L
s
gsave
-0.0125 .11988 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.1) show
1.000 setlinewidth
grestore
0 .2028 m
.00625 .2028 L
s
gsave
-0.0125 .2028 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.15) show
1.000 setlinewidth
grestore
0 .28571 m
.00625 .28571 L
s
gsave
-0.0125 .28571 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.2) show
1.000 setlinewidth
grestore
0 .36862 m
.00625 .36862 L
s
gsave
-0.0125 .36862 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.25) show
1.000 setlinewidth
grestore
0 .45153 m
.00625 .45153 L
s
gsave
-0.0125 .45153 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.3) show
1.000 setlinewidth
grestore
0 .53445 m
.00625 .53445 L
s
gsave
-0.0125 .53445 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.35) show
1.000 setlinewidth
grestore
0 .61736 m
.00625 .61736 L
s
gsave
-0.0125 .61736 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.4) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05355 m
.00375 .05355 L
s
0 .07014 m
.00375 .07014 L
s
0 .08672 m
.00375 .08672 L
s
0 .1033 m
.00375 .1033 L
s
0 .13647 m
.00375 .13647 L
s
0 .15305 m
.00375 .15305 L
s
0 .16963 m
.00375 .16963 L
s
0 .18621 m
.00375 .18621 L
s
0 .21938 m
.00375 .21938 L
s
0 .23596 m
.00375 .23596 L
s
0 .25254 m
.00375 .25254 L
s
0 .26913 m
.00375 .26913 L
s
0 .30229 m
.00375 .30229 L
s
0 .31887 m
.00375 .31887 L
s
0 .33546 m
.00375 .33546 L
s
0 .35204 m
.00375 .35204 L
s
0 .3852 m
.00375 .3852 L
s
0 .40179 m
.00375 .40179 L
s
0 .41837 m
.00375 .41837 L
s
0 .43495 m
.00375 .43495 L
s
0 .46812 m
.00375 .46812 L
s
0 .4847 m
.00375 .4847 L
s
0 .50128 m
.00375 .50128 L
s
0 .51787 m
.00375 .51787 L
s
0 .55103 m
.00375 .55103 L
s
0 .56761 m
.00375 .56761 L
s
0 .5842 m
.00375 .5842 L
s
0 .60078 m
.00375 .60078 L
s
0 .02039 m
.00375 .02039 L
s
0 .00381 m
.00375 .00381 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -95.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Output) show
127.875 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .41644 m
.16667 .05618 L
.25 .35154 L
.33333 .61803 L
.41667 .55617 L
.5 .52291 L
.58333 .49746 L
.66667 .47868 L
.75 .46478 L
.83333 .4545 L
.91667 .44688 L
1 .44124 L
s
1 .44124 m
1 .44124 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.211989 0.64881 0.395928 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.257695 0.26644 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .00875 -14.8125 -11.1875 ]
[-0.0125 .00875 0 11.1875 ]
[-0.0125 .14197 -36.4375 -11.1875 ]
[-0.0125 .14197 0 11.1875 ]
[-0.0125 .27519 -14.8125 -11.1875 ]
[-0.0125 .27519 0 11.1875 ]
[-0.0125 .40841 -36.4375 -11.1875 ]
[-0.0125 .40841 0 11.1875 ]
[-0.0125 .54163 -14.8125 -11.1875 ]
[-0.0125 .54163 0 11.1875 ]
[.5 .63053 -72.2813 0 ]
[.5 .63053 72.2813 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00875 m
.00625 .00875 L
s
gsave
-0.0125 .00875 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .14197 m
.00625 .14197 L
s
gsave
-0.0125 .14197 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
0 .27519 m
.00625 .27519 L
s
gsave
-0.0125 .27519 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .40841 m
.00625 .40841 L
s
gsave
-0.0125 .40841 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
1.000 setlinewidth
grestore
0 .54163 m
.00625 .54163 L
s
gsave
-0.0125 .54163 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03539 m
.00375 .03539 L
s
0 .06203 m
.00375 .06203 L
s
0 .08868 m
.00375 .08868 L
s
0 .11532 m
.00375 .11532 L
s
0 .16861 m
.00375 .16861 L
s
0 .19525 m
.00375 .19525 L
s
0 .2219 m
.00375 .2219 L
s
0 .24854 m
.00375 .24854 L
s
0 .30183 m
.00375 .30183 L
s
0 .32847 m
.00375 .32847 L
s
0 .35512 m
.00375 .35512 L
s
0 .38176 m
.00375 .38176 L
s
0 .43505 m
.00375 .43505 L
s
0 .46169 m
.00375 .46169 L
s
0 .48834 m
.00375 .48834 L
s
0 .51498 m
.00375 .51498 L
s
0 .56827 m
.00375 .56827 L
s
0 .59491 m
.00375 .59491 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -133.281 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Interest) show
160.313 20.000 moveto
(Rate) show
203.563 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .28057 m
.16667 .60808 L
.25 .61803 L
.33333 .05618 L
.41667 .13461 L
.5 .16852 L
.58333 .19527 L
.66667 .21499 L
.75 .22959 L
.83333 .2404 L
.91667 .24841 L
1 .25434 L
s
1 .25434 m
1 .25434 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.211989 0.97619 0.395928 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 0.206591 0.211366 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .10091 -48.3125 -11.1875 ]
[-0.0125 .10091 0 11.1875 ]
[-0.0125 .20659 -14.8125 -11.1875 ]
[-0.0125 .20659 0 11.1875 ]
[-0.0125 .31227 -36.4375 -11.1875 ]
[-0.0125 .31227 0 11.1875 ]
[-0.0125 .41796 -14.8125 -11.1875 ]
[-0.0125 .41796 0 11.1875 ]
[-0.0125 .52364 -36.4375 -11.1875 ]
[-0.0125 .52364 0 11.1875 ]
[.5 .63053 -77.6875 0 ]
[.5 .63053 77.6875 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10091 m
.00625 .10091 L
s
gsave
-0.0125 .10091 -109.313 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Math1Mono-Bold
%%IncludeFont: Math1Mono-Bold
/Math1Mono-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.875 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .20659 m
.00625 .20659 L
s
gsave
-0.0125 .20659 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .31227 m
.00625 .31227 L
s
gsave
-0.0125 .31227 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
0 .41796 m
.00625 .41796 L
s
gsave
-0.0125 .41796 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .52364 m
.00625 .52364 L
s
gsave
-0.0125 .52364 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .01636 m
.00375 .01636 L
s
0 .0375 m
.00375 .0375 L
s
0 .05863 m
.00375 .05863 L
s
0 .07977 m
.00375 .07977 L
s
0 .12204 m
.00375 .12204 L
s
0 .14318 m
.00375 .14318 L
s
0 .16432 m
.00375 .16432 L
s
0 .18545 m
.00375 .18545 L
s
0 .22773 m
.00375 .22773 L
s
0 .24886 m
.00375 .24886 L
s
0 .27 m
.00375 .27 L
s
0 .29114 m
.00375 .29114 L
s
0 .33341 m
.00375 .33341 L
s
0 .35455 m
.00375 .35455 L
s
0 .37568 m
.00375 .37568 L
s
0 .39682 m
.00375 .39682 L
s
0 .43909 m
.00375 .43909 L
s
0 .46023 m
.00375 .46023 L
s
0 .48137 m
.00375 .48137 L
s
0 .5025 m
.00375 .5025 L
s
0 .54478 m
.00375 .54478 L
s
0 .56591 m
.00375 .56591 L
s
0 .58705 m
.00375 .58705 L
s
0 .60819 m
.00375 .60819 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -138.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Inflation) show
171.125 20.000 moveto
(Rate) show
214.375 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .41796 m
.16667 .61803 L
.25 .25812 L
.33333 .05618 L
.41667 .48292 L
.5 .44959 L
.58333 .44247 L
.66667 .43602 L
.75 .43133 L
.83333 .42786 L
.91667 .42528 L
1 .42338 L
s
1 .42338 m
1 .42338 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 116.75},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJy1WV1vXDUQvbn2/djNbpK2KVAJStq09Is0oTQk6UJDgiioEj+Ax6hCah8Q
qPQRaf8oD/yT5d6ZPbPH9t0PQgH1xhmPx2fG47F98tPFu9e//Hrx7s2ri50f
3l78/vrNqz92Xvz2thG5tSxb28my7N1W1rT/zNzf2aeT8eTWeJJl7+vng/Fk
mGVuPKmz7MV4MqC2ye/MFPPxpIfOtjdr/6sg0V5Rfzie5BCYos+yl5BvUjvS
udc2H40nG9Kpg4bUNvlnM8VmuIOitU0OxXWeSGbXEdZOFWTo5+NJP+zRCQbU
ThXutr/tjScl8Hp4oBKXSEwHIdf4lPT1EmyVFzJjkcgjfRjriyBPVq4ngnVp
d+pgRQfS2WTEj9I2lRIS7b07jXZfvCkRHSftRwKpFu9ruGCaEu1GVpGWtvdF
txRsPZEXIq9k3Ll8K7L6TWupFC3radqNN4+7LFVI9rNE/3lrqQJC66llbQvg
MKzqURPTU9Epsc69KSbNDc3LHO0SJr3k4w20K5gvRcdhsYYSkMi8yvemcNWd
HJb028Z2PGn/b5btlkgd+sx+DmtOApQ5HdNathkLjLVUaf4dxlNzmk4BeABo
GjcJgAuzzgGGgVEYGQJy0AUG1rPsqwBKGYJwhFnx3QiR1PNn9xSQJ11LMD8g
JfZqj0LROns7mT2NhskNicb3kBJpCAw+CEA+hZ21A3OkqlYILllLANVJONrw
ZdkRIdiAMof4qQYOC8/OVCizAUDPK3kbWitiqRehsG3swz03m24X3bYKCjDa
TrMBx3Om1NK5F8/amOpLW4sH+2U6jf63ZBWlrJSFLVC4ajmX/o0NLVZa/Cym
ezh2OL4Wm9MOHD6x8RjbkEOnOrXgaOSbHTau0Hx3xUYJjyzwjWQLNhTH89hG
BY/3CUdPquG5eLcpvafTcZXYvSY9fWnvY27V5a3XtH8Wydk0gla5PdJBNxyP
8KFkPfzVh4H2c4xY2zRrnM98++Iry3COhXyOPm08CUXfcJh0nouNfG169ucr
REQdXpdrhpVWzji+A1ptqODwwRxntgE7sjkHbMEHUOC85kSFrZ5jnfU7QInP
6eKW06y8621U5L/FyNEsdTJXjhzOEx/4xlBwb2K2IKjmAsttexUhjGn1bXeP
l28aFRs0DA/KuIo7mmsWnNCLHKul611jyJadCxhYYJv7xJrZMRyKj112uEt1
OesJyIouMzSfuu/o+rOi+4Wk8naSPJd2PIcn5XLHC3RWhJ2zcogrMue+JV3n
DgjKyIL8r5NQOB7Juy7Ke4eS40L/o7wvpfDkdJV2tAekhLmu+5bHAaZ3uwEd
ixbzitrbFGFerPvSuwMLZTiqxlpghF5K58EJYlNGUR4kdcfTZA5na7wyFY3p
wwkfzDWeXCelTSxlUJQLmGx+blLfoGsneAaTlLkZvGJajZqup+Hqj7Ajc5yP
QxzmOYZwCZBXrN59NR3uSfA/lvYnUB/AzHX5fkQ35nU5abrMMKxL2XvftM5l
fx4T7XO0iA46JsLnaDkddELHJdfNEeTL6KBnRPuMFtFBz4j2GS2ig551sT2j
leigURfbM1qJDvo6oXpGq9JBx4hPRO8che/s1eig4zlUz9GqdNAJET4ny+kg
RxdepnUKFFWjgPZREo0yehkTRC58AJYhPfJCes+JldFJTuOhzI2oJCIVmkHf
EenjZ6+PyEwvlLAZPTvOqARuzLigxWacJOOuDNoCazCU+NvLKyJAwP8sNWws
wsPETMDS5MLYRdMZ1xHQSYeXn9gbJ1LODErPl53T0ot/zqwRAsvg5t8DyQwL
qK7LzCTYxstOG12EOiE8FDWGYF1H6UXaaB1ERyP4NNhXnddST8RmBEELiybX
Faz7ciBFdHVw2EZ7MRpHHKZJZolVSGHXKHDStXaVUjG3XbhCT7pnir5Bat4X
FJvzZjLyxpLzaPkcB+GxvwGqQ+1VQaFYYCOOsdo5A2US1q15kT1IKLizmC9Z
AKQx84QoGqZrZKgPaQobpAjWJQ672FSVzG28jBhgClsHGZVlBk5E8j3yEUO3
QPI33216yP7Vdu6iM74x+uT5yO2A9gx3qw/J9ppIrRIwvNxWOi1zqvcISQ3i
Lb3v9nFu27thbUpW3KLjSaPWLPCHNLoI21YEalqsClFu5DdJp082OZk60dkL
q5riMvaAH2f20I5eYExczGzTI2y2AHRKrtM7vJ+8w7kdEwXhLMaYRo8MS5HU
YEngHfUOwlexTi1LtYNxnaRB1fU0zZNgmLIdChWyqEBvv8vjyFSVeKyXKbZQ
Jq6zizldgP5n55w4V4XOlcRAlP/NmxJ/k1vBjyhjp37wq9Z1ee0pyVIM0brx
U7voyk5LSpf4yElpm2cgNvsdiRgRhnwJU/kHCT1QZcGxUgK1EaxcQz1d7zwq
sY3lzeI7MqkTXUpeGNJ59dP+GFEmqIO7ilZExl/QvdbjtVDExAee77YuRVwD
t+R7laqWIjhMdqzDw8cyyPBck1+/ILV+26NngM6gJ3KdzFAJXVqjmhcwpjPf
AfGO4/LqMmOb+AtVp7FKlvbyDEO29g9N3vKf\
\>"],ImageRangeCache->{{{0, 287}, {115.75, 0}} -> {-0.0838802, -0.0304253, \
0.0110375, 0.0110375}, {{7.5625, 92.5}, {112.938, 60.5}} -> {-44.2196, \
48.7791, 1.00376, 0.0775321}, {{101, 185.938}, {112.938, 60.5}} -> {-138.009, \
46.9019, 1.00376, 0.0408471}, {{194.438, 279.375}, {112.938, 60.5}} -> \
{-231.798, -1.84862, 1.00376, 0.0881813}, {{7.5625, 92.5}, {55.25, 2.75}} -> \
{-58.6509, 18.8734, 0.99567, 0.0500358}, {{101, 185.938}, {55.25, 2.75}} -> \
{-136.847, -24.888, 0.99567, 0.311411}, {{194.438, 279.375}, {55.25, 2.75}} -> \
{-229.88, -33.5694, 0.99567, 0.392553}}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", "\"\<c:/temp\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<imp_lambda.eps\>\"", ",", "plot", ",", "\"\<EPS\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "1000"}]}], "]"}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing the Autocorrelation Function", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"nsim", "=", "100000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ndist", "=", 
    RowBox[{"NormalDistribution", "[", 
     RowBox[{"0", ",", "1"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssim", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"nsim", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dsim", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"nsim", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xsim", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"nsim", "+", "1"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"csim", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"nsim", "+", "1"}]}], "}"}]}], "]"}]}], ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ssim", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "=", 
   RowBox[{"sbar", "/.", "ssresult"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dsim", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "=", 
   RowBox[{"dbar", "/.", "ssresult"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"xsim", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "=", "xmean"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"j", "=", "1"}], ",", 
   RowBox[{"j", "<", 
    RowBox[{"nsim", "+", "1"}]}], ",", 
   RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"simrule", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "\[Rule]", 
        RowBox[{"ssim", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], ",", 
       RowBox[{"d", "\[Rule]", 
        RowBox[{"dsim", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], ",", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{"xsim", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], ",", 
       RowBox[{"\[Sigma]", "\[Rule]", "0.006"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"csim", "[", 
      RowBox[{"[", "j", "]"}], "]"}], "=", 
     RowBox[{"First", "@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{"csimfun", "/.", "simrule"}], "}"}], "]"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ssim", "[", 
      RowBox[{"[", 
       RowBox[{"j", "+", "1"}], "]"}], "]"}], "=", 
     RowBox[{"First", "@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{"ssimfun", "/.", "simrule"}], "}"}], "]"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"dsim", "[", 
      RowBox[{"[", 
       RowBox[{"j", "+", "1"}], "]"}], "]"}], "=", 
     RowBox[{"First", "@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{"dsimfun", "/.", "simrule"}], "}"}], "]"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xsim", "[", 
      RowBox[{"[", 
       RowBox[{"j", "+", "1"}], "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"xconst", "+", 
        RowBox[{"\[Rho]", " ", 
         RowBox[{"xsim", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], "+", 
        RowBox[{"\[Sigma]", " ", 
         RowBox[{"Random", "[", "ndist", "]"}]}]}], "/.", "param"}], "/.", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", "\[Rule]", "0.006"}], "}"}]}]}], ";"}]}], 
  "\[IndentingNewLine]", "]"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"autocorrtab", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Correlation", "[", 
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"csim", ",", 
        RowBox[{"-", "j"}]}], "]"}], ",", 
      RowBox[{"Drop", "[", 
       RowBox[{"csim", ",", "j"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "6"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.2975133832600639`", ",", 
   RowBox[{"-", "0.17624956671463404`"}], ",", 
   RowBox[{"-", "0.10839213368764374`"}], ",", 
   RowBox[{"-", "0.08418762412144377`"}], ",", 
   RowBox[{"-", "0.06389493691152652`"}], ",", 
   RowBox[{"-", "0.050331832981467574`"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.28613274172151226`", ",", 
   RowBox[{"-", "0.17688633165371984`"}], ",", 
   RowBox[{"-", "0.10839933666166891`"}], ",", 
   RowBox[{"-", "0.07375557920138792`"}], ",", 
   RowBox[{"-", "0.05366000291427153`"}], ",", 
   RowBox[{"-", "0.03898230950977373`"}]}], "}"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.37844253093892544`", ",", "0.1275873301542992`", ",", 
   "0.01698491414570136`", ",", 
   RowBox[{"-", "0.019951226016482592`"}], ",", 
   RowBox[{"-", "0.03319637243408034`"}], ",", 
   RowBox[{"-", "0.03933112448369378`"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.37844253093892544`", ",", "0.1275873301542992`", ",", 
   "0.01698491414570136`", ",", 
   RowBox[{"-", "0.019951226016482592`"}], ",", 
   RowBox[{"-", "0.03319637243408034`"}], ",", 
   RowBox[{"-", "0.03933112448369378`"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.3251590669401791`", ",", "0.10106579608470753`", ",", 
   "0.011694968925424272`", ",", 
   RowBox[{"-", "0.01750034923959082`"}], ",", 
   RowBox[{"-", "0.05321379934725634`"}], ",", 
   RowBox[{"-", "0.05025966381618768`"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.3251590669401791`", ",", "0.10106579608470753`", ",", 
   "0.011694968925424272`", ",", 
   RowBox[{"-", "0.01750034923959082`"}], ",", 
   RowBox[{"-", "0.05321379934725634`"}], ",", 
   RowBox[{"-", "0.05025966381618768`"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1013, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (April 11, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 34, 0, 101, "Title"],
Cell[617, 24, 57, 0, 56, "Subtitle"],
Cell[677, 26, 461, 9, 125, "Text"],
Cell[1141, 37, 416, 8, 112, "Input"],
Cell[CellGroupData[{
Cell[1582, 49, 33, 0, 70, "Section"],
Cell[1618, 51, 977, 29, 112, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2632, 85, 38, 0, 70, "Section"],
Cell[2673, 87, 1954, 67, 128, "Input"],
Cell[4630, 156, 118, 3, 30, "Text"],
Cell[4751, 161, 2954, 100, 292, "Input"],
Cell[7708, 263, 75, 0, 70, "Text"],
Cell[7786, 265, 1280, 44, 70, "Input"],
Cell[9069, 311, 222, 4, 70, "Text"],
Cell[9294, 317, 1113, 35, 70, "Input"],
Cell[10410, 354, 162, 3, 70, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10609, 362, 51, 0, 70, "Section"],
Cell[CellGroupData[{
Cell[10685, 366, 1383, 42, 70, "Input"],
Cell[12071, 410, 1598, 41, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13706, 456, 115, 3, 70, "Input"],
Cell[13824, 461, 237, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14098, 471, 413, 12, 70, "Input"],
Cell[14514, 485, 260, 6, 70, "Output"]
}, Open  ]],
Cell[14789, 494, 143, 3, 70, "Text"],
Cell[CellGroupData[{
Cell[14957, 501, 319, 10, 70, "Input"],
Cell[15279, 513, 334, 11, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15650, 529, 328, 10, 70, "Input"],
Cell[15981, 541, 926, 24, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[16956, 571, 39, 0, 70, "Section"],
Cell[CellGroupData[{
Cell[17020, 575, 771, 21, 70, "Input"],
Cell[17794, 598, 177, 5, 70, "Output"]
}, Open  ]],
Cell[17986, 606, 278, 5, 70, "Text"],
Cell[18267, 613, 940, 30, 70, "Input"],
Cell[19210, 645, 152, 3, 70, "Text"],
Cell[19365, 650, 199, 7, 70, "Input"],
Cell[19567, 659, 271, 5, 70, "Text"],
Cell[CellGroupData[{
Cell[19863, 668, 663, 20, 70, "Input"],
Cell[20529, 690, 3702, 123, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24268, 818, 36, 0, 70, "Input"],
Cell[24307, 820, 11847, 370, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36191, 1195, 117, 3, 70, "Input"],
Cell[36311, 1200, 3701, 122, 70, "Output"]
}, Open  ]],
Cell[40027, 1325, 1072, 31, 70, "Input"],
Cell[CellGroupData[{
Cell[41124, 1360, 34, 0, 70, "Input"],
Cell[41161, 1362, 12559, 412, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[53769, 1780, 39, 0, 70, "Section"],
Cell[53811, 1782, 174, 3, 70, "Text"],
Cell[53988, 1787, 561, 18, 70, "Input"],
Cell[54552, 1807, 95, 2, 70, "Text"],
Cell[54650, 1811, 3731, 110, 70, "Input"],
Cell[58384, 1923, 2619, 73, 70, "Input"],
Cell[CellGroupData[{
Cell[61028, 2000, 12697, 372, 70, "Input"],
Cell[CellGroupData[{
Cell[73750, 2376, 11724, 551, 70, 9145, 506, "GraphicsData", "PostScript", \
"Graphics"],
Cell[85477, 2929, 9632, 452, 70, 7525, 415, "GraphicsData", "PostScript", \
"Graphics"],
Cell[95112, 3383, 10074, 478, 70, 7899, 440, "GraphicsData", "PostScript", \
"Graphics"],
Cell[105189, 3863, 10433, 487, 70, 8070, 446, "GraphicsData", "PostScript", \
"Graphics"],
Cell[115625, 4352, 10816, 498, 70, 8137, 452, "GraphicsData", "PostScript", \
"Graphics"],
Cell[126444, 4852, 10709, 511, 70, 8613, 474, "GraphicsData", "PostScript", \
"Graphics"],
Cell[137156, 5365, 52319, 2764, 70, 48992, 2709, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[189502, 8133, 300, 7, 70, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[189839, 8145, 57, 0, 70, "Section"],
Cell[189899, 8147, 1085, 37, 70, "Input"],
Cell[190987, 8186, 2559, 78, 70, "Input"],
Cell[CellGroupData[{
Cell[193571, 8268, 388, 12, 70, "Input"],
Cell[193962, 8282, 322, 7, 70, "Output"]
}, Open  ]],
Cell[194299, 8292, 321, 7, 70, "Input"],
Cell[CellGroupData[{
Cell[194645, 8303, 290, 7, 70, "Input"],
Cell[194938, 8312, 291, 7, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[195266, 8324, 290, 7, 70, "Input"],
Cell[195559, 8333, 291, 7, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

