(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.4' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    200994,       8432]
NotebookOptionsPosition[    196558,       8287]
NotebookOutlinePosition[    196899,       8302]
CellTagsIndexPosition[    196856,       8299]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Show Me the Money", "Title"],

Cell["Computation with Perturbation Methods", "Subtitle"],

Cell["\<\
Log utility and quadratic adjustment are assumed. Endogenous state variables \
are d and s, exogenous state is x. x is Normal with unit variance.

The underlying theory for the computations can be found in Judd, \
Schmitt-Grohe and Uribe, and especially Fernandez-Villaverde. Some of the \
code is based on Jesus' code for his computational-method comparison paper. 
\
\>", "Text",
 CellChangeTimes->{{3.6897893256715665`*^9, 3.6897893262406235`*^9}}],

Cell[BoxData[{
 RowBox[{"<<", "Statistics`NormalDistribution`"}], "\[IndentingNewLine]", 
 RowBox[{"<<", 
  "Statistics`MultiDescriptiveStatistics`"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Graphics`MultipleListPlot`"}], "\[IndentingNewLine]", 
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell1"}], "]"}]}], "Input"],

Cell[CellGroupData[{

Cell["Set Parameters", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"param", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Psi]", "\[Rule]", "0.24"}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", "0.99"}], ",", 
     RowBox[{"ad1", "\[Rule]", "10"}], ",", 
     RowBox[{"ad2", "\[Rule]", 
      RowBox[{"-", "0.004114605920440126"}]}], ",", 
     RowBox[{"\[Lambda]", "\[Rule]", " ", "0.14"}], ",", 
     RowBox[{"\[Rho]", "\[Rule]", ".5"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xmean", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xconst", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "\[Rho]"}], ")"}], " ", "xmean"}], "/.", "param"}], "//",
     "Chop"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"orderexpansion", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"myvariables", "=", 
   RowBox[{"{", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "}"}]}], 
  ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Model Equations", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cond1a", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"1", "-", "\[Psi]"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "l"}], ")"}], "w"}]], "-", 
    RowBox[{"\[Beta]", 
     RowBox[{"(", 
      FractionBox["\[Psi]", 
       RowBox[{"c2", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "x"}], ")"}], " ", "p2"}]], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond2a", "=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"1", "-", "\[Psi]"}], 
      RowBox[{"1", "-", "l"}]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "w"], "+", 
       RowBox[{"2", "  ", "ad1", " ", 
        RowBox[{"(", 
         RowBox[{"ad2", "+", "i"}], ")"}]}]}], ")"}]}], "-", 
    RowBox[{"\[Beta]", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"1", "-", "\[Psi]"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "x"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"1", "-", "l2"}], ")"}]}]], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"1", "+", "r2"}], "w2"], "+", 
         RowBox[{"2", " ", "ad1", " ", 
          RowBox[{"(", 
           RowBox[{"ad2", "+", "i2"}], ")"}]}]}], ")"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond3a", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "x"}], ")"}], " ", "d2"}], "-", 
    RowBox[{"(", 
     RowBox[{"d", "+", 
      RowBox[{"r", " ", "s"}], " ", "+", 
      RowBox[{"\[Lambda]", " ", "pi"}], " ", "+", 
      RowBox[{"w", " ", "la"}], " ", "-", "i", " ", "-", 
      RowBox[{"p", " ", "c"}]}], ")"}]}]}], " ", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond4a", "=", 
   RowBox[{"i", "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "x"}], ")"}], " ", "s2"}], "-", "s"}], ")"}]}]}], 
  ";"}]}], "Input"],

Cell["\<\
The replacement rules arising from the remaining model equations (this should \
be documented)\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rep0", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"l", "\[Rule]", " ", 
      RowBox[{"la", "+", "lb"}]}], ",", 
     RowBox[{"l2", "\[Rule]", " ", 
      RowBox[{"la2", "+", "lb2"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep0b", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"lb", "\[Rule]", " ", 
      RowBox[{"ad1", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"ad2", "+", "i"}], ")"}], "^", "2"}]}]}], ",", 
     RowBox[{"lb2", "\[Rule]", " ", 
      RowBox[{"ad1", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"ad2", "+", "i2"}], ")"}], "^", "2"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"la", "\[Rule]", "c"}], ",", 
     RowBox[{"la2", "\[Rule]", "c2"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep2", "=", 
   RowBox[{"{", 
    RowBox[{"pi", "\[Rule]", " ", 
     RowBox[{"1", "-", "d", "-", "s"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep2b", "=", 
   RowBox[{"{", 
    RowBox[{"pi2", "\[Rule]", " ", 
     RowBox[{"1", "-", "d2", "-", "s2"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep3", "=", 
   RowBox[{"{", 
    RowBox[{"p", "\[Rule]", 
     RowBox[{"d", "/", "c"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep3b", "=", 
   RowBox[{"{", 
    RowBox[{"p2", "\[Rule]", 
     RowBox[{"d2", "/", "c2"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep4", "=", 
   RowBox[{"{", 
    RowBox[{"b", "->", 
     RowBox[{"1", "+", "x", "-", "d"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep5", "=", 
   RowBox[{"{", 
    RowBox[{"w", "\[Rule]", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "x", "-", "d"}], ")"}], "/", "c"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep5b", "=", 
   RowBox[{"{", 
    RowBox[{"w2", "\[Rule]", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "x2", "-", "d2"}], ")"}], "/", "c2"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep6", "=", 
   RowBox[{"{", 
    RowBox[{"r", "\[Rule]", 
     RowBox[{
      RowBox[{"d", "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", "x", "-", "d"}], ")"}]}], "-", "1"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rep6b", "=", 
   RowBox[{"{", 
    RowBox[{"r2", "\[Rule]", 
     RowBox[{
      RowBox[{"d2", "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", "x2", "-", "d2"}], ")"}]}], "-", "1"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"repall", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
    "rep1", ",", "rep2", ",", "rep2b", ",", "rep3", ",", "rep3b", ",", "rep4",
      ",", "rep5", ",", "rep5b", ",", "rep6", ",", "rep6b"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{""}]}], "Input"],

Cell["Rework cond2 so that it will be easier to take expectations", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cond1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"cond1a", "/.", "rep0"}], "/.", "rep0b"}], "/.", "repall"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"cond2a", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", "d2", "+", "x2"}], ")"}], "2"]}], ")"}], "/.", 
      "rep0"}], "/.", "rep0b"}], "/.", "repall"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond2", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{"cond2", ",", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", "d2", "+", "x2"}], ")"}], "2"]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cond3", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"cond3a", "/.", "rep0"}], "/.", "rep0b"}], "/.", "repall"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cond4", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"cond4a", "/.", "rep0"}], "/.", "rep0b"}], "/.", "repall"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"F", "=", 
   RowBox[{"{", 
    RowBox[{"cond1", ",", "cond2", ",", "cond3", ",", "cond4"}], "}"}]}], 
  ";"}]}], "Input"],

Cell["\<\
Now replace the decision variables by the functions that we are going to \
compute. Notation is moving towards Schmitt-Grohe and Uribe. g are the \
policies for jumps, h are the policies for states.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"c", "=", 
   RowBox[{"g1", "[", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"i", "=", 
   RowBox[{"g2", "[", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"s2", "=", 
   RowBox[{"h1", "[", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d2", "=", 
   RowBox[{"h2", "[", 
    RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2", "=", 
   RowBox[{"g1", "[", 
    RowBox[{"s2", ",", "d2", ",", "x2", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"i2", "=", 
   RowBox[{"g2", "[", 
    RowBox[{"s2", ",", "d2", ",", "x2", ",", "\[Sigma]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x2", "=", 
   RowBox[{"xconst", "+", 
    RowBox[{"\[Rho]", " ", "*", "x"}], "+", 
    RowBox[{"\[Sigma]", "*", "\[Epsilon]"}]}]}], ";"}]}], "Input"],

Cell["\<\
In terms of number of equations and unknowns, this is fine now. s and d are \
endogenous states, c and i are jumps. x is chosen by nature.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The  Non-Stochastic Steady State", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ssfunrule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"h1", "[", "__", "]"}], "\[Rule]", " ", "s"}], ",", 
     RowBox[{
      RowBox[{"h2", "[", "__", "]"}], "\[Rule]", " ", "d"}], ",", " ", 
     RowBox[{
      RowBox[{"g1", "[", "__", "]"}], "\[Rule]", " ", "cbar"}], ",", 
     RowBox[{
      RowBox[{"g2", "[", "__", "]"}], "\[Rule]", "ibar"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssvalrule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s", "\[Rule]", "sbar"}], ",", 
     RowBox[{"d", "\[Rule]", "dbar"}], ",", 
     RowBox[{"x", "\[Rule]", "xmean"}], ",", 
     RowBox[{"ibar", "\[Rule]", 
      RowBox[{"xmean", " ", "sbar"}]}], ",", 
     RowBox[{"\[Sigma]", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sscond", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"F", "[", 
       RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"ssresult", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"sscond", "/.", "param"}], "/.", "ssfunrule"}], "/.", 
     "ssvalrule"}], ",", 
    RowBox[{"{", 
     RowBox[{"sbar", ",", "dbar", ",", "cbar"}], "}"}]}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", 
      RowBox[{"-", "1.190544984486901`"}]}], ",", 
     RowBox[{"dbar", "\[Rule]", "0.5402016797073761`"}], ",", 
     RowBox[{"sbar", "\[Rule]", 
      RowBox[{"-", "80.90985691256739`"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", 
      RowBox[{"-", "0.4050442500586805`"}]}], ",", 
     RowBox[{"dbar", "\[Rule]", 
      RowBox[{"-", "13.17809810457421`"}]}], ",", 
     RowBox[{"sbar", "\[Rule]", "14.182566102981854`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", 
      RowBox[{"-", "0.331175425476288`"}]}], ",", 
     RowBox[{"dbar", "\[Rule]", "13.91826211519191`"}], ",", 
     RowBox[{"sbar", "\[Rule]", 
      RowBox[{"-", "12.913423128808667`"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", 
      RowBox[{"-", "2.85269722094079`*^-17"}]}], ",", 
     RowBox[{"dbar", "\[Rule]", "1.0099999999999998`"}], ",", 
     RowBox[{"sbar", "\[Rule]", "1.7911811887081415`*^-16"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", "0.17951344772444436`"}], ",", 
     RowBox[{"dbar", "\[Rule]", "0.5404365620111101`"}], ",", 
     RowBox[{"sbar", "\[Rule]", "12.781184632613082`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cbar", "\[Rule]", "0.23277997745375828`"}], ",", 
     RowBox[{"dbar", "\[Rule]", "0.5100497660602998`"}], ",", 
     RowBox[{"sbar", "\[Rule]", "0.41135165740390567`"}]}], "}"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ssresult", "=", 
  RowBox[{"ssresult", "[", 
   RowBox[{"[", "6", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"cbar", "\[Rule]", "0.23277997745375828`"}], ",", 
   RowBox[{"dbar", "\[Rule]", "0.5100497660602998`"}], ",", 
   RowBox[{"sbar", "\[Rule]", "0.41135165740390567`"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"varrule", "=", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"s", "\[Rule]", "sbar"}], "/.", "ssresult"}], ",", 
      RowBox[{
       RowBox[{"d", "\[Rule]", "dbar"}], "/.", "ssresult"}], ",", 
      RowBox[{"x", "\[Rule]", "xmean"}], ",", 
      RowBox[{"\[Sigma]", "\[Rule]", "0"}]}], "}"}], "]"}], "//", 
   "Chop"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"s", "\[Rule]", "0.41135165740390567`"}], ",", 
   RowBox[{"d", "\[Rule]", "0.5100497660602998`"}], ",", 
   RowBox[{"x", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"\[Sigma]", "\[Rule]", "0"}]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
The role of derivrule is to suppress the arguments of all the derivatives. \
The : is a general pattern operator here. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"derivrule", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"d", ":", 
     RowBox[{
      RowBox[{
       RowBox[{"Derivative", "[", "__", "]"}], "[", "__", "]"}], "[", "__", 
      "]"}]}], "\[RuleDelayed]", "  ", 
    RowBox[{"d", "[", 
     RowBox[{"[", "0", "]"}], "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"d", ":", 
    RowBox[{
     SuperscriptBox["__", 
      TagBox[
       RowBox[{"(", "__", ")"}],
       Derivative],
      MultilineFunction->None], "[", "__", "]"}]}], "\[RuleDelayed]", 
   RowBox[{"d", "\[LeftDoubleBracket]", "0", "\[RightDoubleBracket]"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"unirule", "=", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"ssfunrule", "/.", "varrule"}], "/.", "ssvalrule"}], "/.", 
       "ssresult"}], ",", "varrule", ",", "derivrule"}], "]"}], "]"}], "//", 
   "Chop"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"h1", "[", "__", "]"}], "\[Rule]", "0.41135165740390567`"}], ",", 
   RowBox[{
    RowBox[{"h2", "[", "__", "]"}], "\[Rule]", "0.5100497660602998`"}], ",", 
   RowBox[{
    RowBox[{"g1", "[", "__", "]"}], "\[Rule]", "0.23277997745375828`"}], ",", 
   RowBox[{
    RowBox[{"g2", "[", "__", "]"}], "\[Rule]", "0.004113516574039057`"}], ",", 
   RowBox[{"s", "\[Rule]", "0.41135165740390567`"}], ",", 
   RowBox[{"d", "\[Rule]", "0.5100497660602998`"}], ",", 
   RowBox[{"x", "\[Rule]", "0.01`"}], ",", 
   RowBox[{"\[Sigma]", "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"d", ":", 
     RowBox[{
      SuperscriptBox["__", 
       TagBox[
        RowBox[{"(", "__", ")"}],
        Derivative],
       MultilineFunction->None], "[", "__", "]"}]}], "\[RuleDelayed]", 
    RowBox[{"d", "\[LeftDoubleBracket]", "0", "\[RightDoubleBracket]"}]}]}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Taylor Expansion", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"epsrule", "=", 
  RowBox[{"Append", "[", 
   RowBox[{
    RowBox[{"Reverse", "@", 
     RowBox[{"Thread", "[", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", 
        RowBox[{"Range", "[", 
         RowBox[{"2", ",", "orderexpansion", ",", "2"}], "]"}]], "->", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"ExpectedValue", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox["#", "j"], "&"}], ",", 
           RowBox[{"NormalDistribution", "[", 
            RowBox[{"0", ",", "1"}], "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "2", ",", "orderexpansion", ",", "2"}], "}"}]}], 
        "]"}]}], "]"}]}], ",", 
    RowBox[{"\[Epsilon]", "\[Rule]", "0"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[Epsilon]", "\[Rule]", "0"}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Notice that all partial derivatives are taken below, even though some \
cross-derivatives are equal and could be left out. This slows computation, \
but as long as computation time is not an issue, it makes it easier to \
simulate from the outcome later.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Fd", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Fd", "[", 
    RowBox[{"[", "0", "]"}], "]"}], "=", "F"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Fd", "[", 
      RowBox[{"[", "j", "]"}], "]"}], "=", 
     RowBox[{"Union", "[", 
      RowBox[{"Expand", "[", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Outer", "[", 
         RowBox[{"D", ",", 
          RowBox[{"{", 
           RowBox[{"Fd", "[", 
            RowBox[{"[", 
             RowBox[{"j", "-", "1"}], "]"}], "]"}], "}"}], ",", 
          "myvariables"}], "]"}], "]"}], "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "orderexpansion"}], "}"}]}], "]"}], 
  ";"}]}], "Input"],

Cell["\<\
Now we plug in everything that is known, that is, we evaluate the derivative \
at the steady state and at calibrated parameters.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dF", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Fd", "/.", "param"}], "/.", "unirule"}], "/.", "epsrule"}], "//",
     "Chop"}]}], ";"}]], "Input"],

Cell["\<\
Now we simply need to solve the resulting system. In the first step, we also \
have to pick the correct solution. Since the system is quadratic, there may \
be more than one. How to pick this is not obvious; check the result manually \
to be sure.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"firstorder", "=", 
   RowBox[{
    RowBox[{"NSolve", "[", 
     RowBox[{"Thread", "[", 
      RowBox[{
       RowBox[{"First", "[", "dF", "]"}], "\[Equal]", "0"}], "]"}], "]"}], "//",
     "Chop"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"solution", "=", 
  RowBox[{"First", "@", 
   RowBox[{"Select", "[", 
    RowBox[{"firstorder", ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "]"}], "[", "g1", 
          "]"}], "]"}], "<", "1"}], "/.", "#"}], "&"}]}], "]"}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.15181650389058962`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.4874835122029452`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.4335721454802472`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.3720180512799741`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.25035886636988924`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.305058358249576`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.1450032975785672`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.0036338935450715`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.6023185750766169`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.09273128373505915`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.14645333055435286`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.31810894183207183`"}]}], 
  "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["firstorder"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.15181650389058962`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.4874835122029452`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.4335721454802472`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.3720180512799741`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.25035886636988924`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "1.305058358249576`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.1450032975785672`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1.0036338935450715`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.6023185750766169`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.09273128373505915`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.14645333055435286`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.31810894183207183`"}]}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.013848974192360343`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.8160581009789086`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.03954933650934658`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "1.310389148171804`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "4.622549095836259`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.8319368762599822`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.7933677993132625`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "5.375824123011374`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "5.018230706837581`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "1.4382095257758245`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.8013014773063951`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.15974375497741788`"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.016379375299838413`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.5103212082287734`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.04677934026353847`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.437239874884995`"}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.25769532834371645`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.9182655530328674`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.07978147397354633`"}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.49557969883146713`"}]}], ",", 
     RowBox[{
      SuperscriptBox["h1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.089183838415876`"}]}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.27062859819504537`"}], ",", 
     RowBox[{
      SuperscriptBox["g1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", "0.0805792887132818`"}], ",", 
     RowBox[{
      SuperscriptBox["g2", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "\[Rule]", 
      RowBox[{"-", "0.07255179143680399`"}]}]}], "}"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solution", "=", 
  RowBox[{"firstorder", "[", 
   RowBox[{"[", "3", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.016379375299838413`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.5103212082287734`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.04677934026353847`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.437239874884995`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.25769532834371645`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.9182655530328674`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.07978147397354633`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.49557969883146713`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.089183838415876`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.27062859819504537`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.0805792887132818`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.07255179143680399`"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"dF", "[", 
      RowBox[{"[", "j", "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{"dF", "[", 
       RowBox[{"[", "j", "]"}], "]"}], "/.", "solution"}]}], ";", 
    "\[IndentingNewLine]", "    ", 
    RowBox[{"nthorder", "=", 
     RowBox[{"NSolve", "[", 
      RowBox[{
       RowBox[{"dF", "[", 
        RowBox[{"[", "j", "]"}], "]"}], "\[Equal]", 
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", 
            RowBox[{"dF", "[", 
             RowBox[{"[", "j", "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}], 
      "]"}]}], ";", "\[IndentingNewLine]", "    ", 
    RowBox[{"solution", "=", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{"solution", ",", "nthorder"}], "}"}], "]"}], "//", 
      "Chop"}]}]}], ",", "     ", "\[IndentingNewLine]", "    ", 
   RowBox[{"{", 
    RowBox[{"j", ",", "2", ",", "orderexpansion"}], "}"}]}], "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData["solution"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.016379375299838413`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.5103212082287734`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.04677934026353847`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.437239874884995`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.25769532834371645`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.9182655530328674`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.07978147397354633`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.49557969883146713`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.089183838415876`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.27062859819504537`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.0805792887132818`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.07255179143680399`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.7482641682219967`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "2.158325650270709`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "2.1369560893769393`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "2.1369560893769397`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.09779557580026`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.605883682762991`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "2.5713297825999257`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "2.24501645019732`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.6486393946470268`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.4277187404619773`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.492574469738142`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "3.973480193409443`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.6899915339340568`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.2963262647007627`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "1.2834913511888741`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "5.300100808282601`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.5815361850284119`"}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.29163018297162085`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.1979165703014736`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.685342309234929`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "1.1468516794411037`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.7668605759644127`"}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.7592678969944681`"}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "3.2415284788658236`"}], ",", 
   RowBox[{
    SuperscriptBox["g1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.06869259225125225`"}]}], ",", 
   RowBox[{
    SuperscriptBox["g2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.13410272692238043`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", 
    RowBox[{"-", "0.13277497715087172`"}]}], ",", 
   RowBox[{
    SuperscriptBox["h2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "\[Rule]", "0.1327749771508717`"}]}], 
  "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simulate the Outcome", "Section"],

Cell["\<\
simprule below eliminates the derivative that are too high (more than \
orderexpansion total); ssrule replaces the constants with steady state values.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"simprule", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d", ":", 
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", 
         RowBox[{"n__", "/;", 
          RowBox[{
           RowBox[{"Plus", "[", "n", "]"}], ">", "orderexpansion"}]}], "]"}], 
        "[", "__", "]"}], "[", "__", "]"}]}], "\[RuleDelayed]", "  ", "0"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssrule", "=", 
   RowBox[{
    RowBox[{"ssfunrule", "/.", "ssvalrule"}], "/.", "ssresult"}]}], 
  ";"}]}], "Input"],

Cell["\<\
Generating Taylor-Series expansion that the result can be plugged into.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sfun", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"h1", "[", 
       RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", 
        RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}], 
    "//", "Normal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dfun", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"h2", "[", 
       RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", 
        RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}], 
    "//", "Normal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cfun", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"g1", "[", 
       RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", 
        RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"d", ",", 
        RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}], 
    "//", "Normal"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ifun", "=", 
    RowBox[{
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{"g2", "[", 
        RowBox[{"s", ",", "d", ",", "x", ",", "\[Sigma]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"s", ",", 
         RowBox[{"sbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"d", ",", 
         RowBox[{"dbar", "/.", "ssresult"}], ",", "orderexpansion"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "xmean", ",", "orderexpansion"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Sigma]", ",", "0", ",", "orderexpansion"}], "}"}]}], "]"}],
      "//", "Normal"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"sfun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dsimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"dfun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"csimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"cfun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"isimfun", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"ifun", "/.", "simprule"}], "/.", "derivrule"}], "/.", 
     "ssrule"}], "/.", "solution"}]}], ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ssim", "[", "1", "]"}], "=", 
   RowBox[{"sbar", "/.", "ssresult"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dsim", "[", "1", "]"}], "=", 
   RowBox[{"dbar", "/.", "ssresult"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"xsim", "[", "1", "]"}], "=", "xmean"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"j", "=", "1"}], ",", 
   RowBox[{"j", "<", "22"}], ",", 
   RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"simrule", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "\[Rule]", 
        RowBox[{"ssim", "[", "j", "]"}]}], ",", 
       RowBox[{"d", "\[Rule]", 
        RowBox[{"dsim", "[", "j", "]"}]}], ",", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{"xsim", "[", "j", "]"}]}], ",", 
       RowBox[{"\[Sigma]", "\[Rule]", "0.006"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"csim", "[", "j", "]"}], "=", 
     RowBox[{"csimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"isim", "[", "j", "]"}], "=", 
     RowBox[{"isimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ssim", "[", 
      RowBox[{"j", "+", "1"}], "]"}], "=", 
     RowBox[{"ssimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"dsim", "[", 
      RowBox[{"j", "+", "1"}], "]"}], "=", 
     RowBox[{"dsimfun", "/.", "simrule"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xsim", "[", 
      RowBox[{"j", "+", "1"}], "]"}], "=", 
     RowBox[{
      RowBox[{"xconst", "+", 
       RowBox[{"\[Rho]", " ", 
        RowBox[{"xsim", "[", "j", "]"}]}]}], "/.", "param"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"j", "\[Equal]", "1"}], ",", 
      RowBox[{
       RowBox[{"xsim", "[", 
        RowBox[{"j", "+", "1"}], "]"}], "=", ".004"}]}], "]"}], ";"}]}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"This", " ", "is", " ", "a", " ", "one"}], "-", 
    RowBox[{
    "standard", " ", "deviation", " ", "contractionary", " ", "shock"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", "]"}]}], "Input"],

Cell["Now compute the adjustment cost", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"costtable", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"100", " ", "ad1", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"ad2", "+", 
          RowBox[{"isim", "[", "j", "]"}]}], ")"}], "^", "2"}], "/", 
       RowBox[{"csim", "[", "j", "]"}]}]}], "/.", "param"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "12"}], "}"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"costtable", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"500", "*", "3600", " ", "ad1", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"ad2", "+", 
          RowBox[{"isim", "[", "j", "]"}]}], ")"}], "^", "2"}], "/", 
       RowBox[{"csim", "[", "j", "]"}]}]}], "/.", "param"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "12"}], "}"}]}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "5.097842153363955`*^-9", ",", "0.001233670598343786`", ",", 
   "0.00013293065125738015`", ",", "0.00002535892565723703`", ",", 
   "0.00021592748517838427`", ",", "0.00037926226940440374`", ",", 
   "0.0004513099772714052`", ",", "0.0004540099393430851`", ",", 
   "0.0004193200150310263`", ",", "0.0003696573094083594`", ",", 
   "0.0003174602082970936`", ",", "0.0002686078627455166`"}], "}"}]], "Output"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.00009176115876055116`", ",", "22.20607077018815`", ",", 
   "2.3927517226328425`", ",", "0.45646066183026657`", ",", 
   "3.8866947332109163`", ",", "6.826720849279267`", ",", 
   "8.123579590885294`", ",", "8.172178908175532`", ",", "7.547760270558474`",
    ",", "6.65383156935047`", ",", "5.714283749347684`", ",", 
   "4.834941529419299`"}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Multiply", " ", "by", " ", "100", " ", "below", " ", "to", " ", "get", 
    " ", "percentages", " ", "and", " ", "more", " ", "convenient", " ", 
    "units"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"sout", "=", 
    RowBox[{"Flatten", "@", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"100", "*", 
        RowBox[{"ssim", "[", "j", "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
   ";"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", "*", 
       RowBox[{"dsim", "[", "j", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", "*", 
       RowBox[{"csim", "[", "j", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"iout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"isim", "[", "j", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xout", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"xsim", "[", "j", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pout", "=", 
    RowBox[{"Flatten", "@", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"dsim", "[", "j", "]"}], "/", 
        RowBox[{"csim", "[", "j", "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "21"}], "}"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rout", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"100", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"dout", "[", 
          RowBox[{"[", "j", "]"}], "]"}], "/", 
         RowBox[{"(", 
          RowBox[{"100", "+", 
           RowBox[{"100", " ", 
            RowBox[{"xout", "[", 
             RowBox[{"[", "j", "]"}], "]"}]}], "-", 
           RowBox[{"dout", "[", 
            RowBox[{"[", "j", "]"}], "]"}]}], ")"}]}], "-", "1"}], ")"}]}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"infout", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"100", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"xout", "[", 
            RowBox[{"[", "j", "]"}], "]"}]}], ")"}], " ", 
         RowBox[{
          RowBox[{"pout", "[", 
           RowBox[{"[", 
            RowBox[{"j", "+", "1"}], "]"}], "]"}], "/", 
          RowBox[{"pout", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}]}], "-", "1"}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"infout", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "infout"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"piout", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"100", "-", 
       RowBox[{"sout", "[", 
        RowBox[{"[", "j", "]"}], "]"}], "-", 
       RowBox[{"dout", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "20"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot1", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"cout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Thickness", "[", ".01", "]"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "cout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "cout", "]"}], "-", 
              RowBox[{"Min", "[", "cout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "cout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "cout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "cout", "]"}], "-", 
            RowBox[{"Min", "[", "cout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Output\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot2", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"rout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "rout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "rout", "]"}], "-", 
              RowBox[{"Min", "[", "rout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "rout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "rout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "rout", "]"}], "-", 
            RowBox[{"Min", "[", "rout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Interest Rate\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot3", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"infout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "infout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "infout", "]"}], "-", 
              RowBox[{"Min", "[", "infout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "infout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "infout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "infout", "]"}], "-", 
            RowBox[{"Min", "[", "infout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Inflation Rate\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot4", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"dout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "dout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "dout", "]"}], "-", 
              RowBox[{"Min", "[", "dout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "dout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "dout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "dout", "]"}], "-", 
            RowBox[{"Min", "[", "dout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Checking Account\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot5", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"sout", ",", 
     RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", "sout", "]"}], "-", 
           RowBox[{".1", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Max", "[", "sout", "]"}], "-", 
              RowBox[{"Min", "[", "sout", "]"}]}], ")"}]}]}], ",", 
          RowBox[{"Max", "[", "sout", "]"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         RowBox[{"Min", "[", "sout", "]"}], "-", 
         RowBox[{".1", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Max", "[", "sout", "]"}], "-", 
            RowBox[{"Min", "[", "sout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Savings Account\>\""}], ",", 
     RowBox[{"TextStyle", "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontSize", "->", "18"}], ",", 
        RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"plot6", "=", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"piout", ",", 
      RowBox[{"PlotJoined", "\[Rule]", "True"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Thickness", "[", ".01", "]"}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", " ", "12"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Min", "[", "piout", "]"}], "-", 
            RowBox[{".1", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Max", "[", "piout", "]"}], "-", 
               RowBox[{"Min", "[", "piout", "]"}]}], ")"}]}]}], ",", 
           RowBox[{"Max", "[", "piout", "]"}]}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{
          RowBox[{"Min", "[", "piout", "]"}], "-", 
          RowBox[{".1", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Max", "[", "piout", "]"}], "-", 
             RowBox[{"Min", "[", "piout", "]"}]}], ")"}]}]}]}], "}"}]}], ",", 
      RowBox[{"PlotLabel", "\[Rule]", "\"\<Retained Earnings\>\""}], ",", 
      RowBox[{"TextStyle", "\[RuleDelayed]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontSize", "->", "18"}], ",", 
         RowBox[{"FontWeight", "->", "\"\<Bold\>\""}]}], "}"}]}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"plot", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"GraphicsArray", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"plot1", ",", "plot2", ",", "plot3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"plot4", ",", "plot5", ",", "plot6"}], "}"}]}], "}"}], "]"}], 
    "]"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -68.9755 2.98618 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .00529 -47.25 -11.1875 ]
[-0.0125 .00529 0 11.1875 ]
[-0.0125 .1546 -58.0625 -11.1875 ]
[-0.0125 .1546 0 11.1875 ]
[-0.0125 .30391 -47.25 -11.1875 ]
[-0.0125 .30391 0 11.1875 ]
[-0.0125 .45322 -58.0625 -11.1875 ]
[-0.0125 .45322 0 11.1875 ]
[-0.0125 .60253 -47.25 -11.1875 ]
[-0.0125 .60253 0 11.1875 ]
[.5 .63053 -34.4375 0 ]
[.5 .63053 34.4375 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00529 m
.00625 .00529 L
s
gsave
-0.0125 .00529 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.1) show
1.000 setlinewidth
grestore
0 .1546 m
.00625 .1546 L
s
gsave
-0.0125 .1546 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.15) show
1.000 setlinewidth
grestore
0 .30391 m
.00625 .30391 L
s
gsave
-0.0125 .30391 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.2) show
1.000 setlinewidth
grestore
0 .45322 m
.00625 .45322 L
s
gsave
-0.0125 .45322 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.25) show
1.000 setlinewidth
grestore
0 .60253 m
.00625 .60253 L
s
gsave
-0.0125 .60253 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.3) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03516 m
.00375 .03516 L
s
0 .06502 m
.00375 .06502 L
s
0 .09488 m
.00375 .09488 L
s
0 .12474 m
.00375 .12474 L
s
0 .18447 m
.00375 .18447 L
s
0 .21433 m
.00375 .21433 L
s
0 .24419 m
.00375 .24419 L
s
0 .27405 m
.00375 .27405 L
s
0 .33377 m
.00375 .33377 L
s
0 .36364 m
.00375 .36364 L
s
0 .3935 m
.00375 .3935 L
s
0 .42336 m
.00375 .42336 L
s
0 .48308 m
.00375 .48308 L
s
0 .51295 m
.00375 .51295 L
s
0 .54281 m
.00375 .54281 L
s
0 .57267 m
.00375 .57267 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -95.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Output) show
127.875 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .54085 m
.16667 .05618 L
.25 .07287 L
.33333 .23464 L
.41667 .38591 L
.5 .49219 L
.58333 .55719 L
.66667 .59296 L
.75 .61039 L
.83333 .61714 L
.91667 .61803 L
1 .61592 L
s
1 .61592 m
1 .61592 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.77254, 23.0576, \
0.058375, 0.00162903}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.693773 0.402227 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .03024 -36.4375 -11.1875 ]
[-0.0125 .03024 0 11.1875 ]
[-0.0125 .11068 -14.8125 -11.1875 ]
[-0.0125 .11068 0 11.1875 ]
[-0.0125 .19113 -36.4375 -11.1875 ]
[-0.0125 .19113 0 11.1875 ]
[-0.0125 .27157 -36.4375 -11.1875 ]
[-0.0125 .27157 0 11.1875 ]
[-0.0125 .35202 -36.4375 -11.1875 ]
[-0.0125 .35202 0 11.1875 ]
[-0.0125 .43246 -36.4375 -11.1875 ]
[-0.0125 .43246 0 11.1875 ]
[-0.0125 .51291 -14.8125 -11.1875 ]
[-0.0125 .51291 0 11.1875 ]
[-0.0125 .59335 -36.4375 -11.1875 ]
[-0.0125 .59335 0 11.1875 ]
[.5 .63053 -72.2813 0 ]
[.5 .63053 72.2813 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03024 m
.00625 .03024 L
s
gsave
-0.0125 .03024 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
1.000 setlinewidth
grestore
0 .11068 m
.00625 .11068 L
s
gsave
-0.0125 .11068 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .19113 m
.00625 .19113 L
s
gsave
-0.0125 .19113 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
1.000 setlinewidth
grestore
0 .27157 m
.00625 .27157 L
s
gsave
-0.0125 .27157 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
1.000 setlinewidth
grestore
0 .35202 m
.00625 .35202 L
s
gsave
-0.0125 .35202 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
1.000 setlinewidth
grestore
0 .43246 m
.00625 .43246 L
s
gsave
-0.0125 .43246 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
1.000 setlinewidth
grestore
0 .51291 m
.00625 .51291 L
s
gsave
-0.0125 .51291 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
0 .59335 m
.00625 .59335 L
s
gsave
-0.0125 .59335 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05035 m
.00375 .05035 L
s
0 .07046 m
.00375 .07046 L
s
0 .09057 m
.00375 .09057 L
s
0 .13079 m
.00375 .13079 L
s
0 .1509 m
.00375 .1509 L
s
0 .17101 m
.00375 .17101 L
s
0 .21124 m
.00375 .21124 L
s
0 .23135 m
.00375 .23135 L
s
0 .25146 m
.00375 .25146 L
s
0 .29168 m
.00375 .29168 L
s
0 .31179 m
.00375 .31179 L
s
0 .33191 m
.00375 .33191 L
s
0 .37213 m
.00375 .37213 L
s
0 .39224 m
.00375 .39224 L
s
0 .41235 m
.00375 .41235 L
s
0 .45257 m
.00375 .45257 L
s
0 .47269 m
.00375 .47269 L
s
0 .4928 m
.00375 .4928 L
s
0 .53302 m
.00375 .53302 L
s
0 .55313 m
.00375 .55313 L
s
0 .57324 m
.00375 .57324 L
s
0 .01012 m
.00375 .01012 L
s
0 .61346 m
.00375 .61346 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -133.281 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Interest) show
160.313 20.000 moveto
(Rate) show
203.563 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .11877 m
.16667 .61086 L
.25 .61803 L
.33333 .45911 L
.41667 .30493 L
.5 .19467 L
.58333 .12605 L
.66667 .08728 L
.75 .06743 L
.83333 .05871 L
.91667 .05618 L
1 .05691 L
s
1 .05691 m
1 .05691 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJytWVmTFEUQLqanZ3aXlZ3ZY5BjD0RBFDxQNLwAD0ANQUWQQwldVxQMDwIw
UAEbFfFARTnkRk4R5Ab9G/4FH/XZHzBOf9mZlV3VPYAhD0lN5peZdXyVXVU7
d3DtiuXvDK5dOTQ4MGf14KoVK4fWDMx+b3VDFQwzZtiAMeZixTTaG0zwp+mv
R/VxUd2Y6/3/hajeYkxvVA8hi8b0QY6EPkS7inYA2e06jY3qJZY16ItoV1yn
BVG9YMzNkL2QhageGDMa7SLkjZBltjZkl9KMisMsRLMPcccoVz9MSWk6IVvY
asyL3I//EKYVcmQcZhGaYyEDbgc8tDGYiVE5Ydoga3GYxSpMgdtlnta8AMMh
e+IAS1SAuCMm/pf8LCY/k9/Nx9YOyassRicyrV//NcTTGo4q80OE60W7TwF7
wCxNgwo0JeXLnCqhHxSgxFNe4wAldqV2T8KgRtYBOA2gPRZyNHOkiOjSrv2X
fTUtqv+BwGiaRqqoYYrzSbv/Gtp5+NFxYNqXNClldJUI/rdrLGHwZeX/Vwyh
QVbVxJf+L0gDoYydzfI3NV5/ZjX+MN//VFQfnywPAf1e7I7q0xJIN5cimmKB
7IjqNWNmJIvcgHyPSX/eXfWtUC901Vuieiu2blq9GVt/WayeyIvYiP0Z+jmY
UovPJhiHYuOtXBvEuBFjWx4bJ3HlEeN6GN+MjbdxdWvYPkTAt2L17bwXxGcd
jG/Hxslcn8V4AzRvAPJuDJnizf4IaF7HfK5KBuSsYQfkEPqyOoHI3vdjvQb9
mmT8zkoS5FWkW5vMgrOSBHkF+vfdBaG+LEOKdXaxK5AvQ/1Bts9LPJdZxqUw
fpRtXALjencnh4oQlH8x9BtygRKX4FT8NsbwTi7KDl0IuADAj2NglwK2eUAq
6JvsPulWNCLIfLQ/iSE9CtLixZoP+WkMrCmgXkza0c/xlsB3WIAlD/gs5OZk
eoRkIzzC0WzMg/w8gQvhRuSQr8pOevNyMal4RCT4XMgtycwWAXfoSMBnIL+w
jKOFeBryS5c3NICnIL/KNYomx/9JyK/dnHMgt7osa+HPshNlNuQ3V4dT9Fnp
WsmLIadBB/4E5LeWmp0qB2keh/wu9ZVoyUr9GOQ2S00iYpCT+lEu80zQijqk
aDhlnak02yxZyUlOU2U+9BTwMWnIH1y++h5OpumQ213iVkEtH/4I5A5L1i4+
RfhA0Wy3lO3OgT8MudPSh2bpIQXc4RKPBv4g5K5co2h2ZkMegPzRpZw+F9UY
KK67XLh/UiKn+yF3u2XTrwgEvw9yT4qhmecQgetjR/6ZiuA0s3tTnM0sTwIX
zR7L3A4cM/yh3gu5z7KVaqW9RuhCRYh7lGavS90O/sDIjp4Kud/lagdkmxd9
qtLss4ytQpY8+N2QB1JcLeYARbPfMpb6eBfkQZdrZLxTaQ5kQ+6APJRrFM1B
m5nueXRc+imXyE6sKUpz6Op0phx0pDts6dyVw0+C08HwSC6dA2OB4no4l8hO
dDqTHrV0rub0epLSHEmV4Ew4HYSPuUT2u0EXv4lKc9QlsX9eoEeDCZDHXSo3
zzRBaY5ZQvvjIPgtkCcsof3zggBFc9zSiu7u4yF/dgk5ho2iOZENuQnyZK5R
NEgxEWNpUfnHQf4SGyeAoWUvyjilOZkACzjKOtNIEen54VSUecUQiGiQejJv
i4D7Re8OpyO6FoTpfglEXxzzgfQs8msqkQ8RzelU16UvNBlnIv9eJJ6UiFb9
bAJ0irlARHMmyrz69Krac86ypo/VAjzrrj1BaG+dzzWK5lw2hDbxBZu5n9UC
PJ/sL6JU5u2GYlH9uBjDK0yy5nDRXEichHDy3dIPMFIqL9myQk5tyCQQcbqY
FKqAC0qrF5Gq6eVkg4ecoiULKJpLFu5fkvpV2b1iO+BfkhrAtnSXLufWS9qh
Xcb8llEdM88fk/DA8XsCL3OJ06fBK25Z+ydW1K/ztW0RPzYX1SG5wO/X9BUM
+EW7xE/U9EltxxzSgT+JIEcd7T+jWaIihkcpCvwKTsgywpTBkJBnqYCZ0V7T
42BLeSUL3KNQtQvMSMG05SCHcztgTTEn2qxmacvcS2mHGEOoeF/gHVZOezUd
jx84UE++8iEsNQsZ8BBClSTkwRa5rYesu1DhNcmMoFKV1B8yZMFaeWn1Erar
Wdd6as9IhQw0zYpMzZD77nArTJO4Pb2kYTrCTJuICol+rgrUs8w8y+iKAnZA
U70KpKyeTK59o5ph/wLdVHWA\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.14136, 1.42314, \
0.058375, 0.0120941}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.130603 0.440002 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .0454 -36.4375 -11.1875 ]
[-0.0125 .0454 0 11.1875 ]
[-0.0125 .1334 -36.4375 -11.1875 ]
[-0.0125 .1334 0 11.1875 ]
[-0.0125 .2214 -36.4375 -11.1875 ]
[-0.0125 .2214 0 11.1875 ]
[-0.0125 .3094 -14.8125 -11.1875 ]
[-0.0125 .3094 0 11.1875 ]
[-0.0125 .3974 -36.4375 -11.1875 ]
[-0.0125 .3974 0 11.1875 ]
[-0.0125 .4854 -36.4375 -11.1875 ]
[-0.0125 .4854 0 11.1875 ]
[-0.0125 .5734 -36.4375 -11.1875 ]
[-0.0125 .5734 0 11.1875 ]
[.5 .63053 -77.6875 0 ]
[.5 .63053 77.6875 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0454 m
.00625 .0454 L
s
gsave
-0.0125 .0454 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .1334 m
.00625 .1334 L
s
gsave
-0.0125 .1334 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .2214 m
.00625 .2214 L
s
gsave
-0.0125 .2214 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .3094 m
.00625 .3094 L
s
gsave
-0.0125 .3094 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .3974 m
.00625 .3974 L
s
gsave
-0.0125 .3974 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .4854 m
.00625 .4854 L
s
gsave
-0.0125 .4854 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
0 .5734 m
.00625 .5734 L
s
gsave
-0.0125 .5734 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0674 m
.00375 .0674 L
s
0 .0894 m
.00375 .0894 L
s
0 .1114 m
.00375 .1114 L
s
0 .1554 m
.00375 .1554 L
s
0 .1774 m
.00375 .1774 L
s
0 .1994 m
.00375 .1994 L
s
0 .2434 m
.00375 .2434 L
s
0 .2654 m
.00375 .2654 L
s
0 .2874 m
.00375 .2874 L
s
0 .3314 m
.00375 .3314 L
s
0 .3534 m
.00375 .3534 L
s
0 .3754 m
.00375 .3754 L
s
0 .4194 m
.00375 .4194 L
s
0 .4414 m
.00375 .4414 L
s
0 .4634 m
.00375 .4634 L
s
0 .5074 m
.00375 .5074 L
s
0 .5294 m
.00375 .5294 L
s
0 .5514 m
.00375 .5514 L
s
0 .0234 m
.00375 .0234 L
s
0 .0014 m
.00375 .0014 L
s
0 .5954 m
.00375 .5954 L
s
0 .6174 m
.00375 .6174 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -138.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Inflation) show
171.125 20.000 moveto
(Rate) show
214.375 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .3094 m
.16667 .61803 L
.25 .17046 L
.33333 .05618 L
.41667 .098 L
.5 .16626 L
.58333 .22294 L
.66667 .26165 L
.75 .28555 L
.83333 .29938 L
.91667 .30695 L
1 .31088 L
s
1 .31088 m
1 .31088 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.14136, 0.0210336, \
0.058375, 0.0110558}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -149.067 2.92594 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .00981 -58.0625 -11.1875 ]
[-0.0125 .00981 0 11.1875 ]
[-0.0125 .15611 -25.625 -11.1875 ]
[-0.0125 .15611 0 11.1875 ]
[-0.0125 .3024 -58.0625 -11.1875 ]
[-0.0125 .3024 0 11.1875 ]
[-0.0125 .4487 -47.25 -11.1875 ]
[-0.0125 .4487 0 11.1875 ]
[-0.0125 .595 -58.0625 -11.1875 ]
[-0.0125 .595 0 11.1875 ]
[.5 .63053 -88.7188 0 ]
[.5 .63053 88.7188 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00981 m
.00625 .00981 L
s
gsave
-0.0125 .00981 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.95) show
1.000 setlinewidth
grestore
0 .15611 m
.00625 .15611 L
s
gsave
-0.0125 .15611 -86.625 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51) show
1.000 setlinewidth
grestore
0 .3024 m
.00625 .3024 L
s
gsave
-0.0125 .3024 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.05) show
1.000 setlinewidth
grestore
0 .4487 m
.00625 .4487 L
s
gsave
-0.0125 .4487 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.1) show
1.000 setlinewidth
grestore
0 .595 m
.00625 .595 L
s
gsave
-0.0125 .595 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.15) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03907 m
.00375 .03907 L
s
0 .06833 m
.00375 .06833 L
s
0 .09759 m
.00375 .09759 L
s
0 .12685 m
.00375 .12685 L
s
0 .18536 m
.00375 .18536 L
s
0 .21462 m
.00375 .21462 L
s
0 .24388 m
.00375 .24388 L
s
0 .27314 m
.00375 .27314 L
s
0 .33166 m
.00375 .33166 L
s
0 .36092 m
.00375 .36092 L
s
0 .39018 m
.00375 .39018 L
s
0 .41944 m
.00375 .41944 L
s
0 .47796 m
.00375 .47796 L
s
0 .50722 m
.00375 .50722 L
s
0 .53648 m
.00375 .53648 L
s
0 .56574 m
.00375 .56574 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -149.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Checking) show
160.750 20.000 moveto
(Account) show
236.438 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .17067 m
.16667 .15941 L
.25 .61803 L
.33333 .55826 L
.41667 .39396 L
.5 .25172 L
.58333 .15606 L
.66667 .1001 L
.75 .07126 L
.83333 .05901 L
.91667 .05618 L
1 .05835 L
s
1 .05835 m
1 .05835 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.77254, 50.9052, \
0.058375, 0.00166257}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -45.0752 1.09715 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .0176 -47.25 -11.1875 ]
[-0.0125 .0176 0 11.1875 ]
[-0.0125 .12732 -47.25 -11.1875 ]
[-0.0125 .12732 0 11.1875 ]
[-0.0125 .23703 -47.25 -11.1875 ]
[-0.0125 .23703 0 11.1875 ]
[-0.0125 .34675 -47.25 -11.1875 ]
[-0.0125 .34675 0 11.1875 ]
[-0.0125 .45646 -47.25 -11.1875 ]
[-0.0125 .45646 0 11.1875 ]
[-0.0125 .56618 -47.25 -11.1875 ]
[-0.0125 .56618 0 11.1875 ]
[.5 .63053 -83.3125 0 ]
[.5 .63053 83.3125 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0176 m
.00625 .0176 L
s
gsave
-0.0125 .0176 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.1) show
1.000 setlinewidth
grestore
0 .12732 m
.00625 .12732 L
s
gsave
-0.0125 .12732 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.2) show
1.000 setlinewidth
grestore
0 .23703 m
.00625 .23703 L
s
gsave
-0.0125 .23703 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.3) show
1.000 setlinewidth
grestore
0 .34675 m
.00625 .34675 L
s
gsave
-0.0125 .34675 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.4) show
1.000 setlinewidth
grestore
0 .45646 m
.00625 .45646 L
s
gsave
-0.0125 .45646 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.5) show
1.000 setlinewidth
grestore
0 .56618 m
.00625 .56618 L
s
gsave
-0.0125 .56618 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03955 m
.00375 .03955 L
s
0 .06149 m
.00375 .06149 L
s
0 .08343 m
.00375 .08343 L
s
0 .10537 m
.00375 .10537 L
s
0 .14926 m
.00375 .14926 L
s
0 .1712 m
.00375 .1712 L
s
0 .19315 m
.00375 .19315 L
s
0 .21509 m
.00375 .21509 L
s
0 .25898 m
.00375 .25898 L
s
0 .28092 m
.00375 .28092 L
s
0 .30286 m
.00375 .30286 L
s
0 .3248 m
.00375 .3248 L
s
0 .36869 m
.00375 .36869 L
s
0 .39063 m
.00375 .39063 L
s
0 .41258 m
.00375 .41258 L
s
0 .43452 m
.00375 .43452 L
s
0 .4784 m
.00375 .4784 L
s
0 .50035 m
.00375 .50035 L
s
0 .52229 m
.00375 .52229 L
s
0 .54423 m
.00375 .54423 L
s
0 .58812 m
.00375 .58812 L
s
0 .61006 m
.00375 .61006 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -144.313 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Savings) show
149.938 20.000 moveto
(Account) show
225.625 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .05618 m
.16667 .06041 L
.25 .39525 L
.33333 .55198 L
.41667 .61084 L
.5 .61803 L
.58333 .59937 L
.66667 .56888 L
.75 .53398 L
.83333 .4985 L
.91667 .46427 L
1 .43215 L
s
1 .43215 m
1 .43215 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.45695, 40.9733, \
0.058375, 0.00443383}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -6.93896 0.961467 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .07975 -36.4375 -11.1875 ]
[-0.0125 .07975 0 11.1875 ]
[-0.0125 .1759 -36.4375 -11.1875 ]
[-0.0125 .1759 0 11.1875 ]
[-0.0125 .27204 -36.4375 -11.1875 ]
[-0.0125 .27204 0 11.1875 ]
[-0.0125 .36819 -36.4375 -11.1875 ]
[-0.0125 .36819 0 11.1875 ]
[-0.0125 .46434 -36.4375 -11.1875 ]
[-0.0125 .46434 0 11.1875 ]
[-0.0125 .56048 -36.4375 -11.1875 ]
[-0.0125 .56048 0 11.1875 ]
[.5 .63053 -94.0313 0 ]
[.5 .63053 94.0313 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07975 m
.00625 .07975 L
s
gsave
-0.0125 .07975 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.3) show
1.000 setlinewidth
grestore
0 .1759 m
.00625 .1759 L
s
gsave
-0.0125 .1759 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.4) show
1.000 setlinewidth
grestore
0 .27204 m
.00625 .27204 L
s
gsave
-0.0125 .27204 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.5) show
1.000 setlinewidth
grestore
0 .36819 m
.00625 .36819 L
s
gsave
-0.0125 .36819 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.6) show
1.000 setlinewidth
grestore
0 .46434 m
.00625 .46434 L
s
gsave
-0.0125 .46434 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.7) show
1.000 setlinewidth
grestore
0 .56048 m
.00625 .56048 L
s
gsave
-0.0125 .56048 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .09898 m
.00375 .09898 L
s
0 .11821 m
.00375 .11821 L
s
0 .13744 m
.00375 .13744 L
s
0 .15667 m
.00375 .15667 L
s
0 .19513 m
.00375 .19513 L
s
0 .21435 m
.00375 .21435 L
s
0 .23358 m
.00375 .23358 L
s
0 .25281 m
.00375 .25281 L
s
0 .29127 m
.00375 .29127 L
s
0 .3105 m
.00375 .3105 L
s
0 .32973 m
.00375 .32973 L
s
0 .34896 m
.00375 .34896 L
s
0 .38742 m
.00375 .38742 L
s
0 .40665 m
.00375 .40665 L
s
0 .42588 m
.00375 .42588 L
s
0 .44511 m
.00375 .44511 L
s
0 .48357 m
.00375 .48357 L
s
0 .50279 m
.00375 .50279 L
s
0 .52202 m
.00375 .52202 L
s
0 .54125 m
.00375 .54125 L
s
0 .06052 m
.00375 .06052 L
s
0 .04129 m
.00375 .04129 L
s
0 .02206 m
.00375 .02206 L
s
0 .00283 m
.00375 .00283 L
s
0 .57971 m
.00375 .57971 L
s
0 .59894 m
.00375 .59894 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -155.031 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Retained) show
160.563 20.000 moveto
(Earnings) show
247.063 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .61803 m
.16667 .61803 L
.25 .1739 L
.33333 .05618 L
.41667 .0586 L
.5 .09903 L
.58333 .14682 L
.66667 .19193 L
.75 .23199 L
.83333 .26711 L
.91667 .29803 L
1 .32547 L
s
1 .32547 m
1 .32547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.14136, 7.09084, \
0.058375, 0.00505954}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .40558 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00965678 0.31746 [
[ 0 0 0 0 ]
[ 1 .40558 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .40558 L
0 .40558 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00965678 0.321429 0.193595 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -149.067 2.92594 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .00981 -58.0625 -11.1875 ]
[-0.0125 .00981 0 11.1875 ]
[-0.0125 .15611 -25.625 -11.1875 ]
[-0.0125 .15611 0 11.1875 ]
[-0.0125 .3024 -58.0625 -11.1875 ]
[-0.0125 .3024 0 11.1875 ]
[-0.0125 .4487 -47.25 -11.1875 ]
[-0.0125 .4487 0 11.1875 ]
[-0.0125 .595 -58.0625 -11.1875 ]
[-0.0125 .595 0 11.1875 ]
[.5 .63053 -88.7188 0 ]
[.5 .63053 88.7188 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00981 m
.00625 .00981 L
s
gsave
-0.0125 .00981 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50.95) show
1.000 setlinewidth
grestore
0 .15611 m
.00625 .15611 L
s
gsave
-0.0125 .15611 -86.625 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51) show
1.000 setlinewidth
grestore
0 .3024 m
.00625 .3024 L
s
gsave
-0.0125 .3024 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.05) show
1.000 setlinewidth
grestore
0 .4487 m
.00625 .4487 L
s
gsave
-0.0125 .4487 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.1) show
1.000 setlinewidth
grestore
0 .595 m
.00625 .595 L
s
gsave
-0.0125 .595 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(51.15) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03907 m
.00375 .03907 L
s
0 .06833 m
.00375 .06833 L
s
0 .09759 m
.00375 .09759 L
s
0 .12685 m
.00375 .12685 L
s
0 .18536 m
.00375 .18536 L
s
0 .21462 m
.00375 .21462 L
s
0 .24388 m
.00375 .24388 L
s
0 .27314 m
.00375 .27314 L
s
0 .33166 m
.00375 .33166 L
s
0 .36092 m
.00375 .36092 L
s
0 .39018 m
.00375 .39018 L
s
0 .41944 m
.00375 .41944 L
s
0 .47796 m
.00375 .47796 L
s
0 .50722 m
.00375 .50722 L
s
0 .53648 m
.00375 .53648 L
s
0 .56574 m
.00375 .56574 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -149.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Checking) show
160.750 20.000 moveto
(Account) show
236.438 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .17067 m
.16667 .15941 L
.25 .61803 L
.33333 .55826 L
.41667 .39396 L
.5 .25172 L
.58333 .15606 L
.66667 .1001 L
.75 .07126 L
.83333 .05901 L
.91667 .05618 L
1 .05835 L
s
1 .05835 m
1 .05835 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00965678 0.64881 0.193595 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -45.0752 1.09715 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .0176 -47.25 -11.1875 ]
[-0.0125 .0176 0 11.1875 ]
[-0.0125 .12732 -47.25 -11.1875 ]
[-0.0125 .12732 0 11.1875 ]
[-0.0125 .23703 -47.25 -11.1875 ]
[-0.0125 .23703 0 11.1875 ]
[-0.0125 .34675 -47.25 -11.1875 ]
[-0.0125 .34675 0 11.1875 ]
[-0.0125 .45646 -47.25 -11.1875 ]
[-0.0125 .45646 0 11.1875 ]
[-0.0125 .56618 -47.25 -11.1875 ]
[-0.0125 .56618 0 11.1875 ]
[.5 .63053 -83.3125 0 ]
[.5 .63053 83.3125 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0176 m
.00625 .0176 L
s
gsave
-0.0125 .0176 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.1) show
1.000 setlinewidth
grestore
0 .12732 m
.00625 .12732 L
s
gsave
-0.0125 .12732 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.2) show
1.000 setlinewidth
grestore
0 .23703 m
.00625 .23703 L
s
gsave
-0.0125 .23703 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.3) show
1.000 setlinewidth
grestore
0 .34675 m
.00625 .34675 L
s
gsave
-0.0125 .34675 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.4) show
1.000 setlinewidth
grestore
0 .45646 m
.00625 .45646 L
s
gsave
-0.0125 .45646 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.5) show
1.000 setlinewidth
grestore
0 .56618 m
.00625 .56618 L
s
gsave
-0.0125 .56618 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(41.6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03955 m
.00375 .03955 L
s
0 .06149 m
.00375 .06149 L
s
0 .08343 m
.00375 .08343 L
s
0 .10537 m
.00375 .10537 L
s
0 .14926 m
.00375 .14926 L
s
0 .1712 m
.00375 .1712 L
s
0 .19315 m
.00375 .19315 L
s
0 .21509 m
.00375 .21509 L
s
0 .25898 m
.00375 .25898 L
s
0 .28092 m
.00375 .28092 L
s
0 .30286 m
.00375 .30286 L
s
0 .3248 m
.00375 .3248 L
s
0 .36869 m
.00375 .36869 L
s
0 .39063 m
.00375 .39063 L
s
0 .41258 m
.00375 .41258 L
s
0 .43452 m
.00375 .43452 L
s
0 .4784 m
.00375 .4784 L
s
0 .50035 m
.00375 .50035 L
s
0 .52229 m
.00375 .52229 L
s
0 .54423 m
.00375 .54423 L
s
0 .58812 m
.00375 .58812 L
s
0 .61006 m
.00375 .61006 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -144.313 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Savings) show
149.938 20.000 moveto
(Account) show
225.625 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .05618 m
.16667 .06041 L
.25 .39525 L
.33333 .55198 L
.41667 .61084 L
.5 .61803 L
.58333 .59937 L
.66667 .56888 L
.75 .53398 L
.83333 .4985 L
.91667 .46427 L
1 .43215 L
s
1 .43215 m
1 .43215 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00965678 0.97619 0.193595 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -6.93896 0.961467 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .07975 -36.4375 -11.1875 ]
[-0.0125 .07975 0 11.1875 ]
[-0.0125 .1759 -36.4375 -11.1875 ]
[-0.0125 .1759 0 11.1875 ]
[-0.0125 .27204 -36.4375 -11.1875 ]
[-0.0125 .27204 0 11.1875 ]
[-0.0125 .36819 -36.4375 -11.1875 ]
[-0.0125 .36819 0 11.1875 ]
[-0.0125 .46434 -36.4375 -11.1875 ]
[-0.0125 .46434 0 11.1875 ]
[-0.0125 .56048 -36.4375 -11.1875 ]
[-0.0125 .56048 0 11.1875 ]
[.5 .63053 -94.0313 0 ]
[.5 .63053 94.0313 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .07975 m
.00625 .07975 L
s
gsave
-0.0125 .07975 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.3) show
1.000 setlinewidth
grestore
0 .1759 m
.00625 .1759 L
s
gsave
-0.0125 .1759 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.4) show
1.000 setlinewidth
grestore
0 .27204 m
.00625 .27204 L
s
gsave
-0.0125 .27204 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.5) show
1.000 setlinewidth
grestore
0 .36819 m
.00625 .36819 L
s
gsave
-0.0125 .36819 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.6) show
1.000 setlinewidth
grestore
0 .46434 m
.00625 .46434 L
s
gsave
-0.0125 .46434 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.7) show
1.000 setlinewidth
grestore
0 .56048 m
.00625 .56048 L
s
gsave
-0.0125 .56048 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.8) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .09898 m
.00375 .09898 L
s
0 .11821 m
.00375 .11821 L
s
0 .13744 m
.00375 .13744 L
s
0 .15667 m
.00375 .15667 L
s
0 .19513 m
.00375 .19513 L
s
0 .21435 m
.00375 .21435 L
s
0 .23358 m
.00375 .23358 L
s
0 .25281 m
.00375 .25281 L
s
0 .29127 m
.00375 .29127 L
s
0 .3105 m
.00375 .3105 L
s
0 .32973 m
.00375 .32973 L
s
0 .34896 m
.00375 .34896 L
s
0 .38742 m
.00375 .38742 L
s
0 .40665 m
.00375 .40665 L
s
0 .42588 m
.00375 .42588 L
s
0 .44511 m
.00375 .44511 L
s
0 .48357 m
.00375 .48357 L
s
0 .50279 m
.00375 .50279 L
s
0 .52202 m
.00375 .52202 L
s
0 .54125 m
.00375 .54125 L
s
0 .06052 m
.00375 .06052 L
s
0 .04129 m
.00375 .04129 L
s
0 .02206 m
.00375 .02206 L
s
0 .00283 m
.00375 .00283 L
s
0 .57971 m
.00375 .57971 L
s
0 .59894 m
.00375 .59894 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -155.031 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Retained) show
160.563 20.000 moveto
(Earnings) show
247.063 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .61803 m
.16667 .61803 L
.25 .1739 L
.33333 .05618 L
.41667 .0586 L
.5 .09903 L
.58333 .14682 L
.66667 .19193 L
.75 .23199 L
.83333 .26711 L
.91667 .29803 L
1 .32547 L
s
1 .32547 m
1 .32547 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.211989 0.321429 0.395928 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -68.9755 2.98618 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .00529 -47.25 -11.1875 ]
[-0.0125 .00529 0 11.1875 ]
[-0.0125 .1546 -58.0625 -11.1875 ]
[-0.0125 .1546 0 11.1875 ]
[-0.0125 .30391 -47.25 -11.1875 ]
[-0.0125 .30391 0 11.1875 ]
[-0.0125 .45322 -58.0625 -11.1875 ]
[-0.0125 .45322 0 11.1875 ]
[-0.0125 .60253 -47.25 -11.1875 ]
[-0.0125 .60253 0 11.1875 ]
[.5 .63053 -34.4375 0 ]
[.5 .63053 34.4375 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00529 m
.00625 .00529 L
s
gsave
-0.0125 .00529 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.1) show
1.000 setlinewidth
grestore
0 .1546 m
.00625 .1546 L
s
gsave
-0.0125 .1546 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.15) show
1.000 setlinewidth
grestore
0 .30391 m
.00625 .30391 L
s
gsave
-0.0125 .30391 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.2) show
1.000 setlinewidth
grestore
0 .45322 m
.00625 .45322 L
s
gsave
-0.0125 .45322 -119.063 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.25) show
1.000 setlinewidth
grestore
0 .60253 m
.00625 .60253 L
s
gsave
-0.0125 .60253 -108.25 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23.3) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03516 m
.00375 .03516 L
s
0 .06502 m
.00375 .06502 L
s
0 .09488 m
.00375 .09488 L
s
0 .12474 m
.00375 .12474 L
s
0 .18447 m
.00375 .18447 L
s
0 .21433 m
.00375 .21433 L
s
0 .24419 m
.00375 .24419 L
s
0 .27405 m
.00375 .27405 L
s
0 .33377 m
.00375 .33377 L
s
0 .36364 m
.00375 .36364 L
s
0 .3935 m
.00375 .3935 L
s
0 .42336 m
.00375 .42336 L
s
0 .48308 m
.00375 .48308 L
s
0 .51295 m
.00375 .51295 L
s
0 .54281 m
.00375 .54281 L
s
0 .57267 m
.00375 .57267 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -95.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Output) show
127.875 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .54085 m
.16667 .05618 L
.25 .07287 L
.33333 .23464 L
.41667 .38591 L
.5 .49219 L
.58333 .55719 L
.66667 .59296 L
.75 .61039 L
.83333 .61714 L
.91667 .61803 L
1 .61592 L
s
1 .61592 m
1 .61592 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.211989 0.64881 0.395928 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.693773 0.402227 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .03024 -36.4375 -11.1875 ]
[-0.0125 .03024 0 11.1875 ]
[-0.0125 .11068 -14.8125 -11.1875 ]
[-0.0125 .11068 0 11.1875 ]
[-0.0125 .19113 -36.4375 -11.1875 ]
[-0.0125 .19113 0 11.1875 ]
[-0.0125 .27157 -36.4375 -11.1875 ]
[-0.0125 .27157 0 11.1875 ]
[-0.0125 .35202 -36.4375 -11.1875 ]
[-0.0125 .35202 0 11.1875 ]
[-0.0125 .43246 -36.4375 -11.1875 ]
[-0.0125 .43246 0 11.1875 ]
[-0.0125 .51291 -14.8125 -11.1875 ]
[-0.0125 .51291 0 11.1875 ]
[-0.0125 .59335 -36.4375 -11.1875 ]
[-0.0125 .59335 0 11.1875 ]
[.5 .63053 -72.2813 0 ]
[.5 .63053 72.2813 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .03024 m
.00625 .03024 L
s
gsave
-0.0125 .03024 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
1.000 setlinewidth
grestore
0 .11068 m
.00625 .11068 L
s
gsave
-0.0125 .11068 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .19113 m
.00625 .19113 L
s
gsave
-0.0125 .19113 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
1.000 setlinewidth
grestore
0 .27157 m
.00625 .27157 L
s
gsave
-0.0125 .27157 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
1.000 setlinewidth
grestore
0 .35202 m
.00625 .35202 L
s
gsave
-0.0125 .35202 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
1.000 setlinewidth
grestore
0 .43246 m
.00625 .43246 L
s
gsave
-0.0125 .43246 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
1.000 setlinewidth
grestore
0 .51291 m
.00625 .51291 L
s
gsave
-0.0125 .51291 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
0 .59335 m
.00625 .59335 L
s
gsave
-0.0125 .59335 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05035 m
.00375 .05035 L
s
0 .07046 m
.00375 .07046 L
s
0 .09057 m
.00375 .09057 L
s
0 .13079 m
.00375 .13079 L
s
0 .1509 m
.00375 .1509 L
s
0 .17101 m
.00375 .17101 L
s
0 .21124 m
.00375 .21124 L
s
0 .23135 m
.00375 .23135 L
s
0 .25146 m
.00375 .25146 L
s
0 .29168 m
.00375 .29168 L
s
0 .31179 m
.00375 .31179 L
s
0 .33191 m
.00375 .33191 L
s
0 .37213 m
.00375 .37213 L
s
0 .39224 m
.00375 .39224 L
s
0 .41235 m
.00375 .41235 L
s
0 .45257 m
.00375 .45257 L
s
0 .47269 m
.00375 .47269 L
s
0 .4928 m
.00375 .4928 L
s
0 .53302 m
.00375 .53302 L
s
0 .55313 m
.00375 .55313 L
s
0 .57324 m
.00375 .57324 L
s
0 .01012 m
.00375 .01012 L
s
0 .61346 m
.00375 .61346 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -133.281 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Interest) show
160.313 20.000 moveto
(Rate) show
203.563 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .11877 m
.16667 .61086 L
.25 .61803 L
.33333 .45911 L
.41667 .30493 L
.5 .19467 L
.58333 .12605 L
.66667 .08728 L
.75 .06743 L
.83333 .05871 L
.91667 .05618 L
1 .05691 L
s
1 .05691 m
1 .05691 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.211989 0.97619 0.395928 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.77556e-017 0.0833333 -0.130603 0.440002 [
[.16667 -0.0125 -7.40625 -22.375 ]
[.16667 -0.0125 7.40625 0 ]
[.33333 -0.0125 -7.40625 -22.375 ]
[.33333 -0.0125 7.40625 0 ]
[.5 -0.0125 -7.40625 -22.375 ]
[.5 -0.0125 7.40625 0 ]
[.66667 -0.0125 -7.40625 -22.375 ]
[.66667 -0.0125 7.40625 0 ]
[.83333 -0.0125 -12.8125 -22.375 ]
[.83333 -0.0125 12.8125 0 ]
[1 -0.0125 -12.8125 -22.375 ]
[1 -0.0125 12.8125 0 ]
[-0.0125 .0454 -36.4375 -11.1875 ]
[-0.0125 .0454 0 11.1875 ]
[-0.0125 .1334 -36.4375 -11.1875 ]
[-0.0125 .1334 0 11.1875 ]
[-0.0125 .2214 -36.4375 -11.1875 ]
[-0.0125 .2214 0 11.1875 ]
[-0.0125 .3094 -14.8125 -11.1875 ]
[-0.0125 .3094 0 11.1875 ]
[-0.0125 .3974 -36.4375 -11.1875 ]
[-0.0125 .3974 0 11.1875 ]
[-0.0125 .4854 -36.4375 -11.1875 ]
[-0.0125 .4854 0 11.1875 ]
[-0.0125 .5734 -36.4375 -11.1875 ]
[-0.0125 .5734 0 11.1875 ]
[.5 .63053 -77.6875 0 ]
[.5 .63053 77.6875 22.375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
gsave
.16667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.33333 0 m
.33333 .00625 L
s
gsave
.33333 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.66667 0 m
.66667 .00625 L
s
gsave
.66667 -0.0125 -68.4063 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.83333 0 m
.83333 .00625 L
s
gsave
.83333 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -73.8125 -26.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.125 Mabswid
.04167 0 m
.04167 .00375 L
s
.08333 0 m
.08333 .00375 L
s
.125 0 m
.125 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.29167 0 m
.29167 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.70833 0 m
.70833 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.875 0 m
.875 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0454 m
.00625 .0454 L
s
gsave
-0.0125 .0454 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
0 .1334 m
.00625 .1334 L
s
gsave
-0.0125 .1334 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
0 .2214 m
.00625 .2214 L
s
gsave
-0.0125 .2214 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
0 .3094 m
.00625 .3094 L
s
gsave
-0.0125 .3094 -75.8125 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
0 .3974 m
.00625 .3974 L
s
gsave
-0.0125 .3974 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
0 .4854 m
.00625 .4854 L
s
gsave
-0.0125 .4854 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
0 .5734 m
.00625 .5734 L
s
gsave
-0.0125 .5734 -97.4375 -15.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .0674 m
.00375 .0674 L
s
0 .0894 m
.00375 .0894 L
s
0 .1114 m
.00375 .1114 L
s
0 .1554 m
.00375 .1554 L
s
0 .1774 m
.00375 .1774 L
s
0 .1994 m
.00375 .1994 L
s
0 .2434 m
.00375 .2434 L
s
0 .2654 m
.00375 .2654 L
s
0 .2874 m
.00375 .2874 L
s
0 .3314 m
.00375 .3314 L
s
0 .3534 m
.00375 .3534 L
s
0 .3754 m
.00375 .3754 L
s
0 .4194 m
.00375 .4194 L
s
0 .4414 m
.00375 .4414 L
s
0 .4634 m
.00375 .4634 L
s
0 .5074 m
.00375 .5074 L
s
0 .5294 m
.00375 .5294 L
s
0 .5514 m
.00375 .5514 L
s
0 .0234 m
.00375 .0234 L
s
0 .0014 m
.00375 .0014 L
s
0 .5954 m
.00375 .5954 L
s
0 .6174 m
.00375 .6174 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -138.688 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 30.375 translate 1 -1 scale
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Inflation) show
171.125 20.000 moveto
(Rate) show
214.375 20.000 moveto
%%IncludeResource: font Courier-Bold
%%IncludeFont: Courier-Bold
/Courier-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.08333 .3094 m
.16667 .61803 L
.25 .17046 L
.33333 .05618 L
.41667 .098 L
.5 .16626 L
.58333 .22294 L
.66667 .26165 L
.75 .28555 L
.83333 .29938 L
.91667 .30695 L
1 .31088 L
s
1 .31088 m
1 .31088 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 116.75},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{0, 287}, {115.75, 0}} -> {-0.0838802, -0.0304253, \
0.0110375, 0.0110375}, {{7.5625, 92.5}, {112.938, 60.5}} -> {-44.2196, \
50.2224, 1.00376, 0.0285881}, {{101, 185.938}, {112.938, 60.5}} -> {-138.009, \
39.1522, 1.00376, 0.0762403}, {{194.438, 279.375}, {112.938, 60.5}} -> \
{-231.798, 5.01275, 1.00376, 0.0869994}, {{7.5625, 92.5}, {55.25, 2.75}} -> \
{-58.6509, 20.7913, 0.99567, 0.0277855}, {{101, 185.938}, {55.25, 2.75}} -> \
{-136.847, -15.4019, 0.99567, 0.206283}, {{194.438, 279.375}, {55.25, 2.75}} -> \
{-229.88, -15.3596, 0.99567, 0.188573}}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", "\"\<c:/temp\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Export", "[", 
   RowBox[{"\"\<imp_rho.eps\>\"", ",", "plot", ",", "\"\<EPS\>\"", ",", 
    RowBox[{"ImageSize", "\[Rule]", "1000"}]}], "]"}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing the Autocorrelation Function", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"nsim", "=", "200000"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ndist", "=", 
    RowBox[{"NormalDistribution", "[", 
     RowBox[{"0", ",", "1"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ssim", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"nsim", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dsim", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"nsim", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xsim", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"nsim", "+", "1"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"csim", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", 
       RowBox[{"nsim", "+", "1"}]}], "}"}]}], "]"}]}], ";"}]}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ssim", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "=", 
   RowBox[{"sbar", "/.", "ssresult"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dsim", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "=", 
   RowBox[{"dbar", "/.", "ssresult"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"xsim", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "=", "xmean"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"j", "=", "1"}], ",", 
   RowBox[{"j", "<", 
    RowBox[{"nsim", "+", "1"}]}], ",", 
   RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"simrule", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "\[Rule]", 
        RowBox[{"ssim", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], ",", 
       RowBox[{"d", "\[Rule]", 
        RowBox[{"dsim", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], ",", 
       RowBox[{"x", "\[Rule]", 
        RowBox[{"xsim", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], ",", 
       RowBox[{"\[Sigma]", "\[Rule]", "0.006"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"csim", "[", 
      RowBox[{"[", "j", "]"}], "]"}], "=", 
     RowBox[{"First", "@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{"csimfun", "/.", "simrule"}], "}"}], "]"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ssim", "[", 
      RowBox[{"[", 
       RowBox[{"j", "+", "1"}], "]"}], "]"}], "=", 
     RowBox[{"First", "@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{"ssimfun", "/.", "simrule"}], "}"}], "]"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"dsim", "[", 
      RowBox[{"[", 
       RowBox[{"j", "+", "1"}], "]"}], "]"}], "=", 
     RowBox[{"First", "@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{"dsimfun", "/.", "simrule"}], "}"}], "]"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"xsim", "[", 
      RowBox[{"[", 
       RowBox[{"j", "+", "1"}], "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"xconst", "+", 
        RowBox[{"\[Rho]", " ", 
         RowBox[{"xsim", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], "+", 
        RowBox[{"\[Sigma]", " ", 
         RowBox[{"Random", "[", "ndist", "]"}]}]}], "/.", "param"}], "/.", 
      RowBox[{"{", 
       RowBox[{"\[Sigma]", "\[Rule]", "0.006"}], "}"}]}]}], ";"}]}], 
  "\[IndentingNewLine]", "]"}]}], "Input"],

Cell[BoxData["$Aborted"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"autocorrtab", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Correlation", "[", 
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"csim", ",", 
        RowBox[{"-", "j"}]}], "]"}], ",", 
      RowBox[{"Drop", "[", 
       RowBox[{"csim", ",", "j"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "6"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.9996334132582514`", ",", "0.9991710661089399`", ",", 
   "0.9988085872011544`", ",", "0.998565757059153`", ",", 
   "0.9984130922019768`", ",", "0.9983190332418252`"}], "}"}]], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.7300063091703781`", ",", "0.4316263429561644`", ",", 
   "0.2060942200024817`", ",", "0.06111905619908988`", ",", 
   RowBox[{"-", "0.024576504184102448`"}], ",", 
   RowBox[{"-", "0.07364481028864767`"}]}], "}"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.6992029646397385`", ",", "0.4053380581844517`", ",", 
   "0.1846241328319693`", ",", "0.0467700521196967`", ",", 
   RowBox[{"-", "0.030032837826352618`"}], ",", 
   RowBox[{"-", "0.0683691996733585`"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.6992029646397385`", ",", "0.4053380581844517`", ",", 
   "0.1846241328319693`", ",", "0.0467700521196967`", ",", 
   RowBox[{"-", "0.030032837826352618`"}], ",", 
   RowBox[{"-", "0.0683691996733585`"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.37844253093892544`", ",", "0.1275873301542992`", ",", 
   "0.01698491414570136`", ",", 
   RowBox[{"-", "0.019951226016482592`"}], ",", 
   RowBox[{"-", "0.03319637243408034`"}], ",", 
   RowBox[{"-", "0.03933112448369378`"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.37844253093892544`", ",", "0.1275873301542992`", ",", 
   "0.01698491414570136`", ",", 
   RowBox[{"-", "0.019951226016482592`"}], ",", 
   RowBox[{"-", "0.03319637243408034`"}], ",", 
   RowBox[{"-", "0.03933112448369378`"}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.3251590669401791`", ",", "0.10106579608470753`", ",", 
   "0.011694968925424272`", ",", 
   RowBox[{"-", "0.01750034923959082`"}], ",", 
   RowBox[{"-", "0.05321379934725634`"}], ",", 
   RowBox[{"-", "0.05025966381618768`"}]}], "}"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.3251590669401791`", ",", "0.10106579608470753`", ",", 
   "0.011694968925424272`", ",", 
   RowBox[{"-", "0.01750034923959082`"}], ",", 
   RowBox[{"-", "0.05321379934725634`"}], ",", 
   RowBox[{"-", "0.05025966381618768`"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{889, 650},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (April 11, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 34, 0, 101, "Title"],
Cell[617, 24, 57, 0, 56, "Subtitle"],
Cell[677, 26, 461, 9, 125, "Text"],
Cell[1141, 37, 416, 8, 112, "Input"],
Cell[CellGroupData[{
Cell[1582, 49, 33, 0, 70, "Section"],
Cell[1618, 51, 981, 29, 112, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2636, 85, 38, 0, 70, "Section"],
Cell[2677, 87, 1954, 67, 128, "Input"],
Cell[4634, 156, 118, 3, 30, "Text"],
Cell[4755, 161, 2954, 100, 292, "Input"],
Cell[7712, 263, 75, 0, 70, "Text"],
Cell[7790, 265, 1280, 44, 70, "Input"],
Cell[9073, 311, 222, 4, 70, "Text"],
Cell[9298, 317, 1113, 35, 70, "Input"],
Cell[10414, 354, 162, 3, 70, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10613, 362, 51, 0, 70, "Section"],
Cell[CellGroupData[{
Cell[10689, 366, 1383, 42, 70, "Input"],
Cell[12075, 410, 1584, 40, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13696, 455, 115, 3, 70, "Input"],
Cell[13814, 460, 238, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14089, 470, 413, 12, 70, "Input"],
Cell[14505, 484, 261, 6, 70, "Output"]
}, Open  ]],
Cell[14781, 493, 143, 3, 70, "Text"],
Cell[CellGroupData[{
Cell[14949, 500, 319, 10, 70, "Input"],
Cell[15271, 512, 334, 11, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15642, 528, 328, 10, 70, "Input"],
Cell[15973, 540, 928, 24, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[16950, 570, 39, 0, 70, "Section"],
Cell[CellGroupData[{
Cell[17014, 574, 771, 21, 70, "Input"],
Cell[17788, 597, 88, 2, 70, "Output"]
}, Open  ]],
Cell[17891, 602, 278, 5, 70, "Text"],
Cell[18172, 609, 940, 30, 70, "Input"],
Cell[19115, 641, 152, 3, 70, "Text"],
Cell[19270, 646, 199, 7, 70, "Input"],
Cell[19472, 655, 271, 5, 70, "Text"],
Cell[CellGroupData[{
Cell[19768, 664, 663, 20, 70, "Input"],
Cell[20434, 686, 3620, 119, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24091, 810, 36, 0, 70, "Input"],
Cell[24130, 812, 11692, 363, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35859, 1180, 117, 3, 70, "Input"],
Cell[35979, 1185, 3659, 120, 70, "Output"]
}, Open  ]],
Cell[39653, 1308, 1072, 31, 70, "Input"],
Cell[CellGroupData[{
Cell[40750, 1343, 34, 0, 70, "Input"],
Cell[40787, 1345, 12580, 414, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[53416, 1765, 39, 0, 70, "Section"],
Cell[53458, 1767, 174, 3, 70, "Text"],
Cell[53635, 1772, 561, 18, 70, "Input"],
Cell[54199, 1792, 95, 2, 70, "Text"],
Cell[54297, 1796, 3731, 110, 70, "Input"],
Cell[58031, 1908, 2278, 64, 70, "Input"],
Cell[60312, 1974, 47, 0, 70, "Text"],
Cell[CellGroupData[{
Cell[60384, 1978, 868, 26, 70, "Input"],
Cell[61255, 2006, 451, 8, 70, "Output"],
Cell[61709, 2016, 408, 8, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[62154, 2029, 12955, 378, 70, "Input"],
Cell[CellGroupData[{
Cell[75134, 2411, 9769, 448, 70, 7430, 407, "GraphicsData", "PostScript", \
"Graphics"],
Cell[84906, 2861, 11511, 531, 70, 8986, 487, "GraphicsData", "PostScript", \
"Graphics"],
Cell[96420, 3394, 10796, 506, 70, 8444, 465, "GraphicsData", "PostScript", \
"Graphics"],
Cell[107219, 3902, 10110, 455, 70, 7458, 409, "GraphicsData", "PostScript", \
"Graphics"],
Cell[117332, 4359, 10343, 486, 70, 8065, 446, "GraphicsData", "PostScript", \
"Graphics"],
Cell[127678, 4847, 10477, 498, 70, 8199, 458, "GraphicsData", "PostScript", \
"Graphics"],
Cell[138158, 5347, 51484, 2703, 70, 48185, 2648, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[189669, 8054, 297, 7, 70, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[190003, 8066, 57, 0, 70, "Section"],
Cell[190063, 8068, 1085, 37, 70, "Input"],
Cell[CellGroupData[{
Cell[191173, 8109, 2559, 78, 70, "Input"],
Cell[193735, 8189, 35, 0, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[193807, 8194, 388, 12, 70, "Input"],
Cell[194198, 8208, 231, 5, 70, "Output"]
}, Open  ]],
Cell[194444, 8216, 269, 6, 70, "Input"],
Cell[CellGroupData[{
Cell[194738, 8226, 267, 6, 70, "Input"],
Cell[195008, 8234, 268, 6, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[195313, 8245, 290, 7, 70, "Input"],
Cell[195606, 8254, 291, 7, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[195934, 8266, 290, 7, 70, "Input"],
Cell[196227, 8275, 291, 7, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

